backup_dr library

Backup and DR Service — vaults, plans, associations, management server, service config, and restore workloads.

Classes

BackupDrBackupPlanBackupRules
Typed helper for the backup_rules block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupPlanBackupRulesStandardSchedule
Typed helper for the backup_rules.standard_schedule block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupPlanBackupRulesStandardScheduleBackupWindow
Typed helper for the backup_rules.standard_schedule.backup_window block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupPlanBackupRulesStandardScheduleWeekDayOfMonth
Typed helper for the backup_rules.standard_schedule.week_day_of_month block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupPlanComputeInstanceBackupPlanProperties
Typed helper for the compute_instance_backup_plan_properties block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupPlanDiskBackupPlanProperties
Typed helper for the disk_backup_plan_properties block of google_backup_dr_backup_plan (derived from provider schema).
BackupDrBackupVaultEncryptionConfig
Typed helper for the encryption_config block of google_backup_dr_backup_vault (derived from provider schema).
BackupDrManagementServerNetworks
Typed helper for the networks block of google_backup_dr_management_server (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestoreProperties
Typed helper for the compute_instance_restore_properties block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesAdvancedMachineFeatures
Typed helper for the compute_instance_restore_properties.advanced_machine_features block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesAllocationAffinity
Typed helper for the compute_instance_restore_properties.allocation_affinity block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesConfidentialInstanceConfig
Typed helper for the compute_instance_restore_properties.confidential_instance_config block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisks
Typed helper for the compute_instance_restore_properties.disks block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksDiskEncryptionKey
Typed helper for the compute_instance_restore_properties.disks.disk_encryption_key block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksGuestOsFeature
Typed helper for the compute_instance_restore_properties.disks.guest_os_feature block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksInitializeParams
Typed helper for the compute_instance_restore_properties.disks.initialize_params block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisplayDevice
Typed helper for the compute_instance_restore_properties.display_device block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesGuestAccelerators
Typed helper for the compute_instance_restore_properties.guest_accelerators block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesInstanceEncryptionKey
Typed helper for the compute_instance_restore_properties.instance_encryption_key block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesLabels
Typed helper for the compute_instance_restore_properties.labels block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesMetadata
Typed helper for the compute_instance_restore_properties.metadata block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesMetadataItems
Typed helper for the compute_instance_restore_properties.metadata.items block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfaces
Typed helper for the compute_instance_restore_properties.network_interfaces block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesAccessConfigs
Typed helper for the compute_instance_restore_properties.network_interfaces.access_configs block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesAliasIpRanges
Typed helper for the compute_instance_restore_properties.network_interfaces.alias_ip_ranges block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesIpv6AccessConfigs
Typed helper for the compute_instance_restore_properties.network_interfaces.ipv6_access_configs block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkPerformanceConfig
Typed helper for the compute_instance_restore_properties.network_performance_config block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesParams
Typed helper for the compute_instance_restore_properties.params block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesParamsResourceManagerTags
Typed helper for the compute_instance_restore_properties.params.resource_manager_tags block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesScheduling
Typed helper for the compute_instance_restore_properties.scheduling block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingLocalSsdRecoveryTimeout
Typed helper for the compute_instance_restore_properties.scheduling.local_ssd_recovery_timeout block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingMaxRunDuration
Typed helper for the compute_instance_restore_properties.scheduling.max_run_duration block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingNodeAffinities
Typed helper for the compute_instance_restore_properties.scheduling.node_affinities block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesServiceAccounts
Typed helper for the compute_instance_restore_properties.service_accounts block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesShieldedInstanceConfig
Typed helper for the compute_instance_restore_properties.shielded_instance_config block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesTags
Typed helper for the compute_instance_restore_properties.tags block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadComputeInstanceTargetEnvironment
Typed helper for the compute_instance_target_environment block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskRestoreProperties
Typed helper for the disk_restore_properties block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskRestorePropertiesDiskEncryptionKey
Typed helper for the disk_restore_properties.disk_encryption_key block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskRestorePropertiesGuestOsFeature
Typed helper for the disk_restore_properties.guest_os_feature block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskRestorePropertiesLabels
Typed helper for the disk_restore_properties.labels block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskRestorePropertiesResourceManagerTags
Typed helper for the disk_restore_properties.resource_manager_tags block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadDiskTargetEnvironment
Typed helper for the disk_target_environment block of google_backup_dr_restore_workload (derived from provider schema).
BackupDrRestoreWorkloadRegionDiskTargetEnvironment
Typed helper for the region_disk_target_environment block of google_backup_dr_restore_workload (derived from provider schema).
GoogleBackupDrBackupPlan
Factory wrapper for google_backup_dr_backup_plan.
GoogleBackupDrBackupPlanAssociation
Factory wrapper for google_backup_dr_backup_plan_association.
GoogleBackupDrBackupVault
Factory wrapper for google_backup_dr_backup_vault.
GoogleBackupDrManagementServer
Factory wrapper for google_backup_dr_management_server.
GoogleBackupDrRestoreWorkload
Factory wrapper for google_backup_dr_restore_workload.
GoogleBackupDrServiceConfig
Factory wrapper for google_backup_dr_service_config.

Enums

BackupDrBackupPlanBackupRulesStandardScheduleDaysOfWeek
days_of_week — derived from the provider schema description.
BackupDrBackupPlanBackupRulesStandardScheduleMonths
months — derived from the provider schema description.
BackupDrBackupPlanBackupRulesStandardScheduleRecurrenceType
recurrence_type — derived from the provider schema description.
BackupDrBackupPlanBackupRulesStandardScheduleWeekDayOfMonthDayOfWeek
day_of_week — derived from the provider schema description.
BackupDrBackupPlanBackupRulesStandardScheduleWeekDayOfMonthWeekOfMonth
week_of_month — derived from the provider schema description.
BackupDrBackupVaultAccessRestriction
Backup Dr Backup Vault Access enum for access_restriction.
BackupDrBackupVaultBackupRetentionInheritance
Backup Dr Backup Vault Backup Retention enum for backup_retention_inheritance.
BackupDrManagementServerType
Backup Dr Management Server enum for type.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesAllocationAffinityConsumeAllocationType
consume_allocation_type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksDiskInterface
disk_interface — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksGuestOsFeatureType
type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksMode
mode — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksSavedState
saved_state — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksType
type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesKeyRevocationActionType
key_revocation_action_type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesAccessConfigsNetworkTier
network_tier — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesAccessConfigsType
type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesIpv6AccessConfigsNetworkTier
network_tier — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesIpv6AccessConfigsType
type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesIpv6AccessType
ipv6_access_type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesNicType
nic_type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkInterfacesStackType
stack_type — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesNetworkPerformanceConfigTotalEgressBandwidthTier
total_egress_bandwidth_tier — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesPrivateIpv6GoogleAccess
private_ipv6_google_access — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingInstanceTerminationAction
instance_termination_action — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingNodeAffinitiesOperator
operator — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingOnHostMaintenance
on_host_maintenance — derived from the provider schema description.
BackupDrRestoreWorkloadComputeInstanceRestorePropertiesSchedulingProvisioningModel
provisioning_model — derived from the provider schema description.
BackupDrRestoreWorkloadDiskRestorePropertiesAccessMode
access_mode — derived from the provider schema description.
BackupDrRestoreWorkloadDiskRestorePropertiesArchitecture
architecture — derived from the provider schema description.
BackupDrRestoreWorkloadDiskRestorePropertiesGuestOsFeatureType
type — derived from the provider schema description.