BigtableAppProfileDataBoostIsolation class final

Read-only Data Boost isolation.

Inheritance

Constructors

BigtableAppProfileDataBoostIsolation({required TfArg<BigtableAppProfileComputeBillingOwner> computeBillingOwner})
const

Properties

blockKey String
no setteroverride
computeBillingOwner → TfArg<BigtableAppProfileComputeBillingOwner>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited