CatalogKind enum
Whether a catalog entry is a managed resource or a read-only data source.
Values
- resource → const CatalogKind
-
A managed Terraform resource (
resource.<type>.<name>), emitted as afinal class … extends Resourcewrapper. - dataSource → const CatalogKind
-
A read-only Terraform data source (
data.<type>.<name>), emitted as afinal class … extends Datawrapper.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CatalogKind> - A constant List of the values in this enum, in order of their declaration.