cloud_quotas library

Cloud Quotas — project-singleton adjuster settings and quota preferences. Both are never_apply (MM exclude_delete); debt-only.

Classes

CloudQuotasQuotaPreferenceQuotaConfig
Typed helper for the quota_config block of google_cloud_quotas_quota_preference (derived from provider schema).
GoogleCloudQuotasQuotaAdjusterSettings
Factory wrapper for google_cloud_quotas_quota_adjuster_settings.
GoogleCloudQuotasQuotaPreference
Factory wrapper for google_cloud_quotas_quota_preference.

Enums

CloudQuotasQuotaAdjusterSettingsEffectiveEnablement
Cloud Quotas Quota Adjuster Settings Effective enum for effective_enablement.
CloudQuotasQuotaAdjusterSettingsEnablement
Cloud Quotas Quota Adjuster Settings enum for enablement.
CloudQuotasQuotaPreferenceIgnoreSafetyChecks
Quota safety checks that may be skipped on create/update.