network library

Network Connectivity Center (hub / group / spoke / internal range / regional endpoint / policy-based route; gateway advertised route and service connection policy are debt-only), transports / multicloud data-transfer (Partner Cross-Cloud Interconnect managed transport is never_apply — $17+/h), Network Security ULL mirroring, OOB intercept / mirroring deployments + endpoints (Deployment Uptime $0.025/h is never_apply), address groups, URL lists, client/server TLS policies, gateway security policies, Cloud NGFW firewall endpoints (Enterprise Endpoint Uptime is never_apply — $1.75/h), VPC Flow Logs configs, Network Services Mesh, Service Extensions (Authz / LB traffic / route / edge — debt-only: schema required forwarding_rules bill Cloud LB Forwarding Rule Minimum $0.025/h), Wasm plugin metadata (apply-excluded — needs an uploaded plugin image), and Network Services gateways (Secure Web Gateway is never_apply — $1.25/h).

Classes

GoogleNetworkConnectivityDestination
Factory wrapper for google_network_connectivity_destination.
GoogleNetworkConnectivityGatewayAdvertisedRoute
Factory wrapper for google_network_connectivity_gateway_advertised_route.
GoogleNetworkConnectivityGroup
Factory wrapper for google_network_connectivity_group.
GoogleNetworkConnectivityHub
Factory wrapper for google_network_connectivity_hub.
GoogleNetworkConnectivityHubIamBinding
Factory wrapper for google_network_connectivity_hub_iam_binding.
GoogleNetworkConnectivityHubIamMember
Factory wrapper for google_network_connectivity_hub_iam_member.
GoogleNetworkConnectivityHubIamPolicy
Factory wrapper for google_network_connectivity_hub_iam_policy.
GoogleNetworkConnectivityInternalRange
Factory wrapper for google_network_connectivity_internal_range.
GoogleNetworkConnectivityMulticloudDataTransferConfig
Factory wrapper for google_network_connectivity_multicloud_data_transfer_config.
GoogleNetworkConnectivityPolicyBasedRoute
Factory wrapper for google_network_connectivity_policy_based_route.
GoogleNetworkConnectivityRegionalEndpoint
Factory wrapper for google_network_connectivity_regional_endpoint.
GoogleNetworkConnectivityServiceConnectionPolicy
Factory wrapper for google_network_connectivity_service_connection_policy.
GoogleNetworkConnectivitySpoke
Factory wrapper for google_network_connectivity_spoke.
GoogleNetworkConnectivityTransport
Factory wrapper for google_network_connectivity_transport.
GoogleNetworkManagementConnectivityTest
Factory wrapper for google_network_management_connectivity_test.
GoogleNetworkManagementOrganizationVpcFlowLogsConfig
Factory wrapper for google_network_management_organization_vpc_flow_logs_config.
GoogleNetworkManagementVpcFlowLogsConfig
Factory wrapper for google_network_management_vpc_flow_logs_config.
GoogleNetworkSecurityAddressGroup
Factory wrapper for google_network_security_address_group.
GoogleNetworkSecurityAddressGroupIamBinding
Factory wrapper for google_network_security_address_group_iam_binding.
GoogleNetworkSecurityAddressGroupIamMember
Factory wrapper for google_network_security_address_group_iam_member.
GoogleNetworkSecurityAddressGroupIamPolicy
Factory wrapper for google_network_security_address_group_iam_policy.
GoogleNetworkSecurityAuthzPolicy
Factory wrapper for google_network_security_authz_policy.
GoogleNetworkSecurityBackendAuthenticationConfig
Factory wrapper for google_network_security_backend_authentication_config.
GoogleNetworkSecurityClientTlsPolicy
Factory wrapper for google_network_security_client_tls_policy.
GoogleNetworkSecurityDnsThreatDetector
Factory wrapper for google_network_security_dns_threat_detector.
GoogleNetworkSecurityFirewallEndpoint
Factory wrapper for google_network_security_firewall_endpoint.
GoogleNetworkSecurityFirewallEndpointAssociation
Factory wrapper for google_network_security_firewall_endpoint_association.
GoogleNetworkSecurityGatewaySecurityPolicy
Factory wrapper for google_network_security_gateway_security_policy.
GoogleNetworkSecurityGatewaySecurityPolicyRule
Factory wrapper for google_network_security_gateway_security_policy_rule.
GoogleNetworkSecurityInterceptDeployment
Factory wrapper for google_network_security_intercept_deployment.
GoogleNetworkSecurityInterceptDeploymentGroup
Factory wrapper for google_network_security_intercept_deployment_group.
GoogleNetworkSecurityInterceptEndpointGroup
Factory wrapper for google_network_security_intercept_endpoint_group.
GoogleNetworkSecurityInterceptEndpointGroupAssociation
Factory wrapper for google_network_security_intercept_endpoint_group_association.
GoogleNetworkSecurityMirroringDeployment
Factory wrapper for google_network_security_mirroring_deployment.
GoogleNetworkSecurityMirroringDeploymentGroup
Factory wrapper for google_network_security_mirroring_deployment_group.
GoogleNetworkSecurityMirroringEndpoint
Factory wrapper for google_network_security_mirroring_endpoint.
GoogleNetworkSecurityMirroringEndpointGroup
Factory wrapper for google_network_security_mirroring_endpoint_group.
GoogleNetworkSecurityMirroringEndpointGroupAssociation
Factory wrapper for google_network_security_mirroring_endpoint_group_association.
GoogleNetworkSecuritySecurityProfile
Factory wrapper for google_network_security_security_profile.
GoogleNetworkSecuritySecurityProfileGroup
Factory wrapper for google_network_security_security_profile_group.
GoogleNetworkSecurityServerTlsPolicy
Factory wrapper for google_network_security_server_tls_policy.
GoogleNetworkSecurityTlsInspectionPolicy
Factory wrapper for google_network_security_tls_inspection_policy.
GoogleNetworkSecurityUllMirroringCollector
Factory wrapper for google_network_security_ull_mirroring_collector.
GoogleNetworkSecurityUllMirroringCollectorRule
Factory wrapper for google_network_security_ull_mirroring_collector_rule.
GoogleNetworkSecurityUllMirroringEngine
Factory wrapper for google_network_security_ull_mirroring_engine.
GoogleNetworkSecurityUrlLists
Factory wrapper for google_network_security_url_lists.
GoogleNetworkServicesAgentGateway
Factory wrapper for google_network_services_agent_gateway.
GoogleNetworkServicesAuthzExtension
Factory wrapper for google_network_services_authz_extension.
GoogleNetworkServicesEdgeCacheKeyset
Factory wrapper for google_network_services_edge_cache_keyset.
GoogleNetworkServicesEdgeCacheOrigin
Factory wrapper for google_network_services_edge_cache_origin.
GoogleNetworkServicesEdgeCacheService
Factory wrapper for google_network_services_edge_cache_service.
GoogleNetworkServicesEndpointPolicy
Factory wrapper for google_network_services_endpoint_policy.
GoogleNetworkServicesGateway
Factory wrapper for google_network_services_gateway.
GoogleNetworkServicesGrpcRoute
Factory wrapper for google_network_services_grpc_route.
GoogleNetworkServicesHttpRoute
Factory wrapper for google_network_services_http_route.
GoogleNetworkServicesLbEdgeExtension
Factory wrapper for google_network_services_lb_edge_extension.
GoogleNetworkServicesLbRouteExtension
Factory wrapper for google_network_services_lb_route_extension.
GoogleNetworkServicesLbTrafficExtension
Factory wrapper for google_network_services_lb_traffic_extension.
GoogleNetworkServicesMesh
Factory wrapper for google_network_services_mesh.
GoogleNetworkServicesMulticastConsumerAssociation
Factory wrapper for google_network_services_multicast_consumer_association.
GoogleNetworkServicesMulticastDomain
Factory wrapper for google_network_services_multicast_domain.
GoogleNetworkServicesMulticastDomainActivation
Factory wrapper for google_network_services_multicast_domain_activation.
GoogleNetworkServicesMulticastDomainGroup
Factory wrapper for google_network_services_multicast_domain_group.
GoogleNetworkServicesMulticastGroupConsumerActivation
Factory wrapper for google_network_services_multicast_group_consumer_activation.
GoogleNetworkServicesMulticastGroupProducerActivation
Factory wrapper for google_network_services_multicast_group_producer_activation.
GoogleNetworkServicesMulticastGroupRange
Factory wrapper for google_network_services_multicast_group_range.
GoogleNetworkServicesMulticastGroupRangeActivation
Factory wrapper for google_network_services_multicast_group_range_activation.
GoogleNetworkServicesMulticastProducerAssociation
Factory wrapper for google_network_services_multicast_producer_association.
GoogleNetworkServicesServiceBinding
Factory wrapper for google_network_services_service_binding.
GoogleNetworkServicesTcpRoute
Factory wrapper for google_network_services_tcp_route.
GoogleNetworkServicesTlsRoute
Factory wrapper for google_network_services_tls_route.
GoogleNetworkServicesWasmPlugin
Factory wrapper for google_network_services_wasm_plugin.
NetworkConnectivityDestinationEndpoints
Typed helper for the endpoints block of google_network_connectivity_destination (derived from provider schema).
NetworkConnectivityGroupAutoAccept
Optional auto_accept block on GoogleNetworkConnectivityGroup.
NetworkConnectivityInternalRangeAllocationOptions
Optional allocation_options when auto-allocating via prefixLength.
NetworkConnectivityMulticloudDataTransferConfigServices
Typed helper for the services block of google_network_connectivity_multicloud_data_transfer_config (derived from provider schema).
NetworkConnectivityPolicyBasedRouteFilter
Typed helper for the filter block of google_network_connectivity_policy_based_route (derived from provider schema).
NetworkConnectivityPolicyBasedRouteInterconnectAttachment
Typed helper for the interconnect_attachment block of google_network_connectivity_policy_based_route (derived from provider schema).
NetworkConnectivityPolicyBasedRouteNextHop
Exactly one next-hop for GoogleNetworkConnectivityPolicyBasedRoute (MM exactly_one_of on next_hop_ilb_ip / next_hop_other_routes). Use NetworkConnectivityPolicyBasedRouteNextHopOtherRoutes (derived) for the otherRoutes variant.
NetworkConnectivityPolicyBasedRouteNextHopIlbIp
next_hop_ilb_ip variant.
NetworkConnectivityPolicyBasedRouteNextHopOtherRoutesChoice
next_hop_other_routes variant.
NetworkConnectivityPolicyBasedRouteVirtualMachine
Typed helper for the virtual_machine block of google_network_connectivity_policy_based_route (derived from provider schema).
NetworkConnectivityServiceConnectionPolicyPscConfig
Typed helper for the psc_config block of google_network_connectivity_service_connection_policy (derived from provider schema).
NetworkConnectivitySpokeAttachment
Exactly one spoke attachment kind (provider conflicts across linked_* / gateway blocks).
NetworkConnectivitySpokeGateway
gateway — NCC gateway spoke (capacity-billed; never apply-smoke).
NetworkConnectivitySpokeGatewayIpRangeReservation
One /23 reservation inside NetworkConnectivitySpokeGateway.
NetworkConnectivitySpokeLinkedInterconnectAttachments
linked_interconnect_attachments — attach VLAN attachments.
NetworkConnectivitySpokeLinkedProducerVpcNetwork
linked_producer_vpc_network — attach a producer VPC via peering.
NetworkConnectivitySpokeLinkedRouterApplianceInstances
linked_router_appliance_instances — attach router appliance VMs.
NetworkConnectivitySpokeLinkedVpcNetwork
linked_vpc_network — attach a consumer VPC to the hub.
NetworkConnectivitySpokeLinkedVpnTunnels
linked_vpn_tunnels — attach HA VPN tunnels.
NetworkConnectivitySpokeRouterApplianceInstance
One router-appliance VM inside NetworkConnectivitySpokeLinkedRouterApplianceInstances.
NetworkManagementConnectivityTestDestination
Typed helper for the destination block of google_network_management_connectivity_test (derived from provider schema).
NetworkManagementConnectivityTestSource
Typed helper for the source block of google_network_management_connectivity_test (derived from provider schema).
NetworkManagementConnectivityTestSourceAppEngineVersion
Typed helper for the source.app_engine_version block of google_network_management_connectivity_test (derived from provider schema).
NetworkManagementConnectivityTestSourceCloudFunction
Typed helper for the source.cloud_function block of google_network_management_connectivity_test (derived from provider schema).
NetworkManagementConnectivityTestSourceCloudRunRevision
Typed helper for the source.cloud_run_revision block of google_network_management_connectivity_test (derived from provider schema).
NetworkSecurityAuthzPolicyCustomProvider
Typed helper for the custom_provider block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyCustomProviderAuthzExtension
Typed helper for the custom_provider.authz_extension block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyCustomProviderCloudIap
Typed helper for the custom_provider.cloud_iap block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRules
Typed helper for the http_rules block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFrom
Typed helper for the http_rules.from block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSources
Typed helper for the http_rules.from.not_sources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesIpBlocks
Typed helper for the http_rules.from.not_sources.ip_blocks block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipals
Typed helper for the http_rules.from.not_sources.principals block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipalsPrincipal
Typed helper for the http_rules.from.not_sources.principals.principal block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResources
Typed helper for the http_rules.from.not_sources.resources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResourcesIamServiceAccount
Typed helper for the http_rules.from.not_sources.resources.iam_service_account block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResourcesTagValueIdSet
Typed helper for the http_rules.from.not_sources.resources.tag_value_id_set block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSources
Typed helper for the http_rules.from.sources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesIpBlocks
Typed helper for the http_rules.from.sources.ip_blocks block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipals
Typed helper for the http_rules.from.sources.principals block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipalsPrincipal
Typed helper for the http_rules.from.sources.principals.principal block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesResources
Typed helper for the http_rules.from.sources.resources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesResourcesIamServiceAccount
Typed helper for the http_rules.from.sources.resources.iam_service_account block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesFromSourcesResourcesTagValueIdSet
Typed helper for the http_rules.from.sources.resources.tag_value_id_set block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesTo
Typed helper for the http_rules.to block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperations
Typed helper for the http_rules.to.not_operations block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSet
Typed helper for the http_rules.to.not_operations.header_set block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSetHeaders
Typed helper for the http_rules.to.not_operations.header_set.headers block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSetHeadersValue
Typed helper for the http_rules.to.not_operations.header_set.headers.value block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHosts
Typed helper for the http_rules.to.not_operations.hosts block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToNotOperationsPaths
Typed helper for the http_rules.to.not_operations.paths block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperations
Typed helper for the http_rules.to.operations block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSet
Typed helper for the http_rules.to.operations.header_set block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSetHeaders
Typed helper for the http_rules.to.operations.header_set.headers block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSetHeadersValue
Typed helper for the http_rules.to.operations.header_set.headers.value block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsHosts
Typed helper for the http_rules.to.operations.hosts block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsMcp
Typed helper for the http_rules.to.operations.mcp block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethods
Typed helper for the http_rules.to.operations.mcp.methods block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethodsParams
Typed helper for the http_rules.to.operations.mcp.methods.params block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyHttpRulesToOperationsPaths
Typed helper for the http_rules.to.operations.paths block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRules
Typed helper for the network_rules block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFrom
Typed helper for the network_rules.from block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromNotSources
Typed helper for the network_rules.from.not_sources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesIpBlocks
Typed helper for the network_rules.from.not_sources.ip_blocks block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipals
Typed helper for the network_rules.from.not_sources.principals block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipalsPrincipal
Typed helper for the network_rules.from.not_sources.principals.principal block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromSources
Typed helper for the network_rules.from.sources block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromSourcesIpBlocks
Typed helper for the network_rules.from.sources.ip_blocks block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipals
Typed helper for the network_rules.from.sources.principals block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipalsPrincipal
Typed helper for the network_rules.from.sources.principals.principal block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesTo
Typed helper for the network_rules.to block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesToOperations
Typed helper for the network_rules.to.operations block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyNetworkRulesToOperationsSnis
Typed helper for the network_rules.to.operations.snis block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityAuthzPolicyTarget
Typed helper for the target block of google_network_security_authz_policy (derived from provider schema).
NetworkSecurityFirewallEndpointEndpointSettings
Typed helper for the endpoint_settings block of google_network_security_firewall_endpoint (derived from provider schema).
mirroring_deployment_groups variant (BROKER).
Exactly-one link from a mirroring endpoint group to its deployment group(s). DIRECT uses a single group; BROKER uses a list.
mirroring_deployment_group variant (DIRECT).
NetworkSecuritySecurityProfileCustomInterceptProfile
Typed helper for the custom_intercept_profile block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileCustomMirroringProfile
Typed helper for the custom_mirroring_profile block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileThreatPreventionProfile
Typed helper for the threat_prevention_profile block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverrides
Typed helper for the threat_prevention_profile.antivirus_overrides block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverrides
Typed helper for the threat_prevention_profile.severity_overrides block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileThreatPreventionProfileThreatOverrides
Typed helper for the threat_prevention_profile.threat_overrides block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileUrlFilteringProfile
Typed helper for the url_filtering_profile block of google_network_security_security_profile (derived from provider schema).
NetworkSecuritySecurityProfileUrlFilteringProfileUrlFilters
Typed helper for the url_filtering_profile.url_filters block of google_network_security_security_profile (derived from provider schema).
NetworkSecurityUllMirroringCollectorRuleMatch
match block on a ULL mirroring collector rule.
NetworkServicesAgentGatewayDeployment
Exactly one of google_managed / self_managed (MM exactly_one_of).
NetworkServicesAgentGatewayGoogleManaged
google_managed — proxy orchestrated in a Google tenant project.
NetworkServicesAgentGatewayNetworkConfig
Typed helper for the network_config block of google_network_services_agent_gateway (derived from provider schema).
NetworkServicesAgentGatewayNetworkConfigDnsPeeringConfig
Typed helper for the network_config.dns_peering_config block of google_network_services_agent_gateway (derived from provider schema).
NetworkServicesAgentGatewayNetworkConfigEgress
Typed helper for the network_config.egress block of google_network_services_agent_gateway (derived from provider schema).
NetworkServicesAgentGatewaySelfManaged
self_managed — attach an existing networking proxy in-project.
NetworkServicesEdgeCacheKeysetPublicKey
Typed helper for the public_key block of google_network_services_edge_cache_keyset (derived from provider schema).
NetworkServicesEdgeCacheKeysetValidationSharedKeys
Typed helper for the validation_shared_keys block of google_network_services_edge_cache_keyset (derived from provider schema).
NetworkServicesEdgeCacheOriginAwsV4Authentication
Typed helper for the aws_v4_authentication block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginFlexShielding
Typed helper for the flex_shielding block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginOriginOverrideAction
Typed helper for the origin_override_action block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginOriginOverrideActionHeaderAction
Typed helper for the origin_override_action.header_action block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginOriginOverrideActionHeaderActionRequestHeadersToAdd
Typed helper for the origin_override_action.header_action.request_headers_to_add block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginOriginOverrideActionUrlRewrite
Typed helper for the origin_override_action.url_rewrite block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginOriginRedirect
Typed helper for the origin_redirect block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheOriginTimeout
Typed helper for the timeout block of google_network_services_edge_cache_origin (derived from provider schema).
NetworkServicesEdgeCacheServiceLogConfig
Typed helper for the log_config block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRouting
Typed helper for the routing block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingHostRule
Typed helper for the routing.host_rule block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcher
Typed helper for the routing.path_matcher block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRule
Typed helper for the routing.path_matcher.route_rule block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderAction
Typed helper for the routing.path_matcher.route_rule.header_action block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToAdd
Typed helper for the routing.path_matcher.route_rule.header_action.request_header_to_add block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToRemove
Typed helper for the routing.path_matcher.route_rule.header_action.request_header_to_remove block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToAdd
Typed helper for the routing.path_matcher.route_rule.header_action.response_header_to_add block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToRemove
Typed helper for the routing.path_matcher.route_rule.header_action.response_header_to_remove block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRule
Typed helper for the routing.path_matcher.route_rule.match_rule block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleHeaderMatch
Typed helper for the routing.path_matcher.route_rule.match_rule.header_match block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleQueryParameterMatch
Typed helper for the routing.path_matcher.route_rule.match_rule.query_parameter_match block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteAction
Typed helper for the routing.path_matcher.route_rule.route_action block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicy
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy.add_signatures block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy.cache_key_policy block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptions
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy.signed_token_options block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCorsPolicy
Typed helper for the routing.path_matcher.route_rule.route_action.cors_policy block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionUrlRewrite
Typed helper for the routing.path_matcher.route_rule.route_action.url_rewrite block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteMethods
Typed helper for the routing.path_matcher.route_rule.route_methods block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleUrlRedirect
Typed helper for the routing.path_matcher.route_rule.url_redirect block of google_network_services_edge_cache_service (derived from provider schema).
NetworkServicesEndpointPolicyEndpointMatcher
Typed helper for the endpoint_matcher block of google_network_services_endpoint_policy (derived from provider schema).
NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher
Typed helper for the endpoint_matcher.metadata_label_matcher block of google_network_services_endpoint_policy (derived from provider schema).
NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels
Typed helper for the endpoint_matcher.metadata_label_matcher.metadata_labels block of google_network_services_endpoint_policy (derived from provider schema).
NetworkServicesEndpointPolicyTrafficPortSelector
Typed helper for the traffic_port_selector block of google_network_services_endpoint_policy (derived from provider schema).
NetworkServicesGrpcRouteRules
Typed helper for the rules block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesAction
Typed helper for the rules.action block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesActionDestinations
Typed helper for the rules.action.destinations block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesActionFaultInjectionPolicy
Typed helper for the rules.action.fault_injection_policy block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesActionFaultInjectionPolicyAbort
Typed helper for the rules.action.fault_injection_policy.abort block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesActionFaultInjectionPolicyDelay
Typed helper for the rules.action.fault_injection_policy.delay block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesActionRetryPolicy
Typed helper for the rules.action.retry_policy block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesMatches
Typed helper for the rules.matches block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesMatchesHeaders
Typed helper for the rules.matches.headers block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesGrpcRouteRulesMatchesMethod
Typed helper for the rules.matches.method block of google_network_services_grpc_route (derived from provider schema).
NetworkServicesHttpRouteRules
Typed helper for the rules block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesAction
Typed helper for the rules.action block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionCorsPolicy
Typed helper for the rules.action.cors_policy block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionDestinations
Typed helper for the rules.action.destinations block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionFaultInjectionPolicy
Typed helper for the rules.action.fault_injection_policy block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionFaultInjectionPolicyAbort
Typed helper for the rules.action.fault_injection_policy.abort block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionFaultInjectionPolicyDelay
Typed helper for the rules.action.fault_injection_policy.delay block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionRedirect
Typed helper for the rules.action.redirect block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionRequestHeaderModifier
Typed helper for the rules.action.request_header_modifier block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionRequestMirrorPolicy
Typed helper for the rules.action.request_mirror_policy block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionRequestMirrorPolicyDestination
Typed helper for the rules.action.request_mirror_policy.destination block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionResponseHeaderModifier
Typed helper for the rules.action.response_header_modifier block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionRetryPolicy
Typed helper for the rules.action.retry_policy block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesActionUrlRewrite
Typed helper for the rules.action.url_rewrite block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesMatches
Typed helper for the rules.matches block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesMatchesHeaders
Typed helper for the rules.matches.headers block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesMatchesHeadersRangeMatch
Typed helper for the rules.matches.headers.range_match block of google_network_services_http_route (derived from provider schema).
NetworkServicesHttpRouteRulesMatchesQueryParameters
Typed helper for the rules.matches.query_parameters block of google_network_services_http_route (derived from provider schema).
NetworkServicesLbEdgeExtensionExtensionChains
Typed helper for the extension_chains block of google_network_services_lb_edge_extension (derived from provider schema).
NetworkServicesLbEdgeExtensionExtensionChainsExtensions
Typed helper for the extension_chains.extensions block of google_network_services_lb_edge_extension (derived from provider schema).
NetworkServicesLbEdgeExtensionExtensionChainsMatchCondition
Typed helper for the extension_chains.match_condition block of google_network_services_lb_edge_extension (derived from provider schema).
NetworkServicesLbRouteExtensionExtensionChains
Typed helper for the extension_chains block of google_network_services_lb_route_extension (derived from provider schema).
NetworkServicesLbRouteExtensionExtensionChainsExtensions
Typed helper for the extension_chains.extensions block of google_network_services_lb_route_extension (derived from provider schema).
NetworkServicesLbRouteExtensionExtensionChainsMatchCondition
Typed helper for the extension_chains.match_condition block of google_network_services_lb_route_extension (derived from provider schema).
NetworkServicesLbTrafficExtensionExtensionChains
Typed helper for the extension_chains block of google_network_services_lb_traffic_extension (derived from provider schema).
NetworkServicesLbTrafficExtensionExtensionChainsExtensions
Typed helper for the extension_chains.extensions block of google_network_services_lb_traffic_extension (derived from provider schema).
NetworkServicesLbTrafficExtensionExtensionChainsMatchCondition
Typed helper for the extension_chains.match_condition block of google_network_services_lb_traffic_extension (derived from provider schema).
NetworkServicesMulticastDomainActivationTrafficSpec
Typed helper for the traffic_spec block of google_network_services_multicast_domain_activation (derived from provider schema).
NetworkServicesMulticastDomainConnectionConfig
Typed helper for the connection_config block of google_network_services_multicast_domain (derived from provider schema).
NetworkServicesMulticastDomainUllMulticastDomain
Typed helper for the ull_multicast_domain block of google_network_services_multicast_domain (derived from provider schema).
NetworkServicesMulticastGroupConsumerActivationLogConfig
Typed helper for the log_config block of google_network_services_multicast_group_consumer_activation (derived from provider schema).
NetworkServicesMulticastGroupRangeActivationLogConfig
Typed helper for the log_config block of google_network_services_multicast_group_range_activation (derived from provider schema).
NetworkServicesMulticastGroupRangeLogConfig
Typed helper for the log_config block of google_network_services_multicast_group_range (derived from provider schema).
NetworkServicesTcpRouteRules
Typed helper for the rules block of google_network_services_tcp_route (derived from provider schema).
NetworkServicesTcpRouteRulesAction
Typed helper for the rules.action block of google_network_services_tcp_route (derived from provider schema).
NetworkServicesTcpRouteRulesActionDestinations
Typed helper for the rules.action.destinations block of google_network_services_tcp_route (derived from provider schema).
NetworkServicesTcpRouteRulesMatches
Typed helper for the rules.matches block of google_network_services_tcp_route (derived from provider schema).
NetworkServicesTlsRouteRules
Typed helper for the rules block of google_network_services_tls_route (derived from provider schema).
NetworkServicesTlsRouteRulesAction
Typed helper for the rules.action block of google_network_services_tls_route (derived from provider schema).
NetworkServicesTlsRouteRulesActionDestinations
Typed helper for the rules.action.destinations block of google_network_services_tls_route (derived from provider schema).
NetworkServicesTlsRouteRulesMatches
Typed helper for the rules.matches block of google_network_services_tls_route (derived from provider schema).
NetworkServicesWasmPluginLogConfig
Typed helper for the log_config block of google_network_services_wasm_plugin (derived from provider schema).
NetworkServicesWasmPluginVersions
Typed helper for the versions block of google_network_services_wasm_plugin (derived from provider schema).

Enums

NetworkConnectivityGatewayAdvertisedRouteRecipient
Network Connectivity Gateway Advertised Route enum for recipient.
NetworkConnectivityGatewayAdvertisedRouteState
Network Connectivity Gateway Advertised Route enum for state.
NetworkConnectivityGroupName
Network Connectivity Group enum for name.
NetworkConnectivityInternalRangeAllocationStrategy
allocation_strategy on NetworkConnectivityInternalRangeAllocationOptions.
NetworkConnectivityInternalRangePeering
peering for GoogleNetworkConnectivityInternalRange.
NetworkConnectivityInternalRangeUsage
usage for GoogleNetworkConnectivityInternalRange.
NetworkConnectivityPolicyBasedRouteFilterProtocolVersion
protocol_version — derived from the provider schema description.
NetworkConnectivityPolicyBasedRouteNextHopOtherRoutes
Network Connectivity Policy Based Route Next Hop Other enum for next_hop_other_routes.
NetworkConnectivityRegionalEndpointAccessType
Network Connectivity Regional Endpoint Access enum for access_type.
NetworkConnectivityServiceConnectionPolicyPscConfigProducerInstanceLocation
producer_instance_location — derived from the provider schema description.
NetworkConnectivitySpokeGatewayCapacity
Capacity for an NCC gateway spoke.
NetworkConnectivityTransportDeletionPolicy
Terraform deletion_policy for Network Connectivity transports.
NetworkConnectivityTransportStackType
IP stack for google_network_connectivity_transport.stack_type.
NetworkManagementConnectivityTestDestinationNetworkType
network_type — derived from the provider schema description.
NetworkManagementConnectivityTestSourceNetworkType
network_type — derived from the provider schema description.
NetworkManagementVpcFlowLogsConfigAggregationInterval
aggregation_interval for google_network_management_vpc_flow_logs_config.
NetworkManagementVpcFlowLogsConfigMetadata
metadata for google_network_management_vpc_flow_logs_config.
NetworkManagementVpcFlowLogsConfigState
state for google_network_management_vpc_flow_logs_config.
NetworkSecurityAddressGroupType
Network Security Address Group enum for type.
NetworkSecurityAuthzPolicyAction
Network Security Authz Policy enum for action.
NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipalsPrincipalSelector
principal_selector — derived from the provider schema description.
NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipalsPrincipalSelector
principal_selector — derived from the provider schema description.
NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpBaseProtocolMethodsOption
base_protocol_methods_option — derived from the provider schema description.
NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipalsPrincipalSelector
principal_selector — derived from the provider schema description.
NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipalsPrincipalSelector
principal_selector — derived from the provider schema description.
NetworkSecurityAuthzPolicyPolicyProfile
Network Security Authz Policy Policy enum for policy_profile.
NetworkSecurityAuthzPolicyTargetLoadBalancingScheme
load_balancing_scheme — derived from the provider schema description.
NetworkSecurityBackendAuthenticationConfigWellKnownRoots
Network Security Backend Authentication Config Well Known enum for well_known_roots.
NetworkSecurityDnsThreatDetectorThreatDetectorProvider
Network Security Dns Threat Detector Threat Detector enum for threat_detector_provider.
NetworkSecurityFirewallEndpointAssociationState
Network Security Firewall Endpoint Association enum for state.
NetworkSecurityGatewaySecurityPolicyRuleBasicProfile
Network Security Gateway Security Policy Rule Basic enum for basic_profile.
NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverridesAction
action — derived from the provider schema description.
NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverridesProtocol
protocol — derived from the provider schema description.
NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverridesAction
action — derived from the provider schema description.
NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverridesSeverity
severity — derived from the provider schema description.
NetworkSecuritySecurityProfileThreatPreventionProfileThreatOverridesAction
action — derived from the provider schema description.
NetworkSecuritySecurityProfileType
Network Security Security Profile enum for type.
NetworkSecuritySecurityProfileUrlFilteringProfileUrlFiltersFilteringAction
filtering_action — derived from the provider schema description.
NetworkSecurityTlsInspectionPolicyMinTlsVersion
Network Security Tls Inspection Policy Min Tls enum for min_tls_version.
NetworkSecurityTlsInspectionPolicyTlsFeatureProfile
Network Security Tls Inspection Policy Tls Feature enum for tls_feature_profile.
NetworkSecurityUllMirroringCollectorDeletionPolicy
Terraform deletion_policy for ULL mirroring collectors.
NetworkSecurityUllMirroringCollectorRuleDeletionPolicy
Terraform deletion_policy for ULL mirroring collector rules.
NetworkSecurityUllMirroringCollectorRuleDirection
Traffic direction for match.direction.
NetworkSecurityUllMirroringEngineDeletionPolicy
Terraform deletion_policy for ULL mirroring engines.
NetworkServicesAgentGatewayGoogleManagedGovernedAccessPath
governed_access_path under google_managed.
NetworkServicesAuthzExtensionLoadBalancingScheme
Network Services Authz Extension Load Balancing enum for load_balancing_scheme.
NetworkServicesAuthzExtensionWireFormat
Network Services Authz Extension Wire enum for wire_format.
NetworkServicesEdgeCacheOriginFlexShieldingFlexShieldingRegions
flex_shielding_regions — derived from the provider schema description.
NetworkServicesEdgeCacheOriginProtocol
Network Services Edge Cache Origin enum for protocol.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignaturesActions
actions — derived from the provider schema description.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheMode
cache_mode — derived from the provider schema description.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedRequestMode
signed_request_mode — derived from the provider schema description.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptionsAllowedSignatureAlgorithms
allowed_signature_algorithms — derived from the provider schema description.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCompressionMode
compression_mode — derived from the provider schema description.
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleUrlRedirectRedirectResponseCode
redirect_response_code — derived from the provider schema description.
NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelMatchCriteria
metadata_label_match_criteria — derived from the provider schema description.
NetworkServicesEndpointPolicyType
Network Services Endpoint Policy enum for type.
NetworkServicesGatewayEnvoyHeaders
Network Services Gateway Envoy enum for envoy_headers.
NetworkServicesGatewayIpVersion
Network Services Gateway Ip enum for ip_version.
NetworkServicesGatewayRoutingMode
Network Services Gateway Routing enum for routing_mode.
NetworkServicesGatewayType
Network Services Gateway enum for type.
NetworkServicesGrpcRouteRulesActionRetryPolicyRetryConditions
retry_conditions — derived from the provider schema description.
NetworkServicesGrpcRouteRulesMatchesHeadersType
type — derived from the provider schema description.
NetworkServicesLbEdgeExtensionLoadBalancingScheme
Network Services Lb Edge Extension Load Balancing enum for load_balancing_scheme.
NetworkServicesLbRouteExtensionExtensionChainsExtensionsRequestBodySendMode
request_body_send_mode — derived from the provider schema description.
NetworkServicesLbRouteExtensionLoadBalancingScheme
Network Services Lb Route Extension Load Balancing enum for load_balancing_scheme.
NetworkServicesLbTrafficExtensionLoadBalancingScheme
Network Services Lb Traffic Extension Load Balancing enum for load_balancing_scheme.
NetworkServicesWasmPluginLogConfigMinLogLevel
min_log_level — derived from the provider schema description.