OsConfigPatchDeploymentOneTimeSchedule class final

one_time_schedule block — run the patch job once at executeTime.

Inheritance
Annotations
  • @immutable

Constructors

OsConfigPatchDeploymentOneTimeSchedule({required TfArg<String> executeTime})
const

Properties

blockKey String
no setteroverride
executeTime → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() List<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited