OsConfigPatchDeploymentRecurringSchedule class final

recurring_schedule block — run patch jobs on a cadence.

Inheritance
Annotations
  • @immutable

Properties

blockKey String
no setteroverride
endTime → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
monthly OsConfigPatchDeploymentRecurringScheduleMonthly?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>?
final
timeOfDay OsConfigPatchDeploymentRecurringScheduleTimeOfDay?
final
timeZone OsConfigPatchDeploymentRecurringScheduleTimeZone
final
weekly OsConfigPatchDeploymentRecurringScheduleWeekly?
final

Methods

encode() List<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited