OsConfigPatchDeploymentRecurringScheduleMonthly class final
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentRecurringScheduleMonthly.monthDay({required TfArg<
num> ? monthDay}) -
const
- OsConfigPatchDeploymentRecurringScheduleMonthly.weekDayOfMonth({required OsConfigPatchDeploymentRecurringScheduleMonthlyWeekDayOfMonth? weekDayOfMonth})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
monthDay
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weekDayOfMonth → OsConfigPatchDeploymentRecurringScheduleMonthlyWeekDayOfMonth?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited