OsConfigPatchDeploymentRecurringScheduleMonthlyWeekDayOfMonth class final
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentRecurringScheduleMonthlyWeekDayOfMonth({required TfArg<
num> weekOfMonth, required OsConfigPatchDeploymentDayOfWeek dayOfWeek}) -
const
Properties
- dayOfWeek → OsConfigPatchDeploymentDayOfWeek
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
weekOfMonth
→ TfArg<
num> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited