AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType enum

os_type — derived from the provider schema description.

Inheritance
  • Object
  • Enum
  • AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
Available extensions

Values

osUnspecified → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('OS_UNSPECIFIED')
desktopMac → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('DESKTOP_MAC')
desktopWindows → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('DESKTOP_WINDOWS')
desktopLinux → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('DESKTOP_LINUX')
desktopChromeOs → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('DESKTOP_CHROME_OS')
android → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('ANDROID')
ios → const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType
const AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType('IOS')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
The Terraform-side string literal this enum value encodes to. Convention: emitted exactly as it appears in provider docs (typically SCREAMING_SNAKE_CASE for GCP).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraintsOsType>
A constant List of the values in this enum, in order of their declaration.