AccessContextManagerAccessLevelBasicConditionsVpcNetworkSourcesVpcSubnetwork class final

Typed helper for the basic.conditions.vpc_network_sources.vpc_subnetwork block of google_access_context_manager_access_level (derived from provider schema).

Annotations
  • @immutable

Constructors

AccessContextManagerAccessLevelBasicConditionsVpcNetworkSourcesVpcSubnetwork({required TfArg<String> network, TfArg<List<Object?>>? vpcIpSubnetworks})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
network → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vpcIpSubnetworks → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited