AccessContextManagerAccessLevelConditions class final

Typed helper for the basic.conditions block of google_access_context_manager_access_level (derived from provider schema).

Annotations
  • @immutable

Constructors

AccessContextManagerAccessLevelConditions({TfArg<List<String>>? ipSubnetworks, TfArg<List<String>>? members, TfArg<bool>? negate, TfArg<List<String>>? regions, TfArg<List<String>>? requiredAccessLevels, AccessContextManagerAccessLevelDevicePolicy? devicePolicy, List<AccessContextManagerAccessLevelVpcNetworkSources>? vpcNetworkSources})
const

Properties

devicePolicy → AccessContextManagerAccessLevelDevicePolicy?
final
hashCode → int
The hash code for this object.
no setterinherited
ipSubnetworks → TfArg<List<String>>?
final
members → TfArg<List<String>>?
final
negate → TfArg<bool>?
final
regions → TfArg<List<String>>?
final
requiredAccessLevels → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcNetworkSources → List<AccessContextManagerAccessLevelVpcNetworkSources>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited