AccessContextManagerAccessLevels class final

Typed helper for the access_levels block of google_access_context_manager_access_levels (derived from provider schema).

Annotations
  • @immutable

Constructors

AccessContextManagerAccessLevels({TfArg<String>? description, required TfArg<String> name, required TfArg<String> title, AccessContextManagerAccessLevelsBasic? basic, AccessContextManagerAccessLevelsCustom? custom})
const

Properties

basic → AccessContextManagerAccessLevelsBasic?
final
custom → AccessContextManagerAccessLevelsCustom?
final
description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited