AccessContextManagerAccessLevelsDevicePolicy class final

Typed helper for the access_levels.basic.conditions.device_policy block of google_access_context_manager_access_levels (derived from provider schema).

Annotations
  • @immutable

Constructors

AccessContextManagerAccessLevelsDevicePolicy({List<AccessContextManagerAccessLevelsAllowedDeviceManagementLevels>? allowedDeviceManagementLevels, List<AccessContextManagerAccessLevelsAllowedEncryptionStatuses>? allowedEncryptionStatuses, TfArg<bool>? requireAdminApproval, TfArg<bool>? requireCorpOwned, TfArg<bool>? requireScreenLock, List<AccessContextManagerAccessLevelsOsConstraints>? osConstraints})
const

Properties

allowedDeviceManagementLevels → List<AccessContextManagerAccessLevelsAllowedDeviceManagementLevels>?
final
allowedEncryptionStatuses → List<AccessContextManagerAccessLevelsAllowedEncryptionStatuses>?
final
hashCode → int
The hash code for this object.
no setterinherited
osConstraints → List<AccessContextManagerAccessLevelsOsConstraints>?
final
requireAdminApproval → TfArg<bool>?
final
requireCorpOwned → TfArg<bool>?
final
requireScreenLock → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited