AccessContextManagerAccessLevelsVpcSubnetwork class final

Typed helper for the access_levels.basic.conditions.vpc_network_sources.vpc_subnetwork block of google_access_context_manager_access_levels (derived from provider schema).

Annotations
  • @immutable

Constructors

AccessContextManagerAccessLevelsVpcSubnetwork({required TfArg<String> network, TfArg<List<String>>? vpcIpSubnetworks})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
network → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcIpSubnetworks → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited