AccessContextManagerServicePerimeterAddRequestHeader class final

Typed helper for the spec.vpc_accessible_services.allowed_service_patterns.modifiers.add_request_header block of google_access_context_manager_service_perimeter (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AccessContextManagerServicePerimeterAddRequestHeader({required TfArg<String> key, required TfArg<String> value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited