AccessContextManagerServicePerimeterStatus class final

Typed helper for the status block of google_access_context_manager_service_perimeter (derived from provider schema).

Annotations
  • @immutable

Properties

accessLevels → TfArg<List<String>>?
final
egressPolicies → List<AccessContextManagerServicePerimeterEgressPolicies>?
final
hashCode → int
The hash code for this object.
no setterinherited
ingressPolicies → List<AccessContextManagerServicePerimeterIngressPolicies>?
final
resources → TfArg<List<String>>?
final
restrictedServices → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcAccessibleServices → AccessContextManagerServicePerimeterVpcAccessibleServices?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited