AccessContextManagerServicePerimetersServicePerimeters class final
Typed helper for the service_perimeters block of
google_access_context_manager_service_perimeters (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AccessContextManagerServicePerimetersServicePerimeters({TfArg<
String> ? description, required TfArg<String> name, TfArg<AccessContextManagerServicePerimetersServicePerimetersPerimeterType> ? perimeterType, required TfArg<String> title, TfArg<bool> ? useExplicitDryRunSpec, AccessContextManagerServicePerimetersServicePerimetersSpec? spec, AccessContextManagerServicePerimetersServicePerimetersStatus? status}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> -
final
-
perimeterType
→ TfArg<
AccessContextManagerServicePerimetersServicePerimetersPerimeterType> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spec → AccessContextManagerServicePerimetersServicePerimetersSpec?
-
final
- status → AccessContextManagerServicePerimetersServicePerimetersStatus?
-
final
-
title
→ TfArg<
String> -
final
-
useExplicitDryRunSpec
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited