AgentIdentityAuthProviderAuthProviderTypeParamsThreeLeggedOauth class final

Typed helper for the auth_provider_type_params.three_legged_oauth block of google_agent_identity_auth_provider (derived from provider schema).

Annotations
  • @immutable

Constructors

AgentIdentityAuthProviderAuthProviderTypeParamsThreeLeggedOauth({TfArg<String>? authorizationUrl, TfArg<String>? clientId, TfArg<String>? clientSecret, TfArg<String>? clientSecretWo, TfArg<String>? clientSecretWoVersion, TfArg<String>? defaultContinueUri, TfArg<bool>? enablePkce, TfArg<String>? tokenUrl})
const

Properties

authorizationUrl → TfArg<String>?
final
clientId → TfArg<String>?
final
clientSecret → TfArg<String>?
final
clientSecretWo → TfArg<String>?
final
clientSecretWoVersion → TfArg<String>?
final
defaultContinueUri → TfArg<String>?
final
enablePkce → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenUrl → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited