AgentRegistryBindingAuthProviderBinding class final

Typed helper for the auth_provider_binding block of google_agent_registry_binding (derived from provider schema).

Annotations
  • @immutable

Constructors

AgentRegistryBindingAuthProviderBinding({required TfArg<String> authProvider, TfArg<String>? continueUri, TfArg<List<Object?>>? scopes})
const

Properties

authProvider → TfArg<String>
final
continueUri → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited