AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResource class final
Typed helper for the artifacts_config.slide_generation_options.slide_examples.resource block of
google_agentic_applications_analyst_agent_persona (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResource({TfArg<
String> ? displayLabel, TfArg<String> ? modelDescription, TfArg<bool> ? useRag, AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceBigqueryResource? bigqueryResource, AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceF1Resource? f1Resource, AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceGoogleCloudStorageResource? googleCloudStorageResource, AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceGoogleDriveResource? googleDriveResource, AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceRawFileResource? rawFileResource}) -
const
Properties
- bigqueryResource → AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceBigqueryResource?
-
final
-
displayLabel
→ TfArg<
String> ? -
final
- f1Resource → AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceF1Resource?
-
final
- googleCloudStorageResource → AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceGoogleCloudStorageResource?
-
final
- googleDriveResource → AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceGoogleDriveResource?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modelDescription
→ TfArg<
String> ? -
final
- rawFileResource → AgenticApplicationsAnalystAgentPersonaArtifactsConfigSlideGenerationOptionsSlideExamplesResourceRawFileResource?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
useRag
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited