AgenticApplicationsAnalystAgentPersonaArtifactsConfigVisualizationOptionsVisualizationExamplesResourceGoogleDriveResource class final
Typed helper for the artifacts_config.visualization_options.visualization_examples.resource.google_drive_resource block of
google_agentic_applications_analyst_agent_persona (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AgenticApplicationsAnalystAgentPersonaArtifactsConfigVisualizationOptionsVisualizationExamplesResourceGoogleDriveResource({TfArg<
List< ? fileExtensionRestrictions, TfArg<Object?> >String> ? fileReference}) -
const
Properties
-
fileExtensionRestrictions
→ TfArg<
List< ?Object?> > -
final
-
fileReference
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited