AgenticApplicationsAnalystAgentPersonaRawFileResource class final

Typed helper for the resources.raw_file_resource block of google_agentic_applications_analyst_agent_persona (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AgenticApplicationsAnalystAgentPersonaRawFileResource({required TfArg<String> fileContent, required TfArg<String> fileTitle, required TfArg<String> mimeType})
const

Properties

fileContent → TfArg<String>
final
fileTitle → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
mimeType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited