AgenticApplicationsAnalystAgentPersonaSlideExamples class final

Typed helper for the artifacts_config.slide_generation_options.slide_examples block of google_agentic_applications_analyst_agent_persona (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
resource → AgenticApplicationsAnalystAgentPersonaResource
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited