AlertCombiner enum
Combiner for google_monitoring_alert_policy.combiner — how the
conditions list reduces to a single incident-open decision.
Values
- and → const AlertCombiner
-
const AlertCombiner('AND') - or → const AlertCombiner
-
const AlertCombiner('OR') - andWithMatchingResource → const AlertCombiner
-
const AlertCombiner('AND_WITH_MATCHING_RESOURCE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlertCombiner> - A constant List of the values in this enum, in order of their declaration.