AlloydbInstanceMachineConfig class final

Typed helper for the machine_config block of google_alloydb_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

AlloydbInstanceMachineConfig({TfArg<num>? cpuCount, TfArg<String>? machineType})
const

Properties

cpuCount → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
machineType → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited