ApigeeDatastoreDatastoreConfig class

datastore_config block (max=1). Required when targetType is set.

Annotations
  • @immutable

Constructors

ApigeeDatastoreDatastoreConfig({required TfArg<String> projectId, TfArg<String>? bucketName, TfArg<String>? path, TfArg<String>? datasetName, TfArg<String>? tablePrefix})
const

Properties

bucketName → TfArg<String>?
final
datasetName → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
path → TfArg<String>?
final
projectId → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablePrefix → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited