ApihubPluginConfigTemplateAdditionalConfigTemplateMultiSelectOptions class final
Typed helper for the config_template.additional_config_template.multi_select_options block of
google_apihub_plugin (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ApihubPluginConfigTemplateAdditionalConfigTemplateMultiSelectOptions({TfArg<
String> ? description, required TfArg<String> displayName, required TfArg<String> id}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
displayName
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited