ApihubPluginInstanceAuthConfigOauth2ClientCredentialsConfig class final

Typed helper for the auth_config.oauth2_client_credentials_config block of google_apihub_plugin_instance (derived from provider schema).

Annotations
  • @immutable

Properties

clientId → TfArg<String>
final
clientSecret ApihubPluginInstanceAuthConfigOauth2ClientCredentialsConfigClientSecret
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited