ApihubPluginInstanceCustomCuration class final

Typed helper for the actions.curation_config.custom_curation block of google_apihub_plugin_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

ApihubPluginInstanceCustomCuration({required TfArg<String> curation})
const

Properties

curation → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited