ApikeysKeyServerKeyRestrictions class final

Typed helper for the restrictions.server_key_restrictions block of google_apikeys_key (derived from provider schema).

Annotations
  • @immutable

Constructors

ApikeysKeyServerKeyRestrictions({required TfArg<List<String>> allowedIps})
const

Properties

allowedIps → TfArg<List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited