AppEngineHttpTarget class final

app_engine_http_target block — App Engine routing variant.

Inheritance
Annotations
  • @immutable

Constructors

AppEngineHttpTarget({required TfArg<String> relativeUri, TfArg<String>? httpMethod, TfArg<String>? body, TfArg<Map<String, String>>? headers, AppEngineRouting? appEngineRouting})
const

Properties

appEngineRouting AppEngineRouting?
final
blockKey String
argMap key under which this target is emitted (e.g. pubsub_target).
no setteroverride
body → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
headers → TfArg<Map<String, String>>?
final
httpMethod → TfArg<String>?
final
relativeUri → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited