AppEngineIntegrationMode enum

app_engine_integration_mode -- whether the database participates in the legacy App Engine integration. Only meaningful for Datastore-mode databases that were originally provisioned via App Engine.

Inheritance
Available extensions

Values

enabled → const AppEngineIntegrationMode
const AppEngineIntegrationMode('ENABLED')
disabled → const AppEngineIntegrationMode
const AppEngineIntegrationMode('DISABLED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppEngineIntegrationMode>
A constant List of the values in this enum, in order of their declaration.