AppEngineServiceSplitTrafficSplit class final

Typed helper for the split block of google_app_engine_service_split_traffic (derived from provider schema).

Annotations
  • @immutable

Constructors

AppEngineServiceSplitTrafficSplit({required TfArg<Map<String, String>> allocations, AppEngineServiceSplitTrafficShardBy? shardBy})
const

Properties

allocations → TfArg<Map<String, String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shardBy → AppEngineServiceSplitTrafficShardBy?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited