AppEngineStandardAppVersionBasicScaling class final
Typed helper for the basic_scaling block of
google_app_engine_standard_app_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppEngineStandardAppVersionBasicScaling({TfArg<
String> ? idleTimeout, required TfArg<num> maxInstances}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
idleTimeout
→ TfArg<
String> ? -
final
-
maxInstances
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited