AppEngineStandardAppVersionDeploymentZip class final

Typed helper for the deployment.zip block of google_app_engine_standard_app_version (derived from provider schema).

Annotations
  • @immutable

Constructors

AppEngineStandardAppVersionDeploymentZip({TfArg<num>? filesCount, required TfArg<String> sourceUrl})
const

Properties

filesCount → TfArg<num>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUrl → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited