AppEngineStandardAppVersionFiles class final

Typed helper for the deployment.files block of google_app_engine_standard_app_version (derived from provider schema).

Annotations
  • @immutable

Constructors

AppEngineStandardAppVersionFiles({required TfArg<String> name, TfArg<String>? sha1Sum, required TfArg<String> sourceUrl})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Sum → TfArg<String>?
final
sourceUrl → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited