AppEngineStandardAppVersionStandardSchedulerSettings class final

Typed helper for the automatic_scaling.standard_scheduler_settings block of google_app_engine_standard_app_version (derived from provider schema).

Annotations
  • @immutable

Constructors

AppEngineStandardAppVersionStandardSchedulerSettings({TfArg<num>? maxInstances, TfArg<num>? minInstances, TfArg<num>? targetCpuUtilization, TfArg<num>? targetThroughputUtilization})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxInstances → TfArg<num>?
final
minInstances → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetCpuUtilization → TfArg<num>?
final
targetThroughputUtilization → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited