ApphubApplicationDeveloperOwners class final

Typed helper for the attributes.developer_owners block of google_apphub_application (derived from provider schema).

Annotations
  • @immutable

Constructors

ApphubApplicationDeveloperOwners({TfArg<String>? displayName, required TfArg<String> email})
const

Properties

displayName → TfArg<String>?
final
email → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited