ArtifactRegistryRepositoryArtifactRegistryRemoteCommonRepository class
remote_repository_config.common_repository -- generic upstream by
URI. Mutually exclusive with the format-specific
*_repository blocks (see
ArtifactRegistryRepositoryArtifactRegistryRemoteRepositoryConfig.advancedExtra).
- Annotations
-
- @immutable
Constructors
-
ArtifactRegistryRepositoryArtifactRegistryRemoteCommonRepository({required TfArg<
String> uri}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uri
→ TfArg<
String> -
Upstream URI. Accepts an Artifact Registry repo path
(
projects/<p>/locations/<l>/repositories/<repo>), a registry URI (https://registry-1.docker.io), or an Artifact Registry HTTPS URI (https://<region>-docker.pkg.dev/<project>/<repo>).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited