ArtifactRegistryRepositoryMavenRepositoryPublicRepository class final
The ArtifactRegistryRepositoryMavenRepository.publicRepository choice: sets public_repository.
- Inheritance
-
- Object
- ArtifactRegistryRepositoryMavenRepository
- ArtifactRegistryRepositoryMavenRepositoryPublicRepository
Constructors
- ArtifactRegistryRepositoryMavenRepositoryPublicRepository(ArtifactRegistryMavenPublicRepository publicRepository)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicRepository → ArtifactRegistryMavenPublicRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited