ArtifactRegistryRepositoryMostRecentVersions class final

Typed helper for the cleanup_policies.most_recent_versions block of google_artifact_registry_repository (derived from provider schema).

Annotations
  • @immutable

Constructors

ArtifactRegistryRepositoryMostRecentVersions({TfArg<num>? keepCount, TfArg<List<String>>? packageNamePrefixes})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keepCount → TfArg<num>?
final
packageNamePrefixes → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited