ArtifactRegistryRepositoryYumRepositoryPublicRepository class final

Typed helper for the remote_repository_config.yum_repository.public_repository block of google_artifact_registry_repository (derived from provider schema).

Annotations
  • @immutable

Constructors

ArtifactRegistryRepositoryYumRepositoryPublicRepository({required ArtifactRegistryYumRepositoryBase repositoryBase, required TfArg<String> repositoryPath})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
repositoryBase → ArtifactRegistryYumRepositoryBase
final
repositoryPath → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited