BackendBucketCacheMode enum

cdn_policy.cache_mode. Enabling CDN (enable_cdn = true) without setting this defaults to CACHE_ALL_STATIC. Note: this is a distinct type from BackendServiceCacheMode — bucket-side CDN policies are not interchangeable with service-side policies.

Inheritance
Available extensions

Values

useOriginHeaders → const BackendBucketCacheMode
const BackendBucketCacheMode('USE_ORIGIN_HEADERS')
forceCacheAll → const BackendBucketCacheMode
const BackendBucketCacheMode('FORCE_CACHE_ALL')
cacheAllStatic → const BackendBucketCacheMode
const BackendBucketCacheMode('CACHE_ALL_STATIC')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BackendBucketCacheMode>
A constant List of the values in this enum, in order of their declaration.