BackendBucketCacheMode extension type
cdn_policy.cache_mode. Enabling CDN (enable_cdn = true) without
setting this defaults to CACHE_ALL_STATIC. Note: this is a
distinct type from BackendServiceCacheMode — bucket-side CDN
policies are not interchangeable with service-side policies.
Constructors
-
BackendBucketCacheMode.arg(TfArg<
String> arg) -
const
- BackendBucketCacheMode.expression(String template)
- BackendBucketCacheMode.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cacheAllStatic → const BackendBucketCacheMode
- forceCacheAll → const BackendBucketCacheMode
- useOriginHeaders → const BackendBucketCacheMode
-
values
→ const List<
BackendBucketCacheMode>