BackendBucketCdnCacheKeyPolicy class

cdn_policy.cache_key_policy (max_items=1). Buckets only expose the queryStringWhitelist / includeHttpHeaders axes — unlike BackendServiceCdnCacheKeyPolicy, there is no host / protocol / query-string-as-a-whole toggle.

Annotations
  • @immutable

Constructors

BackendBucketCdnCacheKeyPolicy({List<String>? includeHttpHeaders, List<String>? queryStringWhitelist})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includeHttpHeaders List<String>?
Allows HTTP request headers (by name) to be used in the cache key.
final
queryStringWhitelist List<String>?
Names of query-string parameters to include in cache keys. Default parameters are always included. & and = are percent-encoded rather than treated as delimiters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited