BackendServiceCustomMetric class

One entry under the top-level custom_metrics. Mirrors BackendServiceBackendCustomMetric but without maxUtilization (schema only models name + dry_run at this scope).

Annotations
  • @immutable

Constructors

BackendServiceCustomMetric({required TfArg<String> name, required bool dryRun})
const

Properties

dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited