BackendServiceProtocol enum

Wire protocol the backend service uses to talk to backends. HTTP2 and H2C require an HTTP(S)-class load balancer; TCP, SSL, and UDP are for Network Load Balancing / Traffic Director TCP routing. GRPC is required when the URL map is bound to a target gRPC proxy.

Inheritance
Available extensions

Values

http → const BackendServiceProtocol
const BackendServiceProtocol('HTTP')
https → const BackendServiceProtocol
const BackendServiceProtocol('HTTPS')
http2 → const BackendServiceProtocol
const BackendServiceProtocol('HTTP2')
tcp → const BackendServiceProtocol
const BackendServiceProtocol('TCP')
ssl → const BackendServiceProtocol
const BackendServiceProtocol('SSL')
udp → const BackendServiceProtocol
const BackendServiceProtocol('UDP')
grpc → const BackendServiceProtocol
const BackendServiceProtocol('GRPC')
unspecified → const BackendServiceProtocol
const BackendServiceProtocol('UNSPECIFIED')
h2c → const BackendServiceProtocol
const BackendServiceProtocol('H2C')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BackendServiceProtocol>
A constant List of the values in this enum, in order of their declaration.