BackupDrManagementServerNetworks class final

Typed helper for the networks block of google_backup_dr_management_server (derived from provider schema).

Annotations
  • @immutable

Constructors

BackupDrManagementServerNetworks({required TfArg<String> network, TfArg<String>? peeringMode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
network → TfArg<String>
final
peeringMode → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited