BackupDrRestoreWorkloadAccessConfigs class final

Typed helper for the compute_instance_restore_properties.network_interfaces.access_configs block of google_backup_dr_restore_workload (derived from provider schema).

Annotations
  • @immutable

Constructors

BackupDrRestoreWorkloadAccessConfigs({TfArg<String>? externalIp, TfArg<String>? externalIpv6, TfArg<num>? externalIpv6PrefixLength, TfArg<String>? name, BackupDrRestoreWorkloadNetworkTier? networkTier, TfArg<String>? publicPtrDomainName, TfArg<bool>? setPublicPtr, BackupDrRestoreWorkloadAccessConfigsType? type})
const

Properties

externalIp → TfArg<String>?
final
externalIpv6 → TfArg<String>?
final
externalIpv6PrefixLength → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
networkTier → BackupDrRestoreWorkloadNetworkTier?
final
publicPtrDomainName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setPublicPtr → TfArg<bool>?
final
type → BackupDrRestoreWorkloadAccessConfigsType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited