BackupDrRestoreWorkloadAllocationAffinity class final
Typed helper for the compute_instance_restore_properties.allocation_affinity block of
google_backup_dr_restore_workload (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BackupDrRestoreWorkloadAllocationAffinity({BackupDrRestoreWorkloadConsumeAllocationType? consumeAllocationType, TfArg<
String> ? key, TfArg<List< ? values})String> > -
const
Properties
- consumeAllocationType → BackupDrRestoreWorkloadConsumeAllocationType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited