BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksInitializeParams class final

Typed helper for the compute_instance_restore_properties.disks.initialize_params block of google_backup_dr_restore_workload (derived from provider schema).

Annotations
  • @immutable

Constructors

BackupDrRestoreWorkloadComputeInstanceRestorePropertiesDisksInitializeParams({TfArg<String>? diskName, TfArg<List<Object?>>? replicaZones})
const

Properties

diskName → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
replicaZones → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited