BackupDrRestoreWorkloadDiskTargetEnvironment class final

Typed helper for the disk_target_environment block of google_backup_dr_restore_workload (derived from provider schema).

Annotations
  • @immutable

Constructors

BackupDrRestoreWorkloadDiskTargetEnvironment({required TfArg<String> project, TfArg<bool>? useProjectServiceAccount, required TfArg<String> zone})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
project → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useProjectServiceAccount → TfArg<bool>?
final
zone → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited