BackupDrRestoreWorkloadNetworkPerformanceConfig class final

Typed helper for the compute_instance_restore_properties.network_performance_config block of google_backup_dr_restore_workload (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalEgressBandwidthTier → BackupDrRestoreWorkloadTotalEgressBandwidthTier?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited