BiglakeIcebergTableSortOrderFields class final

Typed helper for the sort_order.fields block of google_biglake_iceberg_table (derived from provider schema).

Annotations
  • @immutable

Constructors

BiglakeIcebergTableSortOrderFields({required TfArg<String> direction, required TfArg<String> nullOrder, required TfArg<num> sourceId, required TfArg<String> transform})
const

Properties

direction → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
nullOrder → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId → TfArg<num>
final
transform → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited