BigqueryAnalyticsHubListingSourcePubsubTopic class final
The BigqueryAnalyticsHubListingSource.pubsubTopic choice: sets pubsub_topic.
- Inheritance
-
- Object
- BigqueryAnalyticsHubListingSource
- BigqueryAnalyticsHubListingSourcePubsubTopic
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pubsubTopic → BigqueryAnalyticsHubListingPubsubTopic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited