BigqueryAnalyticsHubListingSubscriptionBigqueryConfig class final

Typed helper for the destination_pubsub_subscription.pubsub_subscription.bigquery_config block of google_bigquery_analytics_hub_listing_subscription (derived from provider schema).

Annotations
  • @immutable

Constructors

BigqueryAnalyticsHubListingSubscriptionBigqueryConfig({TfArg<bool>? dropUnknownFields, RefTo<GoogleServiceAccount>? serviceAccountEmail, TfArg<String>? table, TfArg<bool>? useTableSchema, TfArg<bool>? useTopicSchema, TfArg<bool>? writeMetadata})
const

Properties

dropUnknownFields → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountEmail → RefTo<GoogleServiceAccount>?
final
table → TfArg<String>?
final
useTableSchema → TfArg<bool>?
final
useTopicSchema → TfArg<bool>?
final
writeMetadata → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited