BigqueryConnectionConfigurationNetworkPrivateServiceConnect class

configuration.network.private_service_connect block — Private Service Connect network attachment for connector traffic.

Annotations
  • @immutable

Constructors

BigqueryConnectionConfigurationNetworkPrivateServiceConnect({required TfArg<String> networkAttachment})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
networkAttachment → TfArg<String>
Required. Network attachment resource name in the form projects/{project}/regions/{region}/networkAttachments/{networkAttachment}.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited