BigqueryConnectionSparkMetastoreServiceConfig class

spark.metastore_service_config block — optional binding to a Dataproc Metastore service so Spark stored procedures see Hive tables.

Annotations
  • @immutable

Constructors

BigqueryConnectionSparkMetastoreServiceConfig({TfArg<String>? metastoreService})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metastoreService → TfArg<String>?
Resource name of an existing Dataproc Metastore service in the form projects/{projectId}/locations/{region}/services/{serviceId}.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited