BigqueryDataTransferConfigScheduleOptions class final

Typed helper for the schedule_options block of google_bigquery_data_transfer_config (derived from provider schema).

Annotations
  • @immutable

Constructors

BigqueryDataTransferConfigScheduleOptions({TfArg<bool>? disableAutoScheduling, TfArg<String>? endTime, TfArg<String>? startTime})
const

Properties

disableAutoScheduling → TfArg<bool>?
final
endTime → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited