BigqueryDataTransferConfigSecretAccessKeyChoice class final
The BigqueryDataTransferConfigSecretAccessKey.secretAccessKey choice: sets secret_access_key.
- Inheritance
-
- Object
- BigqueryDataTransferConfigSecretAccessKey
- BigqueryDataTransferConfigSecretAccessKeyChoice
Constructors
-
BigqueryDataTransferConfigSecretAccessKeyChoice(Sensitive<
String> secretAccessKey) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretAccessKey
→ Sensitive<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited