BigqueryDatapolicyv2DataPolicyPredefinedExpression extension type
Predefined masking expression for V2 BigqueryDatapolicyv2DataPolicyDataMaskingPolicy.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- alwaysNull → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- dateYearMask → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- defaultMaskingValue → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- emailMask → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- firstFourCharacters → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- lastFourCharacters → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- randomHash → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
- sha256 → const BigqueryDatapolicyv2DataPolicyPredefinedExpression
-
values
→ const List<
BigqueryDatapolicyv2DataPolicyPredefinedExpression>