BigqueryDatasetAccessAuthorizedView class

view access block — an authorized view that may query this dataset.

Annotations
  • @immutable

Constructors

BigqueryDatasetAccessAuthorizedView({required TfArg<String> datasetId, required TfArg<String> projectId, required TfArg<String> tableId})
const

Properties

datasetId → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
projectId → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited