BigqueryDatasetDatasetAccessChild class

access.dataset sub-block — pairs a dataset reference with the targetTypes this binding applies to (currently only VIEWS).

Annotations
  • @immutable

Constructors

BigqueryDatasetDatasetAccessChild({required BigqueryDatasetDatasetReference dataset, required List<TfArg<String>> targetTypes})
const

Properties

dataset BigqueryDatasetDatasetReference
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetTypes List<TfArg<String>>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited