BigqueryDatasetDatasetRoutineRef class

access.routine sub-block — fully qualified BigQuery routine reference.

Annotations
  • @immutable

Constructors

BigqueryDatasetDatasetRoutineRef({required TfArg<String> projectId, required TfArg<String> datasetId, required TfArg<String> routineId})
const

Properties

datasetId → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
projectId → TfArg<String>
final
routineId → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited