BigqueryDatasetReference class

access.dataset.dataset and access.routine projectId+datasetId pair.

Annotations
  • @immutable

Constructors

BigqueryDatasetReference({required TfArg<String> projectId, required RefTo<GoogleBigqueryDataset> datasetId})
const

Properties

datasetId → RefTo<GoogleBigqueryDataset>
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited