BigqueryJobConfigurationLoad class final
The BigqueryJobConfiguration.load choice: sets load.
- Inheritance
-
- Object
- BigqueryJobConfiguration
- BigqueryJobConfigurationLoad
Constructors
- BigqueryJobConfigurationLoad(BigqueryJobLoad load)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- load → BigqueryJobLoad
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited