BigqueryJobParquetOptions class

load.parquet_options (max_items=1) — Parquet-specific load behavior.

Annotations
  • @immutable

Constructors

BigqueryJobParquetOptions({bool? enableListInference, bool? enumAsString})
const

Properties

enableListInference bool?
final
enumAsString bool?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited