BigqueryJobQueryConnectionProperty class

One entry under query.connection_properties(key, value) pair (e.g. ("time_zone", "America/Los_Angeles")).

Annotations
  • @immutable

Constructors

BigqueryJobQueryConnectionProperty({required TfArg<String> key, required TfArg<String> value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited