BigqueryJobScriptKeyResultStatement enum

query.script_options.key_result_statement. Possible values: ["LAST", "FIRST_SELECT"]. Determines which statement in the script populates the schema and query results of the script job.

Inheritance
Available extensions

Values

last → const BigqueryJobScriptKeyResultStatement
const BigqueryJobScriptKeyResultStatement('LAST')
firstSelect → const BigqueryJobScriptKeyResultStatement
const BigqueryJobScriptKeyResultStatement('FIRST_SELECT')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BigqueryJobScriptKeyResultStatement>
A constant List of the values in this enum, in order of their declaration.