BigqueryJobScriptOptions class final

Typed helper for the query.script_options block of google_bigquery_job (derived from provider schema).

Annotations
  • @immutable

Constructors

BigqueryJobScriptOptions({BigqueryJobKeyResultStatement? keyResultStatement, TfArg<String>? statementByteBudget, TfArg<String>? statementTimeoutMs})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyResultStatement → BigqueryJobKeyResultStatement?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementByteBudget → TfArg<String>?
final
statementTimeoutMs → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited