BigqueryJobUserDefinedFunctionResource class

One entry under query.user_defined_function_resources. Provide either resourceUri (GCS URI to a .js file) or inlineCode — not both.

Annotations
  • @immutable

Constructors

BigqueryJobUserDefinedFunctionResource({TfArg<String>? resourceUri, TfArg<String>? inlineCode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inlineCode → TfArg<String>?
Inline JavaScript UDF code.
final
resourceUri → TfArg<String>?
GCS URI of a JavaScript code file (gs://bucket/path.js).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited