BigqueryRoutineType enum
Type of routine for routine_type. BigQuery currently supports three
shapes at this provider version: scalar UDFs, stored procedures, and
table-valued functions.
Values
- scalarFunction → const BigqueryRoutineType
-
const BigqueryRoutineType('SCALAR_FUNCTION') - procedure → const BigqueryRoutineType
-
const BigqueryRoutineType('PROCEDURE') - tableValuedFunction → const BigqueryRoutineType
-
const BigqueryRoutineType('TABLE_VALUED_FUNCTION')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BigqueryRoutineType> - A constant List of the values in this enum, in order of their declaration.