BigqueryTableColumnReferences class

Inner column_references block of a foreign key constraint — pairs one referencing column with the referenced primary-key column.

Annotations
  • @immutable

Constructors

BigqueryTableColumnReferences({required TfArg<String> referencingColumn, required TfArg<String> referencedColumn})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
referencedColumn → TfArg<String>
final
referencingColumn → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited