BigqueryTableForeignKey class

One entry of table_constraints.foreign_keys. Each entry binds one referencing column to one referenced column in referencedTable; composite foreign keys are represented by multiple entries with the same referencedTable.

Annotations
  • @immutable

Constructors

BigqueryTableForeignKey({required BigqueryTableReferencedTable referencedTable, required BigqueryTableColumnReferences columnReferences, TfArg<String>? name})
const

Properties

columnReferences BigqueryTableColumnReferences
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
referencedTable BigqueryTableReferencedTable
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited