BigqueryTableGoogleSheetsOptions class final

Typed helper for the external_data_configuration.google_sheets_options block of google_bigquery_table (derived from provider schema).

Annotations
  • @immutable

Constructors

BigqueryTableGoogleSheetsOptions({TfArg<String>? range, TfArg<num>? skipLeadingRows})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
range → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipLeadingRows → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited