BigqueryTableHivePartitioningOptions class

external_data_configuration.hive_partitioning_options sub-block. Enables Hive-style partition keys (e.g. dt=2024-01-01/) to be surfaced as table columns.

Annotations
  • @immutable

Constructors

BigqueryTableHivePartitioningOptions({TfArg<String>? mode, TfArg<bool>? requirePartitionFilter, TfArg<String>? sourceUriPrefix})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mode → TfArg<String>?
final
requirePartitionFilter → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUriPrefix → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited