BigqueryTableRangePartitioningRange class

Inner range block of range_partitioning. Half-open: start is inclusive, end is exclusive. interval is the bucket width.

Annotations
  • @immutable

Constructors

BigqueryTableRangePartitioningRange({required TfArg<int> start, required TfArg<int> end, required TfArg<int> interval})
const

Properties

end → TfArg<int>
final
hashCode int
The hash code for this object.
no setterinherited
interval → TfArg<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start → TfArg<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited