BigqueryTableStorageDescriptor class final

Typed helper for the external_catalog_table_options.storage_descriptor block of google_bigquery_table (derived from provider schema).

Annotations
  • @immutable

Constructors

BigqueryTableStorageDescriptor({TfArg<String>? inputFormat, TfArg<String>? locationUri, TfArg<String>? outputFormat, BigqueryTableSerdeInfo? serdeInfo})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormat → TfArg<String>?
final
locationUri → TfArg<String>?
final
outputFormat → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serdeInfo → BigqueryTableSerdeInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited