BigtableAppProfileIsolationDataBoostIsolationReadOnly class final

The BigtableAppProfileIsolation.dataBoostIsolationReadOnly choice: sets data_boost_isolation_read_only.

Inheritance

Properties

dataBoostIsolationReadOnly → BigtableAppProfileDataBoostIsolationReadOnly
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited