BlockchainNodeEngineBlockchainNodesValidatorConfig class final

Typed helper for the ethereum_details.validator_config block of google_blockchain_node_engine_blockchain_nodes (derived from provider schema).

Annotations
  • @immutable

Constructors

BlockchainNodeEngineBlockchainNodesValidatorConfig({TfArg<String>? beaconFeeRecipient, TfArg<List<String>>? mevRelayUrls})
const

Properties

beaconFeeRecipient → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
mevRelayUrls → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited