CesAgentBeforeModelCallbacks class final
Typed helper for the before_model_callbacks block of
google_ces_agent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CesAgentBeforeModelCallbacks({TfArg<
String> ? description, TfArg<bool> ? disabled, required TfArg<String> pythonCode}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
disabled
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pythonCode
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited