CesAgentModelSettings class final

Typed helper for the model_settings block of google_ces_agent (derived from provider schema).

Annotations
  • @immutable

Constructors

CesAgentModelSettings({TfArg<String>? model, TfArg<num>? temperature})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
model → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited