CesAgentTransferRules class final

Typed helper for the transfer_rules block of google_ces_agent (derived from provider schema).

Annotations
  • @immutable

Constructors

CesAgentTransferRules({required TfArg<String> childAgent, required CesAgentDirection direction, CesAgentDeterministicTransfer? deterministicTransfer, CesAgentDisablePlannerTransfer? disablePlannerTransfer})
const

Properties

childAgent → TfArg<String>
final
deterministicTransfer → CesAgentDeterministicTransfer?
final
direction → CesAgentDirection
final
disablePlannerTransfer → CesAgentDisablePlannerTransfer?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited