CesAppAudioRecordingConfig class final

Typed helper for the logging_settings.audio_recording_config block of google_ces_app (derived from provider schema).

Annotations
  • @immutable

Constructors

CesAppAudioRecordingConfig({RefTo<GoogleStorageBucket>? gcsBucket, TfArg<String>? gcsPathPrefix})
const

Properties

gcsBucket → RefTo<GoogleStorageBucket>?
final
gcsPathPrefix → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited