CesAppEndSessionConfig class final

Typed helper for the error_handling_settings.end_session_config block of google_ces_app (derived from provider schema).

Annotations
  • @immutable

Constructors

CesAppEndSessionConfig({TfArg<bool>? escalateSession})
const

Properties

escalateSession → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited