CesAppToolMatchingSettings class final

Typed helper for the evaluation_metrics_thresholds.golden_evaluation_metrics_thresholds.tool_matching_settings block of google_ces_app (derived from provider schema).

Annotations
  • @immutable

Constructors

CesAppToolMatchingSettings({CesAppExtraToolCallBehavior? extraToolCallBehavior})
const

Properties

extraToolCallBehavior → CesAppExtraToolCallBehavior?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited