CesExampleMessagesChunks class final

Typed helper for the messages.chunks block of google_ces_example (derived from provider schema).

Annotations
  • @immutable

Constructors

CesExampleMessagesChunks({TfArg<String>? text, TfArg<String>? updatedVariables, CesExampleMessagesChunksAgentTransfer? agentTransfer, CesExampleMessagesChunksImage? image, CesExampleMessagesChunksToolCall? toolCall, CesExampleMessagesChunksToolResponse? toolResponse})
const

Properties

agentTransfer CesExampleMessagesChunksAgentTransfer?
final
hashCode int
The hash code for this object.
no setterinherited
image CesExampleMessagesChunksImage?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text → TfArg<String>?
final
toolCall CesExampleMessagesChunksToolCall?
final
toolResponse CesExampleMessagesChunksToolResponse?
final
updatedVariables → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited