CesExampleMessagesChunksToolResponse class final
Typed helper for the messages.chunks.tool_response block of
google_ces_example (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CesExampleMessagesChunksToolResponse({TfArg<
String> ? id, required TfArg<String> response, TfArg<String> ? tool, CesExampleMessagesChunksToolResponseToolsetTool? toolsetTool}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> ? -
final
-
response
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tool
→ TfArg<
String> ? -
final
- toolsetTool → CesExampleMessagesChunksToolResponseToolsetTool?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited