CesGuardrailAction class final

Typed helper for the action block of google_ces_guardrail (derived from provider schema).

Annotations
  • @immutable

Constructors

CesGuardrailAction({CesGuardrailActionGenerativeAnswer? generativeAnswer, CesGuardrailActionRespondImmediately? respondImmediately, CesGuardrailActionTransferAgent? transferAgent})
const

Properties

generativeAnswer CesGuardrailActionGenerativeAnswer?
final
hashCode int
The hash code for this object.
no setterinherited
respondImmediately CesGuardrailActionRespondImmediately?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferAgent CesGuardrailActionTransferAgent?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited