CesToolDataStoreSources class final
Typed helper for the data_store_tool.engine_source.data_store_sources block of
google_ces_tool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CesToolDataStoreSources({TfArg<
String> ? filter, CesToolDataStore? dataStore}) -
const
Properties
- dataStore → CesToolDataStore?
-
final
-
filter
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited