CesToolDataStoreTool class final

Typed helper for the data_store_tool block of google_ces_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

CesToolDataStoreTool({TfArg<String>? description, TfArg<CesToolDataStoreToolFilterParameterBehavior>? filterParameterBehavior, TfArg<num>? maxResults, required TfArg<String> name, List<CesToolDataStoreToolBoostSpecs>? boostSpecs, CesToolDataStoreToolDataStoreSource? dataStoreSource, CesToolDataStoreToolEngineSource? engineSource, List<CesToolDataStoreToolModalityConfigs>? modalityConfigs})
const

Properties

boostSpecs List<CesToolDataStoreToolBoostSpecs>?
final
dataStoreSource CesToolDataStoreToolDataStoreSource?
final
description → TfArg<String>?
final
engineSource CesToolDataStoreToolEngineSource?
final
filterParameterBehavior → TfArg<CesToolDataStoreToolFilterParameterBehavior>?
final
hashCode int
The hash code for this object.
no setterinherited
maxResults → TfArg<num>?
final
modalityConfigs List<CesToolDataStoreToolModalityConfigs>?
final
name → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited