CesToolEngineSource class final

Typed helper for the data_store_tool.engine_source block of google_ces_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

CesToolEngineSource({required TfArg<String> engine, TfArg<String>? filter, List<CesToolDataStoreSources>? dataStoreSources})
const

Properties

dataStoreSources → List<CesToolDataStoreSources>?
final
engine → TfArg<String>
final
filter → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited