CesToolFileSearchTool class final

Typed helper for the file_search_tool block of google_ces_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

CesToolFileSearchTool({CesToolCorpusType? corpusType, TfArg<String>? description, TfArg<String>? fileCorpus, required TfArg<String> name})
const

Properties

corpusType → CesToolCorpusType?
final
description → TfArg<String>?
final
fileCorpus → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited