CesToolGoogleSearchToolPromptConfig class final

Typed helper for the google_search_tool.prompt_config block of google_ces_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

CesToolGoogleSearchToolPromptConfig({TfArg<String>? textPrompt, TfArg<String>? voicePrompt})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textPrompt → TfArg<String>?
final
voicePrompt → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited