CesToolsetApiKeyConfig class final
Typed helper for the mcp_toolset.api_authentication.api_key_config block of
google_ces_toolset (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
Properties
-
apiKeySecretVersion
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyName
→ TfArg<
String> -
final
-
requestLocation
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited