CesToolsetConnectorToolsetAuthConfig class final
Typed helper for the connector_toolset.auth_config block of
google_ces_toolset (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- CesToolsetConnectorToolsetAuthConfig({CesToolsetConnectorToolsetAuthConfigOauth2AuthCodeConfig? oauth2AuthCodeConfig, CesToolsetConnectorToolsetAuthConfigOauth2JwtBearerConfig? oauth2JwtBearerConfig})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauth2AuthCodeConfig → CesToolsetConnectorToolsetAuthConfigOauth2AuthCodeConfig?
-
final
- oauth2JwtBearerConfig → CesToolsetConnectorToolsetAuthConfigOauth2JwtBearerConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited