CesToolsetOpenApiToolsetApiAuthentication class final
Typed helper for the open_api_toolset.api_authentication block of
google_ces_toolset (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- CesToolsetOpenApiToolsetApiAuthentication({CesToolsetOpenApiToolsetApiAuthenticationApiKeyConfig? apiKeyConfig, CesToolsetOpenApiToolsetApiAuthenticationBearerTokenConfig? bearerTokenConfig, CesToolsetOpenApiToolsetApiAuthenticationOauthConfig? oauthConfig, CesToolsetOpenApiToolsetApiAuthenticationServiceAccountAuthConfig? serviceAccountAuthConfig, CesToolsetOpenApiToolsetApiAuthenticationServiceAgentIdTokenAuthConfig? serviceAgentIdTokenAuthConfig})
-
const
Properties
- apiKeyConfig → CesToolsetOpenApiToolsetApiAuthenticationApiKeyConfig?
-
final
- bearerTokenConfig → CesToolsetOpenApiToolsetApiAuthenticationBearerTokenConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauthConfig → CesToolsetOpenApiToolsetApiAuthenticationOauthConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountAuthConfig → CesToolsetOpenApiToolsetApiAuthenticationServiceAccountAuthConfig?
-
final
- serviceAgentIdTokenAuthConfig → CesToolsetOpenApiToolsetApiAuthenticationServiceAgentIdTokenAuthConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited