ChronicleBigQueryExportEntityGraphSettings class final

Typed helper for the entity_graph_settings block of google_chronicle_big_query_export (derived from provider schema).

Annotations
  • @immutable

Constructors

ChronicleBigQueryExportEntityGraphSettings({required TfArg<bool> enabled, required TfArg<num> retentionDays})
const

Properties

enabled → TfArg<bool>
final
hashCode int
The hash code for this object.
no setterinherited
retentionDays → TfArg<num>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited