CloudBuildTriggerLogStreamingOption enum

build.options.log_streaming_option. streamDefault uses the project-default log streaming behavior; streamOn forces logs to stream live (visible in the Cloud Build console while the build is running); streamOff suppresses live streaming.

Inheritance
Available extensions

Values

streamDefault → const CloudBuildTriggerLogStreamingOption
const CloudBuildTriggerLogStreamingOption('STREAM_DEFAULT')
streamOn → const CloudBuildTriggerLogStreamingOption
const CloudBuildTriggerLogStreamingOption('STREAM_ON')
streamOff → const CloudBuildTriggerLogStreamingOption
const CloudBuildTriggerLogStreamingOption('STREAM_OFF')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudBuildTriggerLogStreamingOption>
A constant List of the values in this enum, in order of their declaration.