secret property

TfArg<String> secret
final

Resource name of the Secret Manager secret holding the URL signing token. Format: 'projects/{project}/secrets/{secret}/versions/{version}'. Callers attaching the trigger to a webhook must supply the secret's plaintext value in the request as a query string parameter named secret.

Implementation

final TfArg<String> secret;