CloudRunServiceLocalObjectReference class final

Typed helper for the template.spec.containers.env_from.config_map_ref.local_object_reference block of google_cloud_run_service (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

CloudRunServiceLocalObjectReference({required TfArg<String> name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited