CloudRunServiceTemplateSpecContainersEnvValueFrom class final
Typed helper for the template.spec.containers.env.value_from block of
google_cloud_run_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- CloudRunServiceTemplateSpecContainersEnvValueFrom({required CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef secretKeyRef})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKeyRef → CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited