CloudRunServiceTemplateSpecContainersLivenessProbeHttpGet class final
Typed helper for the template.spec.containers.liveness_probe.http_get block of
google_cloud_run_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudRunServiceTemplateSpecContainersLivenessProbeHttpGet({TfArg<
String> ? path, TfArg<num> ? port, List<CloudRunServiceTemplateSpecContainersLivenessProbeHttpGetHttpHeaders> ? httpHeaders}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
httpHeaders
→ List<
CloudRunServiceTemplateSpecContainersLivenessProbeHttpGetHttpHeaders> ? -
final
-
path
→ TfArg<
String> ? -
final
-
port
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited