CloudRunV2JobContainers class final
Typed helper for the template.template.containers block of
google_cloud_run_v2_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudRunV2JobContainers({TfArg<
List< ? args, TfArg<String> >List< ? command, TfArg<String> >List< ? dependsOn, required TfArg<String> >String> image, TfArg<String> ? name, TfArg<bool> ? sandboxLauncher, TfArg<String> ? workingDir, List<CloudRunV2JobEnv> ? env, List<CloudRunV2JobPorts> ? ports, CloudRunV2JobResources? resources, CloudRunV2JobStartupProbe? startupProbe, List<CloudRunV2JobVolumeMounts> ? volumeMounts}) -
const
Properties
-
args
→ TfArg<
List< ?String> > -
final
-
command
→ TfArg<
List< ?String> > -
final
-
dependsOn
→ TfArg<
List< ?String> > -
final
-
env
→ List<
CloudRunV2JobEnv> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
image
→ TfArg<
String> -
final
-
name
→ TfArg<
String> ? -
final
-
ports
→ List<
CloudRunV2JobPorts> ? -
final
- resources → CloudRunV2JobResources?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sandboxLauncher
→ TfArg<
bool> ? -
final
- startupProbe → CloudRunV2JobStartupProbe?
-
final
-
volumeMounts
→ List<
CloudRunV2JobVolumeMounts> ? -
final
-
workingDir
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited