CloudRunV2JobValueSource class final

Typed helper for the template.template.containers.env.value_source block of google_cloud_run_v2_job (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudRunV2JobValueSource({CloudRunV2JobSecretKeyRef? secretKeyRef})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKeyRef → CloudRunV2JobSecretKeyRef?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited