CloudRunV2ServiceBuildConfig class final

Typed helper for the build_config block of google_cloud_run_v2_service (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudRunV2ServiceBuildConfig({TfArg<String>? baseImage, TfArg<bool>? enableAutomaticUpdates, TfArg<Map<String, String>>? environmentVariables, TfArg<String>? functionTarget, TfArg<String>? imageUri, RefTo<GoogleServiceAccount>? serviceAccount, TfArg<String>? sourceLocation, TfArg<String>? workerPool})
const

Properties

baseImage → TfArg<String>?
final
enableAutomaticUpdates → TfArg<bool>?
final
environmentVariables → TfArg<Map<String, String>>?
final
functionTarget → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
imageUri → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → RefTo<GoogleServiceAccount>?
final
sourceLocation → TfArg<String>?
final
workerPool → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited