CloudRunV2ServiceEmptyDirVolume class final

Ephemeral shared volume (empty_dir). Lives only as long as the revision instance.

Inheritance
Annotations
  • @immutable

Constructors

CloudRunV2ServiceEmptyDirVolume({TfArg<EmptyDirMedium>? medium, TfArg<String>? sizeLimit})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
medium → TfArg<EmptyDirMedium>?
Storage backing. Default MEMORY.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeLimit → TfArg<String>?
Cap (Kubernetes Quantity, e.g. '500Mi').
final

Methods

encode() Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited