CloudRunV2ServiceHttpGetAction class
http_get probe action.
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceHttpGetAction({TfArg<
String> ? path, TfArg<int> ? port, List<CloudRunV2ServiceHttpHeader> ? httpHeaders}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
httpHeaders
→ List<
CloudRunV2ServiceHttpHeader> ? -
Custom request headers (HTTP allows repeats).
final
-
path
→ TfArg<
String> ? -
Path on the HTTP server. Default
'/'.final -
port
→ TfArg<
int> ? -
Port to probe. Default is the container port.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited