CloudRunV2ServiceHttpHeader class

One http_headers entry under CloudRunV2ServiceHttpGetAction.httpHeaders.

Annotations
  • @immutable

Constructors

CloudRunV2ServiceHttpHeader({required TfArg<String> name, TfArg<String>? value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
Header field name. Required.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>?
Header field value. Defaults to empty string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited