CloudRunV2ServiceLivenessProbe class

liveness_probe block. Restarts the container on failure. Same shape as CloudRunV2ServiceStartupProbe but uses liveness semantics (probe is gated AFTER startup).

Annotations
  • @immutable

Constructors

CloudRunV2ServiceLivenessProbe({TfArg<int>? initialDelaySeconds, TfArg<int>? timeoutSeconds, TfArg<int>? periodSeconds, TfArg<int>? failureThreshold, CloudRunV2ServiceHttpGetAction? httpGet, CloudRunV2ServiceTcpSocketAction? tcpSocket, Map<String, Object?>? grpc})
const

Properties

failureThreshold → TfArg<int>?
final
grpc Map<String, Object?>?
final
hashCode int
The hash code for this object.
no setterinherited
httpGet CloudRunV2ServiceHttpGetAction?
final
initialDelaySeconds → TfArg<int>?
final
periodSeconds → TfArg<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tcpSocket CloudRunV2ServiceTcpSocketAction?
final
timeoutSeconds → TfArg<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited