CloudRunV2ServiceNetworkInterfaces class final
Typed helper for the template.vpc_access.network_interfaces block of
google_cloud_run_v2_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceNetworkInterfaces({RefTo<
GoogleComputeNetwork> ? network, RefTo<GoogleComputeSubnetwork> ? subnetwork, TfArg<List< ? tags})String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
network
→ RefTo<
GoogleComputeNetwork> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetwork
→ RefTo<
GoogleComputeSubnetwork> ? -
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited