CloudRunV2ServiceResources class final

Typed helper for the template.containers.resources block of google_cloud_run_v2_service (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudRunV2ServiceResources({TfArg<bool>? cpuIdle, TfArg<Map<String, String>>? limits, TfArg<bool>? startupCpuBoost})
const

Properties

cpuIdle → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
limits → TfArg<Map<String, String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startupCpuBoost → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited