CloudRunV2ServiceVpcAccess class final

Typed helper for the template.vpc_access block of google_cloud_run_v2_service (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudRunV2ServiceVpcAccess({CloudRunV2ServiceConnection? connection, VpcAccessEgress? egress})
const

Properties

connection → CloudRunV2ServiceConnection?
final
egress → VpcAccessEgress?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited