CloudRunV2WorkerPoolEnvValueSource class final

The CloudRunV2WorkerPoolEnvSource.valueSource choice: sets value_source.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueSource → CloudRunV2WorkerPoolValueSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited