CloudRunV2WorkerPoolSourceSecret class final

The CloudRunV2WorkerPoolSource.secret choice: sets secret.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → CloudRunV2WorkerPoolSecret
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited