CloudSchedulerJobAppEngineHttpTarget class final

Typed helper for the app_engine_http_target block of google_cloud_scheduler_job (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudSchedulerJobAppEngineHttpTarget({TfArg<String>? body, TfArg<Map<String, String>>? headers, TfArg<String>? httpMethod, required TfArg<String> relativeUri, CloudSchedulerJobAppEngineRouting? appEngineRouting})
const

Properties

appEngineRouting → CloudSchedulerJobAppEngineRouting?
final
body → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → TfArg<Map<String, String>>?
final
httpMethod → TfArg<String>?
final
relativeUri → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited