CloudSecurityComplianceCloudControlParameterSpecSubParametersValidationAllowedValuesValues class final

Typed helper for the parameter_spec.sub_parameters.validation.allowed_values.values block of google_cloud_security_compliance_cloud_control (derived from provider schema).

Annotations
  • @immutable

Properties

boolValue → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
numberValue → TfArg<num>?
final
oneofValue CloudSecurityComplianceCloudControlParameterSpecSubParametersValidationAllowedValuesValuesOneofValue?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringListValue CloudSecurityComplianceCloudControlParameterSpecSubParametersValidationAllowedValuesValuesStringListValue?
final
stringValue → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited