CloudTasksQueueRetryConfig class

retry_config block (Cloud Tasks queue-level retry policy).

Annotations
  • @immutable

Constructors

CloudTasksQueueRetryConfig({TfArg<int>? maxAttempts, TfArg<String>? maxRetryDuration, TfArg<String>? minBackoff, TfArg<String>? maxBackoff, TfArg<int>? maxDoublings})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxAttempts → TfArg<int>?
final
maxBackoff → TfArg<String>?
final
maxDoublings → TfArg<int>?
final
maxRetryDuration → TfArg<String>?
final
minBackoff → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited