CloudbuildTriggerBuildSpec class sealed

Mutually exclusive build-spec sources per MM exactly_one_of.

Implementers

Properties

blockKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotValue → TfArg
Value written to blockKey in the parent argMap (scalar or block list).
no setter

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited