CloudbuildTriggerDeveloperConnectEventConfig class final

Typed helper for the developer_connect_event_config block of google_cloudbuild_trigger (derived from provider schema).

Annotations
  • @immutable

Properties

final
hashCode → int
The hash code for this object.
no setterinherited
pullRequest → CloudbuildTriggerDeveloperConnectEventConfigPullRequest?
final
push → CloudbuildTriggerDeveloperConnectEventConfigPush?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited