Cloudbuildv2ConnectionGithubConfig class

github_config block. Use for connections to github.com (the public GitHub host). For GitHub Enterprise Server pick Cloudbuildv2ConnectionGithubEnterpriseConfig instead.

Annotations
  • @immutable

Constructors

Cloudbuildv2ConnectionGithubConfig({TfArg<int>? appInstallationId, Cloudbuildv2ConnectionGithubAuthorizerCredential? authorizerCredential})
const

Properties

appInstallationId → TfArg<int>?
GitHub App installation id (the numeric id GitHub assigns when the Cloud Build GitHub App is installed on a user / organization).
final
authorizerCredential Cloudbuildv2ConnectionGithubAuthorizerCredential?
Nested OAuth authorizer credential.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited