Cloudbuildv2ConnectionHostGithubEnterpriseConfig class final
The Cloudbuildv2ConnectionHost.githubEnterpriseConfig choice: sets github_enterprise_config.
- Inheritance
-
- Object
- Cloudbuildv2ConnectionHost
- Cloudbuildv2ConnectionHostGithubEnterpriseConfig
Constructors
- Cloudbuildv2ConnectionHostGithubEnterpriseConfig(Cloudbuildv2ConnectionGithubEnterpriseConfig githubEnterpriseConfig)
-
const
Properties
- githubEnterpriseConfig → Cloudbuildv2ConnectionGithubEnterpriseConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited