ClouddeployAutomationRulesTimedPromoteReleaseRule class final

The ClouddeployAutomationRules.timedPromoteReleaseRule choice: sets timed_promote_release_rule.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timedPromoteReleaseRule → ClouddeployAutomationTimedPromoteReleaseRule
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited