ClouddeployCustomTargetTypeIncludeSkaffoldModules class final

Typed helper for the custom_actions.include_skaffold_modules block of google_clouddeploy_custom_target_type (derived from provider schema).

Annotations
  • @immutable

Properties

configs → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ClouddeployCustomTargetTypeSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited