ClouddeployDeployPolicyTimeWindows class final

Typed helper for the rules.rollout_restriction.time_windows block of google_clouddeploy_deploy_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ClouddeployDeployPolicyTimeWindows({required TfArg<String> timeZone, List<ClouddeployDeployPolicyOneTimeWindows>? oneTimeWindows, List<ClouddeployDeployPolicyWeeklyWindows>? weeklyWindows})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
oneTimeWindows → List<ClouddeployDeployPolicyOneTimeWindows>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone → TfArg<String>
final
weeklyWindows → List<ClouddeployDeployPolicyWeeklyWindows>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited