ClouddeployTargetAssociatedEntities class final

Typed helper for the associated_entities block of google_clouddeploy_target (derived from provider schema).

Annotations
  • @immutable

Constructors

ClouddeployTargetAssociatedEntities({required TfArg<String> entityId, List<ClouddeployTargetAnthosClusters>? anthosClusters, List<ClouddeployTargetGkeClusters>? gkeClusters})
const

Properties

anthosClusters → List<ClouddeployTargetAnthosClusters>?
final
entityId → TfArg<String>
final
gkeClusters → List<ClouddeployTargetGkeClusters>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited