workerPool property
Cloud Build Custom Worker Pool resource path. Required when the build must run inside a VPC perimeter.
Implementation
final TfArg<String>? workerPool;
Cloud Build Custom Worker Pool resource path. Required when the build must run inside a VPC perimeter.
final TfArg<String>? workerPool;