Cloudfunctions2FunctionEventTrigger class final

Typed helper for the event_trigger block of google_cloudfunctions2_function (derived from provider schema).

Annotations
  • @immutable

Constructors

Cloudfunctions2FunctionEventTrigger({required TfArg<String> eventType, RefTo<GooglePubsubTopic>? pubsubTopic, EventTriggerRetryPolicy? retryPolicy, RefTo<GoogleServiceAccount>? serviceAccountEmail, TfArg<String>? triggerRegion, List<Cloudfunctions2FunctionEventFilters>? eventFilters})
const

Properties

eventFilters → List<Cloudfunctions2FunctionEventFilters>?
final
eventType → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
pubsubTopic → RefTo<GooglePubsubTopic>?
final
retryPolicy → EventTriggerRetryPolicy?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountEmail → RefTo<GoogleServiceAccount>?
final
triggerRegion → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited