Cloudfunctions2FunctionRevisionTagName class final

The Cloudfunctions2FunctionRevision.tagName choice: sets tag_name.

Inheritance

Constructors

Cloudfunctions2FunctionRevisionTagName(TfArg<String> tagName)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagName → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited