Cloudfunctions2FunctionSecretVolumeVersion class

One entry in secret_volumes.versions. Maps a specific secret version to a relative path under the volume mount.

Annotations
  • @immutable

Constructors

Cloudfunctions2FunctionSecretVolumeVersion({required TfArg<String> path, required TfArg<String> version})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path → TfArg<String>
Relative path within the volume.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version → TfArg<String>
Secret version ('latest' or numeric).
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited