ColabNotebookExecutionCustomCompute class final

custom_environment_spec nested block (literal map matching provider).

Inheritance
Annotations
  • @immutable

Constructors

ColabNotebookExecutionCustomCompute(TfArg<Map<String, Object?>> customEnvironmentSpec)
const

Properties

blockKey String
no setteroverride
customEnvironmentSpec → TfArg<Map<String, Object?>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
Flat {blockKey: value} for Gate 6 / dynamic argMap dispatch.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited