ColabNotebookExecutionDataformRepositorySource class final
Typed helper for the dataform_repository_source block of
google_colab_notebook_execution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ColabNotebookExecutionDataformRepositorySource({TfArg<
String> ? commitSha, required TfArg<String> dataformRepositoryResourceName}) -
const
Properties
-
commitSha
→ TfArg<
String> ? -
final
-
dataformRepositoryResourceName
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited