ColabNotebookExecutionDirectSource class final

direct_notebook_source — base64 ipynb content.

Inheritance
Annotations
  • @immutable

Constructors

ColabNotebookExecutionDirectSource({required TfArg<String> content})
const

Properties

blockKey String
no setteroverride
content → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() List<Map<String, Object?>>
Single-element list (nesting_mode: list, max_items: 1).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited