ColabNotebookExecutionIdentity class sealed

Exactly one execution identity (execution_user or service_account).

Implementers

Constructors

ColabNotebookExecutionIdentity.executionUser(TfArg<String> executionUser)
const
factory
ColabNotebookExecutionIdentity.serviceAccount(TfArg<String> serviceAccount)
const
factory

Properties

blockKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
no setter

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited