ColabNotebookExecutionTemplateCompute class final
notebook_runtime_template_resource_name attribute.
- Inheritance
-
- Object
- ColabNotebookExecutionCompute
- ColabNotebookExecutionTemplateCompute
- Annotations
-
- @immutable
Constructors
-
ColabNotebookExecutionTemplateCompute(TfArg<
String> notebookRuntimeTemplateResourceName) -
const
Properties
- blockKey → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notebookRuntimeTemplateResourceName
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
Flat
{blockKey: value}for Gate 6 / dynamic argMap dispatch.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited