ColabScheduleNotebookExecutionJob class final

Typed helper for the create_notebook_execution_job_request.notebook_execution_job block of google_colab_schedule (derived from provider schema).

Annotations
  • @immutable

Constructors

ColabScheduleNotebookExecutionJob({required TfArg<String> displayName, TfArg<String>? executionTimeout, required ColabScheduleIdentity identity, required TfArg<String> gcsOutputUri, TfArg<String>? kernelName, TfArg<Map<String, String>>? labels, required ColabScheduleCompute compute, required ColabScheduleSource source, ColabScheduleEncryptionSpec? encryptionSpec, ColabScheduleWorkbenchRuntime? workbenchRuntime})
const

Properties

compute → ColabScheduleCompute
final
displayName → TfArg<String>
final
encryptionSpec → ColabScheduleEncryptionSpec?
final
executionTimeout → TfArg<String>?
final
gcsOutputUri → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
identity → ColabScheduleIdentity
final
kernelName → TfArg<String>?
final
labels → TfArg<Map<String, String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ColabScheduleSource
final
workbenchRuntime → ColabScheduleWorkbenchRuntime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited