Comparison enum

Comparison operator for condition_threshold.comparison and condition_sql.row_count_test.comparison.

Inheritance
Available extensions

Values

gt → const Comparison
const Comparison('COMPARISON_GT')
ge → const Comparison
const Comparison('COMPARISON_GE')
lt → const Comparison
const Comparison('COMPARISON_LT')
le → const Comparison
const Comparison('COMPARISON_LE')
eq → const Comparison
const Comparison('COMPARISON_EQ')
ne → const Comparison
const Comparison('COMPARISON_NE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Comparison>
A constant List of the values in this enum, in order of their declaration.