ComposerEnvironmentConfigDataRetentionConfig class final

Typed helper for the config.data_retention_config block of google_composer_environment (derived from provider schema).

Annotations
  • @immutable

Properties

airflowMetadataRetentionConfig List<ComposerEnvironmentConfigDataRetentionConfigAirflowMetadataRetentionConfig>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskLogsRetentionConfig List<ComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited