ComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks class final
Typed helper for the config.master_authorized_networks_config.cidr_blocks block of
google_composer_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks({required TfArg<
String> cidrBlock, TfArg<String> ? displayName}) -
const
Properties
-
cidrBlock
→ TfArg<
String> -
final
-
displayName
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited