ComposerEnvironmentConfigNodeConfig class final

Typed helper for the config.node_config block of google_composer_environment (derived from provider schema).

Annotations
  • @immutable

Constructors

ComposerEnvironmentConfigNodeConfig({TfArg<String>? composerInternalIpv4CidrBlock, TfArg<String>? composerNetworkAttachment, TfArg<num>? diskSizeGb, TfArg<bool>? enableIpMasqAgent, TfArg<String>? machineType, TfArg<String>? network, TfArg<List<Object?>>? oauthScopes, TfArg<String>? serviceAccount, TfArg<String>? subnetwork, TfArg<List<Object?>>? tags, TfArg<String>? zone, ComposerEnvironmentConfigNodeConfigIpAllocationPolicy? ipAllocationPolicy})
const

Properties

composerInternalIpv4CidrBlock → TfArg<String>?
final
composerNetworkAttachment → TfArg<String>?
final
diskSizeGb → TfArg<num>?
final
enableIpMasqAgent → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
ipAllocationPolicy ComposerEnvironmentConfigNodeConfigIpAllocationPolicy?
final
machineType → TfArg<String>?
final
network → TfArg<String>?
final
oauthScopes → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → TfArg<String>?
final
subnetwork → TfArg<String>?
final
tags → TfArg<List<Object?>>?
final
zone → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited