ComposerEnvironmentDagProcessor class final

Typed helper for the config.workloads_config.dag_processor block of google_composer_environment (derived from provider schema).

Annotations
  • @immutable

Constructors

ComposerEnvironmentDagProcessor({TfArg<num>? count, TfArg<num>? cpu, TfArg<num>? memoryGb, TfArg<num>? storageGb})
const

Properties

count → TfArg<num>?
final
cpu → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
memoryGb → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageGb → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited