ComposerEnvironmentDatabaseConfig class final

Typed helper for the config.database_config block of google_composer_environment (derived from provider schema).

Annotations
  • @immutable

Constructors

ComposerEnvironmentDatabaseConfig({TfArg<String>? machineType, TfArg<String>? zone})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
machineType → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited