ComposerEnvironmentMasterAuthorizedNetworksConfig class final
Typed helper for the config.master_authorized_networks_config block of
google_composer_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComposerEnvironmentMasterAuthorizedNetworksConfig({required TfArg<
bool> enabled, List<ComposerEnvironmentCidrBlocks> ? cidrBlocks}) -
const
Properties
-
cidrBlocks
→ List<
ComposerEnvironmentCidrBlocks> ? -
final
-
enabled
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited