ComposerEnvironmentWebServerNetworkAccessControl class final
Typed helper for the config.web_server_network_access_control block of
google_composer_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComposerEnvironmentWebServerNetworkAccessControl({List<
ComposerEnvironmentAllowedIpRange> ? allowedIpRange}) -
const
Properties
-
allowedIpRange
→ List<
ComposerEnvironmentAllowedIpRange> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited