ComputeBackendBucketBackendBucketCdnBypassCacheOnRequestHeader class

Cache-bypass rule keyed on a request header name (one entry in cdn_policy.bypass_cache_on_request_headers, max 5 entries).

Annotations
  • @immutable

Constructors

ComputeBackendBucketBackendBucketCdnBypassCacheOnRequestHeader({required TfArg<String> headerName})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
Header field name (case-insensitive).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited