ComputeBackendBucketBackendBucketCdnNegativeCachingPolicy class

One row in cdn_policy.negative_caching_policy.

Annotations
  • @immutable

Constructors

ComputeBackendBucketBackendBucketCdnNegativeCachingPolicy({TfArg<int>? code, TfArg<int>? ttl})
const

Properties

code → TfArg<int>?
HTTP status code to apply a TTL to. Valid values per schema: 300, 301, 308, 404, 405, 410, 421, 451, 501. Each code may appear at most once.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl → TfArg<int>?
TTL in seconds. Max allowed value 1800 (30 minutes).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited