ComputeBackendServiceBackend class final

Typed helper for the backend block of google_compute_backend_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeBackendServiceBackend({BackendServiceBalancingMode? balancingMode, TfArg<num>? capacityScaler, TfArg<String>? description, required TfArg<String> group, TfArg<num>? maxConnections, TfArg<num>? maxConnectionsPerEndpoint, TfArg<num>? maxConnectionsPerInstance, TfArg<num>? maxRate, TfArg<num>? maxRatePerEndpoint, TfArg<num>? maxRatePerInstance, TfArg<num>? maxUtilization, BackendServicePreference? preference, List<ComputeBackendServiceBackendCustomMetrics>? customMetrics})
const

Properties

balancingMode → BackendServiceBalancingMode?
final
capacityScaler → TfArg<num>?
final
customMetrics → List<ComputeBackendServiceBackendCustomMetrics>?
final
description → TfArg<String>?
final
group → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
maxConnections → TfArg<num>?
final
maxConnectionsPerEndpoint → TfArg<num>?
final
maxConnectionsPerInstance → TfArg<num>?
final
maxRate → TfArg<num>?
final
maxRatePerEndpoint → TfArg<num>?
final
maxRatePerInstance → TfArg<num>?
final
maxUtilization → TfArg<num>?
final
preference → BackendServicePreference?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited