ComputeBackendServiceBackendServiceCdnPolicy class
cdn_policy block. Only honored when enableCdn is true.
- Annotations
-
- @immutable
Constructors
-
ComputeBackendServiceBackendServiceCdnPolicy({BackendServiceCacheMode? cacheMode, TfArg<
int> ? clientTtl, TfArg<int> ? defaultTtl, TfArg<int> ? maxTtl, TfArg<bool> ? negativeCaching, TfArg<bool> ? requestCoalescing, TfArg<int> ? serveWhileStale, TfArg<int> ? signedUrlCacheMaxAgeSec, List<ComputeBackendServiceBackendServiceCdnBypassCacheOnRequestHeader> ? bypassCacheOnRequestHeaders, ComputeBackendServiceBackendServiceCdnCacheKeyPolicy? cacheKeyPolicy, List<ComputeBackendServiceBackendServiceCdnNegativeCachingPolicy> ? negativeCachingPolicy}) -
const
Properties
-
bypassCacheOnRequestHeaders
→ List<
ComputeBackendServiceBackendServiceCdnBypassCacheOnRequestHeader> ? -
Bypass cache when any of these request headers is present.
final
- cacheKeyPolicy → ComputeBackendServiceBackendServiceCdnCacheKeyPolicy?
-
Cache key policy — which request components participate in the
cache key.
final
- cacheMode → BackendServiceCacheMode?
-
Cache mode. Defaults to
CACHE_ALL_STATICwhen CDN is enabled.final -
clientTtl
→ TfArg<
int> ? -
Max TTL (seconds) for content served to clients.
final
-
defaultTtl
→ TfArg<
int> ? -
Default TTL for cached content with no upstream
Cache-Control.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
maxTtl
→ TfArg<
int> ? -
Hard ceiling on cached content TTL.
final
-
negativeCaching
→ TfArg<
bool> ? -
Negative caching for selected status codes.
final
-
negativeCachingPolicy
→ List<
ComputeBackendServiceBackendServiceCdnNegativeCachingPolicy> ? -
Per-status-code negative-cache TTLs. Only honored when
negativeCaching is
true.final -
requestCoalescing
→ TfArg<
bool> ? -
Coalesce concurrent cache-fill requests to the origin.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serveWhileStale
→ TfArg<
int> ? -
Serve cached content during origin revalidation/errors (seconds).
final
-
signedUrlCacheMaxAgeSec
→ TfArg<
int> ? -
TTL for signed-URL responses (defaults to 3600).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited