ComputeBackendServiceBackendServiceConsistentHash class

consistent_hash block. Only meaningful when LocalityLbPolicy is ringHash or maglev.

Annotations
  • @immutable

Constructors

ComputeBackendServiceBackendServiceConsistentHash({TfArg<String>? httpHeaderName, TfArg<int>? minimumRingSize, ComputeBackendServiceBackendServiceConsistentHashHttpCookie? httpCookie})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
httpCookie ComputeBackendServiceBackendServiceConsistentHashHttpCookie?
Hash on a named HTTP cookie.
final
httpHeaderName → TfArg<String>?
Hash on the named HTTP header.
final
minimumRingSize → TfArg<int>?
Minimum ring size for RING_HASH. Default 1024.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited