ComputeBackendServiceBackendServiceConsistentHashHttpCookie class
consistent_hash.http_cookie (max_items=1).
- Annotations
-
- @immutable
Constructors
-
ComputeBackendServiceBackendServiceConsistentHashHttpCookie({TfArg<
String> ? name, TfArg<String> ? path, ComputeBackendServiceBackendServiceDuration? ttl}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
-
path
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl → ComputeBackendServiceBackendServiceDuration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited