ComputeBackendServiceBackendServiceLocalityLbCustomPolicy class

Caller-supplied xDS locality_lb_policies[].custom_policy (max_items=1).

Annotations
  • @immutable

Constructors

ComputeBackendServiceBackendServiceLocalityLbCustomPolicy({required TfArg<String> name, TfArg<String>? data})
const

Properties

data → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited