ComputeBackendServiceBackendServiceLocalityLbPolicyEntry class
One entry under locality_lb_policies. Exactly one of policy /
customPolicy should be set per entry.
- Annotations
-
- @immutable
Constructors
Properties
- customPolicy → ComputeBackendServiceBackendServiceLocalityLbCustomPolicy?
-
Caller-supplied xDS policy (
{ name, data }).final - hashCode → int
-
The hash code for this object.
no setterinherited
- policy → ComputeBackendServiceBackendServiceLocalityLbBuiltinPolicy?
-
Built-in policy reference (
{ name }).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited