ComputeBackendServiceIap class final

Typed helper for the iap block of google_compute_backend_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeBackendServiceIap({required TfArg<bool> enabled, ComputeBackendServiceOauth2ClientId? oauth2ClientId, TfArg<String>? oauth2ClientIdWoVersion, ComputeBackendServiceOauth2ClientSecret? oauth2ClientSecret, TfArg<String>? oauth2ClientSecretWoVersion})
const

Properties

enabled → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
oauth2ClientId → ComputeBackendServiceOauth2ClientId?
final
oauth2ClientIdWoVersion → TfArg<String>?
final
oauth2ClientSecret → ComputeBackendServiceOauth2ClientSecret?
final
oauth2ClientSecretWoVersion → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited