ComputeBackendServiceSecuritySettings class final

Typed helper for the security_settings block of google_compute_backend_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeBackendServiceSecuritySettings({TfArg<String>? clientTlsPolicy, TfArg<List<String>>? subjectAltNames, ComputeBackendServiceAwsV4Authentication? awsV4Authentication})
const

Properties

awsV4Authentication → ComputeBackendServiceAwsV4Authentication?
final
clientTlsPolicy → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subjectAltNames → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited