ComputeDiskGuestOsFeature class

One entry of the guest_os_features block (repeatable list).

Annotations
  • @immutable

Constructors

ComputeDiskGuestOsFeature({required ComputeDiskGuestOsFeatureType type})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ComputeDiskGuestOsFeatureType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited