ComputeDiskSourceImageEncryptionKey class final
Typed helper for the source_image_encryption_key block of
google_compute_disk (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeDiskSourceImageEncryptionKey({RefTo<
GoogleKmsCryptoKey> ? kmsKeySelfLink, TfArg<String> ? kmsKeyServiceAccount, Sensitive<String> ? rawKey}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeySelfLink
→ RefTo<
GoogleKmsCryptoKey> ? -
final
-
kmsKeyServiceAccount
→ TfArg<
String> ? -
final
-
rawKey
→ Sensitive<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited