ComputeFirewallPolicyWithRulesLayer4Config class final

Typed helper for the rule.match.layer4_config block of google_compute_firewall_policy_with_rules (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeFirewallPolicyWithRulesLayer4Config({required TfArg<String> ipProtocol, TfArg<List<String>>? ports})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipProtocol → TfArg<String>
final
ports → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited