ComputeFirewallPolicyWithRulesRuleMatch class final
Typed helper for the rule.match block of
google_compute_firewall_policy_with_rules (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeFirewallPolicyWithRulesRuleMatch({TfArg<
List< ? destAddressGroups, TfArg<Object?> >List< ? destFqdns, TfArg<Object?> >List< ? destIpRanges, TfArg<Object?> >List< ? destRegionCodes, TfArg<Object?> >List< ? destThreatIntelligences, TfArg<Object?> >List< ? srcAddressGroups, TfArg<Object?> >List< ? srcFqdns, TfArg<Object?> >List< ? srcIpRanges, TfArg<Object?> >List< ? srcRegionCodes, TfArg<Object?> >List< ? srcThreatIntelligences, required List<Object?> >ComputeFirewallPolicyWithRulesRuleMatchLayer4Config> layer4Config, List<ComputeFirewallPolicyWithRulesRuleMatchSrcSecureTag> ? srcSecureTag}) -
const
Properties
-
destAddressGroups
→ TfArg<
List< ?Object?> > -
final
-
destFqdns
→ TfArg<
List< ?Object?> > -
final
-
destIpRanges
→ TfArg<
List< ?Object?> > -
final
-
destRegionCodes
→ TfArg<
List< ?Object?> > -
final
-
destThreatIntelligences
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layer4Config
→ List<
ComputeFirewallPolicyWithRulesRuleMatchLayer4Config> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
srcAddressGroups
→ TfArg<
List< ?Object?> > -
final
-
srcFqdns
→ TfArg<
List< ?Object?> > -
final
-
srcIpRanges
→ TfArg<
List< ?Object?> > -
final
-
srcRegionCodes
→ TfArg<
List< ?Object?> > -
final
-
srcSecureTag
→ List<
ComputeFirewallPolicyWithRulesRuleMatchSrcSecureTag> ? -
final
-
srcThreatIntelligences
→ TfArg<
List< ?Object?> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited