ComputeHealthCheckLogConfig class

log_config block. Toggles Cloud Logging export of probe results.

Annotations
  • @immutable

Constructors

ComputeHealthCheckLogConfig({TfArg<bool>? enable})
const

Properties

enable → TfArg<bool>?
true exports each probe result to Cloud Logging. Defaults to false (no logs).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited