ComputeHealthCheckProtocol class sealed
Mutually exclusive per-protocol config block. Each concrete *Config
type below is a sealed variant with its own blockKey.
Properties
Methods
-
encode(
) → List< Map< String, Object?> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited