ComputeInstanceAttachedDisk class
One entry inside attached_disk. Attaches an existing persistent disk
to the instance.
- Annotations
-
- @immutable
Constructors
Properties
-
deviceName
→ TfArg<
String> ? -
final
-
diskEncryptionKeyRaw
→ TfArg<
String> ? -
final
-
diskEncryptionServiceAccount
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeySelfLink
→ TfArg<
String> ? -
final
-
mode
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ TfArg<
String> -
Disk name or self-link. Required.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited