ComputeInstanceConfidentialInstanceConfig class

confidential_instance_config block (max_items=1). Enables Confidential VM. Requires scheduling.on_host_maintenance = TERMINATE.

Annotations
  • @immutable

Constructors

ComputeInstanceConfidentialInstanceConfig({TfArg<bool>? enableConfidentialCompute, ConfidentialInstanceType? confidentialInstanceType})
const

Properties

confidentialInstanceType ConfidentialInstanceType?
final
enableConfidentialCompute → TfArg<bool>?
Deprecated by GCP -- prefer setting confidentialInstanceType to ConfidentialInstanceType.sev.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited