ComputeInstanceFromTemplateBootDisk class final

Typed helper for the boot_disk block of google_compute_instance_from_template (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeInstanceFromTemplateBootDisk({TfArg<bool>? autoDelete, TfArg<String>? deviceName, Sensitive<String>? diskEncryptionKeyRaw, Sensitive<String>? diskEncryptionKeyRsa, TfArg<String>? diskEncryptionServiceAccount, TfArg<bool>? forceAttach, TfArg<List<String>>? guestOsFeatures, TfArg<String>? interface, RefTo<GoogleKmsCryptoKey>? kmsKeySelfLink, TfArg<String>? mode, TfArg<String>? source, ComputeInstanceFromTemplateInitializeParams? initializeParams})
const

Properties

autoDelete → TfArg<bool>?
final
deviceName → TfArg<String>?
final
diskEncryptionKeyRaw → Sensitive<String>?
final
diskEncryptionKeyRsa → Sensitive<String>?
final
diskEncryptionServiceAccount → TfArg<String>?
final
forceAttach → TfArg<bool>?
final
guestOsFeatures → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
initializeParams → ComputeInstanceFromTemplateInitializeParams?
final
interface → TfArg<String>?
final
final
mode → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited