ComputeInstanceFromTemplateNetworkInterface class final

Typed helper for the network_interface block of google_compute_instance_from_template (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeInstanceFromTemplateNetworkInterface({TfArg<String>? igmpQuery, TfArg<num>? internalIpv6PrefixLength, TfArg<String>? ipv6Address, RefTo<GoogleComputeNetwork>? network, TfArg<String>? networkAttachment, TfArg<String>? networkIp, ComputeInstanceFromTemplateNicType? nicType, TfArg<num>? queueCount, TfArg<String>? stackType, RefTo<GoogleComputeSubnetwork>? subnetwork, TfArg<String>? subnetworkProject, TfArg<num>? vlan, List<ComputeInstanceFromTemplateAccessConfig>? accessConfig, List<ComputeInstanceFromTemplateAliasIpRange>? aliasIpRange, List<ComputeInstanceFromTemplateIpv6AccessConfig>? ipv6AccessConfig})
const

Properties

accessConfig → List<ComputeInstanceFromTemplateAccessConfig>?
final
aliasIpRange → List<ComputeInstanceFromTemplateAliasIpRange>?
final
hashCode → int
The hash code for this object.
no setterinherited
igmpQuery → TfArg<String>?
final
internalIpv6PrefixLength → TfArg<num>?
final
ipv6AccessConfig → List<ComputeInstanceFromTemplateIpv6AccessConfig>?
final
ipv6Address → TfArg<String>?
final
network → RefTo<GoogleComputeNetwork>?
final
networkAttachment → TfArg<String>?
final
networkIp → TfArg<String>?
final
nicType → ComputeInstanceFromTemplateNicType?
final
queueCount → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackType → TfArg<String>?
final
subnetwork → RefTo<GoogleComputeSubnetwork>?
final
subnetworkProject → TfArg<String>?
final
vlan → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited