ComputeInstanceFromTemplateScheduling class final
Typed helper for the scheduling block of
google_compute_instance_from_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceFromTemplateScheduling({TfArg<
bool> ? automaticRestart, TfArg<num> ? availabilityDomain, TfArg<num> ? hostErrorTimeoutSeconds, TfArg<String> ? instanceTerminationAction, TfArg<num> ? minNodeCpus, TfArg<String> ? onHostMaintenance, TfArg<bool> ? preemptible, TfArg<String> ? provisioningModel, TfArg<String> ? terminationTime, ComputeInstanceFromTemplateLocalSsdRecoveryTimeout? localSsdRecoveryTimeout, ComputeInstanceFromTemplateMaxRunDuration? maxRunDuration, List<ComputeInstanceFromTemplateNodeAffinities> ? nodeAffinities, ComputeInstanceFromTemplateOnInstanceStopAction? onInstanceStopAction}) -
const
Properties
-
automaticRestart
→ TfArg<
bool> ? -
final
-
availabilityDomain
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostErrorTimeoutSeconds
→ TfArg<
num> ? -
final
-
instanceTerminationAction
→ TfArg<
String> ? -
final
- localSsdRecoveryTimeout → ComputeInstanceFromTemplateLocalSsdRecoveryTimeout?
-
final
- maxRunDuration → ComputeInstanceFromTemplateMaxRunDuration?
-
final
-
minNodeCpus
→ TfArg<
num> ? -
final
-
nodeAffinities
→ List<
ComputeInstanceFromTemplateNodeAffinities> ? -
final
-
onHostMaintenance
→ TfArg<
String> ? -
final
- onInstanceStopAction → ComputeInstanceFromTemplateOnInstanceStopAction?
-
final
-
preemptible
→ TfArg<
bool> ? -
final
-
provisioningModel
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
terminationTime
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited