ComputeInstanceGroupManagerInstanceGroupManagerNamedPort class

One entry in namedPorts. Backend services that reference this MIG by port_name look up the matching port number here.

Annotations
  • @immutable

Constructors

ComputeInstanceGroupManagerInstanceGroupManagerNamedPort({required TfArg<String> name, required TfArg<int> port})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
Port label. 1-63 chars, RFC1035.
final
port → TfArg<int>
Port number (1-65535).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited