ComputeInstanceGroupManagerInstanceGroupManagerStatefulIp class

One entry in statefulInternalIps / statefulExternalIps. Both blocks share the same shape.

Annotations
  • @immutable

Constructors

ComputeInstanceGroupManagerInstanceGroupManagerStatefulIp({TfArg<String>? interfaceName, TfArg<String>? deleteRule})
const

Properties

deleteRule → TfArg<String>?
NEVER (default — detach but keep the Address) or ON_PERMANENT_INSTANCE_DELETION (delete with the VM).
final
hashCode int
The hash code for this object.
no setterinherited
interfaceName → TfArg<String>?
Name of the VM network interface the IP is attached to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited