targetSize property
Cap on how many instances run this version (fixed or percent).
Implementation
final ComputeInstanceGroupManagerInstanceGroupManagerVersionTargetSize?
targetSize;
Cap on how many instances run this version (fixed or percent).
final ComputeInstanceGroupManagerInstanceGroupManagerVersionTargetSize?
targetSize;