ComputeInstanceGroupManagerInstanceGroupManagerVersionTargetSize class

version.target_size (max_items=1). Exactly one of fixed or percent should be set.

Annotations
  • @immutable

Constructors

ComputeInstanceGroupManagerInstanceGroupManagerVersionTargetSize({TfArg<int>? fixed, TfArg<int>? percent})
const

Properties

fixed → TfArg<int>?
Fixed number of instances managed for this version.
final
hashCode int
The hash code for this object.
no setterinherited
percent → TfArg<int>?
Percentage (0-100) of total MIG size managed for this version.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited