ComputeInstanceReservationAffinity class

reservation_affinity block (max_items=1). Controls whether and how the VM consumes capacity from a Compute Engine reservation.

Annotations
  • @immutable

Constructors

ComputeInstanceReservationAffinity({required ReservationAffinityType type, ComputeInstanceSpecificReservation? specificReservation})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificReservation ComputeInstanceSpecificReservation?
final
type ReservationAffinityType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited