ComputeInstanceScheduling class
scheduling block (max_items=1). Controls preemptibility, host
maintenance, max run duration, and sole-tenant affinities.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceScheduling({TfArg<
bool> ? preemptible, OnHostMaintenance? onHostMaintenance, TfArg<bool> ? automaticRestart, ProvisioningModel? provisioningModel, InstanceTerminationAction? instanceTerminationAction, TfArg<int> ? minNodeCpus, List<ComputeInstanceNodeAffinity> ? nodeAffinities, ComputeInstanceSchedulingDuration? maxRunDuration, ComputeInstanceSchedulingDuration? localSsdRecoveryTimeout}) -
const
Properties
-
automaticRestart
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceTerminationAction → InstanceTerminationAction?
-
final
- localSsdRecoveryTimeout → ComputeInstanceSchedulingDuration?
-
Local SSD data-recovery grace period for VMs with
--local-ssd.final - maxRunDuration → ComputeInstanceSchedulingDuration?
-
Hard cap on instance run time. After this elapses GCP applies the
instanceTerminationAction (stop or delete).
final
-
minNodeCpus
→ TfArg<
int> ? -
final
-
nodeAffinities
→ List<
ComputeInstanceNodeAffinity> ? -
final
- onHostMaintenance → OnHostMaintenance?
-
final
-
preemptible
→ TfArg<
bool> ? -
final
- provisioningModel → ProvisioningModel?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited