ComputeInstanceSchedulingDuration class

scheduling.max_run_duration / scheduling.local_ssd_recovery_timeout sub-block (Duration shape). Both fields take this same shape.

Annotations
  • @immutable

Constructors

ComputeInstanceSchedulingDuration({required TfArg<int> seconds, TfArg<int>? nanos})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nanos → TfArg<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited