ComputeInstanceShieldedInstanceConfig class final

Typed helper for the shielded_instance_config block of google_compute_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeInstanceShieldedInstanceConfig({TfArg<bool>? enableIntegrityMonitoring, TfArg<bool>? enableSecureBoot, TfArg<bool>? enableVtpm})
const

Properties

enableIntegrityMonitoring → TfArg<bool>?
final
enableSecureBoot → TfArg<bool>?
final
enableVtpm → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited