ComputeInstanceTemplateDisk class final

Typed helper for the disk block of google_compute_instance_template (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeInstanceTemplateDisk({TfArg<String>? architecture, TfArg<bool>? autoDelete, TfArg<bool>? boot, TfArg<String>? deviceName, TfArg<String>? diskName, TfArg<num>? diskSizeGb, TfArg<String>? diskType, TfArg<List<String>>? guestOsFeatures, TfArg<String>? interface, TfArg<Map<String, String>>? labels, InstanceTemplateDiskMode? mode, TfArg<num>? provisionedIops, TfArg<num>? provisionedThroughput, TfArg<Map<String, String>>? resourceManagerTags, TfArg<List<String>>? resourcePolicies, TfArg<String>? source, TfArg<String>? sourceImage, TfArg<String>? sourceSnapshot, TfArg<String>? storagePool, TfArg<String>? type, ComputeInstanceTemplateDiskEncryptionKey? diskEncryptionKey, ComputeInstanceTemplateSourceImageEncryptionKey? sourceImageEncryptionKey, ComputeInstanceTemplateSourceSnapshotEncryptionKey? sourceSnapshotEncryptionKey})
const

Properties

architecture → TfArg<String>?
final
autoDelete → TfArg<bool>?
final
boot → TfArg<bool>?
final
deviceName → TfArg<String>?
final
diskEncryptionKey → ComputeInstanceTemplateDiskEncryptionKey?
final
diskName → TfArg<String>?
final
diskSizeGb → TfArg<num>?
final
diskType → TfArg<String>?
final
guestOsFeatures → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
interface → TfArg<String>?
final
labels → TfArg<Map<String, String>>?
final
mode → InstanceTemplateDiskMode?
final
provisionedIops → TfArg<num>?
final
provisionedThroughput → TfArg<num>?
final
resourceManagerTags → TfArg<Map<String, String>>?
final
resourcePolicies → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → TfArg<String>?
final
sourceImage → TfArg<String>?
final
sourceImageEncryptionKey → ComputeInstanceTemplateSourceImageEncryptionKey?
final
sourceSnapshot → TfArg<String>?
final
sourceSnapshotEncryptionKey → ComputeInstanceTemplateSourceSnapshotEncryptionKey?
final
storagePool → TfArg<String>?
final
type → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited