ComputeInstanceTemplateInstanceTemplateAccessConfig class

One entry inside network_interface.access_config. An access config gives the interface an external IPv4 address (ephemeral when natIp is null, static when it's a reserved IP).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
natIp → TfArg<String>?
Reserved external IP to attach. Null for an ephemeral IP.
final
networkTier InstanceTemplateAccessConfigNetworkTier?
Network service tier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited