ComputeInstanceTemplateInstanceTemplateAliasIpRange class

One entry inside network_interface.alias_ip_range. Alias IPs let pods / containers running on instances created from this template use secondary CIDR ranges from the attached subnetwork.

Annotations
  • @immutable

Constructors

ComputeInstanceTemplateInstanceTemplateAliasIpRange({required TfArg<String> ipCidrRange, TfArg<String>? subnetworkRangeName})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ipCidrRange → TfArg<String>
Alias range (single IP, netmask, or CIDR).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnetworkRangeName → TfArg<String>?
Name of the secondary range to allocate from. When null, GCP uses the primary range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited