kmsKeyServiceAccount property
Service account used for the KMS encryption request. If null, the Compute Engine default service account is used.
Implementation
final TfArg<String>? kmsKeyServiceAccount;
Service account used for the KMS encryption request. If null, the Compute Engine default service account is used.
final TfArg<String>? kmsKeyServiceAccount;