ComputeInstanceTemplateInstanceTemplateIpv6AccessConfig class

One entry inside network_interface.ipv6_access_config. GCP currently allows at most one IPv6 access config per interface; only PREMIUM tier is valid for IPv6 today.

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
networkTier InstanceTemplateAccessConfigNetworkTier
Service tier. Required by the schema; only PREMIUM is currently accepted by GCP.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited