ComputeInstanceTemplateInstanceTemplateOnInstanceStopAction class

scheduling.on_instance_stop_action block (max_items=1). Defines extra behaviour applied when the chosen instance_termination_action runs.

Annotations
  • @immutable

Constructors

ComputeInstanceTemplateInstanceTemplateOnInstanceStopAction({TfArg<bool>? discardLocalSsd})
const

Properties

discardLocalSsd → TfArg<bool>?
If true, the contents of any attached Local SSD disks will be discarded on stop.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited