ComputeInstanceTemplateInstanceTemplateScheduling class
scheduling block (max_items=1). Controls preemptibility, host
maintenance, max run duration, and sole-tenant affinities.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceTemplateInstanceTemplateScheduling({TfArg<
bool> ? preemptible, InstanceTemplateOnHostMaintenance? onHostMaintenance, TfArg<bool> ? automaticRestart, InstanceTemplateProvisioningModel? provisioningModel, InstanceTemplateInstanceTerminationAction? instanceTerminationAction, TfArg<num> ? minNodeCpus, TfArg<num> ? availabilityDomain, TfArg<String> ? terminationTime, List<ComputeInstanceTemplateInstanceTemplateNodeAffinity> ? nodeAffinities, ComputeInstanceTemplateInstanceTemplateSchedulingDuration? maxRunDuration, ComputeInstanceTemplateInstanceTemplateSchedulingDuration? localSsdRecoveryTimeout, ComputeInstanceTemplateInstanceTemplateOnInstanceStopAction? onInstanceStopAction}) -
const
Properties
-
automaticRestart
→ TfArg<
bool> ? -
final
-
availabilityDomain
→ TfArg<
num> ? -
Availability domain index for stretched zonal placement.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceTerminationAction → InstanceTemplateInstanceTerminationAction?
-
final
- localSsdRecoveryTimeout → ComputeInstanceTemplateInstanceTemplateSchedulingDuration?
-
Local SSD data-recovery grace period for VMs with
--local-ssd.final - maxRunDuration → ComputeInstanceTemplateInstanceTemplateSchedulingDuration?
-
Hard cap on instance run time. After this elapses GCP applies the
instanceTerminationAction (stop or delete).
final
-
minNodeCpus
→ TfArg<
num> ? -
final
-
nodeAffinities
→ List<
ComputeInstanceTemplateInstanceTemplateNodeAffinity> ? -
final
- onHostMaintenance → InstanceTemplateOnHostMaintenance?
-
final
- onInstanceStopAction → ComputeInstanceTemplateInstanceTemplateOnInstanceStopAction?
-
final
-
preemptible
→ TfArg<
bool> ? -
final
- provisioningModel → InstanceTemplateProvisioningModel?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
terminationTime
→ TfArg<
String> ? -
RFC3339 timestamp at which the instance will be terminated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited