ComputeInstanceTemplateInstanceTemplateSpecificReservation class

reservation_affinity.specific_reservation sub-block (max_items=1). Only meaningful when ComputeInstanceTemplateInstanceTemplateReservationAffinity.type is InstanceTemplateReservationAffinityType.specificReservation.

Annotations
  • @immutable

Constructors

ComputeInstanceTemplateInstanceTemplateSpecificReservation({required TfArg<String> key, required List<String> values})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>
Label key. Use 'compute.googleapis.com/reservation-name' to target a reservation by name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited