ComputeNetworkFirewallPolicyRuleMatch class final

Typed helper for the match block of google_compute_network_firewall_policy_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeNetworkFirewallPolicyRuleMatch({TfArg<List<Object?>>? destAddressGroups, TfArg<List<Object?>>? destFqdns, TfArg<List<Object?>>? destIpRanges, TfArg<ComputeNetworkFirewallPolicyRuleMatchDestNetworkContext>? destNetworkContext, TfArg<List<Object?>>? destRegionCodes, TfArg<List<Object?>>? destThreatIntelligences, TfArg<List<Object?>>? srcAddressGroups, TfArg<List<Object?>>? srcFqdns, TfArg<List<Object?>>? srcIpRanges, TfArg<ComputeNetworkFirewallPolicyRuleMatchSrcNetworkContext>? srcNetworkContext, TfArg<List<Object?>>? srcNetworks, TfArg<List<Object?>>? srcRegionCodes, TfArg<List<Object?>>? srcThreatIntelligences, required List<ComputeNetworkFirewallPolicyRuleMatchLayer4Configs> layer4Configs, List<ComputeNetworkFirewallPolicyRuleMatchSrcSecureTags>? srcSecureTags})
const

Properties

destAddressGroups → TfArg<List<Object?>>?
final
destFqdns → TfArg<List<Object?>>?
final
destIpRanges → TfArg<List<Object?>>?
final
destNetworkContext → TfArg<ComputeNetworkFirewallPolicyRuleMatchDestNetworkContext>?
final
destRegionCodes → TfArg<List<Object?>>?
final
destThreatIntelligences → TfArg<List<Object?>>?
final
hashCode int
The hash code for this object.
no setterinherited
layer4Configs List<ComputeNetworkFirewallPolicyRuleMatchLayer4Configs>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srcAddressGroups → TfArg<List<Object?>>?
final
srcFqdns → TfArg<List<Object?>>?
final
srcIpRanges → TfArg<List<Object?>>?
final
srcNetworkContext → TfArg<ComputeNetworkFirewallPolicyRuleMatchSrcNetworkContext>?
final
srcNetworks → TfArg<List<Object?>>?
final
srcRegionCodes → TfArg<List<Object?>>?
final
srcSecureTags List<ComputeNetworkFirewallPolicyRuleMatchSrcSecureTags>?
final
srcThreatIntelligences → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited