ComputeNetworkFirewallPolicyRuleMatchLayer4Configs class final

Typed helper for the match.layer4_configs block of google_compute_network_firewall_policy_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeNetworkFirewallPolicyRuleMatchLayer4Configs({required TfArg<String> ipProtocol, TfArg<List<Object?>>? ports})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ipProtocol → TfArg<String>
final
ports → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited