ComputeNodeGroupShareSettingsProjectMap class final

Typed helper for the share_settings.project_map block of google_compute_node_group (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeNodeGroupShareSettingsProjectMap({required TfArg<String> id, required TfArg<String> projectId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
projectId → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited