ComputeOrganizationSecurityPolicyAdvancedOptionsConfig class final

Typed helper for the advanced_options_config block of google_compute_organization_security_policy (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonCustomConfig → ComputeOrganizationSecurityPolicyJsonCustomConfig?
final
jsonParsing → ComputeOrganizationSecurityPolicyJsonParsing?
final
logLevel → ComputeOrganizationSecurityPolicyLogLevel?
final
requestBodyInspectionSize → ComputeOrganizationSecurityPolicyRequestBodyInspectionSize?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIpRequestHeaders → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited