ComputeOrganizationSecurityPolicyRuleExclusion class final

Typed helper for the preconfigured_waf_config.exclusion block of google_compute_organization_security_policy_rule (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestCookie → List<ComputeOrganizationSecurityPolicyRuleRequestCookie>?
final
requestHeader → List<ComputeOrganizationSecurityPolicyRuleRequestHeader>?
final
requestQueryParam → List<ComputeOrganizationSecurityPolicyRuleRequestQueryParam>?
final
requestUri → List<ComputeOrganizationSecurityPolicyRuleRequestUri>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetRuleIds → TfArg<List<String>>?
final
targetRuleSet → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited