ComputeOrganizationSecurityPolicyRuleMatch class final

Typed helper for the match block of google_compute_organization_security_policy_rule (derived from provider schema).

Annotations
  • @immutable

Properties

config → ComputeOrganizationSecurityPolicyRuleConfig?
final
description → TfArg<String>?
final
expr → ComputeOrganizationSecurityPolicyRuleExpr?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionedExpr → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited