ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusion class final
Typed helper for the preconfigured_waf_config.exclusion block of
google_compute_organization_security_policy_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusion({TfArg<
List< ? targetRuleIds, required TfArg<Object?> >String> targetRuleSet, List<ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestCookie> ? requestCookie, List<ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestHeader> ? requestHeader, List<ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestQueryParam> ? requestQueryParam, List<ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestUri> ? requestUri}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestCookie
→ List<
ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestCookie> ? -
final
-
requestHeader
→ List<
ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestHeader> ? -
final
-
requestQueryParam
→ List<
ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestQueryParam> ? -
final
-
requestUri
→ List<
ComputeOrganizationSecurityPolicyRulePreconfiguredWafConfigExclusionRequestUri> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetRuleIds
→ TfArg<
List< ?Object?> > -
final
-
targetRuleSet
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited