ComputeOrganizationSecurityPolicyRuleRequestHeadersToAdds class final

Typed helper for the header_action.request_headers_to_adds block of google_compute_organization_security_policy_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeOrganizationSecurityPolicyRuleRequestHeadersToAdds({TfArg<String>? headerName, TfArg<String>? headerValue})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>?
final
headerValue → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited