ComputePerInstanceConfigInternalIp class final

Typed helper for the preserved_state.internal_ip block of google_compute_per_instance_config (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputePerInstanceConfigInternalIp({ComputePerInstanceConfigAutoDelete? autoDelete, required TfArg<String> interfaceName, ComputePerInstanceConfigIpAddress? ipAddress})
const

Properties

autoDelete → ComputePerInstanceConfigAutoDelete?
final
hashCode → int
The hash code for this object.
no setterinherited
interfaceName → TfArg<String>
final
ipAddress → ComputePerInstanceConfigIpAddress?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited