ComputePerInstanceConfigPreservedStateExternalIp class final
Typed helper for the preserved_state.external_ip block of
google_compute_per_instance_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputePerInstanceConfigPreservedStateExternalIp({TfArg<
ComputePerInstanceConfigPreservedStateExternalIpAutoDelete> ? autoDelete, required TfArg<String> interfaceName, ComputePerInstanceConfigPreservedStateExternalIpIpAddress? ipAddress}) -
const
Properties
-
autoDelete
→ TfArg<
ComputePerInstanceConfigPreservedStateExternalIpAutoDelete> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interfaceName
→ TfArg<
String> -
final
- ipAddress → ComputePerInstanceConfigPreservedStateExternalIpIpAddress?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited