ComputePreviewFeatureRolloutInput class final

Typed helper for the rollout_operation.rollout_input block of google_compute_preview_feature (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputePreviewFeatureRolloutInput({required TfArg<String> predefinedRolloutPlan})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
predefinedRolloutPlan → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited