ComputeRegionBackendServiceConsistentHash class final
Typed helper for the consistent_hash block of
google_compute_region_backend_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceConsistentHash({TfArg<
String> ? httpHeaderName, TfArg<num> ? minimumRingSize, ComputeRegionBackendServiceHttpCookie? httpCookie}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpCookie → ComputeRegionBackendServiceHttpCookie?
-
final
-
httpHeaderName
→ TfArg<
String> ? -
final
-
minimumRingSize
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited