ComputeRegionBackendServiceNetworkPassThroughLbTrafficPolicy class final

Typed helper for the network_pass_through_lb_traffic_policy block of google_compute_region_backend_service (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zonalAffinity → ComputeRegionBackendServiceZonalAffinity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited