ComputeRegionBackendServiceRegionBackendServiceBackendCustomMetric class
One entry under backend.custom_metrics — a signal exported by the
backend that the load balancer should consider when balancingMode
is RegionBackendServiceBalancingMode.customMetrics.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceRegionBackendServiceBackendCustomMetric({required TfArg<
String> name, required TfArg<bool> dryRun, TfArg<double> ? maxUtilization}) -
const
Properties
-
dryRun
→ TfArg<
bool> -
If
true, the metric is reported to Cloud Monitoring but is not used for load balancing.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
maxUtilization
→ TfArg<
double> ? -
Optional target utilization (
0.0-1.0) for this metric.final -
name
→ TfArg<
String> -
Metric name. 1-64 chars, lowercase RFC1035-ish (see schema).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited