disableConnectionDrainOnFailover property

TfArg<bool>? disableConnectionDrainOnFailover
final

If true, connections to the old active pool are not drained on failover. Can be set to true only when protocol is TCP.

Implementation

final TfArg<bool>? disableConnectionDrainOnFailover;