ComputeRegionBackendServiceRegionBackendServiceLogConfig class

log_config block — Cloud Logging export configuration for the regional backend service.

Annotations
  • @immutable

Constructors

ComputeRegionBackendServiceRegionBackendServiceLogConfig({TfArg<bool>? enable, TfArg<double>? sampleRate, RegionBackendServiceLogOptionalMode? optionalMode, List<String>? optionalFields})
const

Properties

enable → TfArg<bool>?
Master switch.
final
hashCode int
The hash code for this object.
no setterinherited
optionalFields List<String>?
Custom field list when optionalMode is RegionBackendServiceLogOptionalMode.custom.
final
optionalMode RegionBackendServiceLogOptionalMode?
Which optional fields to include.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → TfArg<double>?
Sample rate 0.0-1.0. Ignored when enable is false.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited