ComputeRegionBackendServiceRegionBackendServiceParams class

params block — currently only carries resource-manager tags.

Annotations
  • @immutable

Constructors

ComputeRegionBackendServiceRegionBackendServiceParams({TfArg<Map<String, String>>? resourceManagerTags})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceManagerTags → TfArg<Map<String, String>>?
{tagKey: tagValue} map of resource-manager tag bindings applied at creation time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited