ComputeRegionBackendServiceRegionBackendServiceStrongSessionAffinityCookie class

strong_session_affinity_cookie block. Used only when sessionAffinity is RegionBackendServiceSessionAffinity.strongCookieAffinity.

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
path → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl ComputeRegionBackendServiceRegionBackendServiceDuration?
Cookie TTL. Schema requires seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited