ComputeRegionBackendServiceResponseHeaders class final

Typed helper for the log_config.response_headers block of google_compute_region_backend_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionBackendServiceResponseHeaders({required TfArg<String> headerName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited