ComputeRegionBackendServiceTlsSettings class final

Typed helper for the tls_settings block of google_compute_region_backend_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionBackendServiceTlsSettings({TfArg<String>? authenticationConfig, TfArg<String>? sni, List<ComputeRegionBackendServiceSubjectAltNames>? subjectAltNames})
const

Properties

authenticationConfig → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sni → TfArg<String>?
final
subjectAltNames → List<ComputeRegionBackendServiceSubjectAltNames>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited