ComputeRegionDiskAsyncPrimaryDisk class final

Typed helper for the async_primary_disk block of google_compute_region_disk (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionDiskAsyncPrimaryDisk({required TfArg<String> disk})
const

Properties

disk → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited