ComputeRegionHealthCheckRegionHealthCheckSslConfig class final

ssl_health_check block. Pure SSL/TLS probe.

Inheritance
Annotations
  • @immutable

Constructors

ComputeRegionHealthCheckRegionHealthCheckSslConfig({TfArg<String>? request, TfArg<String>? response, TfArg<int>? port, TfArg<String>? portName, RegionHealthCheckProxyHeader? proxyHeader, RegionHealthCheckPortSpecification? portSpecification})
const

Properties

blockKey String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
port → TfArg<int>?
TCP port. Defaults to 443.
final
portName → TfArg<String>?
final
portSpecification RegionHealthCheckPortSpecification?
final
proxyHeader RegionHealthCheckProxyHeader?
final
request → TfArg<String>?
final
response → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() List<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited