ComputeRegionInstanceGroupManagerInstanceFlexibilityPolicy class

instance_flexibility_policy block — regional only. Lets the MIG pick from multiple machine types when creating new VMs, instead of the single machine type set on the instance template.

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceSelections → List<ComputeRegionInstanceGroupManagerInstanceSelection>?
Named selections of machine types. The MIG ranks selections by ComputeRegionInstanceGroupManagerInstanceSelection.rank (lower = higher preference).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited