forceUpdateOnRepair property
YES to apply the latest template when repairing a VM; NO
(default) to honor the update policy.
Implementation
final TfArg<String>? forceUpdateOnRepair;
YES to apply the latest template when repairing a VM; NO
(default) to honor the update policy.
final TfArg<String>? forceUpdateOnRepair;