ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerInstanceSelection class

Annotations
  • @immutable

Constructors

ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerInstanceSelection({required TfArg<String> name, required List<String> machineTypes, TfArg<int>? rank})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
machineTypes List<String>
Required. Full machine-type names (e.g. n1-standard-16).
final
name → TfArg<String>
Required. Selection label.
final
rank → TfArg<int>?
Lower number = higher preference. Selections with the same rank are treated equally.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited