ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerResourcePolicies class
resource_policies block — wires the MIG to a
google_compute_resource_policy workload policy.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerResourcePolicies({TfArg<
String> ? workloadPolicy}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
workloadPolicy
→ TfArg<
String> ? -
Full or partial URL of the workload policy.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited