deviceName property
Device name the disk is attached to on the VM (matches the
device_name set on the instance template's disk block).
Implementation
final TfArg<String> deviceName;
Device name the disk is attached to on the VM (matches the
device_name set on the instance template's disk block).
final TfArg<String> deviceName;