ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerTargetSizePolicy class

One entry in targetSizePolicies. Configures whether the MIG creates VMs individually or all at once to reach GoogleComputeRegionInstanceGroupManager.targetSize.

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
mode → TfArg<String>
Required. The provisioning mode (e.g. BATCH, INDIVIDUAL).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited