ComputeRegionInstanceTemplateAdvancedMachineFeatures class final

Typed helper for the advanced_machine_features block of google_compute_region_instance_template (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionInstanceTemplateAdvancedMachineFeatures({TfArg<bool>? enableNestedVirtualization, TfArg<bool>? enableUefiNetworking, TfArg<String>? performanceMonitoringUnit, TfArg<num>? threadsPerCore, TfArg<String>? turboMode, TfArg<num>? visibleCoreCount})
const

Properties

enableNestedVirtualization → TfArg<bool>?
final
enableUefiNetworking → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
performanceMonitoringUnit → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadsPerCore → TfArg<num>?
final
turboMode → TfArg<String>?
final
visibleCoreCount → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited