ComputeRegionInstanceTemplateAliasIpRange class final
Typed helper for the network_interface.alias_ip_range block of
google_compute_region_instance_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionInstanceTemplateAliasIpRange({required TfArg<
String> ipCidrRange, TfArg<String> ? subnetworkRangeName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipCidrRange
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetworkRangeName
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited