ComputeRegionPerInstanceConfigPreservedStateInternalIp class final
Typed helper for the preserved_state.internal_ip block of
google_compute_region_per_instance_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionPerInstanceConfigPreservedStateInternalIp({TfArg<
ComputeRegionPerInstanceConfigPreservedStateInternalIpAutoDelete> ? autoDelete, required TfArg<String> interfaceName, ComputeRegionPerInstanceConfigPreservedStateInternalIpIpAddress? ipAddress}) -
const
Properties
-
autoDelete
→ TfArg<
ComputeRegionPerInstanceConfigPreservedStateInternalIpAutoDelete> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interfaceName
→ TfArg<
String> -
final
- ipAddress → ComputeRegionPerInstanceConfigPreservedStateInternalIpIpAddress?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited