ComputeRegionSecurityPolicyRegionSecurityPolicyRule class

One entry in rules[]. Rules are evaluated from highest priority (lowest numeric value) to lowest priority. Cloud Armor REQUIRES a default rule at priority 2147483647 matching all traffic ('*') -- if you omit it the provider injects one with action allow.

Annotations
  • @immutable

Constructors

ComputeRegionSecurityPolicyRegionSecurityPolicyRule({required TfArg<int> priority, required TfArg<String> action, required ComputeRegionSecurityPolicyRegionSecurityPolicyRuleMatch match, TfArg<String>? description, TfArg<bool>? preview, ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitOptions? rateLimitOptions, ComputeRegionSecurityPolicyRegionSecurityPolicyRulePreconfiguredWafConfig? preconfiguredWafConfig})
const

Properties

action → TfArg<String>
Provider action string (allow, deny(403), rate_based_ban, throttle, ...). redirect is not supported on regional policies.
final
description → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
match ComputeRegionSecurityPolicyRegionSecurityPolicyRuleMatch
final
preconfiguredWafConfig ComputeRegionSecurityPolicyRegionSecurityPolicyRulePreconfiguredWafConfig?
final
preview → TfArg<bool>?
final
priority → TfArg<int>
final
rateLimitOptions ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitOptions?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited