ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitOptions class
rules.rate_limit_options -- required when action is
rate_based_ban or throttle.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitOptions({required TfArg<
String> conformAction, required TfArg<String> exceedAction, required ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitThreshold rateLimitThreshold, TfArg<int> ? banDurationSec, ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitThreshold? banThreshold, SecurityPolicyRuleRateLimitEnforceOnKey? enforceOnKey, TfArg<String> ? enforceOnKeyName, List<ComputeRegionSecurityPolicyRegionSecurityPolicyRuleEnforceOnKeyConfig> ? enforceOnKeyConfigs}) -
const
Properties
-
banDurationSec
→ TfArg<
int> ? -
final
- banThreshold → ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitThreshold?
-
final
-
conformAction
→ TfArg<
String> -
final
- enforceOnKey → SecurityPolicyRuleRateLimitEnforceOnKey?
-
final
-
enforceOnKeyConfigs
→ List<
ComputeRegionSecurityPolicyRegionSecurityPolicyRuleEnforceOnKeyConfig> ? -
final
-
enforceOnKeyName
→ TfArg<
String> ? -
final
-
exceedAction
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rateLimitThreshold → ComputeRegionSecurityPolicyRegionSecurityPolicyRuleRateLimitThreshold
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited