ComputeRegionUrlMapFilterLabels class final

Typed helper for the path_matcher.route_rules.match_rules.metadata_filters.filter_labels block of google_compute_region_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionUrlMapFilterLabels({required TfArg<String> name, required TfArg<String> value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited