ComputeRegionUrlMapHeaderMatches class final

Typed helper for the path_matcher.route_rules.match_rules.header_matches block of google_compute_region_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionUrlMapHeaderMatches({TfArg<String>? exactMatch, required TfArg<String> headerName, TfArg<bool>? invertMatch, TfArg<String>? prefixMatch, TfArg<bool>? presentMatch, TfArg<String>? regexMatch, TfArg<String>? suffixMatch, ComputeRegionUrlMapRangeMatch? rangeMatch})
const

Properties

exactMatch → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
final
invertMatch → TfArg<bool>?
final
prefixMatch → TfArg<String>?
final
presentMatch → TfArg<bool>?
final
rangeMatch → ComputeRegionUrlMapRangeMatch?
final
regexMatch → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixMatch → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited