ComputeRegionUrlMapMetadataFilters class final

Typed helper for the path_matcher.route_rules.match_rules.metadata_filters block of google_compute_region_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionUrlMapMetadataFilters({required RegionUrlMapMetadataFilterMatchCriteria filterMatchCriteria, required List<ComputeRegionUrlMapFilterLabels> filterLabels})
const

Properties

filterLabels → List<ComputeRegionUrlMapFilterLabels>
final
filterMatchCriteria → RegionUrlMapMetadataFilterMatchCriteria
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited