ComputeRegionUrlMapRegionUrlMapHeaderToAdd class

One entry in ComputeRegionUrlMapRegionUrlMapHeaderAction.requestHeadersToAdd / ComputeRegionUrlMapRegionUrlMapHeaderAction.responseHeadersToAdd. All three fields are required by the schema at the top-level header_action slot.

Annotations
  • @immutable

Constructors

ComputeRegionUrlMapRegionUrlMapHeaderToAdd({required TfArg<String> headerName, required TfArg<String> headerValue, required TfArg<bool> replace})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
Header name (case-insensitive on the wire).
final
headerValue → TfArg<String>
Header value to set.
final
replace → TfArg<bool>
If true, an existing header with the same name is replaced; if false, the new value is appended.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited