ComputeRegionUrlMapRouteRulesUrlRedirect class final

Typed helper for the path_matcher.route_rules.url_redirect block of google_compute_region_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRegionUrlMapRouteRulesUrlRedirect({TfArg<String>? hostRedirect, TfArg<bool>? httpsRedirect, TfArg<String>? pathRedirect, TfArg<String>? prefixRedirect, RegionUrlMapRedirectResponseCode? redirectResponseCode, TfArg<bool>? stripQuery})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostRedirect → TfArg<String>?
final
httpsRedirect → TfArg<bool>?
final
pathRedirect → TfArg<String>?
final
prefixRedirect → TfArg<String>?
final
redirectResponseCode → RegionUrlMapRedirectResponseCode?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stripQuery → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited