ComputeReservationDeleteAfterDuration class final

Typed helper for the delete_after_duration block of google_compute_reservation (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeReservationDeleteAfterDuration({TfArg<num>? nanos, TfArg<String>? seconds})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nanos → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited