ComputeReservationShareSettings class final

Typed helper for the share_settings block of google_compute_reservation (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectMap → List<ComputeReservationProjectMap>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareType → ComputeReservationShareType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited