ComputeResourcePolicyDailySchedule class final

Daily snapshot schedule.

Inheritance
Annotations
  • @immutable

Constructors

ComputeResourcePolicyDailySchedule({required TfArg<int> daysInCycle, required TfArg<String> startTime})
const

Properties

daysInCycle → TfArg<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>
final

Methods

encode() Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited