ComputeResourcePolicyDayOfWeek class

One entry of a weekly snapshot schedule.

Annotations
  • @immutable

Constructors

ComputeResourcePolicyDayOfWeek({required TfArg<ComputeResourcePolicySnapshotDayOfWeek> day, required TfArg<String> startTime})
const

Properties

day → TfArg<ComputeResourcePolicySnapshotDayOfWeek>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>
Start time in HH:MM (UTC).
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited