ComputeResourcePolicyHourlyScheduleChoice class final

The ComputeResourcePolicySchedule.hourlySchedule choice: sets hourly_schedule.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
hourlySchedule → ComputeResourcePolicyHourlySchedule
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited