ComputeResourcePolicyInstanceSchedulePolicy class final

Typed helper for the instance_schedule_policy block of google_compute_resource_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeResourcePolicyInstanceSchedulePolicy({TfArg<String>? expirationTime, TfArg<String>? startTime, required TfArg<String> timeZone, ComputeResourcePolicyVmStartSchedule? vmStartSchedule, ComputeResourcePolicyVmStopSchedule? vmStopSchedule})
const

Properties

expirationTime → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>?
final
timeZone → TfArg<String>
final
vmStartSchedule → ComputeResourcePolicyVmStartSchedule?
final
vmStopSchedule → ComputeResourcePolicyVmStopSchedule?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited