ComputeResourcePolicyRetentionPolicy class

Retention policy for scheduled snapshots.

Annotations
  • @immutable

Constructors

ComputeResourcePolicyRetentionPolicy({required TfArg<int> maxRetentionDays, TfArg<ComputeResourcePolicyOnSourceDiskDelete>? onSourceDiskDelete})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxRetentionDays → TfArg<int>
final
onSourceDiskDelete → TfArg<ComputeResourcePolicyOnSourceDiskDelete>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited