ComputeResourcePolicyVmStartSchedule class final

Typed helper for the instance_schedule_policy.vm_start_schedule block of google_compute_resource_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeResourcePolicyVmStartSchedule({required TfArg<String> schedule})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited