ComputeResourcePolicyWeeklySchedule class final

Typed helper for the snapshot_schedule_policy.schedule.weekly_schedule block of google_compute_resource_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeResourcePolicyWeeklySchedule({required List<ComputeResourcePolicyDayOfWeeks> dayOfWeeks})
const

Properties

dayOfWeeks → List<ComputeResourcePolicyDayOfWeeks>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited