ComputeResourcePolicyWorkloadType extension type

Workload-placement intent for a GoogleComputeResourcePolicy.

on
Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTfJson() → Object?
Value emitted into Terraform JSON.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

highAvailability → const ComputeResourcePolicyWorkloadType
Spread instances to maximize availability.
highThroughput → const ComputeResourcePolicyWorkloadType
Pack instances to maximize throughput.
values → const List<ComputeResourcePolicyWorkloadType>