ComputeRouteGatewayNextHop class final

Route via the default internet gateway (default-internet-gateway).

Inheritance
Annotations
  • @immutable

Constructors

ComputeRouteGatewayNextHop(TfArg<String> nextHopGateway)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextHopGateway → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
Scalar value written under blockKey.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited