ComputeRouteIlbNextHop class final

Route via an internal load balancer.

Inheritance
Annotations
  • @immutable

Constructors

ComputeRouteIlbNextHop(TfArg<String> nextHopIlb)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextHopIlb → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
Scalar value written under blockKey.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited