ComputeRouterRoutePolicyTerms class final

Typed helper for the terms block of google_compute_router_route_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeRouterRoutePolicyTerms({required TfArg<num> priority, List<ComputeRouterRoutePolicyActions>? actions, required ComputeRouterRoutePolicyMatch match})
const

Properties

actions → List<ComputeRouterRoutePolicyActions>?
final
hashCode → int
The hash code for this object.
no setterinherited
match → ComputeRouterRoutePolicyMatch
final
priority → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited