ComputeSecurityPolicyRuleMatchConfig class

Annotations
  • @immutable

Constructors

ComputeSecurityPolicyRuleMatchConfig({required List<String> srcIpRanges})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcIpRanges → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited