ComputeSecurityPolicyRulesHeaderAdd class

One header rewrite in ComputeSecurityPolicyRulesHeaderAction.requestHeadersToAdds. headerValue is optional -- omitting it adds the header with an empty string value.

Annotations
  • @immutable

Constructors

ComputeSecurityPolicyRulesHeaderAdd({required TfArg<String> headerName, TfArg<String>? headerValue})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
final
headerValue → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited