banDurationSec property
Only honored when the rule action is SecurityPolicyRuleAction.rateBasedBan. Seconds the key remains banned after the rate falls below threshold.
Implementation
final TfArg<int>? banDurationSec;
Only honored when the rule action is SecurityPolicyRuleAction.rateBasedBan. Seconds the key remains banned after the rate falls below threshold.
final TfArg<int>? banDurationSec;