ComputeSecurityPolicySecurityPolicyAdaptiveProtectionConfig class
adaptive_protection_config -- Google's ML-driven layer-7 DDoS
auto-mitigation. When enabled, Cloud Armor watches traffic patterns
and proposes / auto-deploys rules during a suspected attack.
- Annotations
-
- @immutable
Constructors
- ComputeSecurityPolicySecurityPolicyAdaptiveProtectionConfig({ComputeSecurityPolicySecurityPolicyLayer7DdosDefenseConfig? layer7DdosDefenseConfig})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- layer7DdosDefenseConfig → ComputeSecurityPolicySecurityPolicyLayer7DdosDefenseConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited