ComputeSecurityPolicySecurityPolicyJsonCustomConfig class

advanced_options_config.json_custom_config -- list of additional Content-Type values Cloud Armor should treat as JSON for WAF body inspection (beyond the default application/json).

Annotations
  • @immutable

Constructors

ComputeSecurityPolicySecurityPolicyJsonCustomConfig({required List<String> contentTypes})
const

Properties

contentTypes List<String>
Additional Content-Type header values to apply JSON parsing to.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited