ComputeSecurityPolicySecurityPolicyRuleMatch class

rule.match -- the condition under which a rule fires. Mutually-exclusive variants:

Annotations
  • @immutable

Constructors

ComputeSecurityPolicySecurityPolicyRuleMatch.config({required SecurityPolicyRuleMatchVersionedExpr versionedExpr, required ComputeSecurityPolicySecurityPolicyRuleMatchConfig config})
Built-in predicate variant. Pair versionedExpr with config (both required by the schema when this variant is used).
factory
ComputeSecurityPolicySecurityPolicyRuleMatch.expr(ComputeSecurityPolicySecurityPolicyRuleMatchExpr expr)
User-defined CEL expression variant.
factory

Properties

config ComputeSecurityPolicySecurityPolicyRuleMatchConfig?
final
expr ComputeSecurityPolicySecurityPolicyRuleMatchExpr?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionedExpr SecurityPolicyRuleMatchVersionedExpr?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited