ComputeSnapshotDiskSource class final

Create the snapshot from a Persistent Disk (name or self-link).

Inheritance
Annotations
  • @immutable

Constructors

ComputeSnapshotDiskSource({required TfArg<String> sourceDisk})
const

Properties

blockKey String
Terraform attribute name (source_disk or source_instant_snapshot).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceDisk → TfArg<String>
final
value → TfArg<String>
Scalar value written under blockKey.
no setteroverride

Methods

encode() Map<String, Object?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited