ComputeSnapshotSource class sealed

Snapshot source for GoogleComputeSnapshot. Sealed so the provider exactly_one_of on source_disk / source_instant_snapshot is exhaustive at the type level.

Implementers

Constructors

ComputeSnapshotSource.disk(TfArg<String> sourceDisk)
Create the snapshot from a Persistent Disk (name or self-link).
const
factory
ComputeSnapshotSource.instantSnapshot(TfArg<String> sourceInstantSnapshot)
Create the snapshot from a zonal Instant Snapshot (name or self-link).
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
Scalar value written under blockKey.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited