ComputeUrlMapCacheKeyPolicy class final

Typed helper for the default_route_action.cache_policy.cache_key_policy block of google_compute_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeUrlMapCacheKeyPolicy({ComputeUrlMapQueryParameters? queryParameters, TfArg<bool>? includeHost, TfArg<bool>? includeProtocol, TfArg<bool>? includeQueryString, TfArg<List<String>>? includedCookieNames, TfArg<List<String>>? includedHeaderNames})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
includedCookieNames → TfArg<List<String>>?
final
includedHeaderNames → TfArg<List<String>>?
final
includeHost → TfArg<bool>?
final
includeProtocol → TfArg<bool>?
final
includeQueryString → TfArg<bool>?
final
queryParameters → ComputeUrlMapQueryParameters?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited