ComputeUrlMapClientTtl class final

Typed helper for the default_route_action.cache_policy.client_ttl block of google_compute_url_map (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

ComputeUrlMapClientTtl({TfArg<num>? nanos, required TfArg<String> seconds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nanos → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited