ComputeUrlMapHeaderAction class final

Typed helper for the header_action block of google_compute_url_map (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

ComputeUrlMapHeaderAction({TfArg<List<String>>? requestHeadersToRemove, TfArg<List<String>>? responseHeadersToRemove, List<ComputeUrlMapRequestHeadersToAdd>? requestHeadersToAdd, List<ComputeUrlMapResponseHeadersToAdd>? responseHeadersToAdd})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestHeadersToAdd → List<ComputeUrlMapRequestHeadersToAdd>?
final
requestHeadersToRemove → TfArg<List<String>>?
final
responseHeadersToAdd → List<ComputeUrlMapResponseHeadersToAdd>?
final
responseHeadersToRemove → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited