ComputeUrlMapHeaderActionResponseHeadersToAdd class final

Typed helper for the default_route_action.weighted_backend_services.header_action.response_headers_to_add block of google_compute_url_map (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

ComputeUrlMapHeaderActionResponseHeadersToAdd({TfArg<String>? headerName, TfArg<String>? headerValue, TfArg<bool>? replace})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>?
final
headerValue → TfArg<String>?
final
replace → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited