ComputeUrlMapMatchRules class final

Typed helper for the path_matcher.route_rules.match_rules block of google_compute_url_map (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeUrlMapMatchRules({TfArg<String>? fullPathMatch, TfArg<bool>? ignoreCase, TfArg<String>? pathTemplateMatch, TfArg<String>? prefixMatch, TfArg<String>? regexMatch, List<ComputeUrlMapHeaderMatches>? headerMatches, List<ComputeUrlMapMetadataFilters>? metadataFilters, List<ComputeUrlMapQueryParameterMatches>? queryParameterMatches})
const

Properties

fullPathMatch → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headerMatches → List<ComputeUrlMapHeaderMatches>?
final
ignoreCase → TfArg<bool>?
final
metadataFilters → List<ComputeUrlMapMetadataFilters>?
final
pathTemplateMatch → TfArg<String>?
final
prefixMatch → TfArg<String>?
final
queryParameterMatches → List<ComputeUrlMapQueryParameterMatches>?
final
regexMatch → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited