ComputeUrlMapRangeMatch class final
Typed helper for the path_matcher.route_rules.match_rules.header_matches.range_match block of
google_compute_url_map (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapRangeMatch({required TfArg<
num> rangeEnd, required TfArg<num> rangeStart}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rangeEnd
→ TfArg<
num> -
final
-
rangeStart
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited