ComputeUrlMapUrlMapHeaderMatchRange class

header_matches.range_match block. Both bounds required by the schema.

Annotations
  • @immutable

Constructors

ComputeUrlMapUrlMapHeaderMatchRange({required TfArg<int> rangeStart, required TfArg<int> rangeEnd})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rangeEnd → TfArg<int>
Exclusive upper bound.
final
rangeStart → TfArg<int>
Inclusive lower bound.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited