ComputeZoneVmExtensionPolicyInstanceSelectors class final
Typed helper for the instance_selectors block of
google_compute_zone_vm_extension_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- ComputeZoneVmExtensionPolicyInstanceSelectors({ComputeZoneVmExtensionPolicyLabelSelector? labelSelector})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelSelector → ComputeZoneVmExtensionPolicyLabelSelector?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited