ConditionMatchedLog class
condition_matched_log block — fires on log entries matching filter.
If set, no other conditions can be present in the parent
AlertCondition (the alert policy must use a notification_rate_limit
in AlertStrategy when this condition type is used).
Constructors
-
ConditionMatchedLog({required TfArg<
String> filter, TfArg<Map< ? labelExtractors})String, String> > -
const
Properties
-
filter
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labelExtractors
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited