ConfigDeploymentGitSource class final

Typed helper for the terraform_blueprint.git_source block of google_config_deployment (derived from provider schema).

Annotations
  • @immutable

Constructors

ConfigDeploymentGitSource({TfArg<String>? directory, TfArg<String>? ref, required TfArg<String> repo})
const

Properties

directory → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
ref → TfArg<String>?
final
repo → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited