ContainerAttachedClusterOidcConfig class final

Typed helper for the oidc_config block of google_container_attached_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAttachedClusterOidcConfig({required TfArg<String> issuerUrl, TfArg<String>? jwks})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
issuerUrl → TfArg<String>
final
jwks → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited