ContainerAwsClusterControlPlane class final
Typed helper for the control_plane block of
google_container_aws_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerAwsClusterControlPlane({required TfArg<
String> iamInstanceProfile, TfArg<String> ? instanceType, TfArg<List< ? securityGroupIds, required TfArg<Object?> >List< subnetIds, TfArg<Object?> >Map< ? tags, required TfArg<String, String> >String> version, required ContainerAwsClusterControlPlaneAwsServicesAuthentication awsServicesAuthentication, required ContainerAwsClusterControlPlaneConfigEncryption configEncryption, required ContainerAwsClusterControlPlaneDatabaseEncryption databaseEncryption, ContainerAwsClusterControlPlaneMainVolume? mainVolume, ContainerAwsClusterControlPlaneProxyConfig? proxyConfig, ContainerAwsClusterControlPlaneRootVolume? rootVolume, ContainerAwsClusterControlPlaneSshConfig? sshConfig}) -
const
Properties
- awsServicesAuthentication → ContainerAwsClusterControlPlaneAwsServicesAuthentication
-
final
- configEncryption → ContainerAwsClusterControlPlaneConfigEncryption
-
final
- databaseEncryption → ContainerAwsClusterControlPlaneDatabaseEncryption
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iamInstanceProfile
→ TfArg<
String> -
final
-
instanceType
→ TfArg<
String> ? -
final
- mainVolume → ContainerAwsClusterControlPlaneMainVolume?
-
final
- proxyConfig → ContainerAwsClusterControlPlaneProxyConfig?
-
final
- rootVolume → ContainerAwsClusterControlPlaneRootVolume?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
securityGroupIds
→ TfArg<
List< ?Object?> > -
final
- sshConfig → ContainerAwsClusterControlPlaneSshConfig?
-
final
-
subnetIds
→ TfArg<
List< Object?> > -
final
-
final
-
version
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited