ContainerAwsClusterControlPlaneProxyConfig class final

Typed helper for the control_plane.proxy_config block of google_container_aws_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAwsClusterControlPlaneProxyConfig({required TfArg<String> secretArn, required TfArg<String> secretVersion})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretArn → TfArg<String>
final
secretVersion → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited