ContainerAwsClusterControlPlaneRootVolume class final

Typed helper for the control_plane.root_volume block of google_container_aws_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAwsClusterControlPlaneRootVolume({TfArg<num>? iops, TfArg<String>? kmsKeyArn, TfArg<num>? sizeGib, TfArg<num>? throughput, TfArg<ContainerAwsClusterControlPlaneRootVolumeVolumeType>? volumeType})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iops → TfArg<num>?
final
kmsKeyArn → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeGib → TfArg<num>?
final
throughput → TfArg<num>?
final
volumeType → TfArg<ContainerAwsClusterControlPlaneRootVolumeVolumeType>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited