ContainerAwsNodePoolAutoscalingMetricsCollection class final

Typed helper for the config.autoscaling_metrics_collection block of google_container_aws_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAwsNodePoolAutoscalingMetricsCollection({required TfArg<String> granularity, TfArg<List<String>>? metrics})
const

Properties

granularity → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
metrics → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited