ContainerAwsNodePoolConfig class final

Typed helper for the config block of google_container_aws_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAwsNodePoolConfig({required TfArg<String> iamInstanceProfile, TfArg<String>? instanceType, TfArg<Map<String, String>>? labels, TfArg<List<String>>? securityGroupIds, TfArg<Map<String, String>>? tags, ContainerAwsNodePoolAutoscalingMetricsCollection? autoscalingMetricsCollection, required ContainerAwsNodePoolConfigEncryption configEncryption, ContainerAwsNodePoolProxyConfig? proxyConfig, ContainerAwsNodePoolRootVolume? rootVolume, ContainerAwsNodePoolSshConfig? sshConfig, List<ContainerAwsNodePoolTaints>? taints})
const

Properties

autoscalingMetricsCollection → ContainerAwsNodePoolAutoscalingMetricsCollection?
final
configEncryption → ContainerAwsNodePoolConfigEncryption
final
hashCode → int
The hash code for this object.
no setterinherited
iamInstanceProfile → TfArg<String>
final
instanceType → TfArg<String>?
final
labels → TfArg<Map<String, String>>?
final
proxyConfig → ContainerAwsNodePoolProxyConfig?
final
rootVolume → ContainerAwsNodePoolRootVolume?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → TfArg<List<String>>?
final
sshConfig → ContainerAwsNodePoolSshConfig?
final
tags → TfArg<Map<String, String>>?
final
taints → List<ContainerAwsNodePoolTaints>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited