ContainerAzureClusterNetworking class final

Typed helper for the networking block of google_container_azure_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerAzureClusterNetworking({required TfArg<List<Object?>> podAddressCidrBlocks, required TfArg<List<Object?>> serviceAddressCidrBlocks, required TfArg<String> virtualNetworkId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
podAddressCidrBlocks → TfArg<List<Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAddressCidrBlocks → TfArg<List<Object?>>
final
virtualNetworkId → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited