ContainerClusterAdditionalNodeNetworkConfigs class final
Typed helper for the node_pool.network_config.additional_node_network_configs block of
google_container_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerClusterAdditionalNodeNetworkConfigs({RefTo<
GoogleComputeNetwork> ? network, RefTo<GoogleComputeSubnetwork> ? subnetwork}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
network
→ RefTo<
GoogleComputeNetwork> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetwork
→ RefTo<
GoogleComputeSubnetwork> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited