ContainerClusterContainerdConfig class final
Typed helper for the node_config.containerd_config block of
google_container_cluster (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ContainerClusterContainerdConfig({ContainerClusterPrivateRegistryAccessConfig? privateRegistryAccessConfig, List<
ContainerClusterRegistryHosts> ? registryHosts, ContainerClusterWritableCgroups? writableCgroups}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateRegistryAccessConfig → ContainerClusterPrivateRegistryAccessConfig?
-
final
-
registryHosts
→ List<
ContainerClusterRegistryHosts> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writableCgroups → ContainerClusterWritableCgroups?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited