ContainerClusterDnsConfig class final

Typed helper for the dns_config block of google_container_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerClusterDnsConfig({TfArg<String>? additiveVpcScopeDnsDomain, TfArg<String>? clusterDns, TfArg<String>? clusterDnsDomain, TfArg<String>? clusterDnsScope})
const

Properties

additiveVpcScopeDnsDomain → TfArg<String>?
final
clusterDns → TfArg<String>?
final
clusterDnsDomain → TfArg<String>?
final
clusterDnsScope → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited