ContainerClusterEphemeralStorageLocalSsdConfig class final
Typed helper for the node_config.ephemeral_storage_local_ssd_config block of
google_container_cluster (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ContainerClusterEphemeralStorageLocalSsdConfig({TfArg<
num> ? dataCacheCount, required TfArg<num> localSsdCount}) -
const
Properties
-
dataCacheCount
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
localSsdCount
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited