ContainerClusterNetworkPolicy class final

Typed helper for the network_policy block of google_container_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerClusterNetworkPolicy({required TfArg<bool> enabled, TfArg<String>? provider})
const

Properties

enabled → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
provider → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited