ContainerClusterNodeDrainConfig class final

Typed helper for the node_pool.node_drain_config block of google_container_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerClusterNodeDrainConfig({TfArg<String>? graceTerminationDuration, TfArg<String>? pdbTimeoutDuration, TfArg<bool>? respectPdbDuringNodePoolDeletion})
const

Properties

graceTerminationDuration → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
pdbTimeoutDuration → TfArg<String>?
final
respectPdbDuringNodePoolDeletion → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited