ContainerClusterRecurringWindow class final

Typed helper for the maintenance_policy.recurring_window block of google_container_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerClusterRecurringWindow({required TfArg<String> endTime, required TfArg<String> recurrence, required TfArg<String> startTime})
const

Properties

endTime → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
recurrence → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited