ContainerClusterReservationAffinity class final

Typed helper for the node_config.reservation_affinity block of google_container_cluster (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

ContainerClusterReservationAffinity({required TfArg<String> consumeReservationType, TfArg<String>? key, TfArg<List<String>>? values})
const

Properties

consumeReservationType → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
key → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited