ContainerClusterSecretSyncConfig class final
Typed helper for the secret_sync_config block of
google_container_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerClusterSecretSyncConfig({required TfArg<
bool> enabled, ContainerClusterRotationConfig? rotationConfig}) -
const
Properties
-
enabled
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotationConfig → ContainerClusterRotationConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited