ContainerClusterUpgradeSettings class final

Typed helper for the node_pool.upgrade_settings block of google_container_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerClusterUpgradeSettings({TfArg<num>? maxSurge, TfArg<num>? maxUnavailable, TfArg<String>? strategy, ContainerClusterBlueGreenSettings? blueGreenSettings})
const

Properties

blueGreenSettings → ContainerClusterBlueGreenSettings?
final
hashCode → int
The hash code for this object.
no setterinherited
maxSurge → TfArg<num>?
final
maxUnavailable → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited