ContainerNodePoolAdvancedMachineFeatures class final

Typed helper for the node_config.advanced_machine_features block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolAdvancedMachineFeatures({TfArg<bool>? enableNestedVirtualization, TfArg<String>? performanceMonitoringUnit, required TfArg<num> threadsPerCore})
const

Properties

enableNestedVirtualization → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
performanceMonitoringUnit → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadsPerCore → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited