ContainerNodePoolBootDisk class final

Typed helper for the node_config.boot_disk block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolBootDisk({TfArg<String>? diskType, TfArg<num>? provisionedIops, TfArg<num>? provisionedThroughput, TfArg<num>? sizeGb})
const

Properties

diskType → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
provisionedIops → TfArg<num>?
final
provisionedThroughput → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited