ContainerNodePoolBootDiskProfile class final

Typed helper for the node_config.linux_node_config.swap_config.boot_disk_profile block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolBootDiskProfile({TfArg<num>? swapSizeGib, TfArg<num>? swapSizePercent})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swapSizeGib → TfArg<num>?
final
swapSizePercent → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited