ContainerNodePoolKubeletConfig class final
Typed helper for the node_config.kubelet_config block of
google_container_node_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerNodePoolKubeletConfig({TfArg<
List< ? allowedUnsafeSysctls, TfArg<String> >num> ? containerLogMaxFiles, TfArg<String> ? containerLogMaxSize, TfArg<bool> ? cpuCfsQuota, TfArg<String> ? cpuCfsQuotaPeriod, TfArg<String> ? cpuManagerPolicy, TfArg<num> ? evictionMaxPodGracePeriodSeconds, TfArg<num> ? imageGcHighThresholdPercent, TfArg<num> ? imageGcLowThresholdPercent, TfArg<String> ? imageMaximumGcAge, TfArg<String> ? imageMinimumGcAge, TfArg<String> ? insecureKubeletReadonlyPortEnabled, TfArg<num> ? maxParallelImagePulls, TfArg<num> ? podPidsLimit, TfArg<num> ? shutdownGracePeriodCriticalPodsSeconds, TfArg<num> ? shutdownGracePeriodSeconds, TfArg<bool> ? singleProcessOomKill, ContainerNodePoolCrashLoopBackOff? crashLoopBackOff, ContainerNodePoolEvictionMinimumReclaim? evictionMinimumReclaim, ContainerNodePoolEvictionSoft? evictionSoft, ContainerNodePoolEvictionSoftGracePeriod? evictionSoftGracePeriod, ContainerNodePoolMemoryManager? memoryManager, ContainerNodePoolTopologyManager? topologyManager}) -
const
Properties
-
allowedUnsafeSysctls
→ TfArg<
List< ?String> > -
final
-
containerLogMaxFiles
→ TfArg<
num> ? -
final
-
containerLogMaxSize
→ TfArg<
String> ? -
final
-
cpuCfsQuota
→ TfArg<
bool> ? -
final
-
cpuCfsQuotaPeriod
→ TfArg<
String> ? -
final
-
cpuManagerPolicy
→ TfArg<
String> ? -
final
- crashLoopBackOff → ContainerNodePoolCrashLoopBackOff?
-
final
-
evictionMaxPodGracePeriodSeconds
→ TfArg<
num> ? -
final
- evictionMinimumReclaim → ContainerNodePoolEvictionMinimumReclaim?
-
final
- evictionSoft → ContainerNodePoolEvictionSoft?
-
final
- evictionSoftGracePeriod → ContainerNodePoolEvictionSoftGracePeriod?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageGcHighThresholdPercent
→ TfArg<
num> ? -
final
-
imageGcLowThresholdPercent
→ TfArg<
num> ? -
final
-
imageMaximumGcAge
→ TfArg<
String> ? -
final
-
imageMinimumGcAge
→ TfArg<
String> ? -
final
-
insecureKubeletReadonlyPortEnabled
→ TfArg<
String> ? -
final
-
maxParallelImagePulls
→ TfArg<
num> ? -
final
- memoryManager → ContainerNodePoolMemoryManager?
-
final
-
podPidsLimit
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shutdownGracePeriodCriticalPodsSeconds
→ TfArg<
num> ? -
final
-
shutdownGracePeriodSeconds
→ TfArg<
num> ? -
final
-
singleProcessOomKill
→ TfArg<
bool> ? -
final
- topologyManager → ContainerNodePoolTopologyManager?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited