ContainerNodePoolLinuxNodeConfig class final

Typed helper for the node_config.linux_node_config block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolLinuxNodeConfig({TfArg<String>? cgroupMode, TfArg<Map<String, String>>? sysctls, TfArg<String>? transparentHugepageDefrag, TfArg<String>? transparentHugepageEnabled, ContainerNodePoolAccurateTimeConfig? accurateTimeConfig, ContainerNodePoolCustomNodeInit? customNodeInit, ContainerNodePoolHugepagesConfig? hugepagesConfig, ContainerNodePoolNodeKernelModuleLoading? nodeKernelModuleLoading, ContainerNodePoolSwapConfig? swapConfig})
const

Properties

accurateTimeConfig → ContainerNodePoolAccurateTimeConfig?
final
cgroupMode → TfArg<String>?
final
customNodeInit → ContainerNodePoolCustomNodeInit?
final
hashCode → int
The hash code for this object.
no setterinherited
hugepagesConfig → ContainerNodePoolHugepagesConfig?
final
nodeKernelModuleLoading → ContainerNodePoolNodeKernelModuleLoading?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swapConfig → ContainerNodePoolSwapConfig?
final
sysctls → TfArg<Map<String, String>>?
final
transparentHugepageDefrag → TfArg<String>?
final
transparentHugepageEnabled → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited