ContainerNodePoolMaintenancePolicy class final

Typed helper for the maintenance_policy block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolMaintenancePolicy({List<ContainerNodePoolExclusionUntilEndOfSupport>? exclusionUntilEndOfSupport})
const

Properties

exclusionUntilEndOfSupport → List<ContainerNodePoolExclusionUntilEndOfSupport>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited