ContainerNodePoolRegistryHosts class final

Typed helper for the node_config.containerd_config.registry_hosts block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolRegistryHosts({required TfArg<String> server, List<ContainerNodePoolHosts>? hosts})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hosts → List<ContainerNodePoolHosts>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited