ContainerNodePoolShieldedInstanceConfig class final

Typed helper for the node_config.shielded_instance_config block of google_container_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

ContainerNodePoolShieldedInstanceConfig({TfArg<bool>? enableIntegrityMonitoring, TfArg<bool>? enableSecureBoot})
const

Properties

enableIntegrityMonitoring → TfArg<bool>?
final
enableSecureBoot → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited