ContainerPort class

Container port (ports). Cloud Run v2 supports exactly one port per container.

Annotations
  • @immutable

Constructors

ContainerPort({TfArg<int>? containerPort, TfArg<String>? name})
const

Properties

containerPort → TfArg<int>?
TCP port number. Default is the value of PORT env (passed by Cloud Run at runtime).
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>?
Protocol selector. Must be 'http1' or 'h2c'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited