DataFusionInstanceAccelerators class final

Typed helper for the accelerators block of google_data_fusion_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

DataFusionInstanceAccelerators({required DataFusionInstanceAcceleratorType acceleratorType, required DataFusionInstanceAcceleratorsState state})
const

Properties

acceleratorType → DataFusionInstanceAcceleratorType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → DataFusionInstanceAcceleratorsState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited