DataLineageConfigIntegration extension type
integration — derived from the provider schema description.
Constructors
-
DataLineageConfigIntegration.arg(TfArg<
String> arg) -
const
- DataLineageConfigIntegration.expression(String template)
- DataLineageConfigIntegration.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- dataproc → const DataLineageConfigIntegration
- lookerCore → const DataLineageConfigIntegration
-
values
→ const List<
DataLineageConfigIntegration>