DataLossPreventionContentPolicyInspectConfig class final
Typed helper for the inspect_config block of
google_data_loss_prevention_content_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataLossPreventionContentPolicyInspectConfig({List<
DataLossPreventionContentPolicyContentOptions> ? contentOptions, TfArg<bool> ? excludeInfoTypes, TfArg<bool> ? includeQuote, DataLossPreventionContentPolicyMinLikelihood? minLikelihood, List<DataLossPreventionContentPolicyCustomInfoTypes> ? customInfoTypes, List<DataLossPreventionContentPolicyInfoTypes> ? infoTypes, DataLossPreventionContentPolicyLimits? limits, List<DataLossPreventionContentPolicyMinLikelihoodPerInfoType> ? minLikelihoodPerInfoType, List<DataLossPreventionContentPolicyRuleSet> ? ruleSet}) -
const
Properties
-
contentOptions
→ List<
DataLossPreventionContentPolicyContentOptions> ? -
final
-
customInfoTypes
→ List<
DataLossPreventionContentPolicyCustomInfoTypes> ? -
final
-
excludeInfoTypes
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeQuote
→ TfArg<
bool> ? -
final
-
infoTypes
→ List<
DataLossPreventionContentPolicyInfoTypes> ? -
final
- limits → DataLossPreventionContentPolicyLimits?
-
final
- minLikelihood → DataLossPreventionContentPolicyMinLikelihood?
-
final
-
minLikelihoodPerInfoType
→ List<
DataLossPreventionContentPolicyMinLikelihoodPerInfoType> ? -
final
-
ruleSet
→ List<
DataLossPreventionContentPolicyRuleSet> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited