DataLossPreventionContentPolicyRuleSetRules class final
Typed helper for the inspect_config.rule_set.rules block of
google_data_loss_prevention_content_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DataLossPreventionContentPolicyRuleSetRules({DataLossPreventionContentPolicyExclusionRule? exclusionRule, DataLossPreventionContentPolicyHotwordRule? hotwordRule})
-
const
Properties
- exclusionRule → DataLossPreventionContentPolicyExclusionRule?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hotwordRule → DataLossPreventionContentPolicyHotwordRule?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited