DataLossPreventionDeidentifyTemplateTimePartConfig class final
Typed helper for the deidentify_config.info_type_transformations.transformations.primitive_transformation.time_part_config block of
google_data_loss_prevention_deidentify_template (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
- DataLossPreventionDeidentifyTemplateTimePartConfig({DataLossPreventionDeidentifyTemplatePartToExtract? partToExtract})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partToExtract → DataLossPreventionDeidentifyTemplatePartToExtract?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited