DataLossPreventionDiscoveryConfigOrgConfig class final
Typed helper for the org_config block of
google_data_loss_prevention_discovery_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataLossPreventionDiscoveryConfigOrgConfig({TfArg<
String> ? projectId, DataLossPreventionDiscoveryConfigOrgConfigLocation? location}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → DataLossPreventionDiscoveryConfigOrgConfigLocation?
-
final
-
projectId
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited