DataLossPreventionDiscoveryConfigTableReference class final

Typed helper for the targets.big_query_target.filter.table_reference block of google_data_loss_prevention_discovery_config (derived from provider schema).

Annotations
  • @immutable

Constructors

DataLossPreventionDiscoveryConfigTableReference({required RefTo<GoogleBigqueryDataset> datasetId, TfArg<String>? projectId, required TfArg<String> tableId})
const

Properties

datasetId → RefTo<GoogleBigqueryDataset>
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited