DataLossPreventionJobTriggerCloudStorageOptions class final
Typed helper for the inspect_job.storage_config.cloud_storage_options block of
google_data_loss_prevention_job_trigger (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataLossPreventionJobTriggerCloudStorageOptions({TfArg<
num> ? bytesLimitPerFile, TfArg<num> ? bytesLimitPerFilePercent, List<DataLossPreventionJobTriggerFileTypes> ? fileTypes, TfArg<num> ? filesLimitPercent, DataLossPreventionJobTriggerSampleMethod? sampleMethod, required DataLossPreventionJobTriggerFileSet fileSet}) -
const
Properties
-
bytesLimitPerFile
→ TfArg<
num> ? -
final
-
bytesLimitPerFilePercent
→ TfArg<
num> ? -
final
- fileSet → DataLossPreventionJobTriggerFileSet
-
final
-
filesLimitPercent
→ TfArg<
num> ? -
final
-
fileTypes
→ List<
DataLossPreventionJobTriggerFileTypes> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleMethod → DataLossPreventionJobTriggerSampleMethod?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited