DataLossPreventionJobTriggerProximity class final

Typed helper for the inspect_job.inspect_config.rule_set.rules.hotword_rule.proximity block of google_data_loss_prevention_job_trigger (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

DataLossPreventionJobTriggerProximity({TfArg<num>? windowAfter, TfArg<num>? windowBefore})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowAfter → TfArg<num>?
final
windowBefore → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited