DataLossPreventionJobTriggerStorageConfig class final
Typed helper for the inspect_job.storage_config block of
google_data_loss_prevention_job_trigger (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DataLossPreventionJobTriggerStorageConfig({DataLossPreventionJobTriggerBigQueryOptions? bigQueryOptions, DataLossPreventionJobTriggerCloudStorageOptions? cloudStorageOptions, DataLossPreventionJobTriggerDatastoreOptions? datastoreOptions, DataLossPreventionJobTriggerHybridOptions? hybridOptions, DataLossPreventionJobTriggerTimespanConfig? timespanConfig})
-
const
Properties
- bigQueryOptions → DataLossPreventionJobTriggerBigQueryOptions?
-
final
- cloudStorageOptions → DataLossPreventionJobTriggerCloudStorageOptions?
-
final
- datastoreOptions → DataLossPreventionJobTriggerDatastoreOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hybridOptions → DataLossPreventionJobTriggerHybridOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timespanConfig → DataLossPreventionJobTriggerTimespanConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited