DataLossPreventionJobTriggerTableOptions class final
Typed helper for the inspect_job.storage_config.hybrid_options.table_options block of
google_data_loss_prevention_job_trigger (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataLossPreventionJobTriggerTableOptions({List<
DataLossPreventionJobTriggerIdentifyingFields> ? identifyingFields}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifyingFields
→ List<
DataLossPreventionJobTriggerIdentifyingFields> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited