DataLossPreventionJobTriggerTableReference class final

Typed helper for the inspect_job.storage_config.big_query_options.table_reference block of google_data_loss_prevention_job_trigger (derived from provider schema).

Annotations
  • @immutable

Constructors

DataLossPreventionJobTriggerTableReference({required RefTo<GoogleBigqueryDataset> datasetId, required TfArg<String> projectId, required TfArg<String> tableId})
const

Properties

datasetId → RefTo<GoogleBigqueryDataset>
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited