DatabaseFlag class

One settings.database_flags entry — engine-level flag. Both keys are simple strings on the wire (numeric flag values are stringified — '1000', not 1000).

Annotations
  • @immutable

Constructors

DatabaseFlag({required String name, required String value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Engine flag name (e.g. 'max_connections').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Flag value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited