DatabaseMigrationServiceConnectionProfileMachineConfig class final

Typed helper for the alloydb.settings.primary_instance_settings.machine_config block of google_database_migration_service_connection_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

DatabaseMigrationServiceConnectionProfileMachineConfig({required TfArg<num> cpuCount})
const

Properties

cpuCount → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited