DatabaseMigrationServiceConnectionProfilePostgresql class final

Typed helper for the postgresql block of google_database_migration_service_connection_profile (derived from provider schema).

Annotations
  • @immutable

Properties

alloydbClusterId → TfArg<String>?
final
cloudSqlId → TfArg<String>?
final
database → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
host → TfArg<String>?
final
password → Sensitive<String>?
final
port → TfArg<num>?
final
privateConnectivity → DatabaseMigrationServiceConnectionProfilePrivateConnectivity?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssl → DatabaseMigrationServiceConnectionProfileMysqlSsl?
final
username → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited