DatabaseMigrationServiceMigrationJobObjectsConfigSourceObjectsConfig class final

Typed helper for the objects_config.source_objects_config block of google_database_migration_service_migration_job (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
objectConfigs List<DatabaseMigrationServiceMigrationJobObjectsConfigSourceObjectsConfigObjectConfigs>?
final
objectsSelectionType → TfArg<DatabaseMigrationServiceMigrationJobObjectsConfigSourceObjectsConfigObjectsSelectionType>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited