DatabaseMigrationServiceMigrationJobReverseSshConnectivity class final

Typed helper for the reverse_ssh_connectivity block of google_database_migration_service_migration_job (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vm → TfArg<String>?
final
vmIp → TfArg<String>?
final
vmPort → TfArg<num>?
final
vpc → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited