DatabaseMigrationServicePrivateConnectionVpcPeeringConfig class final

Typed helper for the vpc_peering_config block of google_database_migration_service_private_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

DatabaseMigrationServicePrivateConnectionVpcPeeringConfig({required TfArg<String> subnet, required TfArg<String> vpcName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnet → TfArg<String>
final
vpcName → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited