DataplexDatascanCsvOptions class final

Typed helper for the data_discovery_spec.storage_config.csv_options block of google_dataplex_datascan (derived from provider schema).

Annotations
  • @immutable

Constructors

DataplexDatascanCsvOptions({TfArg<String>? delimiter, TfArg<String>? encoding, TfArg<num>? headerRows, TfArg<String>? quote, TfArg<bool>? typeInferenceDisabled})
const

Properties

delimiter → TfArg<String>?
final
encoding → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headerRows → TfArg<num>?
final
quote → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeInferenceDisabled → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited