DataplexDatascanDataProfileSpec class final
data_profile_spec — column statistics for BigQuery tables or entities.
- Inheritance
-
- Object
- DataplexDatascanSpec
- DataplexDatascanDataProfileSpec
- Annotations
-
- @immutable
Constructors
Properties
- blockKey → String
-
no setteroverride
-
catalogPublishingEnabled
→ TfArg<
bool> ? -
final
-
excludeFields
→ TfArg<
Map< ?String, Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeFields
→ TfArg<
Map< ?String, Object?> > -
final
-
postScanActions
→ TfArg<
Map< ?String, Object?> > -
final
-
rowFilter
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samplingPercent
→ TfArg<
double> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited