DataplexDatascanExcludeFields class final

Typed helper for the data_profile_spec.exclude_fields block of google_dataplex_datascan (derived from provider schema).

Annotations
  • @immutable

Constructors

DataplexDatascanExcludeFields({TfArg<List<String>>? fieldNames})
const

Properties

fieldNames → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited