DataplexDatascanExecutionSpecTrigger class final
Typed helper for the execution_spec.trigger block of
google_dataplex_datascan (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DataplexDatascanExecutionSpecTrigger({DataplexDatascanExecutionSpecTriggerOnDemand? onDemand, DataplexDatascanExecutionSpecTriggerOneTime? oneTime, DataplexDatascanExecutionSpecTriggerSchedule? schedule})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDemand → DataplexDatascanExecutionSpecTriggerOnDemand?
-
final
- oneTime → DataplexDatascanExecutionSpecTriggerOneTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule → DataplexDatascanExecutionSpecTriggerSchedule?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited