DataplexDatascanExecutionSpecTriggerSchedule class final

Typed helper for the execution_spec.trigger.schedule block of google_dataplex_datascan (derived from provider schema).

Annotations
  • @immutable

Constructors

DataplexDatascanExecutionSpecTriggerSchedule({required TfArg<String> cron})
const

Properties

cron → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited