DataplexTaskDriverMainClass class final

The DataplexTaskDriver.mainClass choice: sets main_class.

Inheritance

Constructors

DataplexTaskDriverMainClass(TfArg<String> mainClass)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mainClass → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited