DataplexTaskDriverSqlScriptFile class final

The DataplexTaskDriver.sqlScriptFile choice: sets sql_script_file.

Inheritance

Constructors

DataplexTaskDriverSqlScriptFile(TfArg<String> sqlScriptFile)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlScriptFile → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited