DataplexTaskTargetNetwork class final
The DataplexTaskTarget.network choice: sets network.
- Inheritance
-
- Object
- DataplexTaskTarget
- DataplexTaskTargetNetwork
Constructors
-
DataplexTaskTargetNetwork(RefTo<
GoogleComputeNetwork> network) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
network
→ RefTo<
GoogleComputeNetwork> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited