DataplexTaskTriggerSpec class final

Typed helper for the trigger_spec block of google_dataplex_task (derived from provider schema).

Annotations
  • @immutable

Constructors

DataplexTaskTriggerSpec({TfArg<bool>? disabled, TfArg<num>? maxRetries, TfArg<String>? schedule, TfArg<String>? startTime, required DataplexTaskType type})
const

Properties

disabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
maxRetries → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → TfArg<String>?
final
startTime → TfArg<String>?
final
type → DataplexTaskType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited