DataplexZoneResourceSpec class final

Typed helper for the resource_spec block of google_dataplex_zone (derived from provider schema).

Annotations
  • @immutable

Constructors

DataplexZoneResourceSpec({required DataplexZoneLocationType locationType})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
locationType → DataplexZoneLocationType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited