DataprocBatchEnvironmentConfigExecutionConfig class final

Typed helper for the environment_config.execution_config block of google_dataproc_batch (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocBatchEnvironmentConfigExecutionConfig({TfArg<String>? kmsKey, TfArg<List<Object?>>? networkTags, TfArg<String>? networkUri, TfArg<String>? serviceAccount, TfArg<String>? stagingBucket, TfArg<String>? subnetworkUri, TfArg<String>? ttl, DataprocBatchEnvironmentConfigExecutionConfigAuthenticationConfig? authenticationConfig})
const

Properties

authenticationConfig DataprocBatchEnvironmentConfigExecutionConfigAuthenticationConfig?
final
hashCode int
The hash code for this object.
no setterinherited
kmsKey → TfArg<String>?
final
networkTags → TfArg<List<Object?>>?
final
networkUri → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → TfArg<String>?
final
stagingBucket → TfArg<String>?
final
subnetworkUri → TfArg<String>?
final
ttl → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited