DataprocBatchEnvironmentConfigPeripheralsConfig class final

Typed helper for the environment_config.peripherals_config block of google_dataproc_batch (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
metastoreService → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sparkHistoryServerConfig DataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited