DataprocBatchNetworkSubnetworkUri class final
The DataprocBatchNetwork.subnetworkUri choice: sets subnetwork_uri.
- Inheritance
-
- Object
- DataprocBatchNetwork
- DataprocBatchNetworkSubnetworkUri
Constructors
-
DataprocBatchNetworkSubnetworkUri(RefTo<
GoogleComputeSubnetwork> subnetworkUri) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetworkUri
→ RefTo<
GoogleComputeSubnetwork> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited