DataprocBatchPeripheralsConfig class final

Typed helper for the environment_config.peripherals_config block of google_dataproc_batch (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocBatchPeripheralsConfig({TfArg<String>? metastoreService, DataprocBatchSparkHistoryServerConfig? sparkHistoryServerConfig})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metastoreService → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkHistoryServerConfig → DataprocBatchSparkHistoryServerConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited