DataprocClusterClusterConfigMasterConfigDiskConfig class final

Typed helper for the cluster_config.master_config.disk_config block of google_dataproc_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocClusterClusterConfigMasterConfigDiskConfig({TfArg<num>? bootDiskProvisionedIops, TfArg<num>? bootDiskProvisionedThroughput, TfArg<num>? bootDiskSizeGb, TfArg<String>? bootDiskType, TfArg<String>? localSsdInterface, TfArg<num>? numLocalSsds, List<DataprocClusterClusterConfigMasterConfigDiskConfigAttachedDiskConfig>? attachedDiskConfig})
const

Properties

attachedDiskConfig List<DataprocClusterClusterConfigMasterConfigDiskConfigAttachedDiskConfig>?
final
bootDiskProvisionedIops → TfArg<num>?
final
bootDiskProvisionedThroughput → TfArg<num>?
final
bootDiskSizeGb → TfArg<num>?
final
bootDiskType → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
localSsdInterface → TfArg<String>?
final
numLocalSsds → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited