DataprocClusterConfig class final
Typed helper for the cluster_config block of
google_dataproc_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocClusterConfig({TfArg<
String> ? clusterTier, TfArg<String> ? clusterType, TfArg<String> ? engine, TfArg<String> ? stagingBucket, TfArg<String> ? tempBucket, DataprocClusterAutoscalingConfig? autoscalingConfig, List<DataprocClusterAuxiliaryNodeGroups> ? auxiliaryNodeGroups, DataprocClusterDataprocMetricConfig? dataprocMetricConfig, DataprocClusterEncryptionConfig? encryptionConfig, DataprocClusterEndpointConfig? endpointConfig, DataprocClusterGceClusterConfig? gceClusterConfig, List<DataprocClusterInitializationAction> ? initializationAction, DataprocClusterLifecycleConfig? lifecycleConfig, DataprocClusterMasterConfig? masterConfig, DataprocClusterMetastoreConfig? metastoreConfig, DataprocClusterPreemptibleWorkerConfig? preemptibleWorkerConfig, DataprocClusterSecurityConfig? securityConfig, DataprocClusterSoftwareConfig? softwareConfig, DataprocClusterWorkerConfig? workerConfig}) -
const
Properties
- autoscalingConfig → DataprocClusterAutoscalingConfig?
-
final
-
auxiliaryNodeGroups
→ List<
DataprocClusterAuxiliaryNodeGroups> ? -
final
-
clusterTier
→ TfArg<
String> ? -
final
-
clusterType
→ TfArg<
String> ? -
final
- dataprocMetricConfig → DataprocClusterDataprocMetricConfig?
-
final
- encryptionConfig → DataprocClusterEncryptionConfig?
-
final
- endpointConfig → DataprocClusterEndpointConfig?
-
final
-
engine
→ TfArg<
String> ? -
final
- gceClusterConfig → DataprocClusterGceClusterConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initializationAction
→ List<
DataprocClusterInitializationAction> ? -
final
- lifecycleConfig → DataprocClusterLifecycleConfig?
-
final
- masterConfig → DataprocClusterMasterConfig?
-
final
- metastoreConfig → DataprocClusterMetastoreConfig?
-
final
- preemptibleWorkerConfig → DataprocClusterPreemptibleWorkerConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityConfig → DataprocClusterSecurityConfig?
-
final
- softwareConfig → DataprocClusterSoftwareConfig?
-
final
-
stagingBucket
→ TfArg<
String> ? -
final
-
tempBucket
→ TfArg<
String> ? -
final
- workerConfig → DataprocClusterWorkerConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited