DataprocClusterDataprocMetricConfig class final

Typed helper for the cluster_config.dataproc_metric_config block of google_dataproc_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocClusterDataprocMetricConfig({required List<DataprocClusterMetrics> metrics})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics → List<DataprocClusterMetrics>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited