DataprocClusterGceClusterConfig class final
Typed helper for the cluster_config.gce_cluster_config block of
google_dataproc_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocClusterGceClusterConfig({TfArg<
bool> ? internalIpOnly, TfArg<Map< ? metadata, RefTo<String, String> >GoogleComputeNetwork> ? network, TfArg<Map< ? resourceManagerTags, RefTo<String, String> >GoogleServiceAccount> ? serviceAccount, TfArg<List< ? serviceAccountScopes, RefTo<String> >GoogleComputeSubnetwork> ? subnetwork, TfArg<List< ? tags, TfArg<String> >String> ? zone, DataprocClusterConfidentialInstanceConfig? confidentialInstanceConfig, DataprocClusterNodeGroupAffinity? nodeGroupAffinity, DataprocClusterReservationAffinity? reservationAffinity, DataprocClusterShieldedInstanceConfig? shieldedInstanceConfig}) -
const
Properties
- confidentialInstanceConfig → DataprocClusterConfidentialInstanceConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
internalIpOnly
→ TfArg<
bool> ? -
final
-
metadata
→ TfArg<
Map< ?String, String> > -
final
-
network
→ RefTo<
GoogleComputeNetwork> ? -
final
- nodeGroupAffinity → DataprocClusterNodeGroupAffinity?
-
final
- reservationAffinity → DataprocClusterReservationAffinity?
-
final
-
resourceManagerTags
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccount
→ RefTo<
GoogleServiceAccount> ? -
final
-
serviceAccountScopes
→ TfArg<
List< ?String> > -
final
- shieldedInstanceConfig → DataprocClusterShieldedInstanceConfig?
-
final
-
subnetwork
→ RefTo<
GoogleComputeSubnetwork> ? -
final
-
final
-
zone
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited