DataprocClusterMasterConfig class final
Typed helper for the cluster_config.master_config block of
google_dataproc_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocClusterMasterConfig({TfArg<
String> ? imageUri, TfArg<String> ? machineType, TfArg<String> ? minCpuPlatform, TfArg<num> ? numInstances, List<DataprocClusterAccelerators> ? accelerators, DataprocClusterDiskConfig? diskConfig, DataprocClusterMasterConfigInstanceFlexibilityPolicy? instanceFlexibilityPolicy}) -
const
Properties
-
accelerators
→ List<
DataprocClusterAccelerators> ? -
final
- diskConfig → DataprocClusterDiskConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageUri
→ TfArg<
String> ? -
final
- instanceFlexibilityPolicy → DataprocClusterMasterConfigInstanceFlexibilityPolicy?
-
final
-
machineType
→ TfArg<
String> ? -
final
-
minCpuPlatform
→ TfArg<
String> ? -
final
-
numInstances
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited