DataprocClusterNodeGroup class final

Typed helper for the cluster_config.auxiliary_node_groups.node_group block of google_dataproc_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocClusterNodeGroup({required TfArg<List<String>> roles, DataprocClusterNodeGroupConfig? nodeGroupConfig})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeGroupConfig → DataprocClusterNodeGroupConfig?
final
roles → TfArg<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited