DataprocClusterSparkHistoryServerConfig class final

Typed helper for the virtual_cluster_config.auxiliary_services_config.spark_history_server_config block of google_dataproc_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocClusterSparkHistoryServerConfig({TfArg<String>? dataprocCluster})
const

Properties

dataprocCluster → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited