DataprocClusterVirtualClusterConfigAuxiliaryServicesConfig class final
Typed helper for the virtual_cluster_config.auxiliary_services_config block of
google_dataproc_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DataprocClusterVirtualClusterConfigAuxiliaryServicesConfig({DataprocClusterVirtualClusterConfigAuxiliaryServicesConfigMetastoreConfig? metastoreConfig, DataprocClusterVirtualClusterConfigAuxiliaryServicesConfigSparkHistoryServerConfig? sparkHistoryServerConfig})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metastoreConfig → DataprocClusterVirtualClusterConfigAuxiliaryServicesConfigMetastoreConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sparkHistoryServerConfig → DataprocClusterVirtualClusterConfigAuxiliaryServicesConfigSparkHistoryServerConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited