DataprocClusterVirtualClusterConfigKubernetesClusterConfigGkeClusterConfigNodePoolTargetNodePoolConfigConfig class final

Typed helper for the virtual_cluster_config.kubernetes_cluster_config.gke_cluster_config.node_pool_target.node_pool_config.config block of google_dataproc_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocClusterVirtualClusterConfigKubernetesClusterConfigGkeClusterConfigNodePoolTargetNodePoolConfigConfig({TfArg<num>? localSsdCount, TfArg<String>? machineType, TfArg<String>? minCpuPlatform, TfArg<bool>? preemptible, TfArg<bool>? spot})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
localSsdCount → TfArg<num>?
final
machineType → TfArg<String>?
final
minCpuPlatform → TfArg<String>?
final
preemptible → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spot → TfArg<bool>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited