DataprocGdcApplicationEnvironmentSparkApplicationEnvironmentConfig class final
Typed helper for the spark_application_environment_config block of
google_dataproc_gdc_application_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocGdcApplicationEnvironmentSparkApplicationEnvironmentConfig({TfArg<
Map< ? defaultProperties, TfArg<String, String> >String> ? defaultVersion}) -
const
Properties
-
defaultProperties
→ TfArg<
Map< ?String, String> > -
final
-
defaultVersion
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited