DataprocGdcSparkApplicationSparkSqlApplicationConfig class final

Typed helper for the spark_sql_application_config block of google_dataproc_gdc_spark_application (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocGdcSparkApplicationSparkSqlApplicationConfig({TfArg<List<Object?>>? jarFileUris, TfArg<String>? queryFileUri, TfArg<Map<String, String>>? scriptVariables, DataprocGdcSparkApplicationSparkSqlApplicationConfigQueryList? queryList})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
jarFileUris → TfArg<List<Object?>>?
final
queryFileUri → TfArg<String>?
final
queryList DataprocGdcSparkApplicationSparkSqlApplicationConfigQueryList?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptVariables → TfArg<Map<String, String>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited