DataprocGdcSparkApplicationWorkloadSparkRApplicationConfig class final
The DataprocGdcSparkApplicationWorkload.sparkRApplicationConfig choice: sets spark_r_application_config.
- Inheritance
-
- Object
- DataprocGdcSparkApplicationWorkload
- DataprocGdcSparkApplicationWorkloadSparkRApplicationConfig
Constructors
- DataprocGdcSparkApplicationWorkloadSparkRApplicationConfig(DataprocGdcSparkApplicationSparkRApplicationConfig sparkRApplicationConfig)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sparkRApplicationConfig → DataprocGdcSparkApplicationSparkRApplicationConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited