DataprocGdcSparkApplicationWorkloadSparkSqlApplicationConfig class final
The DataprocGdcSparkApplicationWorkload.sparkSqlApplicationConfig choice: sets spark_sql_application_config.
- Inheritance
-
- Object
- DataprocGdcSparkApplicationWorkload
- DataprocGdcSparkApplicationWorkloadSparkSqlApplicationConfig
Constructors
- DataprocGdcSparkApplicationWorkloadSparkSqlApplicationConfig(DataprocGdcSparkApplicationSparkSqlApplicationConfig sparkSqlApplicationConfig)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sparkSqlApplicationConfig → DataprocGdcSparkApplicationSparkSqlApplicationConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited