DataprocMetastoreServiceMaintenanceWindow class final

Typed helper for the maintenance_window block of google_dataproc_metastore_service (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocMetastoreServiceMaintenanceWindow({required DataprocMetastoreServiceDayOfWeek dayOfWeek, required TfArg<num> hourOfDay})
const

Properties

dayOfWeek → DataprocMetastoreServiceDayOfWeek
final
hashCode → int
The hash code for this object.
no setterinherited
hourOfDay → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited