DataprocSessionTemplateAuthenticationConfig class final

Typed helper for the environment_config.execution_config.authentication_config block of google_dataproc_session_template (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userWorkloadAuthenticationType → DataprocSessionTemplateUserWorkloadAuthenticationType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited