DataprocWorkflowTemplateJobsPrestoJob class final

Typed helper for the jobs.presto_job block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateJobsPrestoJob({TfArg<List<Object?>>? clientTags, TfArg<bool>? continueOnFailure, TfArg<String>? outputFormat, TfArg<Map<String, String>>? properties, TfArg<String>? queryFileUri, DataprocWorkflowTemplateJobsPrestoJobLoggingConfig? loggingConfig, DataprocWorkflowTemplateJobsPrestoJobQueryList? queryList})
const

Properties

clientTags → TfArg<List<Object?>>?
final
continueOnFailure → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
loggingConfig DataprocWorkflowTemplateJobsPrestoJobLoggingConfig?
final
outputFormat → TfArg<String>?
final
properties → TfArg<Map<String, String>>?
final
queryFileUri → TfArg<String>?
final
queryList DataprocWorkflowTemplateJobsPrestoJobQueryList?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited