DataprocWorkflowTemplateJobsPrestoJobLoggingConfig class final

Typed helper for the jobs.presto_job.logging_config block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateJobsPrestoJobLoggingConfig({TfArg<Map<String, String>>? driverLogLevels})
const

Properties

driverLogLevels → TfArg<Map<String, String>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited