DataprocWorkflowTemplateJobsPrestoJobQueryList class final

Typed helper for the jobs.presto_job.query_list block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateJobsPrestoJobQueryList({required TfArg<List<Object?>> queries})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
queries → TfArg<List<Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited