DataprocWorkflowTemplateParameters class final

Typed helper for the parameters block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateParameters({TfArg<String>? description, required TfArg<List<String>> fields, required TfArg<String> name, DataprocWorkflowTemplateValidation? validation})
const

Properties

description → TfArg<String>?
final
fields → TfArg<List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validation → DataprocWorkflowTemplateValidation?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited