DataprocWorkflowTemplatePlacementManagedClusterConfigGceClusterConfigShieldedInstanceConfig class final
Typed helper for the placement.managed_cluster.config.gce_cluster_config.shielded_instance_config block of
google_dataproc_workflow_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocWorkflowTemplatePlacementManagedClusterConfigGceClusterConfigShieldedInstanceConfig({TfArg<
bool> ? enableIntegrityMonitoring, TfArg<bool> ? enableSecureBoot, TfArg<bool> ? enableVtpm}) -
const
Properties
-
enableIntegrityMonitoring
→ TfArg<
bool> ? -
final
-
enableSecureBoot
→ TfArg<
bool> ? -
final
-
enableVtpm
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited