DataprocWorkflowTemplatePlacementManagedClusterConfigSoftwareConfig class final

Typed helper for the placement.managed_cluster.config.software_config block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplatePlacementManagedClusterConfigSoftwareConfig({TfArg<String>? imageVersion, TfArg<List<Object?>>? optionalComponents, TfArg<Map<String, String>>? properties})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imageVersion → TfArg<String>?
final
optionalComponents → TfArg<List<Object?>>?
final
properties → TfArg<Map<String, String>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited