DataprocWorkflowTemplateRegex class final

Typed helper for the parameters.validation.regex block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateRegex({required TfArg<List<String>> regexes})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
regexes → TfArg<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited