DataprocWorkflowTemplateReservationAffinity class final
Typed helper for the placement.managed_cluster.config.gce_cluster_config.reservation_affinity block of
google_dataproc_workflow_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocWorkflowTemplateReservationAffinity({DataprocWorkflowTemplateConsumeReservationType? consumeReservationType, TfArg<
String> ? key, TfArg<List< ? values})String> > -
const
Properties
- consumeReservationType → DataprocWorkflowTemplateConsumeReservationType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited