DataprocWorkflowTemplateScheduling class final

Typed helper for the jobs.scheduling block of google_dataproc_workflow_template (derived from provider schema).

Annotations
  • @immutable

Constructors

DataprocWorkflowTemplateScheduling({TfArg<num>? maxFailuresPerHour, TfArg<num>? maxFailuresTotal})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxFailuresPerHour → TfArg<num>?
final
maxFailuresTotal → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited