DatastreamConnectionProfileForwardSshConnectivity class final

Typed helper for the forward_ssh_connectivity block of google_datastream_connection_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamConnectionProfileForwardSshConnectivity({required TfArg<String> hostname, DatastreamConnectionProfileCredential? credential, TfArg<num>? port, required TfArg<String> username})
const

Properties

credential → DatastreamConnectionProfileCredential?
final
hashCode → int
The hash code for this object.
no setterinherited
hostname → TfArg<String>
final
port → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited