DatastreamStreamBackfillAllOracleExcludedObjectsOracleSchemas class final
Typed helper for the backfill_all.oracle_excluded_objects.oracle_schemas block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamBackfillAllOracleExcludedObjectsOracleSchemas({required TfArg<
String> schema, List<DatastreamStreamBackfillAllOracleExcludedObjectsOracleSchemasOracleTables> ? oracleTables}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
oracleTables
→ List<
DatastreamStreamBackfillAllOracleExcludedObjectsOracleSchemasOracleTables> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited