DatastreamStreamBackfillAllSalesforceExcludedObjectsObjects class final
Typed helper for the backfill_all.salesforce_excluded_objects.objects block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamBackfillAllSalesforceExcludedObjectsObjects({TfArg<
String> ? objectName, List<DatastreamStreamBackfillAllSalesforceExcludedObjectsObjectsFields> ? fields}) -
const
Properties
-
fields
→ List<
DatastreamStreamBackfillAllSalesforceExcludedObjectsObjectsFields> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
objectName
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited