DatastreamStreamBackfillAllSqlServerExcludedObjectsSchemasTablesColumns class final

Typed helper for the backfill_all.sql_server_excluded_objects.schemas.tables.columns block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamBackfillAllSqlServerExcludedObjectsSchemasTablesColumns({TfArg<String>? column, TfArg<String>? dataType})
const

Properties

column → TfArg<String>?
final
dataType → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited