DatastreamStreamBigqueryDestinationConfig class final

Typed helper for the destination_config.bigquery_destination_config block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamBigqueryDestinationConfig({TfArg<String>? dataFreshness, DatastreamStreamWriteMode? writeMode, DatastreamStreamBlmtConfig? blmtConfig, required DatastreamStreamDataset dataset})
const

Properties

blmtConfig → DatastreamStreamBlmtConfig?
final
dataFreshness → TfArg<String>?
final
dataset → DatastreamStreamDataset
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeMode → DatastreamStreamWriteMode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited