DatastreamStreamExcludeObjectsSchemas class final
Typed helper for the source_config.spanner_source_config.exclude_objects.schemas block of
google_datastream_stream (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamExcludeObjectsSchemas({required TfArg<
String> schema, List<DatastreamStreamExcludeObjectsTables> ? tables}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ TfArg<
String> -
final
-
tables
→ List<
DatastreamStreamExcludeObjectsTables> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited