DatastreamStreamIntegerRangePartition class final

Typed helper for the rule_sets.customization_rules.bigquery_partitioning.integer_range_partition block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamIntegerRangePartition({required TfArg<String> column, required TfArg<num> end, required TfArg<num> interval, required TfArg<num> start})
const

Properties

column → TfArg<String>
final
end → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
interval → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited