DatastreamStreamJsonFileFormatChoice class final
The DatastreamStreamFileFormat.jsonFileFormat choice: sets json_file_format.
- Inheritance
-
- Object
- DatastreamStreamFileFormat
- DatastreamStreamJsonFileFormatChoice
Constructors
- DatastreamStreamJsonFileFormatChoice(DatastreamStreamJsonFileFormat jsonFileFormat)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonFileFormat → DatastreamStreamJsonFileFormat
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited