DatastreamStreamMysqlSourceConfigExcludeObjects class final

Typed helper for the source_config.mysql_source_config.exclude_objects block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
mysqlDatabases → List<DatastreamStreamMysqlDatabases>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited