DatastreamStreamPartitioningTimeGranularity extension type
partitioning_time_granularity — derived from the provider schema description.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- partitioningTimeGranularityDay → const DatastreamStreamPartitioningTimeGranularity
- partitioningTimeGranularityHour → const DatastreamStreamPartitioningTimeGranularity
- partitioningTimeGranularityMonth → const DatastreamStreamPartitioningTimeGranularity
- partitioningTimeGranularityUnspecified → const DatastreamStreamPartitioningTimeGranularity
- partitioningTimeGranularityYear → const DatastreamStreamPartitioningTimeGranularity
-
values
→ const List<
DatastreamStreamPartitioningTimeGranularity>