DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioning class final
Typed helper for the rule_sets.customization_rules.bigquery_partitioning block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioning({TfArg<
bool> ? requirePartitionFilter, DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningIngestionTimePartition? ingestionTimePartition, DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningIntegerRangePartition? integerRangePartition, DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningTimeUnitPartition? timeUnitPartition}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ingestionTimePartition → DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningIngestionTimePartition?
-
final
- integerRangePartition → DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningIntegerRangePartition?
-
final
-
requirePartitionFilter
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeUnitPartition → DatastreamStreamRuleSetsCustomizationRulesBigqueryPartitioningTimeUnitPartition?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited