DatastreamStreamSourceConfig class final
Typed helper for the source_config block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamSourceConfig({required TfArg<
String> sourceConnectionProfile, DatastreamStreamSourceConfigMongodbSourceConfig? mongodbSourceConfig, DatastreamStreamSourceConfigMysqlSourceConfig? mysqlSourceConfig, DatastreamStreamSourceConfigOracleSourceConfig? oracleSourceConfig, DatastreamStreamSourceConfigPostgresqlSourceConfig? postgresqlSourceConfig, DatastreamStreamSourceConfigSalesforceSourceConfig? salesforceSourceConfig, DatastreamStreamSourceConfigSpannerSourceConfig? spannerSourceConfig, DatastreamStreamSourceConfigSqlServerSourceConfig? sqlServerSourceConfig}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mongodbSourceConfig → DatastreamStreamSourceConfigMongodbSourceConfig?
-
final
- mysqlSourceConfig → DatastreamStreamSourceConfigMysqlSourceConfig?
-
final
- oracleSourceConfig → DatastreamStreamSourceConfigOracleSourceConfig?
-
final
- postgresqlSourceConfig → DatastreamStreamSourceConfigPostgresqlSourceConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesforceSourceConfig → DatastreamStreamSourceConfigSalesforceSourceConfig?
-
final
-
sourceConnectionProfile
→ TfArg<
String> -
final
- spannerSourceConfig → DatastreamStreamSourceConfigSpannerSourceConfig?
-
final
- sqlServerSourceConfig → DatastreamStreamSourceConfigSqlServerSourceConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited