DatastreamStreamSourceConfigMysqlSourceConfigExcludeObjectsMysqlDatabasesMysqlTablesMysqlColumns class final

Typed helper for the source_config.mysql_source_config.exclude_objects.mysql_databases.mysql_tables.mysql_columns block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamSourceConfigMysqlSourceConfigExcludeObjectsMysqlDatabasesMysqlTablesMysqlColumns({TfArg<String>? collation, TfArg<String>? column, TfArg<String>? dataType, TfArg<bool>? nullable, TfArg<num>? ordinalPosition, TfArg<bool>? primaryKey})
const

Properties

collation → TfArg<String>?
final
column → TfArg<String>?
final
dataType → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
nullable → TfArg<bool>?
final
ordinalPosition → TfArg<num>?
final
primaryKey → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited