DatastreamStreamSourceConfigOracleSourceConfigExcludeObjectsOracleSchemasOracleTablesOracleColumns class final

Typed helper for the source_config.oracle_source_config.exclude_objects.oracle_schemas.oracle_tables.oracle_columns block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Properties

column → TfArg<String>?
final
dataType → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited