DatastreamStreamSourceConfigOracleSourceConfigIncludeObjectsOracleSchemasOracleTables class final

Typed helper for the source_config.oracle_source_config.include_objects.oracle_schemas.oracle_tables block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
oracleColumns List<DatastreamStreamSourceConfigOracleSourceConfigIncludeObjectsOracleSchemasOracleTablesOracleColumns>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited