DatastreamStreamSourceConfigSpannerSourceConfig class final

Typed helper for the source_config.spanner_source_config block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamSourceConfigSpannerSourceConfig({TfArg<bool>? backfillDataBoostEnabled, TfArg<String>? changeStreamName, TfArg<String>? fgacRole, TfArg<num>? maxConcurrentBackfillTasks, TfArg<num>? maxConcurrentCdcTasks, TfArg<DatastreamStreamSourceConfigSpannerSourceConfigSpannerRpcPriority>? spannerRpcPriority, DatastreamStreamSourceConfigSpannerSourceConfigExcludeObjects? excludeObjects, DatastreamStreamSourceConfigSpannerSourceConfigIncludeObjects? includeObjects})
const

Properties

backfillDataBoostEnabled → TfArg<bool>?
final
changeStreamName → TfArg<String>?
final
excludeObjects DatastreamStreamSourceConfigSpannerSourceConfigExcludeObjects?
final
fgacRole → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
includeObjects DatastreamStreamSourceConfigSpannerSourceConfigIncludeObjects?
final
maxConcurrentBackfillTasks → TfArg<num>?
final
maxConcurrentCdcTasks → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spannerRpcPriority → TfArg<DatastreamStreamSourceConfigSpannerSourceConfigSpannerRpcPriority>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited