DatastreamStreamSourceConfigSystemSqlServerSourceConfig class final
The DatastreamStreamSourceConfigSystem.sqlServerSourceConfig choice: sets sql_server_source_config.
- Inheritance
-
- Object
- DatastreamStreamSourceConfigSystem
- DatastreamStreamSourceConfigSystemSqlServerSourceConfig
Constructors
- DatastreamStreamSourceConfigSystemSqlServerSourceConfig(DatastreamStreamSqlServerSourceConfig sqlServerSourceConfig)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqlServerSourceConfig → DatastreamStreamSqlServerSourceConfig
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited