DatastreamStreamSourceHierarchyDatasets class final

Typed helper for the destination_config.bigquery_destination_config.source_hierarchy_datasets block of google_datastream_stream (derived from provider schema).

Annotations
  • @immutable

Constructors

DatastreamStreamSourceHierarchyDatasets({TfArg<String>? projectId, required DatastreamStreamDatasetTemplate datasetTemplate})
const

Properties

datasetTemplate → DatastreamStreamDatasetTemplate
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited