DeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential class final

Typed helper for the bitbucket_cloud_config.authorizer_credential block of google_developer_connect_connection (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

DeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential({required TfArg<String> userTokenSecretVersion})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userTokenSecretVersion → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited