DeveloperConnectConnectionBitbucketDataCenterConfig class final
Typed helper for the bitbucket_data_center_config block of
google_developer_connect_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DeveloperConnectConnectionBitbucketDataCenterConfig({required TfArg<
String> hostUri, TfArg<String> ? sslCaCertificate, required TfArg<String> webhookSecretSecretVersion, required DeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential authorizerCredential, required DeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential readAuthorizerCredential, DeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig? serviceDirectoryConfig}) -
const
Properties
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostUri
→ TfArg<
String> -
final
- readAuthorizerCredential → DeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceDirectoryConfig → DeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig?
-
final
-
sslCaCertificate
→ TfArg<
String> ? -
final
-
webhookSecretSecretVersion
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited