DeveloperConnectConnectionGitlabConfig class final

Typed helper for the gitlab_config block of google_developer_connect_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

DeveloperConnectConnectionGitlabConfig({required TfArg<String> webhookSecretSecretVersion, required DeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential authorizerCredential, required DeveloperConnectConnectionReadAuthorizerCredential readAuthorizerCredential})
const

Properties

authorizerCredential → DeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential
final
hashCode → int
The hash code for this object.
no setterinherited
readAuthorizerCredential → DeveloperConnectConnectionReadAuthorizerCredential
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webhookSecretSecretVersion → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited