DeveloperConnectInsightsConfigArtifactConfigs class final

Typed helper for the artifact_configs block of google_developer_connect_insights_config (derived from provider schema).

Annotations
  • @immutable

Properties

googleArtifactAnalysis DeveloperConnectInsightsConfigArtifactConfigsGoogleArtifactAnalysis?
final
googleArtifactRegistry DeveloperConnectInsightsConfigArtifactConfigsGoogleArtifactRegistry?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited