DeveloperConnectInsightsConfigGoogleArtifactRegistry class final
Typed helper for the artifact_configs.google_artifact_registry block of
google_developer_connect_insights_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DeveloperConnectInsightsConfigGoogleArtifactRegistry({required TfArg<
String> artifactRegistryPackage, required TfArg<String> projectId}) -
const
Properties
-
artifactRegistryPackage
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
projectId
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited