DialogflowAgentMatchMode extension type

How intents are matched from user queries for a GoogleDialogflowAgent.

on
Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTfJson() → Object?
Value emitted into Terraform JSON.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

hybrid → const DialogflowAgentMatchMode
Hybrid (rules + ML) — best for small intent sets / templates.
mlOnly → const DialogflowAgentMatchMode
ML-only — best for large intent sets.
values → const List<DialogflowAgentMatchMode>