DialogflowConversationProfileConversationModelConfig class final
Typed helper for the human_agent_assistant_config.end_user_suggestion_config.feature_configs.conversation_model_config block of
google_dialogflow_conversation_profile (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
DialogflowConversationProfileConversationModelConfig({TfArg<
String> ? baselineModelVersion, TfArg<String> ? model}) -
const
Properties
-
baselineModelVersion
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
model
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited