DialogflowConversationProfileEndUserSuggestionConfigFeatureConfigs class final
Typed helper for the human_agent_assistant_config.end_user_suggestion_config.feature_configs block of
google_dialogflow_conversation_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowConversationProfileEndUserSuggestionConfigFeatureConfigs({TfArg<
bool> ? disableAgentQueryLogging, TfArg<bool> ? enableConversationAugmentedQuery, TfArg<bool> ? enableEventBasedSuggestion, TfArg<bool> ? enableQuerySuggestionOnly, TfArg<bool> ? enableQuerySuggestionWhenNoAnswer, DialogflowConversationProfileConversationModelConfig? conversationModelConfig, DialogflowConversationProfileConversationProcessConfig? conversationProcessConfig, DialogflowConversationProfileEndUserSuggestionConfigQueryConfig? queryConfig, DialogflowConversationProfileSuggestionFeature? suggestionFeature, DialogflowConversationProfileSuggestionTriggerSettings? suggestionTriggerSettings}) -
const
Properties
- conversationModelConfig → DialogflowConversationProfileConversationModelConfig?
-
final
- conversationProcessConfig → DialogflowConversationProfileConversationProcessConfig?
-
final
-
disableAgentQueryLogging
→ TfArg<
bool> ? -
final
-
enableConversationAugmentedQuery
→ TfArg<
bool> ? -
final
-
enableEventBasedSuggestion
→ TfArg<
bool> ? -
final
-
enableQuerySuggestionOnly
→ TfArg<
bool> ? -
final
-
enableQuerySuggestionWhenNoAnswer
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- queryConfig → DialogflowConversationProfileEndUserSuggestionConfigQueryConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestionFeature → DialogflowConversationProfileSuggestionFeature?
-
final
- suggestionTriggerSettings → DialogflowConversationProfileSuggestionTriggerSettings?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited