DialogflowConversationProfileNotificationConfig class final
Typed helper for the notification_config block of
google_dialogflow_conversation_profile (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
DialogflowConversationProfileNotificationConfig({DialogflowConversationProfileMessageFormat? messageFormat, RefTo<
GooglePubsubTopic> ? topic}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageFormat → DialogflowConversationProfileMessageFormat?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topic
→ RefTo<
GooglePubsubTopic> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited