DialogflowConversationProfileTtsConfig class final

Typed helper for the tts_config block of google_dialogflow_conversation_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowConversationProfileTtsConfig({TfArg<List<String>>? effectsProfileId, TfArg<num>? pitch, TfArg<num>? speakingRate, TfArg<num>? volumeGainDb, DialogflowConversationProfileVoice? voice})
const

Properties

effectsProfileId → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
pitch → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakingRate → TfArg<num>?
final
voice → DialogflowConversationProfileVoice?
final
volumeGainDb → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited