DialogflowConversationProfileVoice class final
Typed helper for the tts_config.voice block of
google_dialogflow_conversation_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowConversationProfileVoice({TfArg<
String> ? name, DialogflowConversationProfileSsmlGender? ssmlGender}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssmlGender → DialogflowConversationProfileSsmlGender?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited