DialogflowCxAgentGenAppBuilderSettings class final

Typed helper for the gen_app_builder_settings block of google_dialogflow_cx_agent (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxAgentGenAppBuilderSettings({required TfArg<String> engine})
const

Properties

engine → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited