DialogflowCxFlowAdvancedSettingsSpeechSettings class final

Typed helper for the advanced_settings.speech_settings block of google_dialogflow_cx_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxFlowAdvancedSettingsSpeechSettings({TfArg<num>? endpointerSensitivity, TfArg<Map<String, String>>? models, TfArg<String>? noSpeechTimeout, TfArg<bool>? useTimeoutBasedEndpointing})
const

Properties

endpointerSensitivity → TfArg<num>?
final
hashCode int
The hash code for this object.
no setterinherited
models → TfArg<Map<String, String>>?
final
noSpeechTimeout → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useTimeoutBasedEndpointing → TfArg<bool>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited