DialogflowCxFlowEventHandlers class final

Typed helper for the event_handlers block of google_dialogflow_cx_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxFlowEventHandlers({TfArg<String>? event, TfArg<String>? targetFlow, TfArg<String>? targetPage, DialogflowCxFlowEventHandlersTriggerFulfillment? triggerFulfillment})
const

Properties

event → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFlow → TfArg<String>?
final
targetPage → TfArg<String>?
final
triggerFulfillment → DialogflowCxFlowEventHandlersTriggerFulfillment?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited