DialogflowCxFlowEventHandlersTriggerFulfillmentMessagesOutputAudioText class final

Typed helper for the event_handlers.trigger_fulfillment.messages.output_audio_text block of google_dialogflow_cx_flow (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssml → TfArg<String>?
final
text → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited