DialogflowCxFlowKnowledgeConnectorSettingsMessages class final

Typed helper for the knowledge_connector_settings.trigger_fulfillment.messages block of google_dialogflow_cx_flow (derived from provider schema).

Annotations
  • @immutable

Properties

channel → TfArg<String>?
final
conversationSuccess → DialogflowCxFlowConversationSuccess?
final
hashCode → int
The hash code for this object.
no setterinherited
knowledgeInfoCard → DialogflowCxFlowKnowledgeInfoCard?
final
liveAgentHandoff → DialogflowCxFlowLiveAgentHandoff?
final
outputAudioText → DialogflowCxFlowOutputAudioText?
final
payload → TfArg<String>?
final
playAudio → DialogflowCxFlowPlayAudio?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
telephonyTransferCall → DialogflowCxFlowTelephonyTransferCall?
final
text → DialogflowCxFlowText?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited