DialogflowCxFlowTriggerFulfillmentAdvancedSettings class final
Typed helper for the knowledge_connector_settings.trigger_fulfillment.advanced_settings block of
google_dialogflow_cx_flow (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DialogflowCxFlowTriggerFulfillmentAdvancedSettings({DialogflowCxFlowAdvancedSettingsDtmfSettings? dtmfSettings, DialogflowCxFlowLoggingSettings? loggingSettings, DialogflowCxFlowSpeechSettings? speechSettings})
-
const
Properties
- dtmfSettings → DialogflowCxFlowAdvancedSettingsDtmfSettings?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loggingSettings → DialogflowCxFlowLoggingSettings?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speechSettings → DialogflowCxFlowSpeechSettings?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited