DialogflowCxGenerativeSettingsFallbackSettingsPromptTemplates class final

Typed helper for the fallback_settings.prompt_templates block of google_dialogflow_cx_generative_settings (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxGenerativeSettingsFallbackSettingsPromptTemplates({TfArg<String>? displayName, TfArg<bool>? frozen, TfArg<String>? promptText})
const

Properties

displayName → TfArg<String>?
final
frozen → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
promptText → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited