DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessages class final
Typed helper for the form.parameters.fill_behavior.initial_prompt_fulfillment.messages block of
google_dialogflow_cx_page (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessages({TfArg<
String> ? channel, TfArg<String> ? payload, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesConversationSuccess? conversationSuccess, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesLiveAgentHandoff? liveAgentHandoff, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesOutputAudioText? outputAudioText, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesPlayAudio? playAudio, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesTelephonyTransferCall? telephonyTransferCall, DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesText? text}) -
const
Properties
-
channel
→ TfArg<
String> ? -
final
- conversationSuccess → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesConversationSuccess?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- liveAgentHandoff → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesLiveAgentHandoff?
-
final
- outputAudioText → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesOutputAudioText?
-
final
-
payload
→ TfArg<
String> ? -
final
- playAudio → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesPlayAudio?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telephonyTransferCall → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesTelephonyTransferCall?
-
final
- text → DialogflowCxPageFormParametersFillBehaviorInitialPromptFulfillmentMessagesText?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited