DialogflowCxTestCaseEvent class final

Typed helper for the test_case_conversation_turns.user_input.input.event block of google_dialogflow_cx_test_case (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxTestCaseEvent({required TfArg<String> event})
const

Properties

event → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited