DialogflowCxTestCaseTestCaseConversationTurnsUserInputInput class final
Typed helper for the test_case_conversation_turns.user_input.input block of
google_dialogflow_cx_test_case (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxTestCaseTestCaseConversationTurnsUserInputInput({TfArg<
String> ? languageCode, DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputDtmf? dtmf, DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputEvent? event, DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputText? text}) -
const
Properties
- dtmf → DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputDtmf?
-
final
- event → DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputEvent?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languageCode
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → DialogflowCxTestCaseTestCaseConversationTurnsUserInputInputText?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited