DialogflowCxTestCaseTestConfig class final

Typed helper for the test_config block of google_dialogflow_cx_test_case (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxTestCaseTestConfig({DialogflowCxTestCaseStart? start, TfArg<List<String>>? trackingParameters})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DialogflowCxTestCaseStart?
final
trackingParameters → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited