DialogflowCxToolAuthentication class final

Typed helper for the open_api_spec.authentication block of google_dialogflow_cx_tool (derived from provider schema).

Annotations
  • @immutable

Properties

apiKeyConfig → DialogflowCxToolApiKeyConfig?
final
bearerTokenConfig → DialogflowCxToolBearerTokenConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
oauthConfig → DialogflowCxToolOauthConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAgentAuthConfig → DialogflowCxToolServiceAgentAuthConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited