DialogflowCxToolOpenApiSpecAuthenticationBearerTokenConfig class final

Typed helper for the open_api_spec.authentication.bearer_token_config block of google_dialogflow_cx_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolOpenApiSpecAuthenticationBearerTokenConfig({TfArg<String>? secretVersionForToken, TfArg<String>? token})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretVersionForToken → TfArg<String>?
final
token → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited