DialogflowCxToolServiceDirectoryConfig class final

Typed helper for the open_api_spec.service_directory_config block of google_dialogflow_cx_tool (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolServiceDirectoryConfig({required TfArg<String> service})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited