DialogflowCxToolVersionBearerTokenConfig class final

Typed helper for the tool.open_api_spec.authentication.bearer_token_config block of google_dialogflow_cx_tool_version (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolVersionBearerTokenConfig({TfArg<String>? secretVersionForToken, Sensitive<String>? token})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretVersionForToken → TfArg<String>?
final
token → Sensitive<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited