DialogflowCxToolVersionDataStoreSpec class final

Typed helper for the tool.data_store_spec block of google_dialogflow_cx_tool_version (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolVersionDataStoreSpec({required List<DialogflowCxToolVersionDataStoreConnections> dataStoreConnections, required DialogflowCxToolVersionFallbackPrompt fallbackPrompt})
const

Properties

dataStoreConnections → List<DialogflowCxToolVersionDataStoreConnections>
final
fallbackPrompt → DialogflowCxToolVersionFallbackPrompt
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited