DialogflowCxToolVersionOauthConfig class final

Typed helper for the tool.open_api_spec.authentication.oauth_config block of google_dialogflow_cx_tool_version (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolVersionOauthConfig({required TfArg<String> clientId, Sensitive<String>? clientSecret, required TfArg<String> oauthGrantType, TfArg<List<String>>? scopes, TfArg<String>? secretVersionForClientSecret, required TfArg<String> tokenEndpoint})
const

Properties

clientId → TfArg<String>
final
clientSecret → Sensitive<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
oauthGrantType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → TfArg<List<String>>?
final
secretVersionForClientSecret → TfArg<String>?
final
tokenEndpoint → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited