DialogflowCxToolVersionTool class final

Typed helper for the tool block of google_dialogflow_cx_tool_version (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxToolVersionTool({required TfArg<String> description, required TfArg<String> displayName, DialogflowCxToolVersionToolDataStoreSpec? dataStoreSpec, DialogflowCxToolVersionToolFunctionSpec? functionSpec, DialogflowCxToolVersionToolOpenApiSpec? openApiSpec})
const

Properties

dataStoreSpec DialogflowCxToolVersionToolDataStoreSpec?
final
description → TfArg<String>
final
displayName → TfArg<String>
final
functionSpec DialogflowCxToolVersionToolFunctionSpec?
final
hashCode int
The hash code for this object.
no setterinherited
openApiSpec DialogflowCxToolVersionToolOpenApiSpec?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited