DialogflowCxToolVersionToolOpenApiSpec class final
Typed helper for the tool.open_api_spec block of
google_dialogflow_cx_tool_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxToolVersionToolOpenApiSpec({required TfArg<
String> textSchema, DialogflowCxToolVersionToolOpenApiSpecAuthentication? authentication, DialogflowCxToolVersionToolOpenApiSpecServiceDirectoryConfig? serviceDirectoryConfig, DialogflowCxToolVersionToolOpenApiSpecTlsConfig? tlsConfig}) -
const
Properties
- authentication → DialogflowCxToolVersionToolOpenApiSpecAuthentication?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceDirectoryConfig → DialogflowCxToolVersionToolOpenApiSpecServiceDirectoryConfig?
-
final
-
textSchema
→ TfArg<
String> -
final
- tlsConfig → DialogflowCxToolVersionToolOpenApiSpecTlsConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited