DialogflowCxToolVersionToolOpenApiSpecAuthentication class final
Typed helper for the tool.open_api_spec.authentication block of
google_dialogflow_cx_tool_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DialogflowCxToolVersionToolOpenApiSpecAuthentication({DialogflowCxToolVersionToolOpenApiSpecAuthenticationApiKeyConfig? apiKeyConfig, DialogflowCxToolVersionToolOpenApiSpecAuthenticationBearerTokenConfig? bearerTokenConfig, DialogflowCxToolVersionToolOpenApiSpecAuthenticationOauthConfig? oauthConfig, DialogflowCxToolVersionToolOpenApiSpecAuthenticationServiceAgentAuthConfig? serviceAgentAuthConfig})
-
const
Properties
- apiKeyConfig → DialogflowCxToolVersionToolOpenApiSpecAuthenticationApiKeyConfig?
-
final
- bearerTokenConfig → DialogflowCxToolVersionToolOpenApiSpecAuthenticationBearerTokenConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauthConfig → DialogflowCxToolVersionToolOpenApiSpecAuthenticationOauthConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAgentAuthConfig → DialogflowCxToolVersionToolOpenApiSpecAuthenticationServiceAgentAuthConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited