DialogflowCxToolVersionToolOpenApiSpecAuthenticationApiKeyConfig class final
Typed helper for the tool.open_api_spec.authentication.api_key_config block of
google_dialogflow_cx_tool_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxToolVersionToolOpenApiSpecAuthenticationApiKeyConfig({TfArg<
String> ? apiKey, required TfArg<String> keyName, required TfArg<String> requestLocation, TfArg<String> ? secretVersionForApiKey}) -
const
Properties
-
apiKey
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyName
→ TfArg<
String> -
final
-
requestLocation
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretVersionForApiKey
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited