DialogflowCxWebhookServiceDirectoryGenericWebService class final
Typed helper for the service_directory.generic_web_service block of
google_dialogflow_cx_webhook (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxWebhookServiceDirectoryGenericWebService({TfArg<
List< ? allowedCaCerts, TfArg<Object?> >DialogflowCxWebhookServiceDirectoryGenericWebServiceHttpMethod> ? httpMethod, TfArg<Map< ? parameterMapping, TfArg<String, String> >String> ? requestBody, TfArg<Map< ? requestHeaders, TfArg<String, String> >String> ? secretVersionForUsernamePassword, TfArg<DialogflowCxWebhookServiceDirectoryGenericWebServiceServiceAgentAuth> ? serviceAgentAuth, required TfArg<String> uri, TfArg<DialogflowCxWebhookServiceDirectoryGenericWebServiceWebhookType> ? webhookType, DialogflowCxWebhookServiceDirectoryGenericWebServiceOauthConfig? oauthConfig, List<DialogflowCxWebhookServiceDirectoryGenericWebServiceSecretVersionsForRequestHeaders> ? secretVersionsForRequestHeaders, DialogflowCxWebhookServiceDirectoryGenericWebServiceServiceAccountAuthConfig? serviceAccountAuthConfig}) -
const
Properties
-
allowedCaCerts
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
httpMethod
→ TfArg<
DialogflowCxWebhookServiceDirectoryGenericWebServiceHttpMethod> ? -
final
- oauthConfig → DialogflowCxWebhookServiceDirectoryGenericWebServiceOauthConfig?
-
final
-
parameterMapping
→ TfArg<
Map< ?String, String> > -
final
-
requestBody
→ TfArg<
String> ? -
final
-
requestHeaders
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretVersionForUsernamePassword
→ TfArg<
String> ? -
final
-
secretVersionsForRequestHeaders
→ List<
DialogflowCxWebhookServiceDirectoryGenericWebServiceSecretVersionsForRequestHeaders> ? -
final
- serviceAccountAuthConfig → DialogflowCxWebhookServiceDirectoryGenericWebServiceServiceAccountAuthConfig?
-
final
-
serviceAgentAuth
→ TfArg<
DialogflowCxWebhookServiceDirectoryGenericWebServiceServiceAgentAuth> ? -
final
-
uri
→ TfArg<
String> -
final
-
webhookType
→ TfArg<
DialogflowCxWebhookServiceDirectoryGenericWebServiceWebhookType> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited