DialogflowCxWebhookServiceDirectoryGenericWebServiceOauthConfig class final

Typed helper for the service_directory.generic_web_service.oauth_config block of google_dialogflow_cx_webhook (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxWebhookServiceDirectoryGenericWebServiceOauthConfig({required TfArg<String> clientId, TfArg<String>? clientSecret, TfArg<List<Object?>>? scopes, TfArg<String>? secretVersionForClientSecret, required TfArg<String> tokenEndpoint})
const

Properties

clientId → TfArg<String>
final
clientSecret → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes → TfArg<List<Object?>>?
final
secretVersionForClientSecret → TfArg<String>?
final
tokenEndpoint → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited