DialogflowGeneratorInferenceParameter class final

Typed helper for the inference_parameter block of google_dialogflow_generator (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowGeneratorInferenceParameter({TfArg<num>? maxOutputTokens, TfArg<num>? temperature, TfArg<num>? topK, TfArg<num>? topP})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxOutputTokens → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → TfArg<num>?
final
topK → TfArg<num>?
final
topP → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited