DiscoveryEngineChatEngineAgentCreationConfig class final

Typed helper for the chat_engine_config.agent_creation_config block of google_discovery_engine_chat_engine (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineChatEngineAgentCreationConfig({TfArg<String>? business, required TfArg<String> defaultLanguageCode, TfArg<String>? location, required TfArg<String> timeZone})
const

Properties

business → TfArg<String>?
final
defaultLanguageCode → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
location → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited