DiscoveryEngineControlQueryTerms class final

Typed helper for the conditions.query_terms block of google_discovery_engine_control (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineControlQueryTerms({TfArg<bool>? fullMatch, TfArg<String>? value})
const

Properties

fullMatch → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited