DiscoveryEngineDataConnectorActionConfig class final

Typed helper for the action_config block of google_discovery_engine_data_connector (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineDataConnectorActionConfig({TfArg<Map<String, String>>? actionParams, TfArg<bool>? createBapConnection})
const

Properties

actionParams → TfArg<Map<String, String>>?
final
createBapConnection → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited