DiscoveryEngineDataConnectorMetadata class final

Typed helper for the metadata block of google_discovery_engine_data_connector (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineDataConnectorMetadata({TfArg<String>? author, TfArg<String>? description, TfArg<String>? note, TfArg<String>? shortDescription, TfArg<String>? title})
const

Properties

author → TfArg<String>?
final
description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
note → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortDescription → TfArg<String>?
final
title → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited