DiscoveryEngineDataStoreLayoutParsingConfig class final

Typed helper for the document_processing_config.default_parsing_config.layout_parsing_config block of google_discovery_engine_data_store (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

DiscoveryEngineDataStoreLayoutParsingConfig({TfArg<bool>? enableGetProcessedDocument, TfArg<bool>? enableImageAnnotation, TfArg<bool>? enableLlmLayoutParsing, TfArg<bool>? enableTableAnnotation, TfArg<List<String>>? excludeHtmlClasses, TfArg<List<String>>? excludeHtmlElements, TfArg<List<String>>? excludeHtmlIds, TfArg<List<String>>? structuredContentTypes})
const

Properties

enableGetProcessedDocument → TfArg<bool>?
final
enableImageAnnotation → TfArg<bool>?
final
enableLlmLayoutParsing → TfArg<bool>?
final
enableTableAnnotation → TfArg<bool>?
final
excludeHtmlClasses → TfArg<List<String>>?
final
excludeHtmlElements → TfArg<List<String>>?
final
excludeHtmlIds → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredContentTypes → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited