DiscoveryEngineRecommendationEngineOptimizationObjectiveConfig class final

Typed helper for the media_recommendation_engine_config.optimization_objective_config block of google_discovery_engine_recommendation_engine (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineRecommendationEngineOptimizationObjectiveConfig({TfArg<String>? targetField, TfArg<num>? targetFieldValueFloat})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetField → TfArg<String>?
final
targetFieldValueFloat → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited