DiscoveryEngineSearchEngineFeatureConfig class final

Typed helper for the knowledge_graph_config.feature_config block of google_discovery_engine_search_engine (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineSearchEngineFeatureConfig({TfArg<bool>? disablePrivateKgAutoComplete, TfArg<bool>? disablePrivateKgEnrichment, TfArg<bool>? disablePrivateKgQueryUiChips, TfArg<bool>? disablePrivateKgQueryUnderstanding})
const

Properties

disablePrivateKgAutoComplete → TfArg<bool>?
final
disablePrivateKgEnrichment → TfArg<bool>?
final
disablePrivateKgQueryUiChips → TfArg<bool>?
final
disablePrivateKgQueryUnderstanding → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited