DiscoveryEngineWidgetConfigAccessSettings class final

Typed helper for the access_settings block of google_discovery_engine_widget_config (derived from provider schema).

Annotations
  • @immutable

Constructors

DiscoveryEngineWidgetConfigAccessSettings({TfArg<bool>? allowPublicAccess, TfArg<List<String>>? allowlistedDomains, TfArg<bool>? enableWebApp, TfArg<String>? languageCode, TfArg<String>? workforceIdentityPoolProvider})
const

Properties

allowlistedDomains → TfArg<List<String>>?
final
allowPublicAccess → TfArg<bool>?
final
enableWebApp → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
languageCode → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workforceIdentityPoolProvider → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited