DnsResponsePolicyRuleLocalDataEntry class

Annotations
  • @immutable

Constructors

DnsResponsePolicyRuleLocalDataEntry({required TfArg<String> name, required DnsResponsePolicyRuleRecordType type, required TfArg<int> ttl, required List<String> rrdatas})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
rrdatas List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl → TfArg<int>
final
type DnsResponsePolicyRuleRecordType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited