EdgecontainerClusterControlPlaneEncryption class final

Typed helper for the control_plane_encryption block of google_edgecontainer_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

EdgecontainerClusterControlPlaneEncryption({TfArg<String>? kmsKey})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kmsKey → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited