EdgecontainerClusterMaintenancePolicyWindowRecurringWindowWindow class final

Typed helper for the maintenance_policy.window.recurring_window.window block of google_edgecontainer_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

EdgecontainerClusterMaintenancePolicyWindowRecurringWindowWindow({TfArg<String>? endTime, TfArg<String>? startTime})
const

Properties

endTime → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited