EventarcMessageBusLoggingConfig class

logging_config block — shared across Eventarc message buses, API sources, and pipelines.

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
logSeverity EventarcMessageBusLogSeverity?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited