FilestoreInstanceInitialReplication class final
Typed helper for the initial_replication block of
google_filestore_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
FilestoreInstanceInitialReplication({FilestoreInstanceReplicationRole? role, List<
FilestoreInstanceReplicas> ? replicas}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
replicas
→ List<
FilestoreInstanceReplicas> ? -
final
- role → FilestoreInstanceReplicationRole?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited