FilestoreInstanceIopsPerTb class final

Typed helper for the performance_config.iops_per_tb block of google_filestore_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

FilestoreInstanceIopsPerTb({TfArg<num>? maxIopsPerTb})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxIopsPerTb → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited