FirebaseAppHostingBuildCodebase class final

Typed helper for the source.codebase block of google_firebase_app_hosting_build (derived from provider schema).

Annotations
  • @immutable

Constructors

FirebaseAppHostingBuildCodebase({TfArg<String>? branch, TfArg<String>? commit})
const

Properties

branch → TfArg<String>?
final
commit → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited