useInAppDefault property
When true, the parameter is omitted from values returned to the client (the client falls back to its in-app default).
Implementation
final TfArg<bool>? useInAppDefault;
When true, the parameter is omitted from values returned to the client (the client falls back to its in-app default).
final TfArg<bool>? useInAppDefault;