FirestoreChangeStreamDatabaseScopeChoice class final
The FirestoreChangeStreamScope.databaseScope choice: sets database_scope.
- Inheritance
-
- Object
- FirestoreChangeStreamScope
- FirestoreChangeStreamDatabaseScopeChoice
Constructors
- FirestoreChangeStreamDatabaseScopeChoice([FirestoreChangeStreamDatabaseScope databaseScope = const FirestoreChangeStreamDatabaseScope()])
-
const
Properties
- databaseScope → FirestoreChangeStreamDatabaseScope
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited