FirestoreFieldModeOrder class final

The FirestoreFieldMode.order choice: sets order.

Inheritance

Constructors

FirestoreFieldModeOrder(FirestoreFieldOrder order)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
order → FirestoreFieldOrder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited