FirestoreIndexFieldArrayConfig class final

Array-contains dimension for a field. Firestore only supports 'CONTAINS' as the array config today, so no parameter is exposed.

Inheritance
Annotations
  • @immutable

Constructors

FirestoreIndexFieldArrayConfig()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited