FirewallAllowRule class

One allow entry: an IP protocol plus optional list of port specs.

protocol is a string rather than an enum because GCP accepts both well-known names (tcp, udp, icmp, esp, ah, sctp, ipip, all) and raw IANA protocol numbers (e.g. '47' for GRE).

ports entries can be a single port ('22') or a range ('8000-9000'). Leave ports null when protocol does not support ports (e.g. icmp, esp).

Constructors

FirewallAllowRule({required String protocol, List<String>? ports})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ports List<String>?
final
protocol String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited