FolderOrganizationPolicyListPolicyAllow class final

Typed helper for the list_policy.allow block of google_folder_organization_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

FolderOrganizationPolicyListPolicyAllow({TfArg<bool>? all, TfArg<List<Object?>>? values})
const

Properties

all → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited