ForwardingPath enum

forwarding_config.target_name_servers.forwarding_path — how Cloud DNS resolves the target's address range.

Inheritance
Available extensions

Values

standard → const ForwardingPath
const ForwardingPath('default')
private → const ForwardingPath
const ForwardingPath('private')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ForwardingPath>
A constant List of the values in this enum, in order of their declaration.