ForwardingRuleIpVersion enum

IP version for the regional forwarding rule's VIP. Default IPV4. Selecting ipv6 requires a regional IPv6 GoogleComputeAddress for GoogleComputeForwardingRule.ipAddress, and (for external IPv6 NetLB rules) typically pairs with GoogleComputeForwardingRule.ipCollection pointing at a PublicDelegatedPrefix in EXTERNAL_IPV6_FORWARDING_RULE_CREATION mode.

Inheritance
Available extensions

Values

ipv4 → const ForwardingRuleIpVersion
const ForwardingRuleIpVersion('IPV4')
ipv6 → const ForwardingRuleIpVersion
const ForwardingRuleIpVersion('IPV6')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ForwardingRuleIpVersion>
A constant List of the values in this enum, in order of their declaration.