GeminiCodeToolsSettingEnabledToolConfig class final

Typed helper for the enabled_tool.config block of google_gemini_code_tools_setting (derived from provider schema).

Annotations
  • @immutable

Constructors

GeminiCodeToolsSettingEnabledToolConfig({required TfArg<String> key, required TfArg<String> value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited