GkeHubFeatureMembershipConfigSync class final

Typed helper for the configmanagement.config_sync block of google_gke_hub_feature_membership (derived from provider schema).

Annotations
  • @immutable

Constructors

GkeHubFeatureMembershipConfigSync({TfArg<bool>? enabled, TfArg<String>? metricsGcpServiceAccountEmail, TfArg<bool>? preventDrift, TfArg<String>? sourceFormat, TfArg<bool>? stopSyncing, List<GkeHubFeatureMembershipDeploymentOverrides>? deploymentOverrides, GkeHubFeatureMembershipGit? git, GkeHubFeatureMembershipOci? oci})
const

Properties

deploymentOverrides → List<GkeHubFeatureMembershipDeploymentOverrides>?
final
enabled → TfArg<bool>?
final
git → GkeHubFeatureMembershipGit?
final
hashCode → int
The hash code for this object.
no setterinherited
metricsGcpServiceAccountEmail → TfArg<String>?
final
oci → GkeHubFeatureMembershipOci?
final
preventDrift → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFormat → TfArg<String>?
final
stopSyncing → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited