GkeHubFeatureMembershipPolicyControllerHubConfig class final

Typed helper for the policycontroller.policy_controller_hub_config block of google_gke_hub_feature_membership (derived from provider schema).

Annotations
  • @immutable

Constructors

GkeHubFeatureMembershipPolicyControllerHubConfig({TfArg<num>? auditIntervalSeconds, TfArg<num>? constraintViolationLimit, TfArg<List<String>>? exemptableNamespaces, GkeHubFeatureMembershipInstallSpec? installSpec, TfArg<bool>? logDeniesEnabled, TfArg<bool>? mutationEnabled, TfArg<bool>? referentialRulesEnabled, List<GkeHubFeatureMembershipDeploymentConfigs>? deploymentConfigs, GkeHubFeatureMembershipMonitoring? monitoring, GkeHubFeatureMembershipPolicyContent? policyContent})
const

Properties

auditIntervalSeconds → TfArg<num>?
final
constraintViolationLimit → TfArg<num>?
final
deploymentConfigs → List<GkeHubFeatureMembershipDeploymentConfigs>?
final
exemptableNamespaces → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
installSpec → GkeHubFeatureMembershipInstallSpec?
final
logDeniesEnabled → TfArg<bool>?
final
monitoring → GkeHubFeatureMembershipMonitoring?
final
mutationEnabled → TfArg<bool>?
final
policyContent → GkeHubFeatureMembershipPolicyContent?
final
referentialRulesEnabled → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited