GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfig class final
Typed helper for the policycontroller.policy_controller_hub_config block of
google_gke_hub_feature_membership (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfig({TfArg<
num> ? auditIntervalSeconds, TfArg<num> ? constraintViolationLimit, TfArg<List< ? exemptableNamespaces, TfArg<Object?> >GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigInstallSpec> ? installSpec, TfArg<bool> ? logDeniesEnabled, TfArg<bool> ? mutationEnabled, TfArg<bool> ? referentialRulesEnabled, List<GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigDeploymentConfigs> ? deploymentConfigs, GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigMonitoring? monitoring, GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent? policyContent}) -
const
Properties
-
auditIntervalSeconds
→ TfArg<
num> ? -
final
-
constraintViolationLimit
→ TfArg<
num> ? -
final
-
deploymentConfigs
→ List<
GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigDeploymentConfigs> ? -
final
-
exemptableNamespaces
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
installSpec
→ TfArg<
GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigInstallSpec> ? -
final
-
logDeniesEnabled
→ TfArg<
bool> ? -
final
- monitoring → GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigMonitoring?
-
final
-
mutationEnabled
→ TfArg<
bool> ? -
final
- policyContent → GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent?
-
final
-
referentialRulesEnabled
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited