GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigDeploymentConfigsContainerResourcesRequests class final

Typed helper for the policycontroller.policy_controller_hub_config.deployment_configs.container_resources.requests block of google_gke_hub_feature_membership (derived from provider schema).

Annotations
  • @immutable

Properties

cpu → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
memory → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited