GkeHubFeaturePolicyContent class final
Typed helper for the fleet_default_member_config.policycontroller.policy_controller_hub_config.policy_content block of
google_gke_hub_feature (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GkeHubFeaturePolicyContent({List<
GkeHubFeatureBundles> ? bundles, GkeHubFeatureTemplateLibrary? templateLibrary}) -
const
Properties
-
bundles
→ List<
GkeHubFeatureBundles> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateLibrary → GkeHubFeatureTemplateLibrary?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited