GkeHubFeatureTemplateLibrary class final

Typed helper for the fleet_default_member_config.policycontroller.policy_controller_hub_config.policy_content.template_library block of google_gke_hub_feature (derived from provider schema).

Annotations
  • @immutable

Constructors

GkeHubFeatureTemplateLibrary({GkeHubFeatureInstallation? installation})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
installation → GkeHubFeatureInstallation?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited