GkeonpremBareMetalAdminClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfig class final

Typed helper for the control_plane.control_plane_node_pool_config.node_pool_config block of google_gkeonprem_bare_metal_admin_cluster (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
labels → TfArg<Map<String, String>>?
final
nodeConfigs List<GkeonpremBareMetalAdminClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfigNodeConfigs>?
final
operatingSystem → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taints List<GkeonpremBareMetalAdminClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfigTaints>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited