GkeonpremBareMetalClusterControlPlaneControlPlaneNodePoolConfig class final
Typed helper for the control_plane.control_plane_node_pool_config block of
google_gkeonprem_bare_metal_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodePoolConfig → GkeonpremBareMetalClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited