GkeonpremBareMetalClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfigTaints class final

Typed helper for the control_plane.control_plane_node_pool_config.node_pool_config.taints block of google_gkeonprem_bare_metal_cluster (derived from provider schema).

Annotations
  • @immutable

Properties

effect → TfArg<GkeonpremBareMetalClusterControlPlaneControlPlaneNodePoolConfigNodePoolConfigTaintsEffect>?
final
hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited