GkeonpremVmwareClusterAutoResizeConfig class final

Typed helper for the control_plane_node.auto_resize_config block of google_gkeonprem_vmware_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

GkeonpremVmwareClusterAutoResizeConfig({required TfArg<bool> enabled})
const

Properties

enabled → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited