GkeonpremVmwareNodePoolConfig class final

Typed helper for the config block of google_gkeonprem_vmware_node_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

GkeonpremVmwareNodePoolConfig({TfArg<num>? bootDiskSizeGb, TfArg<num>? cpus, TfArg<bool>? enableLoadBalancer, TfArg<String>? image, required TfArg<String> imageType, TfArg<Map<String, String>>? labels, TfArg<num>? memoryMb, TfArg<num>? replicas, List<GkeonpremVmwareNodePoolConfigTaints>? taints, GkeonpremVmwareNodePoolConfigVsphereConfig? vsphereConfig})
const

Properties

bootDiskSizeGb → TfArg<num>?
final
cpus → TfArg<num>?
final
enableLoadBalancer → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
image → TfArg<String>?
final
imageType → TfArg<String>
final
labels → TfArg<Map<String, String>>?
final
memoryMb → TfArg<num>?
final
replicas → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taints List<GkeonpremVmwareNodePoolConfigTaints>?
final
vsphereConfig GkeonpremVmwareNodePoolConfigVsphereConfig?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited