GuestAccelerator class

One entry inside guest_accelerator. Attaches a GPU / TPU to the VM.

Annotations
  • @immutable

Constructors

GuestAccelerator({required String type, required int count})
const

Properties

count int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Accelerator type self-link or short name (e.g. 'nvidia-tesla-t4').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited