HealthCheckProxyHeader enum

proxy_header value used inside every per-protocol HTTP-shaped block (HTTP, HTTPS, HTTP2, TCP, SSL). Defaults to none on the GCP API.

Inheritance
Available extensions

Values

none → const HealthCheckProxyHeader
const HealthCheckProxyHeader('NONE')
proxyV1 → const HealthCheckProxyHeader
const HealthCheckProxyHeader('PROXY_V1')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HealthCheckProxyHeader>
A constant List of the values in this enum, in order of their declaration.