HypercomputeclusterClusterNetworkResourcesConfig class final

Typed helper for the network_resources.config block of google_hypercomputecluster_cluster (derived from provider schema).

Annotations
  • @immutable

Properties

existingNetwork → HypercomputeclusterClusterExistingNetwork?
final
hashCode → int
The hash code for this object.
no setterinherited
newNetwork → HypercomputeclusterClusterNewNetwork?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited