HypercomputeclusterClusterNodeSets class final

Typed helper for the orchestrator.slurm.node_sets block of google_hypercomputecluster_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

HypercomputeclusterClusterNodeSets({TfArg<String>? computeId, required TfArg<String> id, TfArg<String>? maxDynamicNodeCount, TfArg<String>? staticNodeCount, HypercomputeclusterClusterComputeInstance? computeInstance, List<HypercomputeclusterClusterStorageConfigs>? storageConfigs})
const

Properties

computeId → TfArg<String>?
final
computeInstance → HypercomputeclusterClusterComputeInstance?
final
hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
maxDynamicNodeCount → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticNodeCount → TfArg<String>?
final
storageConfigs → List<HypercomputeclusterClusterStorageConfigs>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited