HypercomputeclusterClusterStorageResourcesConfig class final
Typed helper for the storage_resources.config block of
google_hypercomputecluster_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- HypercomputeclusterClusterStorageResourcesConfig({HypercomputeclusterClusterExistingBucket? existingBucket, HypercomputeclusterClusterExistingFilestore? existingFilestore, HypercomputeclusterClusterExistingLustre? existingLustre, HypercomputeclusterClusterNewBucket? newBucket, HypercomputeclusterClusterNewFilestore? newFilestore, HypercomputeclusterClusterNewLustre? newLustre})
-
const
Properties
- existingBucket → HypercomputeclusterClusterExistingBucket?
-
final
- existingFilestore → HypercomputeclusterClusterExistingFilestore?
-
final
- existingLustre → HypercomputeclusterClusterExistingLustre?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newBucket → HypercomputeclusterClusterNewBucket?
-
final
- newFilestore → HypercomputeclusterClusterNewFilestore?
-
final
- newLustre → HypercomputeclusterClusterNewLustre?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited