IamWorkforcePoolProviderKeyKeyData class final

Typed helper for the key_data block of google_iam_workforce_pool_provider_key (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
keySpec → TfArg<IamWorkforcePoolProviderKeyKeyDataKeySpec>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited