IamWorkloadIdentityPoolProviderTrustStore class final
Typed helper for the x509.trust_store block of
google_iam_workload_identity_pool_provider (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IamWorkloadIdentityPoolProviderTrustStore({List<
IamWorkloadIdentityPoolProviderIntermediateCas> ? intermediateCas, required List<IamWorkloadIdentityPoolProviderTrustAnchors> trustAnchors}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
intermediateCas
→ List<
IamWorkloadIdentityPoolProviderIntermediateCas> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trustAnchors
→ List<
IamWorkloadIdentityPoolProviderTrustAnchors> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited