IdentityPlatformConfigEmail class final

Typed helper for the sign_in.email block of google_identity_platform_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IdentityPlatformConfigEmail({required TfArg<bool> enabled, TfArg<bool>? passwordRequired})
const

Properties

enabled → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
passwordRequired → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited