IdentityPlatformConfigMultiTenant class final
Typed helper for the multi_tenant block of
google_identity_platform_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IdentityPlatformConfigMultiTenant({TfArg<
bool> ? allowTenants, TfArg<String> ? defaultTenantLocation}) -
const
Properties
-
allowTenants
→ TfArg<
bool> ? -
final
-
defaultTenantLocation
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited