IdentityPlatformConfigSignUpQuotaConfig class final

Typed helper for the quota.sign_up_quota_config block of google_identity_platform_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IdentityPlatformConfigSignUpQuotaConfig({TfArg<num>? quota, TfArg<String>? quotaDuration, TfArg<String>? startTime})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
quota → TfArg<num>?
final
quotaDuration → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited