IdentityPlatformInboundSamlConfigIdpConfig class final

Typed helper for the idp_config block of google_identity_platform_inbound_saml_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IdentityPlatformInboundSamlConfigIdpConfig({required TfArg<String> idpEntityId, TfArg<bool>? signRequest, required TfArg<String> ssoUrl, required List<IdentityPlatformInboundSamlConfigIdpCertificates> idpCertificates})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
idpCertificates → List<IdentityPlatformInboundSamlConfigIdpCertificates>
final
idpEntityId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signRequest → TfArg<bool>?
final
ssoUrl → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited