IdentityPlatformInboundSamlConfigSpConfig class final

Typed helper for the sp_config block of google_identity_platform_inbound_saml_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IdentityPlatformInboundSamlConfigSpConfig({TfArg<String>? callbackUri, TfArg<String>? spEntityId})
const

Properties

callbackUri → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spEntityId → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited