InstanceGroupManagerUpdatePolicyReplacementMethod enum

update_policy.replacement_method. SUBSTITUTE (default) replaces VMs with newly-named ones; RECREATE preserves instance names but requires max_unavailable_* > 0.

Inheritance
  • Object
  • Enum
  • InstanceGroupManagerUpdatePolicyReplacementMethod
Available extensions

Values

substitute → const InstanceGroupManagerUpdatePolicyReplacementMethod
const InstanceGroupManagerUpdatePolicyReplacementMethod('SUBSTITUTE')
recreate → const InstanceGroupManagerUpdatePolicyReplacementMethod
const InstanceGroupManagerUpdatePolicyReplacementMethod('RECREATE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InstanceGroupManagerUpdatePolicyReplacementMethod>
A constant List of the values in this enum, in order of their declaration.