targetSize property
Cap on how many instances run this version (fixed or percent).
Implementation
final InstanceGroupManagerVersionTargetSize? targetSize;
Cap on how many instances run this version (fixed or percent).
final InstanceGroupManagerVersionTargetSize? targetSize;