InstanceTemplateAdvancedMachineFeatures class

advanced_machine_features block (max_items=1). Per-CPU tuning knobs.

Annotations
  • @immutable

Constructors

InstanceTemplateAdvancedMachineFeatures({bool? enableNestedVirtualization, num? threadsPerCore, num? visibleCoreCount, bool? enableUefiNetworking, InstanceTemplatePerformanceMonitoringUnit? performanceMonitoringUnit, String? turboMode})
const

Properties

enableNestedVirtualization bool?
final
enableUefiNetworking bool?
final
hashCode int
The hash code for this object.
no setterinherited
performanceMonitoringUnit InstanceTemplatePerformanceMonitoringUnit?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadsPerCore num?
final
turboMode String?
Turbo frequency mode. Currently 'ALL_CORE_MAX' is the only supported value.
final
visibleCoreCount num?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited