InstanceTemplateNicType enum

network_interface.nic_type -- vNIC family used for the interface.

Inheritance
Available extensions

Values

gvnic → const InstanceTemplateNicType
const InstanceTemplateNicType('GVNIC')
virtioNet → const InstanceTemplateNicType
const InstanceTemplateNicType('VIRTIO_NET')
mrdma → const InstanceTemplateNicType
const InstanceTemplateNicType('MRDMA')
irdma → const InstanceTemplateNicType
const InstanceTemplateNicType('IRDMA')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InstanceTemplateNicType>
A constant List of the values in this enum, in order of their declaration.