InstanceTemplateScheduling class
scheduling block (max_items=1). Controls preemptibility, host
maintenance, max run duration, and sole-tenant affinities.
- Annotations
-
- @immutable
Constructors
-
InstanceTemplateScheduling({bool? preemptible, InstanceTemplateOnHostMaintenance? onHostMaintenance, bool? automaticRestart, InstanceTemplateProvisioningModel? provisioningModel, InstanceTemplateInstanceTerminationAction? instanceTerminationAction, num? minNodeCpus, num? availabilityDomain, String? terminationTime, List<
InstanceTemplateNodeAffinity> ? nodeAffinities, InstanceTemplateSchedulingDuration? maxRunDuration, InstanceTemplateSchedulingDuration? localSsdRecoveryTimeout, InstanceTemplateOnInstanceStopAction? onInstanceStopAction}) -
const
Properties
- automaticRestart → bool?
-
final
- availabilityDomain → num?
-
Availability domain index for stretched zonal placement.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceTerminationAction → InstanceTemplateInstanceTerminationAction?
-
final
- localSsdRecoveryTimeout → InstanceTemplateSchedulingDuration?
-
Local SSD data-recovery grace period for VMs with
--local-ssd.final - maxRunDuration → InstanceTemplateSchedulingDuration?
-
Hard cap on instance run time. After this elapses GCP applies the
instanceTerminationAction (stop or delete).
final
- minNodeCpus → num?
-
final
-
nodeAffinities
→ List<
InstanceTemplateNodeAffinity> ? -
final
- onHostMaintenance → InstanceTemplateOnHostMaintenance?
-
final
- onInstanceStopAction → InstanceTemplateOnInstanceStopAction?
-
final
- preemptible → bool?
-
final
- provisioningModel → InstanceTemplateProvisioningModel?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminationTime → String?
-
RFC3339 timestamp at which the instance will be terminated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited