IntegrationConnectorsConnectionAuthConfig class final
Typed helper for the auth_config block of
google_integration_connectors_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IntegrationConnectorsConnectionAuthConfig({TfArg<
String> ? authKey, required TfArg<IntegrationConnectorsConnectionAuthConfigAuthType> authType, List<IntegrationConnectorsConnectionAuthConfigAdditionalVariable> ? additionalVariable, IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow? oauth2AuthCodeFlow, IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials? oauth2ClientCredentials, IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer? oauth2JwtBearer, IntegrationConnectorsConnectionAuthConfigSshPublicKey? sshPublicKey, IntegrationConnectorsConnectionAuthConfigUserPassword? userPassword}) -
const
Properties
-
additionalVariable
→ List<
IntegrationConnectorsConnectionAuthConfigAdditionalVariable> ? -
final
-
authKey
→ TfArg<
String> ? -
final
-
authType
→ TfArg<
IntegrationConnectorsConnectionAuthConfigAuthType> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauth2AuthCodeFlow → IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow?
-
final
- oauth2ClientCredentials → IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials?
-
final
- oauth2JwtBearer → IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sshPublicKey → IntegrationConnectorsConnectionAuthConfigSshPublicKey?
-
final
- userPassword → IntegrationConnectorsConnectionAuthConfigUserPassword?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited