IntegrationConnectorsConnectionAuthConfigAdditionalVariable class final

Typed helper for the auth_config.additional_variable block of google_integration_connectors_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

IntegrationConnectorsConnectionAuthConfigAdditionalVariable({TfArg<bool>? booleanValue, TfArg<num>? integerValue, required TfArg<String> key, TfArg<String>? stringValue, IntegrationConnectorsConnectionEncryptionKeyValue? encryptionKeyValue, IntegrationConnectorsConnectionSecretValue? secretValue})
const

Properties

booleanValue → TfArg<bool>?
final
encryptionKeyValue → IntegrationConnectorsConnectionEncryptionKeyValue?
final
hashCode → int
The hash code for this object.
no setterinherited
integerValue → TfArg<num>?
final
key → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretValue → IntegrationConnectorsConnectionSecretValue?
final
stringValue → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited