IntegrationConnectorsConnectionDestinationConfigDestination class final

Typed helper for the destination_config.destination block of google_integration_connectors_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

IntegrationConnectorsConnectionDestinationConfigDestination({TfArg<String>? host, TfArg<num>? port, TfArg<String>? serviceAttachment})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
host → TfArg<String>?
final
port → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachment → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited