IntegrationConnectorsConnectionLogConfig class final

Typed helper for the log_config block of google_integration_connectors_connection (derived from provider schema).

Annotations
  • @immutable

Properties

enabled → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
level → IntegrationConnectorsConnectionLevel?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited