IntegrationConnectorsConnectionNodeConfig class final

Typed helper for the node_config block of google_integration_connectors_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

IntegrationConnectorsConnectionNodeConfig({TfArg<num>? maxNodeCount, TfArg<num>? minNodeCount})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxNodeCount → TfArg<num>?
final
minNodeCount → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited