IntegrationConnectorsConnectionSslConfig class final
Typed helper for the ssl_config block of
google_integration_connectors_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IntegrationConnectorsConnectionSslConfig({TfArg<
String> ? clientCertType, TfArg<String> ? serverCertType, IntegrationConnectorsConnectionTrustModel? trustModel, required IntegrationConnectorsConnectionType type, TfArg<bool> ? useSsl, List<IntegrationConnectorsConnectionEventingConfigAdditionalVariable> ? additionalVariable, IntegrationConnectorsConnectionClientCertificate? clientCertificate, IntegrationConnectorsConnectionClientPrivateKey? clientPrivateKey, IntegrationConnectorsConnectionClientPrivateKeyPass? clientPrivateKeyPass, IntegrationConnectorsConnectionPrivateServerCertificate? privateServerCertificate}) -
const
Properties
-
additionalVariable
→ List<
IntegrationConnectorsConnectionEventingConfigAdditionalVariable> ? -
final
- clientCertificate → IntegrationConnectorsConnectionClientCertificate?
-
final
-
clientCertType
→ TfArg<
String> ? -
final
- clientPrivateKey → IntegrationConnectorsConnectionClientPrivateKey?
-
final
- clientPrivateKeyPass → IntegrationConnectorsConnectionClientPrivateKeyPass?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateServerCertificate → IntegrationConnectorsConnectionPrivateServerCertificate?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serverCertType
→ TfArg<
String> ? -
final
- trustModel → IntegrationConnectorsConnectionTrustModel?
-
final
- type → IntegrationConnectorsConnectionType
-
final
-
useSsl
→ TfArg<
bool> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited