IntegrationsAuthConfigDecryptedCredential class final
Typed helper for the decrypted_credential block of
google_integrations_auth_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IntegrationsAuthConfigDecryptedCredential({required RefTo<
GoogleIntegrationsAuthConfig> credentialType, IntegrationsAuthConfigSecret? secret}) -
const
Properties
-
credentialType
→ RefTo<
GoogleIntegrationsAuthConfig> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret → IntegrationsAuthConfigSecret?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited