IntegrationsAuthConfigDecryptedCredentialJwt class final

Typed helper for the decrypted_credential.jwt block of google_integrations_auth_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IntegrationsAuthConfigDecryptedCredentialJwt({TfArg<String>? jwtHeader, TfArg<String>? jwtPayload, TfArg<String>? secret})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
jwtHeader → TfArg<String>?
final
jwtPayload → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited