IntegrationsAuthConfigUsernameAndPassword class final

Typed helper for the decrypted_credential.username_and_password block of google_integrations_auth_config (derived from provider schema).

Annotations
  • @immutable

Constructors

IntegrationsAuthConfigUsernameAndPassword({TfArg<String>? password, TfArg<String>? username})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited