KmsAutokeyConfigKeyProjectResolutionMode enum
Kms Autokey Config Key Project Resolution enum for key_project_resolution_mode.
Values
- dedicatedKeyProject → const KmsAutokeyConfigKeyProjectResolutionMode
-
const KmsAutokeyConfigKeyProjectResolutionMode('DEDICATED_KEY_PROJECT') - resourceProject → const KmsAutokeyConfigKeyProjectResolutionMode
-
const KmsAutokeyConfigKeyProjectResolutionMode('RESOURCE_PROJECT') - disabled → const KmsAutokeyConfigKeyProjectResolutionMode
-
const KmsAutokeyConfigKeyProjectResolutionMode('DISABLED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KmsAutokeyConfigKeyProjectResolutionMode> - A constant List of the values in this enum, in order of their declaration.