KmsKeyPurpose enum

Purpose for google_kms_crypto_key.purpose (immutable, default encryptDecrypt). See the CryptoKeyPurpose reference.

Inheritance
Available extensions

Values

encryptDecrypt → const KmsKeyPurpose
const KmsKeyPurpose('ENCRYPT_DECRYPT')
asymmetricSign → const KmsKeyPurpose
const KmsKeyPurpose('ASYMMETRIC_SIGN')
asymmetricDecrypt → const KmsKeyPurpose
const KmsKeyPurpose('ASYMMETRIC_DECRYPT')
mac → const KmsKeyPurpose
const KmsKeyPurpose('MAC')
rawEncryptDecrypt → const KmsKeyPurpose
const KmsKeyPurpose('RAW_ENCRYPT_DECRYPT')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KmsKeyPurpose>
A constant List of the values in this enum, in order of their declaration.