KmsProtectionLevel enum

Protection level for version_template.protection_level (immutable, default software). Per MM docs, possible values are SOFTWARE, HSM, EXTERNAL, EXTERNAL_VPC.

Inheritance
Available extensions

Values

software → const KmsProtectionLevel
const KmsProtectionLevel('SOFTWARE')
hsm → const KmsProtectionLevel
const KmsProtectionLevel('HSM')
external → const KmsProtectionLevel
const KmsProtectionLevel('EXTERNAL')
externalVpc → const KmsProtectionLevel
const KmsProtectionLevel('EXTERNAL_VPC')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KmsProtectionLevel>
A constant List of the values in this enum, in order of their declaration.