LifecycleAction class

Action to take when a lifecycle_rule's condition matches. storageClass is required iff type == LifecycleActionType.setStorageClass.

Constructors

LifecycleAction({required LifecycleActionType type, BucketStorageClass? storageClass})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageClass BucketStorageClass?
final
type LifecycleActionType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited