LoggingMetricLabelValueType enum
metric_descriptor.labels[].value_type — the data type of a label
extracted from log entries. The label-level value space is narrower
than the descriptor's (no DOUBLE / DISTRIBUTION / MONEY).
Defaults to LoggingMetricLabelValueType.string when omitted.
Values
- boolean → const LoggingMetricLabelValueType
-
const LoggingMetricLabelValueType('BOOL') - int64 → const LoggingMetricLabelValueType
-
const LoggingMetricLabelValueType('INT64') - string → const LoggingMetricLabelValueType
-
const LoggingMetricLabelValueType('STRING')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LoggingMetricLabelValueType> - A constant List of the values in this enum, in order of their declaration.