LoggingProjectSinkBigqueryOptions class

bigquery_options block. Toggles partitioned tables for BigQuery destinations (date-sharded vs. partitioned by _PARTITIONTIME).

Constructors

LoggingProjectSinkBigqueryOptions({required TfArg<bool> usePartitionedTables})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usePartitionedTables → TfArg<bool>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited