LookerInstanceEncryptionConfig class final

Typed helper for the encryption_config block of google_looker_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

LookerInstanceEncryptionConfig({RefTo<GoogleKmsCryptoKey>? kmsKeyName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName → RefTo<GoogleKmsCryptoKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited