ManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs class final

Typed helper for the gcp_config.access_config.network_configs block of google_managed_kafka_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

ManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs({required TfArg<String> subnet})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnet → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited