MemcacheInstanceNodeConfig class

node_config nested block (required, max=1).

Constructors

MemcacheInstanceNodeConfig({required TfArg<num> cpuCount, required TfArg<num> memorySizeMb})
const

Properties

cpuCount → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
memorySizeMb → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited