MemorystoreInstanceAofConfig class final

Typed helper for the persistence_config.aof_config block of google_memorystore_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

MemorystoreInstanceAofConfig({TfArg<String>? appendFsync})
const

Properties

appendFsync → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited