MemorystoreInstanceWeeklyMaintenanceWindowStartTime class final

Typed helper for the maintenance_policy.weekly_maintenance_window.start_time block of google_memorystore_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

MemorystoreInstanceWeeklyMaintenanceWindowStartTime({TfArg<num>? hours, TfArg<num>? minutes, TfArg<num>? nanos, TfArg<num>? seconds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hours → TfArg<num>?
final
minutes → TfArg<num>?
final
nanos → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited