MigrationCenterImportDataFileFormat enum
Import payload format for google_migration_center_import_data_file.format.
Values
- rvtoolsXlsx → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_RVTOOLS_XLSX') - rvtoolsCsv → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_RVTOOLS_CSV') - exportedAwsCsv → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_EXPORTED_AWS_CSV') - exportedAzureCsv → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_EXPORTED_AZURE_CSV') - stratozoneCsv → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_STRATOZONE_CSV') - databaseZip → const MigrationCenterImportDataFileFormat
-
const MigrationCenterImportDataFileFormat('IMPORT_JOB_FORMAT_DATABASE_ZIP')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MigrationCenterImportDataFileFormat> - A constant List of the values in this enum, in order of their declaration.