MigrationCenterPreferenceSetRegionPreferences class final

Typed helper for the virtual_machine_preferences.region_preferences block of google_migration_center_preference_set (derived from provider schema).

Annotations
  • @immutable

Constructors

MigrationCenterPreferenceSetRegionPreferences({TfArg<List<String>>? preferredRegions})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
preferredRegions → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited