ModelArmorTemplateFilterConfigSdpSettingsAdvancedConfig class final
Typed helper for the filter_config.sdp_settings.advanced_config block of
google_model_armor_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ModelArmorTemplateFilterConfigSdpSettingsAdvancedConfig({TfArg<
String> ? deidentifyTemplate, TfArg<String> ? inspectTemplate}) -
const
Properties
-
deidentifyTemplate
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inspectTemplate
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited