ModelArmorTemplateTemplateMetadata class final
Typed helper for the template_metadata block of
google_model_armor_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ModelArmorTemplateTemplateMetadata({TfArg<
num> ? customLlmResponseSafetyErrorCode, TfArg<String> ? customLlmResponseSafetyErrorMessage, TfArg<num> ? customPromptSafetyErrorCode, TfArg<String> ? customPromptSafetyErrorMessage, TfArg<String> ? enforcementType, TfArg<bool> ? ignorePartialInvocationFailures, TfArg<bool> ? logSanitizeOperations, TfArg<bool> ? logTemplateOperations, ModelArmorTemplateTemplateMetadataFilterVersionSelector? filterVersionSelector, ModelArmorTemplateTemplateMetadataMultiLanguageDetection? multiLanguageDetection}) -
const
Properties
-
customLlmResponseSafetyErrorCode
→ TfArg<
num> ? -
final
-
customLlmResponseSafetyErrorMessage
→ TfArg<
String> ? -
final
-
customPromptSafetyErrorCode
→ TfArg<
num> ? -
final
-
customPromptSafetyErrorMessage
→ TfArg<
String> ? -
final
-
enforcementType
→ TfArg<
String> ? -
final
- filterVersionSelector → ModelArmorTemplateTemplateMetadataFilterVersionSelector?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignorePartialInvocationFailures
→ TfArg<
bool> ? -
final
-
logSanitizeOperations
→ TfArg<
bool> ? -
final
-
logTemplateOperations
→ TfArg<
bool> ? -
final
- multiLanguageDetection → ModelArmorTemplateTemplateMetadataMultiLanguageDetection?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited