ModelArmorTemplateTemplateMetadataMultiLanguageDetection class final
Typed helper for the template_metadata.multi_language_detection block of
google_model_armor_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ModelArmorTemplateTemplateMetadataMultiLanguageDetection({required TfArg<
bool> enableMultiLanguageDetection}) -
const
Properties
-
enableMultiLanguageDetection
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited