MonitoringAlertPolicyAggregation class

One entry in an aggregations / denominator_aggregations list. Multiple MonitoringAlertPolicyAggregations are applied in order.

Constructors

MonitoringAlertPolicyAggregation({TfArg<String>? alignmentPeriod, Aligner? perSeriesAligner, Reducer? crossSeriesReducer, TfArg<List<String>>? groupByFields})
const

Properties

alignmentPeriod → TfArg<String>?
Per-time-series alignment period (Duration string, e.g. '60s').
final
crossSeriesReducer Reducer?
final
groupByFields → TfArg<List<String>>?
final
hashCode int
The hash code for this object.
no setterinherited
perSeriesAligner Aligner?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited