MonitoringAlertPolicyBooleanTestChoice class final
The MonitoringAlertPolicyTest.booleanTest choice: sets boolean_test.
- Inheritance
-
- Object
- MonitoringAlertPolicyTest
- MonitoringAlertPolicyBooleanTestChoice
Constructors
- MonitoringAlertPolicyBooleanTestChoice(MonitoringAlertPolicyBooleanTest booleanTest)
-
const
Properties
- booleanTest → MonitoringAlertPolicyBooleanTest
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited