MonitoringAlertPolicyNotificationRateLimit class

alert_strategy.notification_rate_limit (max=1). period is a Duration string (e.g. '300s'). Required when the parent policy uses a MonitoringAlertPolicyConditionMatchedLog condition.

Constructors

MonitoringAlertPolicyNotificationRateLimit({TfArg<String>? period})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
period → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited