MonitoringAlertPolicySqlExecutionTime class

condition_sql.daily.execution_time (max=1) — wall-clock time of day (UTC) for the daily run.

Constructors

MonitoringAlertPolicySqlExecutionTime({TfArg<num>? hours, TfArg<num>? minutes, TfArg<num>? seconds, TfArg<num>? nanos})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hours → TfArg<num>?
final
minutes → TfArg<num>?
final
nanos → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited