MonitoringAlertPolicySqlRowCountTest class

condition_sql.row_count_test — fires when the result row count satisfies count [comparison] threshold.

Constructors

MonitoringAlertPolicySqlRowCountTest({required TfArg<Comparison> comparison, required TfArg<num> threshold})
const

Properties

comparison → TfArg<Comparison>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited