MonitoringNotificationChannelCredentialPasswordWo class final
The MonitoringNotificationChannelCredential.passwordWo choice: sets password_wo.
- Inheritance
-
- Object
- MonitoringNotificationChannelCredential
- MonitoringNotificationChannelCredentialPasswordWo
Constructors
-
MonitoringNotificationChannelCredentialPasswordWo(TfArg<
String> passwordWo) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
passwordWo
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited