MonitoringNotificationChannelSensitiveLabels class final

Typed helper for the sensitive_labels block of google_monitoring_notification_channel (derived from provider schema).

Annotations
  • @immutable

Constructors

MonitoringNotificationChannelSensitiveLabels({required MonitoringNotificationChannelCredential credential, TfArg<String>? authTokenWoVersion, TfArg<String>? passwordWoVersion, TfArg<String>? serviceKeyWoVersion})
const

Properties

authTokenWoVersion → TfArg<String>?
final
credential → MonitoringNotificationChannelCredential
final
hashCode → int
The hash code for this object.
no setterinherited
passwordWoVersion → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceKeyWoVersion → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited