MonitoringSloBasicSli class final

Typed helper for the basic_sli block of google_monitoring_slo (derived from provider schema).

Annotations
  • @immutable

Constructors

MonitoringSloBasicSli({TfArg<List<String>>? location, TfArg<List<String>>? method, TfArg<List<String>>? version, required MonitoringSloObjective objective})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → TfArg<List<String>>?
final
method → TfArg<List<String>>?
final
objective → MonitoringSloObjective
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited