MonitoringSloDistributionCut class final
Typed helper for the request_based_sli.distribution_cut block of
google_monitoring_slo (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
MonitoringSloDistributionCut({required TfArg<
String> distributionFilter, required MonitoringSloRange range}) -
const
Properties
-
distributionFilter
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- range → MonitoringSloRange
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited