MonitoringUptimeCheckCloudFunctionV2 class

synthetic_monitor.cloud_function_v2 block (min=1, max=1) — target Cloud Functions V2 instance that implements the probe logic.

Constructors

MonitoringUptimeCheckCloudFunctionV2({required String name})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Fully-qualified Cloud Functions V2 function name, e.g. 'projects/p/locations/us-central1/functions/my-probe'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited