MonitoringUptimeCheckConfigAcceptedResponseStatusCodes class final

Typed helper for the http_check.accepted_response_status_codes block of google_monitoring_uptime_check_config (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusClass → MonitoringUptimeCheckStatusClass?
final
statusValue → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited