MonitoringUptimeCheckConfigCloudFunctionV2 class final

Typed helper for the synthetic_monitor.cloud_function_v2 block of google_monitoring_uptime_check_config (derived from provider schema).

Annotations
  • @immutable

Constructors

MonitoringUptimeCheckConfigCloudFunctionV2({required TfArg<String> name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited