MonitoringUptimeCheckConfigJsonPathMatcher class

content_matchers[].json_path_matcher block (max=1). Used by the MATCHES_JSON_PATH / NOT_MATCHES_JSON_PATH parent matchers.

Constructors

MonitoringUptimeCheckConfigJsonPathMatcher({required TfArg<String> jsonPath, MonitoringUptimeCheckJsonMatcher? jsonMatcher})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonMatcher MonitoringUptimeCheckJsonMatcher?
final
jsonPath → TfArg<String>
JSONPath expression to resolve before applying the jsonMatcher.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited