MonitoringUptimeCheckConfigTcpCheck class
tcp_check block (max=1). Mutually exclusive with httpCheck and
syntheticMonitor on the parent resource.
Constructors
-
MonitoringUptimeCheckConfigTcpCheck({required TfArg<
int> port, MonitoringUptimeCheckConfigPingConfig? pingConfig}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pingConfig → MonitoringUptimeCheckConfigPingConfig?
-
Optional companion ICMP ping configuration.
final
-
port
→ TfArg<
int> -
TCP port to connect to (combined with the host derived from
monitoredResource).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited