NetappStoragePoolServiceLevel extension type
Netapp Storage Pool Service enum for service_level.
Constructors
-
NetappStoragePoolServiceLevel.arg(TfArg<
String> arg) -
const
- NetappStoragePoolServiceLevel.expression(String template)
- NetappStoragePoolServiceLevel.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- extreme → const NetappStoragePoolServiceLevel
- flex → const NetappStoragePoolServiceLevel
- standard → const NetappStoragePoolServiceLevel
-
values
→ const List<
NetappStoragePoolServiceLevel>