NetappVolumeBlockDevices class final

Typed helper for the block_devices block of google_netapp_volume (derived from provider schema).

Annotations
  • @immutable

Constructors

NetappVolumeBlockDevices({TfArg<List<Object?>>? hostGroups, TfArg<String>? name, required TfArg<NetappVolumeBlockDevicesOsType> osType})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hostGroups → TfArg<List<Object?>>?
final
name → TfArg<String>?
final
osType → TfArg<NetappVolumeBlockDevicesOsType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited