NetappVolumeMonthlySchedule class final

Typed helper for the snapshot_policy.monthly_schedule block of google_netapp_volume (derived from provider schema).

Annotations
  • @immutable

Constructors

NetappVolumeMonthlySchedule({TfArg<String>? daysOfMonth, TfArg<num>? hour, TfArg<num>? minute, required TfArg<num> snapshotsToKeep})
const

Properties

daysOfMonth → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
hour → TfArg<num>?
final
minute → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotsToKeep → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited