NetappVolumeReplicationTieringPolicy class final
Typed helper for the destination_volume_parameters.tiering_policy block of
google_netapp_volume_replication (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetappVolumeReplicationTieringPolicy({TfArg<
num> ? coolingThresholdDays, NetappVolumeReplicationTierAction? tierAction}) -
const
Properties
-
coolingThresholdDays
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tierAction → NetappVolumeReplicationTierAction?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited