NetappVolumeTieringPolicy class final

Typed helper for the tiering_policy block of google_netapp_volume (derived from provider schema).

Annotations
  • @immutable

Constructors

NetappVolumeTieringPolicy({TfArg<num>? coolingThresholdDays, TfArg<bool>? hotTierBypassModeEnabled, TfArg<NetappVolumeTieringPolicyTierAction>? tierAction})
const

Properties

coolingThresholdDays → TfArg<num>?
final
hashCode int
The hash code for this object.
no setterinherited
hotTierBypassModeEnabled → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tierAction → TfArg<NetappVolumeTieringPolicyTierAction>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited