NetworkConnectivityInternalRangeAllocationOptions class final

Optional allocation_options when auto-allocating via prefixLength.

Annotations
  • @immutable

Constructors

NetworkConnectivityInternalRangeAllocationOptions({TfArg<NetworkConnectivityInternalRangeAllocationStrategy>? allocationStrategy, TfArg<int>? firstAvailableRangesLookupSize})
const

Properties

allocationStrategy → TfArg<NetworkConnectivityInternalRangeAllocationStrategy>?
final
firstAvailableRangesLookupSize → TfArg<int>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited