NetworkManagementConnectivityTestDestination class final

Typed helper for the destination block of google_network_management_connectivity_test (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkManagementConnectivityTestDestination({TfArg<String>? cloudSqlInstance, TfArg<String>? forwardingRule, TfArg<String>? fqdn, TfArg<String>? gkeMasterCluster, TfArg<String>? gkePod, TfArg<String>? instance, TfArg<String>? ipAddress, TfArg<String>? network, TfArg<NetworkManagementConnectivityTestDestinationNetworkType>? networkType, TfArg<num>? port, TfArg<String>? projectId, TfArg<String>? redisCluster, TfArg<String>? redisInstance})
const

Properties

cloudSqlInstance → TfArg<String>?
final
forwardingRule → TfArg<String>?
final
fqdn → TfArg<String>?
final
gkeMasterCluster → TfArg<String>?
final
gkePod → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
instance → TfArg<String>?
final
ipAddress → TfArg<String>?
final
network → TfArg<String>?
final
networkType → TfArg<NetworkManagementConnectivityTestDestinationNetworkType>?
final
port → TfArg<num>?
final
projectId → TfArg<String>?
final
redisCluster → TfArg<String>?
final
redisInstance → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited