NetworkManagementConnectivityTestSource class final
Typed helper for the source block of
google_network_management_connectivity_test (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkManagementConnectivityTestSource({TfArg<
String> ? cloudSqlInstance, TfArg<String> ? gkeMasterCluster, TfArg<String> ? instance, TfArg<String> ? ipAddress, TfArg<String> ? network, TfArg<NetworkManagementConnectivityTestSourceNetworkType> ? networkType, TfArg<num> ? port, TfArg<String> ? projectId, NetworkManagementConnectivityTestSourceAppEngineVersion? appEngineVersion, NetworkManagementConnectivityTestSourceCloudFunction? cloudFunction, NetworkManagementConnectivityTestSourceCloudRunRevision? cloudRunRevision}) -
const
Properties
- appEngineVersion → NetworkManagementConnectivityTestSourceAppEngineVersion?
-
final
- cloudFunction → NetworkManagementConnectivityTestSourceCloudFunction?
-
final
- cloudRunRevision → NetworkManagementConnectivityTestSourceCloudRunRevision?
-
final
-
cloudSqlInstance
→ TfArg<
String> ? -
final
-
gkeMasterCluster
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instance
→ TfArg<
String> ? -
final
-
ipAddress
→ TfArg<
String> ? -
final
-
network
→ TfArg<
String> ? -
final
-
networkType
→ TfArg<
NetworkManagementConnectivityTestSourceNetworkType> ? -
final
-
port
→ TfArg<
num> ? -
final
-
projectId
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited