NetworkSecurityAuthzPolicyHttpRulesFrom class final

Typed helper for the http_rules.from block of google_network_security_authz_policy (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
notSources → List<NetworkSecurityAuthzPolicyHttpRulesNotSources>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources → List<NetworkSecurityAuthzPolicyHttpRulesSources>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited