NetworkSecurityAuthzPolicyHttpRulesToOperations class final
Typed helper for the http_rules.to.operations block of
google_network_security_authz_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkSecurityAuthzPolicyHttpRulesToOperations({TfArg<
List< ? methods, NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSet? headerSet, List<Object?> >NetworkSecurityAuthzPolicyHttpRulesToOperationsHosts> ? hosts, NetworkSecurityAuthzPolicyHttpRulesToOperationsMcp? mcp, List<NetworkSecurityAuthzPolicyHttpRulesToOperationsPaths> ? paths}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerSet → NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSet?
-
final
-
hosts
→ List<
NetworkSecurityAuthzPolicyHttpRulesToOperationsHosts> ? -
final
- mcp → NetworkSecurityAuthzPolicyHttpRulesToOperationsMcp?
-
final
-
methods
→ TfArg<
List< ?Object?> > -
final
-
paths
→ List<
NetworkSecurityAuthzPolicyHttpRulesToOperationsPaths> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited