NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethodsParams class final

Typed helper for the http_rules.to.operations.mcp.methods.params block of google_network_security_authz_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethodsParams({TfArg<String>? contains, TfArg<String>? exact, TfArg<bool>? ignoreCase, TfArg<String>? prefix, TfArg<String>? suffix})
const

Properties

contains → TfArg<String>?
final
exact → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
ignoreCase → TfArg<bool>?
final
prefix → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited