NetworkSecurityAuthzPolicyNetworkRulesFromNotSources class final

Typed helper for the network_rules.from.not_sources block of google_network_security_authz_policy (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
ipBlocks List<NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesIpBlocks>?
final
principals List<NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipals>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited