NetworkSecurityClientTlsPolicyGrpcEndpoint class final

Typed helper for the client_certificate.grpc_endpoint block of google_network_security_client_tls_policy (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

NetworkSecurityClientTlsPolicyGrpcEndpoint({required TfArg<String> targetUri})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetUri → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited