NetworkServicesEdgeCacheKeysetPublicKey class final

Typed helper for the public_key block of google_network_services_edge_cache_keyset (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesEdgeCacheKeysetPublicKey({required TfArg<String> id, TfArg<bool>? managed, TfArg<String>? value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
managed → TfArg<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited