NetworkServicesEdgeCacheServiceHeaderMatch class final

Typed helper for the routing.path_matcher.route_rule.match_rule.header_match block of google_network_services_edge_cache_service (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesEdgeCacheServiceHeaderMatch({TfArg<String>? exactMatch, required TfArg<String> headerName, TfArg<bool>? invertMatch, TfArg<String>? prefixMatch, TfArg<bool>? presentMatch, TfArg<String>? suffixMatch})
const

Properties

exactMatch → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
final
invertMatch → TfArg<bool>?
final
prefixMatch → TfArg<String>?
final
presentMatch → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixMatch → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited