NetworkServicesEdgeCacheServiceHostRule class final

Typed helper for the routing.host_rule block of google_network_services_edge_cache_service (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesEdgeCacheServiceHostRule({TfArg<String>? description, required TfArg<List<String>> hosts, required TfArg<String> pathMatcher})
const

Properties

description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
hosts → TfArg<List<String>>
final
pathMatcher → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited