NetworkServicesEdgeCacheServiceResponseHeaderToAdd class final

Typed helper for the routing.path_matcher.route_rule.header_action.response_header_to_add block of google_network_services_edge_cache_service (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesEdgeCacheServiceResponseHeaderToAdd({required TfArg<String> headerName, required TfArg<String> headerValue, TfArg<bool>? replace})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName → TfArg<String>
final
headerValue → TfArg<String>
final
replace → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited