NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderAction class final
Typed helper for the routing.path_matcher.route_rule.header_action block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderAction({List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToAdd> ? requestHeaderToAdd, List<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToRemove> ? requestHeaderToRemove, List<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToAdd> ? responseHeaderToAdd, List<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToRemove> ? responseHeaderToRemove}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestHeaderToAdd
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToAdd> ? -
final
-
requestHeaderToRemove
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToRemove> ? -
final
-
responseHeaderToAdd
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToAdd> ? -
final
-
responseHeaderToRemove
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToRemove> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited