NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRule class final
Typed helper for the routing.path_matcher.route_rule.match_rule block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRule({TfArg<
String> ? fullPathMatch, TfArg<bool> ? ignoreCase, TfArg<String> ? pathTemplateMatch, TfArg<String> ? prefixMatch, List<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleHeaderMatch> ? headerMatch, List<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleQueryParameterMatch> ? queryParameterMatch}) -
const
Properties
-
fullPathMatch
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerMatch
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleHeaderMatch> ? -
final
-
ignoreCase
→ TfArg<
bool> ? -
final
-
pathTemplateMatch
→ TfArg<
String> ? -
final
-
prefixMatch
→ TfArg<
String> ? -
final
-
queryParameterMatch
→ List<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleQueryParameterMatch> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited