NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicy class final
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicy({TfArg<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheMode> ? cacheMode, TfArg<String> ? clientTtl, TfArg<String> ? defaultTtl, TfArg<String> ? maxTtl, TfArg<bool> ? negativeCaching, TfArg<Map< ? negativeCachingPolicy, TfArg<String, String> >String> ? signedRequestKeyset, TfArg<String> ? signedRequestMaximumExpirationTtl, TfArg<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedRequestMode> ? signedRequestMode, NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures? addSignatures, NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy? cacheKeyPolicy, NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptions? signedTokenOptions}) -
const
Properties
- addSignatures → NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures?
-
final
- cacheKeyPolicy → NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy?
-
final
-
cacheMode
→ TfArg<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheMode> ? -
final
-
clientTtl
→ TfArg<
String> ? -
final
-
defaultTtl
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxTtl
→ TfArg<
String> ? -
final
-
negativeCaching
→ TfArg<
bool> ? -
final
-
negativeCachingPolicy
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signedRequestKeyset
→ TfArg<
String> ? -
final
-
signedRequestMaximumExpirationTtl
→ TfArg<
String> ? -
final
-
signedRequestMode
→ TfArg<
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedRequestMode> ? -
final
- signedTokenOptions → NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptions?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited