NetworkServicesEndpointPolicyMetadataLabelMatcher class final

Typed helper for the endpoint_matcher.metadata_label_matcher block of google_network_services_endpoint_policy (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadataLabelMatchCriteria → NetworkServicesEndpointPolicyMetadataLabelMatchCriteria
final
metadataLabels → List<NetworkServicesEndpointPolicyMetadataLabels>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited