NetworkServicesHttpRouteQueryParameters class final
Typed helper for the rules.matches.query_parameters block of
google_network_services_http_route (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesHttpRouteQueryParameters({required NetworkServicesHttpRouteQueryParametersMatch match, TfArg<
String> ? queryParameter}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- match → NetworkServicesHttpRouteQueryParametersMatch
-
final
-
queryParameter
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited