NetworkServicesHttpRouteRangeMatch class final

Typed helper for the rules.matches.headers.range_match block of google_network_services_http_route (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesHttpRouteRangeMatch({required TfArg<num> end, required TfArg<num> start})
const

Properties

end → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited