NetworkServicesHttpRouteRulesActionFaultInjectionPolicy class final

Typed helper for the rules.action.fault_injection_policy block of google_network_services_http_route (derived from provider schema).

Annotations
  • @immutable

Properties

abort NetworkServicesHttpRouteRulesActionFaultInjectionPolicyAbort?
final
delay NetworkServicesHttpRouteRulesActionFaultInjectionPolicyDelay?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited