NetworkServicesHttpRouteRulesActionFaultInjectionPolicyDelay class final

Typed helper for the rules.action.fault_injection_policy.delay block of google_network_services_http_route (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesHttpRouteRulesActionFaultInjectionPolicyDelay({TfArg<String>? fixedDelay, TfArg<num>? percentage})
const

Properties

fixedDelay → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
percentage → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited