NetworkServicesMulticastDomainActivationTrafficSpec class final

Typed helper for the traffic_spec block of google_network_services_multicast_domain_activation (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkServicesMulticastDomainActivationTrafficSpec({TfArg<String>? aggrEgressPps, TfArg<String>? aggrIngressPps, TfArg<num>? avgPacketSize, TfArg<String>? maxPerGroupIngressPps, TfArg<String>? maxPerGroupSubscribers})
const

Properties

aggrEgressPps → TfArg<String>?
final
aggrIngressPps → TfArg<String>?
final
avgPacketSize → TfArg<num>?
final
hashCode int
The hash code for this object.
no setterinherited
maxPerGroupIngressPps → TfArg<String>?
final
maxPerGroupSubscribers → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited