NetworkServicesTlsRouteAction class final

Typed helper for the rules.action block of google_network_services_tls_route (derived from provider schema).

Annotations
  • @immutable

Properties

destinations → List<NetworkServicesTlsRouteDestinations>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited