NodeSelector class

GPU accelerator selector (template.node_selector). Required for GPU-tier revisions.

Annotations
  • @immutable

Constructors

NodeSelector({required TfArg<String> accelerator})
const

Properties

accelerator → TfArg<String>
Accelerator type, e.g. 'nvidia-l4'. See https://cloud.google.com/run/docs/configuring/services/gpu.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited