NotebooksInstanceReservationAffinity class final
Typed helper for the reservation_affinity block of
google_notebooks_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NotebooksInstanceReservationAffinity({required TfArg<
NotebooksInstanceReservationAffinityConsumeReservationType> consumeReservationType, TfArg<String> ? key, TfArg<List< ? values})Object?> > -
const
Properties
-
consumeReservationType
→ TfArg<
NotebooksInstanceReservationAffinityConsumeReservationType> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?Object?> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited