OnHostMaintenance enum

scheduling.on_host_maintenance -- behaviour during host maintenance. MIGRATE (live migration) is the default for standard VMs; preemptible / SPOT / confidential VMs must use TERMINATE.

Inheritance
Available extensions

Values

migrate → const OnHostMaintenance
const OnHostMaintenance('MIGRATE')
terminate → const OnHostMaintenance
const OnHostMaintenance('TERMINATE')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OnHostMaintenance>
A constant List of the values in this enum, in order of their declaration.