OracleDatabaseExadbVmClusterVmFileSystemStorage class final

Typed helper for the properties.vm_file_system_storage block of google_oracle_database_exadb_vm_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseExadbVmClusterVmFileSystemStorage({required TfArg<num> sizeInGbsPerNode})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeInGbsPerNode → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited