OracleDatabaseExascaleDbStorageVaultExascaleDbStorageDetails class final

Typed helper for the properties.exascale_db_storage_details block of google_oracle_database_exascale_db_storage_vault (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseExascaleDbStorageVaultExascaleDbStorageDetails({required TfArg<num> totalSizeGbs})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSizeGbs → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited