OracleDatabaseGoldengateConnectionAmazonS3ConnectionProperties class final

Typed helper for the properties.amazon_s3_connection_properties block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateConnectionAmazonS3ConnectionProperties({TfArg<String>? accessKeyId, TfArg<String>? endpoint, TfArg<String>? region, TfArg<String>? secretAccessKeySecret, TfArg<String>? technologyType})
const

Properties

accessKeyId → TfArg<String>?
final
endpoint → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
region → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretAccessKeySecret → TfArg<String>?
final
technologyType → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited