OracleDatabaseGoldengateConnectionAmazonS3IcebergStorage class final

Typed helper for the properties.iceberg_connection_properties.storage.amazon_s3_iceberg_storage block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateConnectionAmazonS3IcebergStorage({required TfArg<String> accessKeyId, required TfArg<String> bucket, TfArg<String>? endpoint, required TfArg<String> region, required TfArg<String> schemeType, TfArg<String>? secretAccessKeySecret})
const

Properties

accessKeyId → TfArg<String>
final
bucket → TfArg<String>
final
endpoint → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
region → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemeType → TfArg<String>
final
secretAccessKeySecret → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited