OracleDatabaseGoldengateConnectionAzureDataLakeStorageIcebergStorage class final

Typed helper for the properties.iceberg_connection_properties.storage.azure_data_lake_storage_iceberg_storage block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateConnectionAzureDataLakeStorageIcebergStorage({TfArg<String>? accountKeySecret, required TfArg<String> azureAccount, required TfArg<String> container, TfArg<String>? endpoint})
const

Properties

accountKeySecret → TfArg<String>?
final
azureAccount → TfArg<String>
final
container → TfArg<String>
final
endpoint → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited