OracleDatabaseGoldengateConnectionBootstrapServers class final

Typed helper for the properties.kafka_connection_properties.bootstrap_servers block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateConnectionBootstrapServers({required TfArg<String> host, TfArg<num>? port, TfArg<String>? privateIpAddress})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → TfArg<String>
final
port → TfArg<num>?
final
privateIpAddress → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited