OracleDatabaseGoldengateConnectionCatalog class final
Typed helper for the properties.iceberg_connection_properties.catalog block of
google_oracle_database_goldengate_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OracleDatabaseGoldengateConnectionCatalog({required TfArg<
String> catalogType, OracleDatabaseGoldengateConnectionGlueIcebergCatalog? glueIcebergCatalog, OracleDatabaseGoldengateConnectionNessieIcebergCatalog? nessieIcebergCatalog, OracleDatabaseGoldengateConnectionPolarisIcebergCatalog? polarisIcebergCatalog, OracleDatabaseGoldengateConnectionRestIcebergCatalog? restIcebergCatalog}) -
const
Properties
-
catalogType
→ TfArg<
String> -
final
- glueIcebergCatalog → OracleDatabaseGoldengateConnectionGlueIcebergCatalog?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nessieIcebergCatalog → OracleDatabaseGoldengateConnectionNessieIcebergCatalog?
-
final
- polarisIcebergCatalog → OracleDatabaseGoldengateConnectionPolarisIcebergCatalog?
-
final
- restIcebergCatalog → OracleDatabaseGoldengateConnectionRestIcebergCatalog?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited