OracleDatabaseGoldengateConnectionGoogleCloudStorageIcebergStorage class final
Typed helper for the properties.iceberg_connection_properties.storage.google_cloud_storage_iceberg_storage block of
google_oracle_database_goldengate_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OracleDatabaseGoldengateConnectionGoogleCloudStorageIcebergStorage({required RefTo<
GoogleStorageBucket> bucket, required TfArg<String> projectId, TfArg<String> ? serviceAccountKeyFile}) -
const
Properties
-
bucket
→ RefTo<
GoogleStorageBucket> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
projectId
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccountKeyFile
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited