OracleDatabaseGoldengateConnectionIcebergConnectionProperties class final

Typed helper for the properties.iceberg_connection_properties block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Properties

catalog → OracleDatabaseGoldengateConnectionCatalog
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → OracleDatabaseGoldengateConnectionStorage
final
technologyType → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited