OracleDatabaseGoldengateConnectionPostgresqlConnectionProperties class final

Typed helper for the properties.postgresql_connection_properties block of google_oracle_database_goldengate_connection (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateConnectionPostgresqlConnectionProperties({TfArg<String>? database, TfArg<String>? dbSystemId, TfArg<String>? host, TfArg<String>? password, TfArg<String>? passwordSecretVersion, TfArg<num>? port, TfArg<String>? securityProtocol, TfArg<String>? sslCaFile, TfArg<String>? sslCertFile, TfArg<String>? sslCrlFile, TfArg<String>? sslKeyFile, TfArg<String>? sslMode, TfArg<String>? technologyType, TfArg<String>? username, List<OracleDatabaseGoldengateConnectionAdditionalAttributes>? additionalAttributes})
const

Properties

additionalAttributes → List<OracleDatabaseGoldengateConnectionAdditionalAttributes>?
final
database → TfArg<String>?
final
dbSystemId → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
host → TfArg<String>?
final
password → TfArg<String>?
final
passwordSecretVersion → TfArg<String>?
final
port → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProtocol → TfArg<String>?
final
sslCaFile → TfArg<String>?
final
sslCertFile → TfArg<String>?
final
sslCrlFile → TfArg<String>?
final
sslKeyFile → TfArg<String>?
final
sslMode → TfArg<String>?
final
technologyType → TfArg<String>?
final
username → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited