OracleDatabaseGoldengateConnectionRestIcebergCatalog class final
Typed helper for the properties.iceberg_connection_properties.catalog.rest_iceberg_catalog block of
google_oracle_database_goldengate_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OracleDatabaseGoldengateConnectionRestIcebergCatalog({TfArg<
String> ? properties, required TfArg<String> uri}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uri
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited