OracleDatabaseGoldengateDeploymentMaintenanceWindow class final

Typed helper for the properties.maintenance_window block of google_oracle_database_goldengate_deployment (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateDeploymentMaintenanceWindow({required TfArg<String> day, required TfArg<num> startHour})
const

Properties

day → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startHour → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited