OracleDatabaseGoldengateDeploymentProperties class final

Typed helper for the properties block of google_oracle_database_goldengate_deployment (derived from provider schema).

Annotations
  • @immutable

Constructors

OracleDatabaseGoldengateDeploymentProperties({TfArg<num>? cpuCoreCount, required TfArg<String> deploymentType, TfArg<String>? description, TfArg<String>? environmentType, TfArg<bool>? isAutoScalingEnabled, TfArg<String>? licenseModel, OracleDatabaseGoldengateDeploymentMaintenanceConfig? maintenanceConfig, OracleDatabaseGoldengateDeploymentMaintenanceWindow? maintenanceWindow, required OracleDatabaseGoldengateDeploymentOggData oggData})
const

Properties

cpuCoreCount → TfArg<num>?
final
deploymentType → TfArg<String>
final
description → TfArg<String>?
final
environmentType → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
isAutoScalingEnabled → TfArg<bool>?
final
licenseModel → TfArg<String>?
final
maintenanceConfig → OracleDatabaseGoldengateDeploymentMaintenanceConfig?
final
maintenanceWindow → OracleDatabaseGoldengateDeploymentMaintenanceWindow?
final
oggData → OracleDatabaseGoldengateDeploymentOggData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited