OrgPolicyPolicyDryRunSpec class final

Typed helper for the dry_run_spec block of google_org_policy_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

OrgPolicyPolicyDryRunSpec({TfArg<bool>? inheritFromParent, TfArg<bool>? reset, List<OrgPolicyPolicyDryRunSpecRules>? rules})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inheritFromParent → TfArg<bool>?
final
reset → TfArg<bool>?
final
rules List<OrgPolicyPolicyDryRunSpecRules>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited