OrgPolicyPolicyDryRunSpecRulesCondition class final

Typed helper for the dry_run_spec.rules.condition block of google_org_policy_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

OrgPolicyPolicyDryRunSpecRulesCondition({TfArg<String>? description, TfArg<String>? expression, TfArg<String>? location, TfArg<String>? title})
const

Properties

description → TfArg<String>?
final
expression → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
location → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited