OrganizationPolicyBooleanPolicy class final

Typed helper for the boolean_policy block of google_organization_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

OrganizationPolicyBooleanPolicy({required TfArg<bool> enforced})
const

Properties

enforced → TfArg<bool>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited