OsConfigOsPolicyAssignmentDisruptionBudget class final

Typed helper for the rollout.disruption_budget block of google_os_config_os_policy_assignment (derived from provider schema).

Annotations
  • @immutable

Constructors

OsConfigOsPolicyAssignmentDisruptionBudget({TfArg<num>? fixed, TfArg<num>? percent})
const

Properties

fixed → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
percent → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited