OsConfigOsPolicyAssignmentRpm class final

Typed helper for the os_policies.resource_groups.resources.pkg.rpm block of google_os_config_os_policy_assignment (derived from provider schema).

Annotations
  • @immutable

Constructors

OsConfigOsPolicyAssignmentRpm({TfArg<bool>? pullDeps, required OsConfigOsPolicyAssignmentSource source})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pullDeps → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → OsConfigOsPolicyAssignmentSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited