OsConfigPatchDeploymentPatchConfigApt class final

Typed helper for the patch_config.apt block of google_os_config_patch_deployment (derived from provider schema).

Annotations
  • @immutable

Constructors

OsConfigPatchDeploymentPatchConfigApt({TfArg<List<Object?>>? excludes, TfArg<List<Object?>>? exclusivePackages, TfArg<OsConfigPatchDeploymentPatchConfigAptType>? type})
const

Properties

excludes → TfArg<List<Object?>>?
final
exclusivePackages → TfArg<List<Object?>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<OsConfigPatchDeploymentPatchConfigAptType>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited