OsConfigPatchDeploymentPatchConfigPreStep class final
Typed helper for the patch_config.pre_step block of
google_os_config_patch_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- OsConfigPatchDeploymentPatchConfigPreStep({OsConfigPatchDeploymentPatchConfigPreStepLinuxExecStepConfig? linuxExecStepConfig, OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfig? windowsExecStepConfig})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- linuxExecStepConfig → OsConfigPatchDeploymentPatchConfigPreStepLinuxExecStepConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windowsExecStepConfig → OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfig?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited