OsConfigPatchDeploymentPostStep class final

Typed helper for the patch_config.post_step block of google_os_config_patch_deployment (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
linuxExecStepConfig → OsConfigPatchDeploymentLinuxExecStepConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowsExecStepConfig → OsConfigPatchDeploymentWindowsExecStepConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited