OsConfigPatchDeploymentRecurringSchedule class final
Typed helper for the recurring_schedule block of
google_os_config_patch_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentRecurringSchedule({TfArg<
String> ? endTime, TfArg<String> ? startTime, OsConfigPatchDeploymentMonthly? monthly, required OsConfigPatchDeploymentTimeOfDay timeOfDay, required OsConfigPatchDeploymentTimeZone timeZone, OsConfigPatchDeploymentWeekly? weekly}) -
const
Properties
-
endTime
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- monthly → OsConfigPatchDeploymentMonthly?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startTime
→ TfArg<
String> ? -
final
- timeOfDay → OsConfigPatchDeploymentTimeOfDay
-
final
- timeZone → OsConfigPatchDeploymentTimeZone
-
final
- weekly → OsConfigPatchDeploymentWeekly?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited