OsConfigV2PolicyOrchestratorForFolderRepositoryApt class final

Typed helper for the orchestrated_resource.os_policy_assignment_v1_payload.os_policies.resource_groups.resources.repository.apt block of google_os_config_v2_policy_orchestrator_for_folder (derived from provider schema).

Annotations
  • @immutable

Constructors

OsConfigV2PolicyOrchestratorForFolderRepositoryApt({required OsConfigV2PolicyOrchestratorForFolderArchiveType archiveType, required TfArg<List<String>> components, required TfArg<String> distribution, TfArg<String>? gpgKey, required TfArg<String> uri})
const

Properties

archiveType → OsConfigV2PolicyOrchestratorForFolderArchiveType
final
components → TfArg<List<String>>
final
distribution → TfArg<String>
final
gpgKey → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited