OsConfigV2PolicyOrchestratorForFolderSource class final

Typed helper for the orchestrated_resource.os_policy_assignment_v1_payload.os_policies.resource_groups.resources.pkg.deb.source block of google_os_config_v2_policy_orchestrator_for_folder (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

allowInsecure → TfArg<bool>?
final
gcs → OsConfigV2PolicyOrchestratorForFolderGcs?
final
hashCode → int
The hash code for this object.
no setterinherited
localPath → TfArg<String>?
final
remote → OsConfigV2PolicyOrchestratorForFolderRemote?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited