OsConfigV2PolicyOrchestratorRemote class final

Typed helper for the orchestrated_resource.os_policy_assignment_v1_payload.os_policies.resource_groups.resources.file.file.remote block of google_os_config_v2_policy_orchestrator (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

OsConfigV2PolicyOrchestratorRemote({TfArg<String>? sha256Checksum, required TfArg<String> uri})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256Checksum → TfArg<String>?
final
uri → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited