PrivateVisibilityConfig class

private_visibility_config block. At least one of gkeClusters or networks must be supplied.

Properties

gkeClusters List<PrivateVisibilityGkeCluster>?
final
hashCode int
The hash code for this object.
no setterinherited
networks List<PrivateVisibilityNetwork>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited