PrivateVisibilityNetwork class

One entry inside private_visibility_config.networks.

Constructors

PrivateVisibilityNetwork({required String networkUrl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
networkUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited