PrivatecaCaPoolAdditionalExtensions class final

Typed helper for the issuance_policy.baseline_values.additional_extensions block of google_privateca_ca_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

PrivatecaCaPoolAdditionalExtensions({required TfArg<bool> critical, required TfArg<String> value, required PrivatecaCaPoolObjectId objectId})
const

Properties

critical → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
objectId → PrivatecaCaPoolObjectId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited