PrivatecaCaPoolBaseKeyUsage class final

Typed helper for the issuance_policy.baseline_values.key_usage.base_key_usage block of google_privateca_ca_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

PrivatecaCaPoolBaseKeyUsage({TfArg<bool>? certSign, TfArg<bool>? contentCommitment, TfArg<bool>? crlSign, TfArg<bool>? dataEncipherment, TfArg<bool>? decipherOnly, TfArg<bool>? digitalSignature, TfArg<bool>? encipherOnly, TfArg<bool>? keyAgreement, TfArg<bool>? keyEncipherment})
const

Properties

certSign → TfArg<bool>?
final
contentCommitment → TfArg<bool>?
final
crlSign → TfArg<bool>?
final
dataEncipherment → TfArg<bool>?
final
decipherOnly → TfArg<bool>?
final
digitalSignature → TfArg<bool>?
final
encipherOnly → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
keyAgreement → TfArg<bool>?
final
keyEncipherment → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited