PrivatecaCaPoolIdentityConstraints class final

Typed helper for the issuance_policy.identity_constraints block of google_privateca_ca_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

PrivatecaCaPoolIdentityConstraints({required TfArg<bool> allowSubjectAltNamesPassthrough, required TfArg<bool> allowSubjectPassthrough, PrivatecaCaPoolCelExpression? celExpression})
const

Properties

allowSubjectAltNamesPassthrough → TfArg<bool>
final
allowSubjectPassthrough → TfArg<bool>
final
celExpression → PrivatecaCaPoolCelExpression?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited