PrivatecaCaPoolKeyUsage class final

Typed helper for the issuance_policy.baseline_values.key_usage block of google_privateca_ca_pool (derived from provider schema).

Annotations
  • @immutable

Constructors

PrivatecaCaPoolKeyUsage({required PrivatecaCaPoolBaseKeyUsage baseKeyUsage, required PrivatecaCaPoolExtendedKeyUsage extendedKeyUsage, List<PrivatecaCaPoolUnknownExtendedKeyUsages>? unknownExtendedKeyUsages})
const

Properties

baseKeyUsage → PrivatecaCaPoolBaseKeyUsage
final
extendedKeyUsage → PrivatecaCaPoolExtendedKeyUsage
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownExtendedKeyUsages → List<PrivatecaCaPoolUnknownExtendedKeyUsages>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited