PubsubLiteTopicPartitionConfig class final

Typed helper for the partition_config block of google_pubsub_lite_topic (derived from provider schema).

Annotations
  • @immutable

Constructors

PubsubLiteTopicPartitionConfig({required TfArg<num> count, PubsubLiteTopicCapacity? capacity})
const

Properties

capacity → PubsubLiteTopicCapacity?
final
count → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited