PubsubLiteTopicPartitionConfigCapacity class final

Typed helper for the partition_config.capacity block of google_pubsub_lite_topic (derived from provider schema).

Annotations
  • @immutable

Constructors

PubsubLiteTopicPartitionConfigCapacity({required TfArg<num> publishMibPerSec, required TfArg<num> subscribeMibPerSec})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
publishMibPerSec → TfArg<num>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribeMibPerSec → TfArg<num>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited