PubsubLiteTopicReservationConfig class final

Typed helper for the reservation_config block of google_pubsub_lite_topic (derived from provider schema).

Annotations
  • @immutable

Constructors

PubsubLiteTopicReservationConfig({TfArg<String>? throughputReservation})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throughputReservation → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited