PubsubSubscriptionAvroConfig class final

Typed helper for the cloud_storage_config.avro_config block of google_pubsub_subscription (derived from provider schema).

Annotations
  • @immutable

Constructors

PubsubSubscriptionAvroConfig({TfArg<bool>? useTopicSchema, TfArg<bool>? writeMetadata})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useTopicSchema → TfArg<bool>?
final
writeMetadata → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited