PubsubSubscriptionPushConfig class

push_config block. Pair with pushEndpoint; optionally attach an oidcToken (recommended for authenticated webhooks) or noWrapper.

Annotations
  • @immutable

Constructors

PubsubSubscriptionPushConfig({required TfArg<String> pushEndpoint, TfArg<Map<String, String>>? attributes, PubsubSubscriptionOidcToken? oidcToken, PubsubSubscriptionNoWrapper? noWrapper})
const

Properties

attributes → TfArg<Map<String, String>>?
final
hashCode int
The hash code for this object.
no setterinherited
noWrapper PubsubSubscriptionNoWrapper?
final
oidcToken PubsubSubscriptionOidcToken?
final
pushEndpoint → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited