PubsubTopicMessageTransforms class final

Typed helper for the message_transforms block of google_pubsub_topic (derived from provider schema).

Annotations
  • @immutable

Constructors

PubsubTopicMessageTransforms({TfArg<bool>? disabled, PubsubTopicAiInference? aiInference, PubsubTopicJavascriptUdf? javascriptUdf})
const

Properties

aiInference → PubsubTopicAiInference?
final
disabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
javascriptUdf → PubsubTopicJavascriptUdf?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited