QuicOverride enum
QUIC negotiation policy for the HTTPS target proxy. When set to none (the default), Google manages whether QUIC is offered to clients; enable always offers QUIC; disable never offers it.
Values
- none → const QuicOverride
-
const QuicOverride('NONE') - enable → const QuicOverride
-
const QuicOverride('ENABLE') - disable → const QuicOverride
-
const QuicOverride('DISABLE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QuicOverride> - A constant List of the values in this enum, in order of their declaration.