RedisClusterMaintenancePolicyWeeklyMaintenanceWindow class final
Typed helper for the maintenance_policy.weekly_maintenance_window block of
google_redis_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
RedisClusterMaintenancePolicyWeeklyMaintenanceWindow({required TfArg<
RedisClusterMaintenancePolicyWeeklyMaintenanceWindowDay> day, required RedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime startTime}) -
const
Properties
-
day
→ TfArg<
RedisClusterMaintenancePolicyWeeklyMaintenanceWindowDay> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → RedisClusterMaintenancePolicyWeeklyMaintenanceWindowStartTime
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited