RedisInstanceTransitEncryptionMode extension type

transit_encryption_mode — in-transit TLS mode (provider default DISABLED). When SERVER_AUTHENTICATION is set, clients verify the server against GoogleRedisInstance.serverCaCerts.

on
Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTfJson() → Object?
Value emitted into Terraform JSON.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited