scaleInControl property
Smoothing applied to scale-in decisions (replica removals). Prevents the autoscaler from shedding replicas too aggressively during traffic dips.
Implementation
final RegionAutoscalerScaleInControl? scaleInControl;
Smoothing applied to scale-in decisions (replica removals). Prevents the autoscaler from shedding replicas too aggressively during traffic dips.
final RegionAutoscalerScaleInControl? scaleInControl;