RegionAutoscalerCpuPredictiveMethod enum
Predictive autoscaling method for RegionAutoscalerCpuUtilization.
- none — disable predictive autoscaling (default).
- optimizeAvailability — monitor weekly load patterns and scale out ahead of anticipated demand.
Values
- none → const RegionAutoscalerCpuPredictiveMethod
-
const RegionAutoscalerCpuPredictiveMethod('NONE') - optimizeAvailability → const RegionAutoscalerCpuPredictiveMethod
-
const RegionAutoscalerCpuPredictiveMethod('OPTIMIZE_AVAILABILITY')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RegionAutoscalerCpuPredictiveMethod> - A constant List of the values in this enum, in order of their declaration.