RegionInstanceGroupManagerUpdatePolicyReplacementMethod extension type

update_policy.replacement_method. SUBSTITUTE (default) replaces VMs with newly-named ones; RECREATE preserves instance names but requires max_unavailable_* > 0.

on
Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTfJson() → Object?
Value emitted into Terraform JSON.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited