SccFolderCustomModuleCustomConfigResourceSelector class final

Typed helper for the custom_config.resource_selector block of google_scc_folder_custom_module (derived from provider schema).

Annotations
  • @immutable

Constructors

SccFolderCustomModuleCustomConfigResourceSelector({required TfArg<List<Object?>> resourceTypes})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceTypes → TfArg<List<Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited