SccFolderCustomModuleCustomOutput class final

Typed helper for the custom_config.custom_output block of google_scc_folder_custom_module (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties → List<SccFolderCustomModuleProperties>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited