SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfig class final
Typed helper for the custom_config block of
google_scc_management_folder_security_health_analytics_custom_module (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfig({TfArg<
String> ? description, TfArg<String> ? recommendation, TfArg<SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigSeverity> ? severity, SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput? customOutput, SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigPredicate? predicate, SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector? resourceSelector}) -
const
Properties
- customOutput → SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput?
-
final
-
description
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- predicate → SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigPredicate?
-
final
-
recommendation
→ TfArg<
String> ? -
final
- resourceSelector → SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
severity
→ TfArg<
SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigSeverity> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited