SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfig class final
Typed helper for the custom_config block of
google_scc_management_organization_security_health_analytics_custom_module (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfig({TfArg<
String> ? description, required TfArg<String> recommendation, required TfArg<SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigSeverity> severity, SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput? customOutput, required SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigPredicate predicate, required SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector resourceSelector}) -
const
Properties
- customOutput → SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput?
-
final
-
description
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- predicate → SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigPredicate
-
final
-
recommendation
→ TfArg<
String> -
final
- resourceSelector → SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
severity
→ TfArg<
SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigSeverity> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited