SccOrganizationCustomModuleCustomConfig class final

Typed helper for the custom_config block of google_scc_organization_custom_module (derived from provider schema).

Annotations
  • @immutable

Constructors

SccOrganizationCustomModuleCustomConfig({TfArg<String>? description, required TfArg<String> recommendation, required TfArg<SccOrganizationCustomModuleCustomConfigSeverity> severity, SccOrganizationCustomModuleCustomConfigCustomOutput? customOutput, required SccOrganizationCustomModuleCustomConfigPredicate predicate, required SccOrganizationCustomModuleCustomConfigResourceSelector resourceSelector})
const

Properties

customOutput SccOrganizationCustomModuleCustomConfigCustomOutput?
final
description → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
predicate SccOrganizationCustomModuleCustomConfigPredicate
final
recommendation → TfArg<String>
final
resourceSelector SccOrganizationCustomModuleCustomConfigResourceSelector
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity → TfArg<SccOrganizationCustomModuleCustomConfigSeverity>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited