SecretManagerSecretSecretTopic class

Pub/Sub topics entry under google_secret_manager_secret.topics.

Annotations
  • @immutable

Constructors

SecretManagerSecretSecretTopic({required TfArg<String> name})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
Topic resource path, e.g. TfArg.ref(notifyTopic.id).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited