SecurityposturePostureCustomConstraint class final
Typed helper for the policy_sets.policies.constraint.org_policy_constraint_custom.custom_constraint block of
google_securityposture_posture (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SecurityposturePostureCustomConstraint({required SecurityposturePostureActionType actionType, required TfArg<
String> condition, TfArg<String> ? description, TfArg<String> ? displayName, required TfArg<List< methodTypes, required TfArg<String> >String> name, required TfArg<List< resourceTypes})String> > -
const
Properties
- actionType → SecurityposturePostureActionType
-
final
-
condition
→ TfArg<
String> -
final
-
description
→ TfArg<
String> ? -
final
-
displayName
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methodTypes
→ TfArg<
List< String> > -
final
-
name
→ TfArg<
String> -
final
-
resourceTypes
→ TfArg<
List< String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited