SecurityposturePostureValues class final

Typed helper for the policy_sets.policies.constraint.org_policy_constraint.policy_rules.values block of google_securityposture_posture (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

SecurityposturePostureValues({TfArg<List<String>>? allowedValues, TfArg<List<String>>? deniedValues})
const

Properties

allowedValues → TfArg<List<String>>?
final
deniedValues → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited