SpannerBackupScheduleEncryptionConfig class final
Typed helper for the encryption_config block of
google_spanner_backup_schedule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- SpannerBackupScheduleEncryptionConfig({required SpannerBackupScheduleEncryptionType encryptionType, SpannerBackupScheduleKmsKeyName? kmsKeyName})
-
const
Properties
- encryptionType → SpannerBackupScheduleEncryptionType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kmsKeyName → SpannerBackupScheduleKmsKeyName?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited