SpannerDatabaseEncryptionConfigKmsKeyNames class final

The SpannerDatabaseEncryptionConfig.kmsKeyNames choice: sets kms_key_names.

Inheritance

Constructors

SpannerDatabaseEncryptionConfigKmsKeyNames(TfArg<List<String>> kmsKeyNames)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyNames → TfArg<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited