SpannerInstanceAutoscalingConfig class final

Typed helper for the autoscaling_config block of google_spanner_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SpannerInstanceAutoscalingConfig({List<SpannerInstanceAsymmetricAutoscalingOptions>? asymmetricAutoscalingOptions, SpannerInstanceAutoscalingLimits? autoscalingLimits, SpannerInstanceAutoscalingTargets? autoscalingTargets})
const

Properties

asymmetricAutoscalingOptions → List<SpannerInstanceAsymmetricAutoscalingOptions>?
final
autoscalingLimits → SpannerInstanceAutoscalingLimits?
final
autoscalingTargets → SpannerInstanceAutoscalingTargets?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited