SqlDatabaseInstanceBackupRetentionSettings class final

Typed helper for the settings.backup_configuration.backup_retention_settings block of google_sql_database_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SqlDatabaseInstanceBackupRetentionSettings({required TfArg<num> retainedBackups, TfArg<String>? retentionUnit})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
retainedBackups → TfArg<num>
final
retentionUnit → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited