SqlDatabaseInstancePscConfig class final

Typed helper for the settings.ip_configuration.psc_config block of google_sql_database_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SqlDatabaseInstancePscConfig({TfArg<List<String>>? allowedConsumerProjects, TfArg<String>? networkAttachmentUri, TfArg<bool>? pscAutoConnectionPolicyEnabled, TfArg<bool>? pscAutoDnsEnabled, TfArg<bool>? pscEnabled, TfArg<bool>? pscWriteEndpointDnsEnabled, List<SqlDatabaseInstancePscAutoConnections>? pscAutoConnections})
const

Properties

allowedConsumerProjects → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
networkAttachmentUri → TfArg<String>?
final
pscAutoConnectionPolicyEnabled → TfArg<bool>?
final
pscAutoConnections → List<SqlDatabaseInstancePscAutoConnections>?
final
pscAutoDnsEnabled → TfArg<bool>?
final
pscEnabled → TfArg<bool>?
final
pscWriteEndpointDnsEnabled → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited