SqlDatabaseInstanceReadPoolAutoScaleConfig class final

Typed helper for the settings.read_pool_auto_scale_config block of google_sql_database_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SqlDatabaseInstanceReadPoolAutoScaleConfig({TfArg<bool>? disableScaleIn, TfArg<bool>? enabled, TfArg<num>? maxNodeCount, TfArg<num>? minNodeCount, TfArg<num>? scaleInCooldownSeconds, TfArg<num>? scaleOutCooldownSeconds, List<SqlDatabaseInstanceTargetMetrics>? targetMetrics})
const

Properties

disableScaleIn → TfArg<bool>?
final
enabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
maxNodeCount → TfArg<num>?
final
minNodeCount → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleInCooldownSeconds → TfArg<num>?
final
scaleOutCooldownSeconds → TfArg<num>?
final
targetMetrics → List<SqlDatabaseInstanceTargetMetrics>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited