SqlDatabaseInstanceReplicationCluster class final

Typed helper for the replication_cluster block of google_sql_database_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SqlDatabaseInstanceReplicationCluster({TfArg<String>? failoverDrReplicaName, TfArg<String>? psaWriteEndpoint})
const

Properties

failoverDrReplicaName → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
psaWriteEndpoint → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited