SqlDatabaseInstanceRestoreBackupContext class final

Typed helper for the restore_backup_context block of google_sql_database_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

SqlDatabaseInstanceRestoreBackupContext({required TfArg<num> backupRunId, TfArg<String>? instanceId, TfArg<String>? project})
const

Properties

backupRunId → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → TfArg<String>?
final
project → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited