StorageBucketBucketLogging class

Access-log delivery configuration.

Constructors

StorageBucketBucketLogging({required TfArg<String> logBucket, TfArg<String>? logObjectPrefix})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
logBucket → TfArg<String>
final
logObjectPrefix → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited