value property

  1. @override
TfArg<String> get value
override

The scalar value that will be written to the argMap under blockKey. Always a TfArg<String> (source is a file path, content is the inline string).

Implementation

@override
TfArg<String> get value => source;