StorageBucketPublicNetworkSource class final

Typed helper for the ip_filter.public_network_source block of google_storage_bucket (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageBucketPublicNetworkSource({required TfArg<List<String>> allowedIpCidrRanges})
const

Properties

allowedIpCidrRanges → TfArg<List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited