StorageBucketVpcNetworkSource class

Constructors

StorageBucketVpcNetworkSource({required TfArg<String> network, required List<String> allowedIpCidrRanges})
const

Properties

allowedIpCidrRanges List<String>
final
hashCode int
The hash code for this object.
no setterinherited
network → TfArg<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited