StorageControlOrganizationIntelligenceConfigIncludedCloudStorageBuckets class final

Typed helper for the filter.included_cloud_storage_buckets block of google_storage_control_organization_intelligence_config (derived from provider schema).

Annotations
  • @immutable

Properties

bucketIdRegexes → TfArg<List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited