StorageFtpServerConsumerAcceptList class final
Typed helper for the internal_config.consumer_accept_list block of
google_storage_ftp_server (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
StorageFtpServerConsumerAcceptList({required TfArg<
num> connectionLimit, required TfArg<String> project}) -
const
Properties
-
connectionLimit
→ TfArg<
num> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
project
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited