StorageInsightsDatasetConfigExcludeCloudStorageBuckets class final
Typed helper for the exclude_cloud_storage_buckets block of
google_storage_insights_dataset_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
StorageInsightsDatasetConfigExcludeCloudStorageBuckets({required List<
StorageInsightsDatasetConfigExcludeCloudStorageBucketsCloudStorageBuckets> cloudStorageBuckets}) -
const
Properties
-
cloudStorageBuckets
→ List<
StorageInsightsDatasetConfigExcludeCloudStorageBucketsCloudStorageBuckets> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited