StorageTransferJobGcsDataSource class final
Typed helper for the replication_spec.gcs_data_source block of
google_storage_transfer_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
StorageTransferJobGcsDataSource({required RefTo<
GoogleStorageBucket> bucketName, TfArg<String> ? path}) -
const
Properties
-
bucketName
→ RefTo<
GoogleStorageBucket> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited