StorageTransferJobPosixDataSource class final

Typed helper for the transfer_spec.posix_data_source block of google_storage_transfer_job (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageTransferJobPosixDataSource({required TfArg<String> rootDirectory})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rootDirectory → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited