StorageTransferJobReplicationSpecTransferOptionsMetadataOptions class final

Typed helper for the replication_spec.transfer_options.metadata_options block of google_storage_transfer_job (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageTransferJobReplicationSpecTransferOptionsMetadataOptions({TfArg<String>? acl, TfArg<String>? gid, TfArg<String>? kmsKey, TfArg<String>? mode, TfArg<String>? storageClass, TfArg<String>? symlink, TfArg<String>? temporaryHold, TfArg<String>? timeCreated, TfArg<String>? uid})
const

Properties

acl → TfArg<String>?
final
gid → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
kmsKey → TfArg<String>?
final
mode → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageClass → TfArg<String>?
final
final
temporaryHold → TfArg<String>?
final
timeCreated → TfArg<String>?
final
uid → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited