StorageTransferJobScheduleStartDate class final

Typed helper for the schedule.schedule_start_date block of google_storage_transfer_job (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageTransferJobScheduleStartDate({required TfArg<num> day, required TfArg<num> month, required TfArg<num> year})
const

Properties

day → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
month → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited