StorageTransferJobStartTimeOfDay class final

Typed helper for the schedule.start_time_of_day block of google_storage_transfer_job (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageTransferJobStartTimeOfDay({required TfArg<num> hours, required TfArg<num> minutes, required TfArg<num> nanos, required TfArg<num> seconds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hours → TfArg<num>
final
minutes → TfArg<num>
final
nanos → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited