StorageTransferJobTransferSpecAwsS3CompatibleDataSource class final

Typed helper for the transfer_spec.aws_s3_compatible_data_source block of google_storage_transfer_job (derived from provider schema).

Annotations
  • @immutable

Constructors

StorageTransferJobTransferSpecAwsS3CompatibleDataSource({required TfArg<String> bucketName, required TfArg<String> endpoint, TfArg<String>? path, TfArg<String>? region, StorageTransferJobTransferSpecAwsS3CompatibleDataSourceS3Metadata? s3Metadata})
const

Properties

bucketName → TfArg<String>
final
endpoint → TfArg<String>
final
hashCode int
The hash code for this object.
no setterinherited
path → TfArg<String>?
final
region → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s3Metadata StorageTransferJobTransferSpecAwsS3CompatibleDataSourceS3Metadata?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited