SubnetworkLogConfigAggregationInterval extension type
VPC flow log aggregation interval. The default on GCP is interval5Sec (denser sampling, higher cost).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- interval1Min → const SubnetworkLogConfigAggregationInterval
- interval5Min → const SubnetworkLogConfigAggregationInterval
- interval5Sec → const SubnetworkLogConfigAggregationInterval
- interval10Min → const SubnetworkLogConfigAggregationInterval
- interval15Min → const SubnetworkLogConfigAggregationInterval
- interval30Sec → const SubnetworkLogConfigAggregationInterval
-
values
→ const List<
SubnetworkLogConfigAggregationInterval>