SubnetworkPurpose enum

Purpose of the subnetwork. Defaults to private when unspecified.

regionalManagedProxy / globalManagedProxy reserve the subnet for Envoy-based load balancers (the SubnetworkRole field then selects ACTIVE vs BACKUP). privateServiceConnect reserves the subnet for a Private Service Connect published service. peerMigration reserves the subnet for migrating resources between peered networks. privateNat is used as the source range for Private NAT gateways.

Inheritance
Available extensions

Values

private → const SubnetworkPurpose
const SubnetworkPurpose('PRIVATE')
regionalManagedProxy → const SubnetworkPurpose
const SubnetworkPurpose('REGIONAL_MANAGED_PROXY')
globalManagedProxy → const SubnetworkPurpose
const SubnetworkPurpose('GLOBAL_MANAGED_PROXY')
privateServiceConnect → const SubnetworkPurpose
const SubnetworkPurpose('PRIVATE_SERVICE_CONNECT')
peerMigration → const SubnetworkPurpose
const SubnetworkPurpose('PEER_MIGRATION')
privateNat → const SubnetworkPurpose
const SubnetworkPurpose('PRIVATE_NAT')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformValue String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubnetworkPurpose>
A constant List of the values in this enum, in order of their declaration.