SubnetworkResolveSubnetMask extension type
ARP resolution mode for the subnetwork. Controls which ranges respond to ARP requests. Used only by reserved-internal-range subnetworks.
Constructors
-
SubnetworkResolveSubnetMask.arg(TfArg<
String> arg) -
const
- SubnetworkResolveSubnetMask.expression(String template)
- SubnetworkResolveSubnetMask.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited