SynthException class final

Thrown by Stack.synth() and Stack.writeTo() when the Stack has one or more SynthIssues. Nothing is written.

Implemented types

Constructors

SynthException(String stack, List<SynthIssue> issues)

Properties

hashCode → int
The hash code for this object.
no setterinherited
issues → List<SynthIssue>
Every issue, in Stack order.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → String
The Stack's class name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited