expression property
String
get
expression
The constraint as Terraform writes it, which is also its tf.json form.
Implementation
String get expression;
The constraint as Terraform writes it, which is also its tf.json form.
String get expression;