TranscoderJobConfigEditList class final

Typed helper for the config.edit_list block of google_transcoder_job (derived from provider schema).

Annotations
  • @immutable

Constructors

TranscoderJobConfigEditList({TfArg<List<Object?>>? inputs, TfArg<String>? key, TfArg<String>? startTimeOffset})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputs → TfArg<List<Object?>>?
final
key → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeOffset → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited