TranscoderJobConfigOverlaysAnimationsAnimationFadeXy class final

Typed helper for the config.overlays.animations.animation_fade.xy block of google_transcoder_job (derived from provider schema).

Annotations
  • @immutable

Constructors

TranscoderJobConfigOverlaysAnimationsAnimationFadeXy({TfArg<num>? x, TfArg<num>? y})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x → TfArg<num>?
final
y → TfArg<num>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited