TranscoderJobTemplateConfig class final
Typed helper for the config block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
TranscoderJobTemplateConfig({List<
TranscoderJobTemplateAdBreaks> ? adBreaks, List<TranscoderJobTemplateEditList> ? editList, List<TranscoderJobTemplateElementaryStreams> ? elementaryStreams, List<TranscoderJobTemplateEncryptions> ? encryptions, List<TranscoderJobTemplateInputs> ? inputs, List<TranscoderJobTemplateManifests> ? manifests, List<TranscoderJobTemplateMuxStreams> ? muxStreams, TranscoderJobTemplateOutput? output, List<TranscoderJobTemplateOverlays> ? overlays, TranscoderJobTemplatePubsubDestination? pubsubDestination}) -
const
Properties
-
adBreaks
→ List<
TranscoderJobTemplateAdBreaks> ? -
final
-
editList
→ List<
TranscoderJobTemplateEditList> ? -
final
-
elementaryStreams
→ List<
TranscoderJobTemplateElementaryStreams> ? -
final
-
encryptions
→ List<
TranscoderJobTemplateEncryptions> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ List<
TranscoderJobTemplateInputs> ? -
final
-
manifests
→ List<
TranscoderJobTemplateManifests> ? -
final
-
muxStreams
→ List<
TranscoderJobTemplateMuxStreams> ? -
final
- output → TranscoderJobTemplateOutput?
-
final
-
overlays
→ List<
TranscoderJobTemplateOverlays> ? -
final
- pubsubDestination → TranscoderJobTemplatePubsubDestination?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited