TranscoderJobTemplateConfigEncryptions class final
Typed helper for the config.encryptions block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
TranscoderJobTemplateConfigEncryptions({required TfArg<
String> id, TranscoderJobTemplateConfigEncryptionsAes128? aes128, TranscoderJobTemplateConfigEncryptionsDrmSystems? drmSystems, TranscoderJobTemplateConfigEncryptionsMpegCenc? mpegCenc, TranscoderJobTemplateConfigEncryptionsSampleAes? sampleAes, TranscoderJobTemplateConfigEncryptionsSecretManagerKeySource? secretManagerKeySource}) -
const
Properties
- aes128 → TranscoderJobTemplateConfigEncryptionsAes128?
-
final
- drmSystems → TranscoderJobTemplateConfigEncryptionsDrmSystems?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> -
final
- mpegCenc → TranscoderJobTemplateConfigEncryptionsMpegCenc?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleAes → TranscoderJobTemplateConfigEncryptionsSampleAes?
-
final
- secretManagerKeySource → TranscoderJobTemplateConfigEncryptionsSecretManagerKeySource?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited