TranscoderJobTemplateConfigEncryptionsDrmSystems class final
Typed helper for the config.encryptions.drm_systems block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- TranscoderJobTemplateConfigEncryptionsDrmSystems({TranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey? clearkey, TranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay? fairplay, TranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready? playready, TranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine? widevine})
-
const
Properties
- clearkey → TranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey?
-
final
- fairplay → TranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- playready → TranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widevine → TranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited