TranscoderJobTemplateConfigEncryptionsSecretManagerKeySource class final
Typed helper for the config.encryptions.secret_manager_key_source block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
TranscoderJobTemplateConfigEncryptionsSecretManagerKeySource({required TfArg<
String> secretVersion}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretVersion
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited