TranscoderJobTemplateConfigInputs class final

Typed helper for the config.inputs block of google_transcoder_job_template (derived from provider schema).

Annotations
  • @immutable

Constructors

TranscoderJobTemplateConfigInputs({TfArg<String>? key, TfArg<String>? uri})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited