TranscoderJobTemplateConfigOverlays class final
Typed helper for the config.overlays block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
TranscoderJobTemplateConfigOverlays({List<
TranscoderJobTemplateConfigOverlaysAnimations> ? animations, TranscoderJobTemplateConfigOverlaysImage? image}) -
const
Properties
-
animations
→ List<
TranscoderJobTemplateConfigOverlaysAnimations> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → TranscoderJobTemplateConfigOverlaysImage?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited