TranscoderJobTemplateEncryptions class final
Typed helper for the config.encryptions block of
google_transcoder_job_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
TranscoderJobTemplateEncryptions({required TfArg<
String> id, TranscoderJobTemplateAes128? aes128, TranscoderJobTemplateDrmSystems? drmSystems, TranscoderJobTemplateMpegCenc? mpegCenc, TranscoderJobTemplateSampleAes? sampleAes, TranscoderJobTemplateSecretManagerKeySource? secretManagerKeySource}) -
const
Properties
- aes128 → TranscoderJobTemplateAes128?
-
final
- drmSystems → TranscoderJobTemplateDrmSystems?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> -
final
- mpegCenc → TranscoderJobTemplateMpegCenc?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleAes → TranscoderJobTemplateSampleAes?
-
final
- secretManagerKeySource → TranscoderJobTemplateSecretManagerKeySource?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited