TranscoderJobVideoStream class final

Typed helper for the config.elementary_streams.video_stream block of google_transcoder_job (derived from provider schema).

Annotations
  • @immutable

Constructors

TranscoderJobVideoStream({TranscoderJobH264? h264})
const

Properties

h264 → TranscoderJobH264?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited