UrlMapCacheMode extension type
route_action.cache_policy.cache_mode and nested cache policy blocks.
Constructors
-
UrlMapCacheMode.arg(TfArg<
String> arg) -
const
- UrlMapCacheMode.expression(String template)
- UrlMapCacheMode.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cacheAllStatic → const UrlMapCacheMode
- forceCacheAll → const UrlMapCacheMode
- useOriginHeaders → const UrlMapCacheMode
-
values
→ const List<
UrlMapCacheMode>