UrlMapQueryParameterMatch class

One match_rules[].query_parameter_matches[] entry. Matches a single query parameter by name with a chosen predicate.

Annotations
  • @immutable

Constructors

UrlMapQueryParameterMatch({required TfArg<String> name, TfArg<String>? exactMatch, TfArg<String>? regexMatch, TfArg<bool>? presentMatch})
const

Properties

exactMatch → TfArg<String>?
Exact value match.
final
hashCode int
The hash code for this object.
no setterinherited
name → TfArg<String>
Query parameter name.
final
presentMatch → TfArg<bool>?
Match if the parameter is present (any value).
final
regexMatch → TfArg<String>?
Regex value match (RE2 syntax).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited