VectorSearchCollectionDenseVector class final

Typed helper for the vector_schema.dense_vector block of google_vector_search_collection (derived from provider schema).

Annotations
  • @immutable

Constructors

VectorSearchCollectionDenseVector({TfArg<num>? dimensions, VectorSearchCollectionVertexEmbeddingConfig? vertexEmbeddingConfig})
const

Properties

dimensions → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexEmbeddingConfig → VectorSearchCollectionVertexEmbeddingConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited