VectorSearchCollectionVectorSchemaDenseVector class final

Typed helper for the vector_schema.dense_vector block of google_vector_search_collection (derived from provider schema).

Annotations
  • @immutable

Properties

dimensions → TfArg<num>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertexEmbeddingConfig VectorSearchCollectionVectorSchemaDenseVectorVertexEmbeddingConfig?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited