VectorSearchIndexDedicatedInfrastructureAutoscalingSpec class final

Typed helper for the dedicated_infrastructure.autoscaling_spec block of google_vector_search_index (derived from provider schema).

Annotations
  • @immutable

Constructors

VectorSearchIndexDedicatedInfrastructureAutoscalingSpec({TfArg<num>? maxReplicaCount, TfArg<num>? minReplicaCount})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxReplicaCount → TfArg<num>?
final
minReplicaCount → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited