VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecHealthProbeTcpSocket class final

Typed helper for the model_config.container_spec.health_probe.tcp_socket block of google_vertex_ai_endpoint_with_model_garden_deployment (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
host → TfArg<String>?
final
port → TfArg<num>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited