VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbe class final
Typed helper for the model_config.container_spec.startup_probe block of
google_vertex_ai_endpoint_with_model_garden_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbe({TfArg<
num> ? failureThreshold, TfArg<num> ? initialDelaySeconds, TfArg<num> ? periodSeconds, TfArg<num> ? successThreshold, TfArg<num> ? timeoutSeconds, VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeExec? exec, VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeGrpc? grpc, VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeHttpGet? httpGet, VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeTcpSocket? tcpSocket}) -
const
Properties
- exec → VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeExec?
-
final
-
failureThreshold
→ TfArg<
num> ? -
final
- grpc → VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeGrpc?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpGet → VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeHttpGet?
-
final
-
initialDelaySeconds
→ TfArg<
num> ? -
final
-
periodSeconds
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
successThreshold
→ TfArg<
num> ? -
final
- tcpSocket → VertexAiEndpointWithModelGardenDeploymentModelConfigContainerSpecStartupProbeTcpSocket?
-
final
-
timeoutSeconds
→ TfArg<
num> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited