VertexAiFeatureOnlineStoreFeatureviewBigQuerySource class final

big_query_source — materialize a BigQuery view on each sync.

Inheritance
Annotations
  • @immutable

Constructors

VertexAiFeatureOnlineStoreFeatureviewBigQuerySource({required TfArg<String> uri, required TfArg<List<String>> entityIdColumns})
const

Properties

blockKey String
no setteroverride
entityIdColumns → TfArg<List<String>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri → TfArg<String>
final

Methods

encode() List<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited