VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource class final
feature_registry_source — sync selected Feature Registry features.
- Inheritance
-
- Object
- VertexAiFeatureOnlineStoreFeatureviewSource
- VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource
- Annotations
-
- @immutable
Constructors
-
VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource({required List<
VertexAiFeatureOnlineStoreFeatureviewFeatureGroup> featureGroups, TfArg<String> ? projectNumber}) -
const
Properties
- blockKey → String
-
no setteroverride
-
featureGroups
→ List<
VertexAiFeatureOnlineStoreFeatureviewFeatureGroup> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
projectNumber
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → List< Map< String, Object?> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited