VertexAiFeatureOnlineStoreFeatureviewSyncConfig class final
Optional sync_config block (cron and/or continuous).
- Annotations
-
- @immutable
Constructors
-
VertexAiFeatureOnlineStoreFeatureviewSyncConfig({TfArg<
String> ? cron, TfArg<bool> ? continuous}) -
const
Properties
-
continuous
→ TfArg<
bool> ? -
final
-
cron
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → List< Map< String, Object?> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited