VertexAiPersistentResourceResourcePoolsMachineSpec class final
Typed helper for the resource_pools.machine_spec block of
google_vertex_ai_persistent_resource (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VertexAiPersistentResourceResourcePoolsMachineSpec({TfArg<
num> ? acceleratorCount, TfArg<String> ? acceleratorType, TfArg<String> ? machineType}) -
const
Properties
-
acceleratorCount
→ TfArg<
num> ? -
final
-
acceleratorType
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
machineType
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited