VertexAiReasoningEngineFunctionCall class final

Typed helper for the context_spec.memory_bank_config.customization_configs.generate_memories_examples.conversation_source.events.content.parts.function_call block of google_vertex_ai_reasoning_engine (derived from provider schema).

Annotations
  • @immutable

Constructors

VertexAiReasoningEngineFunctionCall({TfArg<String>? args, TfArg<String>? id, TfArg<String>? name})
const

Properties

args → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>?
final
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited