VertexAiReasoningEngineMemoryBankConfig class final
Typed helper for the context_spec.memory_bank_config block of
google_vertex_ai_reasoning_engine (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VertexAiReasoningEngineMemoryBankConfig({TfArg<
bool> ? disableMemoryRevisions, List<VertexAiReasoningEngineCustomizationConfigs> ? customizationConfigs, VertexAiReasoningEngineGenerationConfig? generationConfig, VertexAiReasoningEngineSimilaritySearchConfig? similaritySearchConfig, List<VertexAiReasoningEngineStructuredMemoryConfigs> ? structuredMemoryConfigs, VertexAiReasoningEngineTtlConfig? ttlConfig}) -
const
Properties
-
customizationConfigs
→ List<
VertexAiReasoningEngineCustomizationConfigs> ? -
final
-
disableMemoryRevisions
→ TfArg<
bool> ? -
final
- generationConfig → VertexAiReasoningEngineGenerationConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- similaritySearchConfig → VertexAiReasoningEngineSimilaritySearchConfig?
-
final
-
structuredMemoryConfigs
→ List<
VertexAiReasoningEngineStructuredMemoryConfigs> ? -
final
- ttlConfig → VertexAiReasoningEngineTtlConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited