VmwareengineExternalAccessRuleDestinationIpRanges class final

Typed helper for the destination_ip_ranges block of google_vmwareengine_external_access_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

VmwareengineExternalAccessRuleDestinationIpRanges({TfArg<String>? externalAddress, TfArg<String>? ipAddressRange})
const

Properties

externalAddress → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
ipAddressRange → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited