VmwareenginePrivateCloudManagementClusterStretchedClusterConfig class final

Typed helper for the management_cluster.stretched_cluster_config block of google_vmwareengine_private_cloud (derived from provider schema).

Annotations
  • @immutable

Constructors

VmwareenginePrivateCloudManagementClusterStretchedClusterConfig({TfArg<String>? preferredLocation, TfArg<String>? secondaryLocation})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
preferredLocation → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryLocation → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited