VmwareenginePrivateCloudStorageThresholds class final

Typed helper for the management_cluster.autoscaling_settings.autoscaling_policies.storage_thresholds block of google_vmwareengine_private_cloud (derived from provider schema).

Annotations
  • @immutable

Constructors

VmwareenginePrivateCloudStorageThresholds({required TfArg<num> scaleIn, required TfArg<num> scaleOut})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleIn → TfArg<num>
final
scaleOut → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited