day property

BackupDayOfWeek? day
final

Day of week to run. When null, the field is omitted from the encoded block and the provider treats it as DAY_OF_WEEK_UNSPECIFIED.

Implementation

final BackupDayOfWeek? day;