WorkbenchInstanceAcceleratorConfigs class final

Typed helper for the gce_setup.accelerator_configs block of google_workbench_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkbenchInstanceAcceleratorConfigs({TfArg<String>? coreCount, WorkbenchInstanceType? type})
const

Properties

coreCount → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → WorkbenchInstanceType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited