WorkbenchInstanceDataDisks class final

Typed helper for the gce_setup.data_disks block of google_workbench_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkbenchInstanceDataDisks({WorkbenchInstanceDiskEncryption? diskEncryption, TfArg<String>? diskSizeGb, WorkbenchInstanceDataDisksDiskType? diskType, RefTo<GoogleKmsCryptoKey>? kmsKey, TfArg<List<String>>? resourcePolicies})
const

Properties

diskEncryption → WorkbenchInstanceDiskEncryption?
final
diskSizeGb → TfArg<String>?
final
diskType → WorkbenchInstanceDataDisksDiskType?
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKey → RefTo<GoogleKmsCryptoKey>?
final
resourcePolicies → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited