WorkbenchInstanceGceSetupReservationAffinity class final

Typed helper for the gce_setup.reservation_affinity block of google_workbench_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkbenchInstanceGceSetupReservationAffinity({TfArg<WorkbenchInstanceGceSetupReservationAffinityConsumeReservationType>? consumeReservationType, TfArg<String>? key, TfArg<List<Object?>>? values})
const

Properties

consumeReservationType → TfArg<WorkbenchInstanceGceSetupReservationAffinityConsumeReservationType>?
final
hashCode int
The hash code for this object.
no setterinherited
key → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited