WorkstationsWorkstationConfigBoostConfigs class final

Typed helper for the host.gce_instance.boost_configs block of google_workstations_workstation_config (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkstationsWorkstationConfigBoostConfigs({TfArg<num>? bootDiskSizeGb, TfArg<bool>? enableNestedVirtualization, required TfArg<String> id, TfArg<String>? machineType, TfArg<num>? poolSize, List<WorkstationsWorkstationConfigAccelerators>? accelerators})
const

Properties

accelerators → List<WorkstationsWorkstationConfigAccelerators>?
final
bootDiskSizeGb → TfArg<num>?
final
enableNestedVirtualization → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
machineType → TfArg<String>?
final
poolSize → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited