WorkstationsWorkstationConfigHostGceInstanceAccelerators class final

Typed helper for the host.gce_instance.accelerators block of google_workstations_workstation_config (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkstationsWorkstationConfigHostGceInstanceAccelerators({required TfArg<num> count, required TfArg<String> type})
const

Properties

count → TfArg<num>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited