apigee library
Apigee: organizations, runtime instances, environments, env groups, add-ons, data collectors, analytics datastores, NAT addresses, endpoint attachments, DNS zones, spaces, sync authorization, target servers, developers, developer apps, API products, app groups, env keystores/references, KVMs, keystore aliases (self-signed / key+cert / PKCS12), API proxies, shared flows + deployments, flow hooks, environment debug masks, proxy deployments, control-plane access, and Advanced API Security profiles / feedback / monitoring conditions. Org/instance/env bill while provisioned (never_apply for apply-smoke).
Classes
- ApigeeAddonsConfigAddonsConfig
-
Typed helper for the
addons_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig
-
Typed helper for the
addons_config.advanced_api_ops_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeAddonsConfigAddonsConfigApiSecurityConfig
-
Typed helper for the
addons_config.api_security_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig
-
Typed helper for the
addons_config.connectors_platform_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeAddonsConfigAddonsConfigIntegrationConfig
-
Typed helper for the
addons_config.integration_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeAddonsConfigAddonsConfigMonetizationConfig
-
Typed helper for the
addons_config.monetization_configblock ofgoogle_apigee_addons_config(derived from provider schema). - ApigeeApiProductAttributes
-
Typed helper for the
attributesblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGraphqlOperationGroup
-
Typed helper for the
graphql_operation_groupblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGraphqlOperationGroupOperationConfigs
-
Typed helper for the
graphql_operation_group.operation_configsblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGraphqlOperationGroupOperationConfigsAttributes
-
Typed helper for the
graphql_operation_group.operation_configs.attributesblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGraphqlOperationGroupOperationConfigsOperations
-
Typed helper for the
graphql_operation_group.operation_configs.operationsblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGraphqlOperationGroupOperationConfigsQuota
-
Typed helper for the
graphql_operation_group.operation_configs.quotablock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGrpcOperationGroup
-
Typed helper for the
grpc_operation_groupblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGrpcOperationGroupOperationConfigs
-
Typed helper for the
grpc_operation_group.operation_configsblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGrpcOperationGroupOperationConfigsAttributes
-
Typed helper for the
grpc_operation_group.operation_configs.attributesblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductGrpcOperationGroupOperationConfigsQuota
-
Typed helper for the
grpc_operation_group.operation_configs.quotablock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductOperationGroup
-
Typed helper for the
operation_groupblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductOperationGroupOperationConfigs
-
Typed helper for the
operation_group.operation_configsblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductOperationGroupOperationConfigsAttributes
-
Typed helper for the
operation_group.operation_configs.attributesblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductOperationGroupOperationConfigsOperations
-
Typed helper for the
operation_group.operation_configs.operationsblock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeApiProductOperationGroupOperationConfigsQuota
-
Typed helper for the
operation_group.operation_configs.quotablock ofgoogle_apigee_api_product(derived from provider schema). - ApigeeAppGroupAttributes
-
Typed helper for the
attributesblock ofgoogle_apigee_app_group(derived from provider schema). - ApigeeDatastoreDatastoreConfig
-
datastore_configblock (max=1). Required whentargetTypeis set. - ApigeeDeveloperAppAttributes
-
Typed helper for the
attributesblock ofgoogle_apigee_developer_app(derived from provider schema). - ApigeeDeveloperAttributes
-
Typed helper for the
attributesblock ofgoogle_apigee_developer(derived from provider schema). - ApigeeDnsZonePeeringConfig
-
Typed helper for the
peering_configblock ofgoogle_apigee_dns_zone(derived from provider schema). - ApigeeEnvironmentClientIpResolutionConfig
-
Typed helper for the
client_ip_resolution_configblock ofgoogle_apigee_environment(derived from provider schema). - ApigeeEnvironmentClientIpResolutionConfigHeaderIndexAlgorithm
-
Typed helper for the
client_ip_resolution_config.header_index_algorithmblock ofgoogle_apigee_environment(derived from provider schema). - ApigeeEnvironmentNodeConfig
-
Typed helper for the
node_configblock ofgoogle_apigee_environment(derived from provider schema). - ApigeeEnvironmentProperties
-
Typed helper for the
propertiesblock ofgoogle_apigee_environment(derived from provider schema). - ApigeeEnvironmentPropertiesProperty
-
Typed helper for the
properties.propertyblock ofgoogle_apigee_environment(derived from provider schema). - ApigeeInstanceAccessLoggingConfig
-
Typed helper for the
access_logging_configblock ofgoogle_apigee_instance(derived from provider schema). - ApigeeKeystoresAliasesSelfSignedCertSubject
-
Typed helper for the
subjectblock ofgoogle_apigee_keystores_aliases_self_signed_cert(derived from provider schema). - ApigeeKeystoresAliasesSelfSignedCertSubjectAlternativeDnsNames
-
Typed helper for the
subject_alternative_dns_namesblock ofgoogle_apigee_keystores_aliases_self_signed_cert(derived from provider schema). - ApigeeOrganizationProperties
-
Typed helper for the
propertiesblock ofgoogle_apigee_organization(derived from provider schema). - ApigeeOrganizationPropertiesProperty
-
Typed helper for the
properties.propertyblock ofgoogle_apigee_organization(derived from provider schema). - ApigeeSecurityActionAllow
-
Typed helper for the
allowblock ofgoogle_apigee_security_action(derived from provider schema). - ApigeeSecurityActionConditionConfig
-
Typed helper for the
condition_configblock ofgoogle_apigee_security_action(derived from provider schema). - ApigeeSecurityActionDeny
-
Typed helper for the
denyblock ofgoogle_apigee_security_action(derived from provider schema). - ApigeeSecurityActionFlag
-
Typed helper for the
flagblock ofgoogle_apigee_security_action(derived from provider schema). - ApigeeSecurityActionFlagHeaders
-
Typed helper for the
flag.headersblock ofgoogle_apigee_security_action(derived from provider schema). - ApigeeSecurityFeedbackFeedbackContexts
-
Typed helper for the
feedback_contextsblock ofgoogle_apigee_security_feedback(derived from provider schema). - ApigeeSecurityMonitoringConditionIncludeAllResources
-
Empty
include_all_resources {}block required by the provider (exactly_one_ofwith one live member; siblingincludeis not shipped yet). - ApigeeSecurityProfileV2ProfileAssessmentConfigs
-
Typed helper for the
profile_assessment_configsblock ofgoogle_apigee_security_profile_v2(derived from provider schema). - ApigeeTargetServerSSlInfo
-
Typed helper for the
s_sl_infoblock ofgoogle_apigee_target_server(derived from provider schema). - ApigeeTargetServerSSlInfoCommonName
-
Typed helper for the
s_sl_info.common_nameblock ofgoogle_apigee_target_server(derived from provider schema). - GoogleApigeeAddonsConfig
-
Factory wrapper for
google_apigee_addons_config. - GoogleApigeeApi
-
Factory wrapper for
google_apigee_api. - GoogleApigeeApiDeployment
-
Factory wrapper for
google_apigee_api_deployment. - GoogleApigeeApiProduct
-
Factory wrapper for
google_apigee_api_product. - GoogleApigeeAppGroup
-
Factory wrapper for
google_apigee_app_group. - GoogleApigeeControlPlaneAccess
-
Factory wrapper for
google_apigee_control_plane_access. - GoogleApigeeDataCollector
-
Factory wrapper for
google_apigee_data_collector. - GoogleApigeeDatastore
-
Factory wrapper for
google_apigee_datastore. - GoogleApigeeDeveloper
-
Factory wrapper for
google_apigee_developer. - GoogleApigeeDeveloperApp
-
Factory wrapper for
google_apigee_developer_app. - GoogleApigeeDnsZone
-
Factory wrapper for
google_apigee_dns_zone. - GoogleApigeeEndpointAttachment
-
Factory wrapper for
google_apigee_endpoint_attachment. - GoogleApigeeEnvgroup
-
Factory wrapper for
google_apigee_envgroup. - GoogleApigeeEnvgroupAttachment
-
Factory wrapper for
google_apigee_envgroup_attachment. - GoogleApigeeEnvironment
-
Factory wrapper for
google_apigee_environment. - GoogleApigeeEnvironmentAddonsConfig
-
Factory wrapper for
google_apigee_environment_addons_config. - GoogleApigeeEnvironmentApiRevisionDeployment
-
Factory wrapper for
google_apigee_environment_api_revision_deployment. - GoogleApigeeEnvironmentDebugmask
-
Factory wrapper for
google_apigee_environment_debugmask. - GoogleApigeeEnvironmentIamBinding
-
Factory wrapper for
google_apigee_environment_iam_binding. - GoogleApigeeEnvironmentIamMember
-
Factory wrapper for
google_apigee_environment_iam_member. - GoogleApigeeEnvironmentIamPolicy
-
Factory wrapper for
google_apigee_environment_iam_policy. - GoogleApigeeEnvironmentKeyvaluemaps
-
Factory wrapper for
google_apigee_environment_keyvaluemaps. - GoogleApigeeEnvironmentKeyvaluemapsEntries
-
Factory wrapper for
google_apigee_environment_keyvaluemaps_entries. - GoogleApigeeEnvKeystore
-
Factory wrapper for
google_apigee_env_keystore. - GoogleApigeeEnvReferences
-
Factory wrapper for
google_apigee_env_references. - GoogleApigeeFlowhook
-
Factory wrapper for
google_apigee_flowhook. - GoogleApigeeInstance
-
Factory wrapper for
google_apigee_instance. - GoogleApigeeInstanceAttachment
-
Factory wrapper for
google_apigee_instance_attachment. - GoogleApigeeKeystoresAliasesKeyCertFile
-
Factory wrapper for
google_apigee_keystores_aliases_key_cert_file. - GoogleApigeeKeystoresAliasesPkcs12
-
Factory wrapper for
google_apigee_keystores_aliases_pkcs12. - GoogleApigeeKeystoresAliasesSelfSignedCert
-
Factory wrapper for
google_apigee_keystores_aliases_self_signed_cert. - GoogleApigeeNatAddress
-
Factory wrapper for
google_apigee_nat_address. - GoogleApigeeOrganization
-
Factory wrapper for
google_apigee_organization. - GoogleApigeeSecurityAction
-
Factory wrapper for
google_apigee_security_action. - GoogleApigeeSecurityFeedback
-
Factory wrapper for
google_apigee_security_feedback. - GoogleApigeeSecurityMonitoringCondition
-
Factory wrapper for
google_apigee_security_monitoring_condition. - GoogleApigeeSecurityProfileV2
-
Factory wrapper for
google_apigee_security_profile_v2. -
Factory wrapper for
google_apigee_sharedflow. -
Factory wrapper for
google_apigee_sharedflow_deployment. - GoogleApigeeSpace
-
Factory wrapper for
google_apigee_space. - GoogleApigeeSyncAuthorization
-
Factory wrapper for
google_apigee_sync_authorization. - GoogleApigeeTargetServer
-
Factory wrapper for
google_apigee_target_server.
Enums
- ApigeeApiProductApprovalType
-
Apigee Api Product Approval enum for
approval_type. - ApigeeApiProductGraphqlOperationGroupOperationConfigType
-
operation_config_type— derived from the provider schema description. - ApigeeApiProductOperationGroupOperationConfigType
-
operation_config_type— derived from the provider schema description. - ApigeeApiProductQuotaCounterScope
-
Apigee Api Product Quota Counter enum for
quota_counter_scope. - ApigeeAppGroupStatus
-
Apigee App Group enum for
status. - ApigeeDataCollectorDeletionPolicy
-
Terraform
deletion_policyfor Apigee data collectors. - ApigeeDataCollectorType
-
Data type collected by
google_apigee_data_collector. - ApigeeDatastoreDeletionPolicy
-
Terraform
deletion_policyfor Apigee datastores. - ApigeeDatastoreTargetType
-
Target backend for
google_apigee_datastore. - ApigeeEnvironmentApiProxyType
-
Apigee Environment Api Proxy enum for
api_proxy_type. - ApigeeEnvironmentDeploymentType
-
Apigee Environment Deployment enum for
deployment_type. - ApigeeEnvironmentType
-
Apigee Environment enum for
type. - ApigeeKeystoresAliasesSelfSignedCertType
-
Apigee Keystores Aliases Self Signed Cert enum for
type. - ApigeeOrganizationRetention
-
Soft-delete data retention for
google_apigee_organization.retention(query param on delete; not in MMproperties, so not deriveEnums-backed). - ApigeeOrganizationRuntimeType
-
Apigee Organization Runtime enum for
runtime_type. - ApigeeSecurityActionState
-
Apigee Security Action enum for
state. - ApigeeSecurityFeedbackFeedbackContextsAttribute
-
attribute— derived from the provider schema description. - ApigeeSecurityFeedbackFeedbackType
-
Apigee Security Feedback Feedback enum for
feedback_type. - ApigeeSecurityFeedbackReason
-
Apigee Security Feedback enum for
reason. - ApigeeSecurityProfileV2ProfileAssessmentConfigsWeight
-
weight— derived from the provider schema description. - ApigeeTargetServerProtocol
-
Apigee Target Server enum for
protocol.