BigtableInstanceCluster class
One cluster block on google_bigtable_instance.
Constructors
-
BigtableInstanceCluster({required TfArg<
String> clusterId, TfArg<String> ? zone, TfArg<num> ? numNodes, TfArg<BigtableClusterStorageType> ? storageType, TfArg<String> ? kmsKeyName}) -
const
Properties
-
clusterId
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyName
→ TfArg<
String> ? -
final
-
numNodes
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storageType
→ TfArg<
BigtableClusterStorageType> ? -
final
-
zone
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited