clouddeploy library

Cloud Deploy — continuous-delivery pipelines, targets, custom target types, automations, and deploy policies. Nested config blocks (serial pipeline stages, deployment targets, custom actions, automation rules, policy selectors) are passed as structured maps.

Classes

GoogleClouddeployAutomation
Factory wrapper for google_clouddeploy_automation.
GoogleClouddeployCustomTargetType
Factory wrapper for google_clouddeploy_custom_target_type.
GoogleClouddeployCustomTargetTypeIamBinding
Factory wrapper for google_clouddeploy_custom_target_type_iam_binding.
GoogleClouddeployCustomTargetTypeIamMember
Factory wrapper for google_clouddeploy_custom_target_type_iam_member.
GoogleClouddeployCustomTargetTypeIamPolicy
Factory wrapper for google_clouddeploy_custom_target_type_iam_policy.
GoogleClouddeployDeliveryPipeline
Factory wrapper for google_clouddeploy_delivery_pipeline.
GoogleClouddeployDeliveryPipelineIamBinding
Factory wrapper for google_clouddeploy_delivery_pipeline_iam_binding.
GoogleClouddeployDeliveryPipelineIamMember
Factory wrapper for google_clouddeploy_delivery_pipeline_iam_member.
GoogleClouddeployDeliveryPipelineIamPolicy
Factory wrapper for google_clouddeploy_delivery_pipeline_iam_policy.
GoogleClouddeployDeployPolicy
Factory wrapper for google_clouddeploy_deploy_policy.
GoogleClouddeployTarget
Factory wrapper for google_clouddeploy_target.
GoogleClouddeployTargetIamBinding
Factory wrapper for google_clouddeploy_target_iam_binding.
GoogleClouddeployTargetIamMember
Factory wrapper for google_clouddeploy_target_iam_member.
GoogleClouddeployTargetIamPolicy
Factory wrapper for google_clouddeploy_target_iam_policy.