document_ai library

Document AI — document processors (OCR / form parser / etc.) for extracting structured data from documents.

Classes

DocumentAiWarehouseDocumentSchemaPropertyDefinitions
Typed helper for the property_definitions block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsDateTimeTypeOptions
Typed helper for the property_definitions.date_time_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsEnumTypeOptions
Typed helper for the property_definitions.enum_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsFloatTypeOptions
Typed helper for the property_definitions.float_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsIntegerTypeOptions
Typed helper for the property_definitions.integer_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsMapTypeOptions
Typed helper for the property_definitions.map_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptions
Typed helper for the property_definitions.property_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitions
Typed helper for the property_definitions.property_type_options.property_definitions block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsDateTimeTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.date_time_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsEnumTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.enum_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsFloatTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.float_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsIntegerTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.integer_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsMapTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.map_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsSchemaSources
Typed helper for the property_definitions.property_type_options.property_definitions.schema_sources block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTextTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.text_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsTimestampTypeOptions
Typed helper for the property_definitions.property_type_options.property_definitions.timestamp_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsSchemaSources
Typed helper for the property_definitions.schema_sources block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTextTypeOptions
Typed helper for the property_definitions.text_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsTimestampTypeOptions
Typed helper for the property_definitions.timestamp_type_options block of google_document_ai_warehouse_document_schema (derived from provider schema).
GoogleDocumentAiProcessor
Factory wrapper for google_document_ai_processor.
GoogleDocumentAiProcessorDefaultVersion
Factory wrapper for google_document_ai_processor_default_version.
GoogleDocumentAiSchema
Factory wrapper for google_document_ai_schema.
GoogleDocumentAiWarehouseDocumentSchema
Factory wrapper for google_document_ai_warehouse_document_schema.
GoogleDocumentAiWarehouseLocation
Factory wrapper for google_document_ai_warehouse_location.

Enums

DocumentAiWarehouseDocumentSchemaPropertyDefinitionsPropertyTypeOptionsPropertyDefinitionsRetrievalImportance
retrieval_importance — derived from the provider schema description.
DocumentAiWarehouseDocumentSchemaPropertyDefinitionsRetrievalImportance
retrieval_importance — derived from the provider schema description.
DocumentAiWarehouseLocationAccessControlMode
Document Ai Warehouse Location Access Control enum for access_control_mode.
DocumentAiWarehouseLocationDatabaseType
Document Ai Warehouse Location Database enum for database_type.
DocumentAiWarehouseLocationDocumentCreatorDefaultRole
Document Ai Warehouse Location Document Creator Default enum for document_creator_default_role.