network library
Network Connectivity Center (hub / group / spoke / internal range / regional endpoint / policy-based route; gateway advertised route and service connection policy are debt-only), transports / multicloud data-transfer (Partner Cross-Cloud Interconnect managed transport is never_apply — $17+/h), Network Security ULL mirroring, OOB intercept / mirroring deployments + endpoints (Deployment Uptime $0.025/h is never_apply), address groups, URL lists, client/server TLS policies, gateway security policies, Cloud NGFW firewall endpoints (Enterprise Endpoint Uptime is never_apply — $1.75/h), VPC Flow Logs configs, Network Services Mesh, Service Extensions (Authz / LB traffic / route / edge — debt-only: schema required forwarding_rules bill Cloud LB Forwarding Rule Minimum $0.025/h), Wasm plugin metadata (apply-excluded — needs an uploaded plugin image), and Network Services gateways (Secure Web Gateway is never_apply — $1.25/h).
Classes
- GoogleNetworkConnectivityDestination
-
Factory wrapper for
google_network_connectivity_destination. - GoogleNetworkConnectivityGatewayAdvertisedRoute
-
Factory wrapper for
google_network_connectivity_gateway_advertised_route. - GoogleNetworkConnectivityGroup
-
Factory wrapper for
google_network_connectivity_group. - GoogleNetworkConnectivityHub
-
Factory wrapper for
google_network_connectivity_hub. - GoogleNetworkConnectivityHubIamBinding
-
Factory wrapper for
google_network_connectivity_hub_iam_binding. - GoogleNetworkConnectivityHubIamMember
-
Factory wrapper for
google_network_connectivity_hub_iam_member. - GoogleNetworkConnectivityHubIamPolicy
-
Factory wrapper for
google_network_connectivity_hub_iam_policy. - GoogleNetworkConnectivityInternalRange
-
Factory wrapper for
google_network_connectivity_internal_range. - GoogleNetworkConnectivityMulticloudDataTransferConfig
-
Factory wrapper for
google_network_connectivity_multicloud_data_transfer_config. - GoogleNetworkConnectivityPolicyBasedRoute
-
Factory wrapper for
google_network_connectivity_policy_based_route. - GoogleNetworkConnectivityRegionalEndpoint
-
Factory wrapper for
google_network_connectivity_regional_endpoint. - GoogleNetworkConnectivityServiceConnectionPolicy
-
Factory wrapper for
google_network_connectivity_service_connection_policy. - GoogleNetworkConnectivitySpoke
-
Factory wrapper for
google_network_connectivity_spoke. - GoogleNetworkConnectivityTransport
-
Factory wrapper for
google_network_connectivity_transport. - GoogleNetworkManagementConnectivityTest
-
Factory wrapper for
google_network_management_connectivity_test. - GoogleNetworkManagementOrganizationVpcFlowLogsConfig
-
Factory wrapper for
google_network_management_organization_vpc_flow_logs_config. - GoogleNetworkManagementVpcFlowLogsConfig
-
Factory wrapper for
google_network_management_vpc_flow_logs_config. - GoogleNetworkSecurityAddressGroup
-
Factory wrapper for
google_network_security_address_group. - GoogleNetworkSecurityAddressGroupIamBinding
-
Factory wrapper for
google_network_security_address_group_iam_binding. - GoogleNetworkSecurityAddressGroupIamMember
-
Factory wrapper for
google_network_security_address_group_iam_member. - GoogleNetworkSecurityAddressGroupIamPolicy
-
Factory wrapper for
google_network_security_address_group_iam_policy. - GoogleNetworkSecurityAuthzPolicy
-
Factory wrapper for
google_network_security_authz_policy. - GoogleNetworkSecurityBackendAuthenticationConfig
-
Factory wrapper for
google_network_security_backend_authentication_config. - GoogleNetworkSecurityClientTlsPolicy
-
Factory wrapper for
google_network_security_client_tls_policy. - GoogleNetworkSecurityDnsThreatDetector
-
Factory wrapper for
google_network_security_dns_threat_detector. - GoogleNetworkSecurityFirewallEndpoint
-
Factory wrapper for
google_network_security_firewall_endpoint. - GoogleNetworkSecurityFirewallEndpointAssociation
-
Factory wrapper for
google_network_security_firewall_endpoint_association. - GoogleNetworkSecurityGatewaySecurityPolicy
-
Factory wrapper for
google_network_security_gateway_security_policy. - GoogleNetworkSecurityGatewaySecurityPolicyRule
-
Factory wrapper for
google_network_security_gateway_security_policy_rule. - GoogleNetworkSecurityInterceptDeployment
-
Factory wrapper for
google_network_security_intercept_deployment. - GoogleNetworkSecurityInterceptDeploymentGroup
-
Factory wrapper for
google_network_security_intercept_deployment_group. - GoogleNetworkSecurityInterceptEndpointGroup
-
Factory wrapper for
google_network_security_intercept_endpoint_group. - GoogleNetworkSecurityInterceptEndpointGroupAssociation
-
Factory wrapper for
google_network_security_intercept_endpoint_group_association. - GoogleNetworkSecurityMirroringDeployment
-
Factory wrapper for
google_network_security_mirroring_deployment. - GoogleNetworkSecurityMirroringDeploymentGroup
-
Factory wrapper for
google_network_security_mirroring_deployment_group. - GoogleNetworkSecurityMirroringEndpoint
-
Factory wrapper for
google_network_security_mirroring_endpoint. - GoogleNetworkSecurityMirroringEndpointGroup
-
Factory wrapper for
google_network_security_mirroring_endpoint_group. - GoogleNetworkSecurityMirroringEndpointGroupAssociation
-
Factory wrapper for
google_network_security_mirroring_endpoint_group_association. - GoogleNetworkSecuritySecurityProfile
-
Factory wrapper for
google_network_security_security_profile. - GoogleNetworkSecuritySecurityProfileGroup
-
Factory wrapper for
google_network_security_security_profile_group. - GoogleNetworkSecurityServerTlsPolicy
-
Factory wrapper for
google_network_security_server_tls_policy. - GoogleNetworkSecurityTlsInspectionPolicy
-
Factory wrapper for
google_network_security_tls_inspection_policy. - GoogleNetworkSecurityUllMirroringCollector
-
Factory wrapper for
google_network_security_ull_mirroring_collector. - GoogleNetworkSecurityUllMirroringCollectorRule
-
Factory wrapper for
google_network_security_ull_mirroring_collector_rule. - GoogleNetworkSecurityUllMirroringEngine
-
Factory wrapper for
google_network_security_ull_mirroring_engine. - GoogleNetworkSecurityUrlLists
-
Factory wrapper for
google_network_security_url_lists. - GoogleNetworkServicesAgentGateway
-
Factory wrapper for
google_network_services_agent_gateway. - GoogleNetworkServicesAuthzExtension
-
Factory wrapper for
google_network_services_authz_extension. - GoogleNetworkServicesEdgeCacheKeyset
-
Factory wrapper for
google_network_services_edge_cache_keyset. - GoogleNetworkServicesEdgeCacheOrigin
-
Factory wrapper for
google_network_services_edge_cache_origin. - GoogleNetworkServicesEdgeCacheService
-
Factory wrapper for
google_network_services_edge_cache_service. - GoogleNetworkServicesEndpointPolicy
-
Factory wrapper for
google_network_services_endpoint_policy. - GoogleNetworkServicesGateway
-
Factory wrapper for
google_network_services_gateway. - GoogleNetworkServicesGrpcRoute
-
Factory wrapper for
google_network_services_grpc_route. - GoogleNetworkServicesHttpRoute
-
Factory wrapper for
google_network_services_http_route. - GoogleNetworkServicesLbEdgeExtension
-
Factory wrapper for
google_network_services_lb_edge_extension. - GoogleNetworkServicesLbRouteExtension
-
Factory wrapper for
google_network_services_lb_route_extension. - GoogleNetworkServicesLbTrafficExtension
-
Factory wrapper for
google_network_services_lb_traffic_extension. - GoogleNetworkServicesMesh
-
Factory wrapper for
google_network_services_mesh. - GoogleNetworkServicesMulticastConsumerAssociation
-
Factory wrapper for
google_network_services_multicast_consumer_association. - GoogleNetworkServicesMulticastDomain
-
Factory wrapper for
google_network_services_multicast_domain. - GoogleNetworkServicesMulticastDomainActivation
-
Factory wrapper for
google_network_services_multicast_domain_activation. - GoogleNetworkServicesMulticastDomainGroup
-
Factory wrapper for
google_network_services_multicast_domain_group. - GoogleNetworkServicesMulticastGroupConsumerActivation
-
Factory wrapper for
google_network_services_multicast_group_consumer_activation. - GoogleNetworkServicesMulticastGroupProducerActivation
-
Factory wrapper for
google_network_services_multicast_group_producer_activation. - GoogleNetworkServicesMulticastGroupRange
-
Factory wrapper for
google_network_services_multicast_group_range. - GoogleNetworkServicesMulticastGroupRangeActivation
-
Factory wrapper for
google_network_services_multicast_group_range_activation. - GoogleNetworkServicesMulticastProducerAssociation
-
Factory wrapper for
google_network_services_multicast_producer_association. - GoogleNetworkServicesServiceBinding
-
Factory wrapper for
google_network_services_service_binding. - GoogleNetworkServicesTcpRoute
-
Factory wrapper for
google_network_services_tcp_route. - GoogleNetworkServicesTlsRoute
-
Factory wrapper for
google_network_services_tls_route. - GoogleNetworkServicesWasmPlugin
-
Factory wrapper for
google_network_services_wasm_plugin. - NetworkConnectivityDestinationEndpoints
-
Typed helper for the
endpointsblock ofgoogle_network_connectivity_destination(derived from provider schema). - NetworkConnectivityGroupAutoAccept
-
Optional
auto_acceptblock on GoogleNetworkConnectivityGroup. - NetworkConnectivityInternalRangeAllocationOptions
-
Optional
allocation_optionswhen auto-allocating viaprefixLength. - NetworkConnectivityMulticloudDataTransferConfigServices
-
Typed helper for the
servicesblock ofgoogle_network_connectivity_multicloud_data_transfer_config(derived from provider schema). - NetworkConnectivityPolicyBasedRouteFilter
-
Typed helper for the
filterblock ofgoogle_network_connectivity_policy_based_route(derived from provider schema). - NetworkConnectivityPolicyBasedRouteInterconnectAttachment
-
Typed helper for the
interconnect_attachmentblock ofgoogle_network_connectivity_policy_based_route(derived from provider schema). - NetworkConnectivityPolicyBasedRouteNextHop
-
Exactly one next-hop for GoogleNetworkConnectivityPolicyBasedRoute
(MM
exactly_one_ofonnext_hop_ilb_ip/next_hop_other_routes). Use NetworkConnectivityPolicyBasedRouteNextHopOtherRoutes (derived) for theotherRoutesvariant. - NetworkConnectivityPolicyBasedRouteNextHopIlbIp
-
next_hop_ilb_ipvariant. - NetworkConnectivityPolicyBasedRouteNextHopOtherRoutesChoice
-
next_hop_other_routesvariant. - NetworkConnectivityPolicyBasedRouteVirtualMachine
-
Typed helper for the
virtual_machineblock ofgoogle_network_connectivity_policy_based_route(derived from provider schema). - NetworkConnectivityServiceConnectionPolicyPscConfig
-
Typed helper for the
psc_configblock ofgoogle_network_connectivity_service_connection_policy(derived from provider schema). - NetworkConnectivitySpokeAttachment
-
Exactly one spoke attachment kind (provider
conflictsacross linked_* /gatewayblocks). - NetworkConnectivitySpokeGateway
-
gateway— NCC gateway spoke (capacity-billed; never apply-smoke). - NetworkConnectivitySpokeGatewayIpRangeReservation
-
One
/23reservation inside NetworkConnectivitySpokeGateway. - NetworkConnectivitySpokeLinkedInterconnectAttachments
-
linked_interconnect_attachments— attach VLAN attachments. - NetworkConnectivitySpokeLinkedProducerVpcNetwork
-
linked_producer_vpc_network— attach a producer VPC via peering. - NetworkConnectivitySpokeLinkedRouterApplianceInstances
-
linked_router_appliance_instances— attach router appliance VMs. - NetworkConnectivitySpokeLinkedVpcNetwork
-
linked_vpc_network— attach a consumer VPC to the hub. - NetworkConnectivitySpokeLinkedVpnTunnels
-
linked_vpn_tunnels— attach HA VPN tunnels. - NetworkConnectivitySpokeRouterApplianceInstance
- One router-appliance VM inside NetworkConnectivitySpokeLinkedRouterApplianceInstances.
- NetworkManagementConnectivityTestDestination
-
Typed helper for the
destinationblock ofgoogle_network_management_connectivity_test(derived from provider schema). - NetworkManagementConnectivityTestSource
-
Typed helper for the
sourceblock ofgoogle_network_management_connectivity_test(derived from provider schema). - NetworkManagementConnectivityTestSourceAppEngineVersion
-
Typed helper for the
source.app_engine_versionblock ofgoogle_network_management_connectivity_test(derived from provider schema). - NetworkManagementConnectivityTestSourceCloudFunction
-
Typed helper for the
source.cloud_functionblock ofgoogle_network_management_connectivity_test(derived from provider schema). - NetworkManagementConnectivityTestSourceCloudRunRevision
-
Typed helper for the
source.cloud_run_revisionblock ofgoogle_network_management_connectivity_test(derived from provider schema). - NetworkSecurityAuthzPolicyCustomProvider
-
Typed helper for the
custom_providerblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyCustomProviderAuthzExtension
-
Typed helper for the
custom_provider.authz_extensionblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyCustomProviderCloudIap
-
Typed helper for the
custom_provider.cloud_iapblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRules
-
Typed helper for the
http_rulesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFrom
-
Typed helper for the
http_rules.fromblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSources
-
Typed helper for the
http_rules.from.not_sourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesIpBlocks
-
Typed helper for the
http_rules.from.not_sources.ip_blocksblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipals
-
Typed helper for the
http_rules.from.not_sources.principalsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipalsPrincipal
-
Typed helper for the
http_rules.from.not_sources.principals.principalblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResources
-
Typed helper for the
http_rules.from.not_sources.resourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResourcesIamServiceAccount
-
Typed helper for the
http_rules.from.not_sources.resources.iam_service_accountblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesResourcesTagValueIdSet
-
Typed helper for the
http_rules.from.not_sources.resources.tag_value_id_setblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSources
-
Typed helper for the
http_rules.from.sourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesIpBlocks
-
Typed helper for the
http_rules.from.sources.ip_blocksblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipals
-
Typed helper for the
http_rules.from.sources.principalsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipalsPrincipal
-
Typed helper for the
http_rules.from.sources.principals.principalblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesResources
-
Typed helper for the
http_rules.from.sources.resourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesResourcesIamServiceAccount
-
Typed helper for the
http_rules.from.sources.resources.iam_service_accountblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesFromSourcesResourcesTagValueIdSet
-
Typed helper for the
http_rules.from.sources.resources.tag_value_id_setblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesTo
-
Typed helper for the
http_rules.toblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperations
-
Typed helper for the
http_rules.to.not_operationsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSet
-
Typed helper for the
http_rules.to.not_operations.header_setblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSetHeaders
-
Typed helper for the
http_rules.to.not_operations.header_set.headersblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHeaderSetHeadersValue
-
Typed helper for the
http_rules.to.not_operations.header_set.headers.valueblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperationsHosts
-
Typed helper for the
http_rules.to.not_operations.hostsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToNotOperationsPaths
-
Typed helper for the
http_rules.to.not_operations.pathsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperations
-
Typed helper for the
http_rules.to.operationsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSet
-
Typed helper for the
http_rules.to.operations.header_setblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSetHeaders
-
Typed helper for the
http_rules.to.operations.header_set.headersblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsHeaderSetHeadersValue
-
Typed helper for the
http_rules.to.operations.header_set.headers.valueblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsHosts
-
Typed helper for the
http_rules.to.operations.hostsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsMcp
-
Typed helper for the
http_rules.to.operations.mcpblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethods
-
Typed helper for the
http_rules.to.operations.mcp.methodsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpMethodsParams
-
Typed helper for the
http_rules.to.operations.mcp.methods.paramsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyHttpRulesToOperationsPaths
-
Typed helper for the
http_rules.to.operations.pathsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRules
-
Typed helper for the
network_rulesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFrom
-
Typed helper for the
network_rules.fromblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromNotSources
-
Typed helper for the
network_rules.from.not_sourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesIpBlocks
-
Typed helper for the
network_rules.from.not_sources.ip_blocksblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipals
-
Typed helper for the
network_rules.from.not_sources.principalsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipalsPrincipal
-
Typed helper for the
network_rules.from.not_sources.principals.principalblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromSources
-
Typed helper for the
network_rules.from.sourcesblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromSourcesIpBlocks
-
Typed helper for the
network_rules.from.sources.ip_blocksblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipals
-
Typed helper for the
network_rules.from.sources.principalsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipalsPrincipal
-
Typed helper for the
network_rules.from.sources.principals.principalblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesTo
-
Typed helper for the
network_rules.toblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesToOperations
-
Typed helper for the
network_rules.to.operationsblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyNetworkRulesToOperationsSnis
-
Typed helper for the
network_rules.to.operations.snisblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityAuthzPolicyTarget
-
Typed helper for the
targetblock ofgoogle_network_security_authz_policy(derived from provider schema). - NetworkSecurityFirewallEndpointEndpointSettings
-
Typed helper for the
endpoint_settingsblock ofgoogle_network_security_firewall_endpoint(derived from provider schema). - NetworkSecurityMirroringEndpointGroupBrokerDeploymentLink
-
mirroring_deployment_groupsvariant (BROKER). - NetworkSecurityMirroringEndpointGroupDeploymentLink
- Exactly-one link from a mirroring endpoint group to its deployment group(s). DIRECT uses a single group; BROKER uses a list.
- NetworkSecurityMirroringEndpointGroupDirectDeploymentLink
-
mirroring_deployment_groupvariant (DIRECT). - NetworkSecuritySecurityProfileCustomInterceptProfile
-
Typed helper for the
custom_intercept_profileblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileCustomMirroringProfile
-
Typed helper for the
custom_mirroring_profileblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileThreatPreventionProfile
-
Typed helper for the
threat_prevention_profileblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverrides
-
Typed helper for the
threat_prevention_profile.antivirus_overridesblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverrides
-
Typed helper for the
threat_prevention_profile.severity_overridesblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileThreatPreventionProfileThreatOverrides
-
Typed helper for the
threat_prevention_profile.threat_overridesblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileUrlFilteringProfile
-
Typed helper for the
url_filtering_profileblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecuritySecurityProfileUrlFilteringProfileUrlFilters
-
Typed helper for the
url_filtering_profile.url_filtersblock ofgoogle_network_security_security_profile(derived from provider schema). - NetworkSecurityUllMirroringCollectorRuleMatch
-
matchblock on a ULL mirroring collector rule. - NetworkServicesAgentGatewayDeployment
-
Exactly one of google_managed / self_managed (MM
exactly_one_of). - NetworkServicesAgentGatewayGoogleManaged
-
google_managed— proxy orchestrated in a Google tenant project. - NetworkServicesAgentGatewayNetworkConfig
-
Typed helper for the
network_configblock ofgoogle_network_services_agent_gateway(derived from provider schema). - NetworkServicesAgentGatewayNetworkConfigDnsPeeringConfig
-
Typed helper for the
network_config.dns_peering_configblock ofgoogle_network_services_agent_gateway(derived from provider schema). - NetworkServicesAgentGatewayNetworkConfigEgress
-
Typed helper for the
network_config.egressblock ofgoogle_network_services_agent_gateway(derived from provider schema). - NetworkServicesAgentGatewaySelfManaged
-
self_managed— attach an existing networking proxy in-project. - NetworkServicesEdgeCacheKeysetPublicKey
-
Typed helper for the
public_keyblock ofgoogle_network_services_edge_cache_keyset(derived from provider schema). -
Typed helper for the
validation_shared_keysblock ofgoogle_network_services_edge_cache_keyset(derived from provider schema). - NetworkServicesEdgeCacheOriginAwsV4Authentication
-
Typed helper for the
aws_v4_authenticationblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginFlexShielding
-
Typed helper for the
flex_shieldingblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginOriginOverrideAction
-
Typed helper for the
origin_override_actionblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginOriginOverrideActionHeaderAction
-
Typed helper for the
origin_override_action.header_actionblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginOriginOverrideActionHeaderActionRequestHeadersToAdd
-
Typed helper for the
origin_override_action.header_action.request_headers_to_addblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginOriginOverrideActionUrlRewrite
-
Typed helper for the
origin_override_action.url_rewriteblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginOriginRedirect
-
Typed helper for the
origin_redirectblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheOriginTimeout
-
Typed helper for the
timeoutblock ofgoogle_network_services_edge_cache_origin(derived from provider schema). - NetworkServicesEdgeCacheServiceLogConfig
-
Typed helper for the
log_configblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRouting
-
Typed helper for the
routingblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingHostRule
-
Typed helper for the
routing.host_ruleblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcher
-
Typed helper for the
routing.path_matcherblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRule
-
Typed helper for the
routing.path_matcher.route_ruleblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderAction
-
Typed helper for the
routing.path_matcher.route_rule.header_actionblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToAdd
-
Typed helper for the
routing.path_matcher.route_rule.header_action.request_header_to_addblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionRequestHeaderToRemove
-
Typed helper for the
routing.path_matcher.route_rule.header_action.request_header_to_removeblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToAdd
-
Typed helper for the
routing.path_matcher.route_rule.header_action.response_header_to_addblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleHeaderActionResponseHeaderToRemove
-
Typed helper for the
routing.path_matcher.route_rule.header_action.response_header_to_removeblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRule
-
Typed helper for the
routing.path_matcher.route_rule.match_ruleblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleHeaderMatch
-
Typed helper for the
routing.path_matcher.route_rule.match_rule.header_matchblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleMatchRuleQueryParameterMatch
-
Typed helper for the
routing.path_matcher.route_rule.match_rule.query_parameter_matchblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteAction
-
Typed helper for the
routing.path_matcher.route_rule.route_actionblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicy
-
Typed helper for the
routing.path_matcher.route_rule.route_action.cdn_policyblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures
-
Typed helper for the
routing.path_matcher.route_rule.route_action.cdn_policy.add_signaturesblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy
-
Typed helper for the
routing.path_matcher.route_rule.route_action.cdn_policy.cache_key_policyblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptions
-
Typed helper for the
routing.path_matcher.route_rule.route_action.cdn_policy.signed_token_optionsblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCorsPolicy
-
Typed helper for the
routing.path_matcher.route_rule.route_action.cors_policyblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionUrlRewrite
-
Typed helper for the
routing.path_matcher.route_rule.route_action.url_rewriteblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteMethods
-
Typed helper for the
routing.path_matcher.route_rule.route_methodsblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleUrlRedirect
-
Typed helper for the
routing.path_matcher.route_rule.url_redirectblock ofgoogle_network_services_edge_cache_service(derived from provider schema). - NetworkServicesEndpointPolicyEndpointMatcher
-
Typed helper for the
endpoint_matcherblock ofgoogle_network_services_endpoint_policy(derived from provider schema). - NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher
-
Typed helper for the
endpoint_matcher.metadata_label_matcherblock ofgoogle_network_services_endpoint_policy(derived from provider schema). - NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels
-
Typed helper for the
endpoint_matcher.metadata_label_matcher.metadata_labelsblock ofgoogle_network_services_endpoint_policy(derived from provider schema). - NetworkServicesEndpointPolicyTrafficPortSelector
-
Typed helper for the
traffic_port_selectorblock ofgoogle_network_services_endpoint_policy(derived from provider schema). - NetworkServicesGrpcRouteRules
-
Typed helper for the
rulesblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesAction
-
Typed helper for the
rules.actionblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesActionDestinations
-
Typed helper for the
rules.action.destinationsblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesActionFaultInjectionPolicy
-
Typed helper for the
rules.action.fault_injection_policyblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesActionFaultInjectionPolicyAbort
-
Typed helper for the
rules.action.fault_injection_policy.abortblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesActionFaultInjectionPolicyDelay
-
Typed helper for the
rules.action.fault_injection_policy.delayblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesActionRetryPolicy
-
Typed helper for the
rules.action.retry_policyblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesMatches
-
Typed helper for the
rules.matchesblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesMatchesHeaders
-
Typed helper for the
rules.matches.headersblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesGrpcRouteRulesMatchesMethod
-
Typed helper for the
rules.matches.methodblock ofgoogle_network_services_grpc_route(derived from provider schema). - NetworkServicesHttpRouteRules
-
Typed helper for the
rulesblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesAction
-
Typed helper for the
rules.actionblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionCorsPolicy
-
Typed helper for the
rules.action.cors_policyblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionDestinations
-
Typed helper for the
rules.action.destinationsblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionFaultInjectionPolicy
-
Typed helper for the
rules.action.fault_injection_policyblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionFaultInjectionPolicyAbort
-
Typed helper for the
rules.action.fault_injection_policy.abortblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionFaultInjectionPolicyDelay
-
Typed helper for the
rules.action.fault_injection_policy.delayblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionRedirect
-
Typed helper for the
rules.action.redirectblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionRequestHeaderModifier
-
Typed helper for the
rules.action.request_header_modifierblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionRequestMirrorPolicy
-
Typed helper for the
rules.action.request_mirror_policyblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionRequestMirrorPolicyDestination
-
Typed helper for the
rules.action.request_mirror_policy.destinationblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionResponseHeaderModifier
-
Typed helper for the
rules.action.response_header_modifierblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionRetryPolicy
-
Typed helper for the
rules.action.retry_policyblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesActionUrlRewrite
-
Typed helper for the
rules.action.url_rewriteblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesMatches
-
Typed helper for the
rules.matchesblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesMatchesHeaders
-
Typed helper for the
rules.matches.headersblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesMatchesHeadersRangeMatch
-
Typed helper for the
rules.matches.headers.range_matchblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesHttpRouteRulesMatchesQueryParameters
-
Typed helper for the
rules.matches.query_parametersblock ofgoogle_network_services_http_route(derived from provider schema). - NetworkServicesLbEdgeExtensionExtensionChains
-
Typed helper for the
extension_chainsblock ofgoogle_network_services_lb_edge_extension(derived from provider schema). - NetworkServicesLbEdgeExtensionExtensionChainsExtensions
-
Typed helper for the
extension_chains.extensionsblock ofgoogle_network_services_lb_edge_extension(derived from provider schema). - NetworkServicesLbEdgeExtensionExtensionChainsMatchCondition
-
Typed helper for the
extension_chains.match_conditionblock ofgoogle_network_services_lb_edge_extension(derived from provider schema). - NetworkServicesLbRouteExtensionExtensionChains
-
Typed helper for the
extension_chainsblock ofgoogle_network_services_lb_route_extension(derived from provider schema). - NetworkServicesLbRouteExtensionExtensionChainsExtensions
-
Typed helper for the
extension_chains.extensionsblock ofgoogle_network_services_lb_route_extension(derived from provider schema). - NetworkServicesLbRouteExtensionExtensionChainsMatchCondition
-
Typed helper for the
extension_chains.match_conditionblock ofgoogle_network_services_lb_route_extension(derived from provider schema). - NetworkServicesLbTrafficExtensionExtensionChains
-
Typed helper for the
extension_chainsblock ofgoogle_network_services_lb_traffic_extension(derived from provider schema). - NetworkServicesLbTrafficExtensionExtensionChainsExtensions
-
Typed helper for the
extension_chains.extensionsblock ofgoogle_network_services_lb_traffic_extension(derived from provider schema). - NetworkServicesLbTrafficExtensionExtensionChainsMatchCondition
-
Typed helper for the
extension_chains.match_conditionblock ofgoogle_network_services_lb_traffic_extension(derived from provider schema). - NetworkServicesMulticastDomainActivationTrafficSpec
-
Typed helper for the
traffic_specblock ofgoogle_network_services_multicast_domain_activation(derived from provider schema). - NetworkServicesMulticastDomainConnectionConfig
-
Typed helper for the
connection_configblock ofgoogle_network_services_multicast_domain(derived from provider schema). - NetworkServicesMulticastDomainUllMulticastDomain
-
Typed helper for the
ull_multicast_domainblock ofgoogle_network_services_multicast_domain(derived from provider schema). - NetworkServicesMulticastGroupConsumerActivationLogConfig
-
Typed helper for the
log_configblock ofgoogle_network_services_multicast_group_consumer_activation(derived from provider schema). - NetworkServicesMulticastGroupRangeActivationLogConfig
-
Typed helper for the
log_configblock ofgoogle_network_services_multicast_group_range_activation(derived from provider schema). - NetworkServicesMulticastGroupRangeLogConfig
-
Typed helper for the
log_configblock ofgoogle_network_services_multicast_group_range(derived from provider schema). - NetworkServicesTcpRouteRules
-
Typed helper for the
rulesblock ofgoogle_network_services_tcp_route(derived from provider schema). - NetworkServicesTcpRouteRulesAction
-
Typed helper for the
rules.actionblock ofgoogle_network_services_tcp_route(derived from provider schema). - NetworkServicesTcpRouteRulesActionDestinations
-
Typed helper for the
rules.action.destinationsblock ofgoogle_network_services_tcp_route(derived from provider schema). - NetworkServicesTcpRouteRulesMatches
-
Typed helper for the
rules.matchesblock ofgoogle_network_services_tcp_route(derived from provider schema). - NetworkServicesTlsRouteRules
-
Typed helper for the
rulesblock ofgoogle_network_services_tls_route(derived from provider schema). - NetworkServicesTlsRouteRulesAction
-
Typed helper for the
rules.actionblock ofgoogle_network_services_tls_route(derived from provider schema). - NetworkServicesTlsRouteRulesActionDestinations
-
Typed helper for the
rules.action.destinationsblock ofgoogle_network_services_tls_route(derived from provider schema). - NetworkServicesTlsRouteRulesMatches
-
Typed helper for the
rules.matchesblock ofgoogle_network_services_tls_route(derived from provider schema). - NetworkServicesWasmPluginLogConfig
-
Typed helper for the
log_configblock ofgoogle_network_services_wasm_plugin(derived from provider schema). - NetworkServicesWasmPluginVersions
-
Typed helper for the
versionsblock ofgoogle_network_services_wasm_plugin(derived from provider schema).
Enums
- NetworkConnectivityGatewayAdvertisedRouteRecipient
-
Network Connectivity Gateway Advertised Route enum for
recipient. - NetworkConnectivityGatewayAdvertisedRouteState
-
Network Connectivity Gateway Advertised Route enum for
state. - NetworkConnectivityGroupName
-
Network Connectivity Group enum for
name. - NetworkConnectivityInternalRangeAllocationStrategy
-
allocation_strategyon NetworkConnectivityInternalRangeAllocationOptions. - NetworkConnectivityInternalRangePeering
-
peeringfor GoogleNetworkConnectivityInternalRange. - NetworkConnectivityInternalRangeUsage
-
usagefor GoogleNetworkConnectivityInternalRange. - NetworkConnectivityPolicyBasedRouteFilterProtocolVersion
-
protocol_version— derived from the provider schema description. - NetworkConnectivityPolicyBasedRouteNextHopOtherRoutes
-
Network Connectivity Policy Based Route Next Hop Other enum for
next_hop_other_routes. - NetworkConnectivityRegionalEndpointAccessType
-
Network Connectivity Regional Endpoint Access enum for
access_type. - NetworkConnectivityServiceConnectionPolicyPscConfigProducerInstanceLocation
-
producer_instance_location— derived from the provider schema description. - NetworkConnectivitySpokeGatewayCapacity
- Capacity for an NCC gateway spoke.
- NetworkConnectivityTransportDeletionPolicy
-
Terraform
deletion_policyfor Network Connectivity transports. - NetworkConnectivityTransportStackType
-
IP stack for
google_network_connectivity_transport.stack_type. - NetworkManagementConnectivityTestDestinationNetworkType
-
network_type— derived from the provider schema description. - NetworkManagementConnectivityTestSourceNetworkType
-
network_type— derived from the provider schema description. - NetworkManagementVpcFlowLogsConfigAggregationInterval
-
aggregation_intervalforgoogle_network_management_vpc_flow_logs_config. - NetworkManagementVpcFlowLogsConfigMetadata
-
metadataforgoogle_network_management_vpc_flow_logs_config. - NetworkManagementVpcFlowLogsConfigState
-
stateforgoogle_network_management_vpc_flow_logs_config. - NetworkSecurityAddressGroupType
-
Network Security Address Group enum for
type. - NetworkSecurityAuthzPolicyAction
-
Network Security Authz Policy enum for
action. - NetworkSecurityAuthzPolicyHttpRulesFromNotSourcesPrincipalsPrincipalSelector
-
principal_selector— derived from the provider schema description. - NetworkSecurityAuthzPolicyHttpRulesFromSourcesPrincipalsPrincipalSelector
-
principal_selector— derived from the provider schema description. - NetworkSecurityAuthzPolicyHttpRulesToOperationsMcpBaseProtocolMethodsOption
-
base_protocol_methods_option— derived from the provider schema description. - NetworkSecurityAuthzPolicyNetworkRulesFromNotSourcesPrincipalsPrincipalSelector
-
principal_selector— derived from the provider schema description. - NetworkSecurityAuthzPolicyNetworkRulesFromSourcesPrincipalsPrincipalSelector
-
principal_selector— derived from the provider schema description. - NetworkSecurityAuthzPolicyPolicyProfile
-
Network Security Authz Policy Policy enum for
policy_profile. - NetworkSecurityAuthzPolicyTargetLoadBalancingScheme
-
load_balancing_scheme— derived from the provider schema description. - NetworkSecurityBackendAuthenticationConfigWellKnownRoots
-
Network Security Backend Authentication Config Well Known enum for
well_known_roots. - NetworkSecurityDnsThreatDetectorThreatDetectorProvider
-
Network Security Dns Threat Detector Threat Detector enum for
threat_detector_provider. - NetworkSecurityFirewallEndpointAssociationState
-
Network Security Firewall Endpoint Association enum for
state. - NetworkSecurityGatewaySecurityPolicyRuleBasicProfile
-
Network Security Gateway Security Policy Rule Basic enum for
basic_profile. - NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverridesAction
-
action— derived from the provider schema description. - NetworkSecuritySecurityProfileThreatPreventionProfileAntivirusOverridesProtocol
-
protocol— derived from the provider schema description. - NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverridesAction
-
action— derived from the provider schema description. - NetworkSecuritySecurityProfileThreatPreventionProfileSeverityOverridesSeverity
-
severity— derived from the provider schema description. - NetworkSecuritySecurityProfileThreatPreventionProfileThreatOverridesAction
-
action— derived from the provider schema description. - NetworkSecuritySecurityProfileType
-
Network Security Security Profile enum for
type. - NetworkSecuritySecurityProfileUrlFilteringProfileUrlFiltersFilteringAction
-
filtering_action— derived from the provider schema description. - NetworkSecurityTlsInspectionPolicyMinTlsVersion
-
Network Security Tls Inspection Policy Min Tls enum for
min_tls_version. - NetworkSecurityTlsInspectionPolicyTlsFeatureProfile
-
Network Security Tls Inspection Policy Tls Feature enum for
tls_feature_profile. - NetworkSecurityUllMirroringCollectorDeletionPolicy
-
Terraform
deletion_policyfor ULL mirroring collectors. - NetworkSecurityUllMirroringCollectorRuleDeletionPolicy
-
Terraform
deletion_policyfor ULL mirroring collector rules. - NetworkSecurityUllMirroringCollectorRuleDirection
-
Traffic direction for
match.direction. - NetworkSecurityUllMirroringEngineDeletionPolicy
-
Terraform
deletion_policyfor ULL mirroring engines. - NetworkServicesAgentGatewayGoogleManagedGovernedAccessPath
-
governed_access_pathundergoogle_managed. - NetworkServicesAuthzExtensionLoadBalancingScheme
-
Network Services Authz Extension Load Balancing enum for
load_balancing_scheme. - NetworkServicesAuthzExtensionWireFormat
-
Network Services Authz Extension Wire enum for
wire_format. - NetworkServicesEdgeCacheOriginFlexShieldingFlexShieldingRegions
-
flex_shielding_regions— derived from the provider schema description. - NetworkServicesEdgeCacheOriginProtocol
-
Network Services Edge Cache Origin enum for
protocol. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignaturesActions
-
actions— derived from the provider schema description. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheMode
-
cache_mode— derived from the provider schema description. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedRequestMode
-
signed_request_mode— derived from the provider schema description. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicySignedTokenOptionsAllowedSignatureAlgorithms
-
allowed_signature_algorithms— derived from the provider schema description. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCompressionMode
-
compression_mode— derived from the provider schema description. - NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleUrlRedirectRedirectResponseCode
-
redirect_response_code— derived from the provider schema description. - NetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelMatchCriteria
-
metadata_label_match_criteria— derived from the provider schema description. - NetworkServicesEndpointPolicyType
-
Network Services Endpoint Policy enum for
type. - NetworkServicesGatewayEnvoyHeaders
-
Network Services Gateway Envoy enum for
envoy_headers. - NetworkServicesGatewayIpVersion
-
Network Services Gateway Ip enum for
ip_version. - NetworkServicesGatewayRoutingMode
-
Network Services Gateway Routing enum for
routing_mode. - NetworkServicesGatewayType
-
Network Services Gateway enum for
type. - NetworkServicesGrpcRouteRulesActionRetryPolicyRetryConditions
-
retry_conditions— derived from the provider schema description. - NetworkServicesGrpcRouteRulesMatchesHeadersType
-
type— derived from the provider schema description. - NetworkServicesLbEdgeExtensionLoadBalancingScheme
-
Network Services Lb Edge Extension Load Balancing enum for
load_balancing_scheme. - NetworkServicesLbRouteExtensionExtensionChainsExtensionsRequestBodySendMode
-
request_body_send_mode— derived from the provider schema description. - NetworkServicesLbRouteExtensionLoadBalancingScheme
-
Network Services Lb Route Extension Load Balancing enum for
load_balancing_scheme. - NetworkServicesLbTrafficExtensionLoadBalancingScheme
-
Network Services Lb Traffic Extension Load Balancing enum for
load_balancing_scheme. - NetworkServicesWasmPluginLogConfigMinLogLevel
-
min_log_level— derived from the provider schema description.