scc library
Security Command Center (SCC) v1 / v2 / Management — sources, notification configs, mute configs, custom modules, BigQuery exports, and source IAM. Org/folder factories are apply-excluded.
Classes
- GoogleSccEventThreatDetectionCustomModule
-
Factory wrapper for
google_scc_event_threat_detection_custom_module. - GoogleSccFolderCustomModule
-
Factory wrapper for
google_scc_folder_custom_module. - GoogleSccFolderNotificationConfig
-
Factory wrapper for
google_scc_folder_notification_config. - GoogleSccFolderSccBigQueryExport
-
Factory wrapper for
google_scc_folder_scc_big_query_export. - GoogleSccManagementFolderSecurityHealthAnalyticsCustomModule
-
Factory wrapper for
google_scc_management_folder_security_health_analytics_custom_module. - GoogleSccManagementOrganizationEventThreatDetectionCustomModule
-
Factory wrapper for
google_scc_management_organization_event_threat_detection_custom_module. - GoogleSccManagementOrganizationSecurityHealthAnalyticsCustomModule
-
Factory wrapper for
google_scc_management_organization_security_health_analytics_custom_module. - GoogleSccManagementProjectSecurityHealthAnalyticsCustomModule
-
Factory wrapper for
google_scc_management_project_security_health_analytics_custom_module. - GoogleSccMuteConfig
-
Factory wrapper for
google_scc_mute_config. - GoogleSccNotificationConfig
-
Factory wrapper for
google_scc_notification_config. - GoogleSccOrganizationCustomModule
-
Factory wrapper for
google_scc_organization_custom_module. - GoogleSccOrganizationSccBigQueryExport
-
Factory wrapper for
google_scc_organization_scc_big_query_export. - GoogleSccProjectCustomModule
-
Factory wrapper for
google_scc_project_custom_module. - GoogleSccProjectNotificationConfig
-
Factory wrapper for
google_scc_project_notification_config. - GoogleSccProjectSccBigQueryExport
-
Factory wrapper for
google_scc_project_scc_big_query_export. - GoogleSccSource
-
Factory wrapper for
google_scc_source. - GoogleSccSourceIamBinding
-
Factory wrapper for
google_scc_source_iam_binding. - GoogleSccSourceIamMember
-
Factory wrapper for
google_scc_source_iam_member. - GoogleSccSourceIamPolicy
-
Factory wrapper for
google_scc_source_iam_policy. - GoogleSccV2FolderMuteConfig
-
Factory wrapper for
google_scc_v2_folder_mute_config. - GoogleSccV2FolderNotificationConfig
-
Factory wrapper for
google_scc_v2_folder_notification_config. - GoogleSccV2FolderSccBigQueryExport
-
Factory wrapper for
google_scc_v2_folder_scc_big_query_export. - GoogleSccV2OrganizationMuteConfig
-
Factory wrapper for
google_scc_v2_organization_mute_config. - GoogleSccV2OrganizationNotificationConfig
-
Factory wrapper for
google_scc_v2_organization_notification_config. - GoogleSccV2OrganizationSccBigQueryExport
-
Factory wrapper for
google_scc_v2_organization_scc_big_query_export. - GoogleSccV2OrganizationSccBigQueryExports
-
Factory wrapper for
google_scc_v2_organization_scc_big_query_exports. - GoogleSccV2OrganizationSource
-
Factory wrapper for
google_scc_v2_organization_source. - GoogleSccV2OrganizationSourceIamBinding
-
Factory wrapper for
google_scc_v2_organization_source_iam_binding. - GoogleSccV2OrganizationSourceIamMember
-
Factory wrapper for
google_scc_v2_organization_source_iam_member. - GoogleSccV2OrganizationSourceIamPolicy
-
Factory wrapper for
google_scc_v2_organization_source_iam_policy. - GoogleSccV2ProjectMuteConfig
-
Factory wrapper for
google_scc_v2_project_mute_config. - GoogleSccV2ProjectNotificationConfig
-
Factory wrapper for
google_scc_v2_project_notification_config. - GoogleSccV2ProjectSccBigQueryExport
-
Factory wrapper for
google_scc_v2_project_scc_big_query_export. - SccFolderCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_folder_custom_module(derived from provider schema). - SccFolderNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_folder_notification_config(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_management_folder_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_management_organization_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_management_project_security_health_analytics_custom_module(derived from provider schema). - SccNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_notification_config(derived from provider schema). - SccOrganizationCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccOrganizationCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccOrganizationCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccOrganizationCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccOrganizationCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_organization_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfig
-
Typed helper for the
custom_configblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfigCustomOutput
-
Typed helper for the
custom_config.custom_outputblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfigCustomOutputProperties
-
Typed helper for the
custom_config.custom_output.propertiesblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression
-
Typed helper for the
custom_config.custom_output.properties.value_expressionblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfigPredicate
-
Typed helper for the
custom_config.predicateblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectCustomModuleCustomConfigResourceSelector
-
Typed helper for the
custom_config.resource_selectorblock ofgoogle_scc_project_custom_module(derived from provider schema). - SccProjectNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_project_notification_config(derived from provider schema). - SccV2FolderNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_v2_folder_notification_config(derived from provider schema). - SccV2OrganizationNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_v2_organization_notification_config(derived from provider schema). - SccV2ProjectNotificationConfigStreamingConfig
-
Typed helper for the
streaming_configblock ofgoogle_scc_v2_project_notification_config(derived from provider schema).
Enums
- SccEventThreatDetectionCustomModuleEnablementState
-
Scc Event Threat Detection Custom Module Enablement enum for
enablement_state. - SccFolderCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccFolderCustomModuleEnablementState
-
Scc Folder Custom Module Enablement enum for
enablement_state. - SccManagementFolderSecurityHealthAnalyticsCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccManagementFolderSecurityHealthAnalyticsCustomModuleEnablementState
-
Scc Management Folder Security Health Analytics Custom Module Enablement enum for
enablement_state. - SccManagementOrganizationEventThreatDetectionCustomModuleEnablementState
-
Scc Management Organization Event Threat Detection Custom Module Enablement enum for
enablement_state. - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccManagementOrganizationSecurityHealthAnalyticsCustomModuleEnablementState
-
Scc Management Organization Security Health Analytics Custom Module Enablement enum for
enablement_state. - SccManagementProjectSecurityHealthAnalyticsCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccManagementProjectSecurityHealthAnalyticsCustomModuleEnablementState
-
Scc Management Project Security Health Analytics Custom Module Enablement enum for
enablement_state. - SccMuteConfigType
-
Scc Mute Config enum for
type. - SccOrganizationCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccOrganizationCustomModuleEnablementState
-
Scc Organization Custom Module Enablement enum for
enablement_state. - SccProjectCustomModuleCustomConfigSeverity
-
severity— derived from the provider schema description. - SccProjectCustomModuleEnablementState
-
Scc Project Custom Module Enablement enum for
enablement_state.