AccessContextManagerAccessLevelOsConstraints class final
Typed helper for the basic.conditions.device_policy.os_constraints block of
google_access_context_manager_access_level (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AccessContextManagerAccessLevelOsConstraints({TfArg<
String> ? minimumVersion, required AccessContextManagerAccessLevelOsType osType, TfArg<bool> ? requireVerifiedChromeOs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
minimumVersion
→ TfArg<
String> ? -
final
- osType → AccessContextManagerAccessLevelOsType
-
final
-
requireVerifiedChromeOs
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited