AccessContextManagerServicePerimeterStatus class final

Typed helper for the status block of google_access_context_manager_service_perimeter (derived from provider schema).

Annotations
  • @immutable

Properties

accessLevels → TfArg<List<Object?>>?
final
egressPolicies List<AccessContextManagerServicePerimeterStatusEgressPolicies>?
final
hashCode int
The hash code for this object.
no setterinherited
ingressPolicies List<AccessContextManagerServicePerimeterStatusIngressPolicies>?
final
resources → TfArg<List<Object?>>?
final
restrictedServices → TfArg<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vpcAccessibleServices AccessContextManagerServicePerimeterStatusVpcAccessibleServices?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited