AgenticApplicationsAnalystAgentPersonaArtifactsConfigVisualizationOptionsVisualizationExamplesResourceBigqueryResource class final
Typed helper for the artifacts_config.visualization_options.visualization_examples.resource.bigquery_resource block of
google_agentic_applications_analyst_agent_persona (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
bigqueryDataset
→ TfArg<
String> ? -
final
-
bigqueryTable
→ TfArg<
String> ? -
final
-
columnDescriptions
→ TfArg<
Map< ?String, String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited