AppConstant<T>.ref constructor
The literal an attribute of this Stack is set to:
.ref(topic.name) for name: .literal('orders-prod') becomes
static const String ordersTopicName = r'orders-prod';.
Synth fails when the attribute is not a literal — set by a reference,
a variable or an expression, or left for the provider to compute —
or is a sensitive field: a constant must be known before apply and
must not put a secret into source. For an apply-time value use
Stack.addOutput.
Implementation
const factory AppConstant.ref(TfRef<T> ref, {String? description}) =
RefConstant<T>;