AppEngineStandardAppVersionAutomaticScaling class final
Typed helper for the automatic_scaling block of
google_app_engine_standard_app_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppEngineStandardAppVersionAutomaticScaling({TfArg<
num> ? maxConcurrentRequests, TfArg<num> ? maxIdleInstances, TfArg<String> ? maxPendingLatency, TfArg<num> ? minIdleInstances, TfArg<String> ? minPendingLatency, AppEngineStandardAppVersionAutomaticScalingStandardSchedulerSettings? standardSchedulerSettings}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxConcurrentRequests
→ TfArg<
num> ? -
final
-
maxIdleInstances
→ TfArg<
num> ? -
final
-
maxPendingLatency
→ TfArg<
String> ? -
final
-
minIdleInstances
→ TfArg<
num> ? -
final
-
minPendingLatency
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- standardSchedulerSettings → AppEngineStandardAppVersionAutomaticScalingStandardSchedulerSettings?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited