ArtifactRegistryRepositoryArtifactRegistryRemoteUpstreamCredentials class
remote_repository_config.upstream_credentials -- single helper for
the only credential variant currently modeled by the schema
(username_password_credentials).
- Annotations
-
- @immutable
Constructors
- ArtifactRegistryRepositoryArtifactRegistryRemoteUpstreamCredentials({ArtifactRegistryRepositoryArtifactRegistryRemoteUsernamePasswordCredentials? usernamePasswordCredentials})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usernamePasswordCredentials → ArtifactRegistryRepositoryArtifactRegistryRemoteUsernamePasswordCredentials?
-
Username + Secret-Manager password version pair.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited