BackendServiceLogOptionalMode enum
log_config.optional_mode. Controls which optional access-log
fields are exported when ComputeBackendServiceBackendServiceLogConfig.enable is true.
Values
- includeAllOptional → const BackendServiceLogOptionalMode
-
const BackendServiceLogOptionalMode('INCLUDE_ALL_OPTIONAL') - excludeAllOptional → const BackendServiceLogOptionalMode
-
const BackendServiceLogOptionalMode('EXCLUDE_ALL_OPTIONAL') - custom → const BackendServiceLogOptionalMode
-
const BackendServiceLogOptionalMode('CUSTOM')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BackendServiceLogOptionalMode> - A constant List of the values in this enum, in order of their declaration.