BackupDrRestoreWorkloadDiskEncryptionKey class final
Typed helper for the disk_restore_properties.disk_encryption_key block of
google_backup_dr_restore_workload (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
BackupDrRestoreWorkloadDiskEncryptionKey({RefTo<
GoogleKmsCryptoKey> ? kmsKeyName, TfArg<String> ? kmsKeyServiceAccount, Sensitive<String> ? rawKey, Sensitive<String> ? rsaEncryptedKey}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyName
→ RefTo<
GoogleKmsCryptoKey> ? -
final
-
kmsKeyServiceAccount
→ TfArg<
String> ? -
final
-
rawKey
→ Sensitive<
String> ? -
final
-
rsaEncryptedKey
→ Sensitive<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited