BiglakeHiveTableStorageDescriptor class final
Typed helper for the storage_descriptor block of
google_biglake_hive_table (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BiglakeHiveTableStorageDescriptor({TfArg<
List< ? bucketCols, TfArg<String> >bool> ? compressed, TfArg<String> ? inputFormat, TfArg<String> ? locationUri, TfArg<num> ? numBuckets, TfArg<String> ? outputFormat, TfArg<Map< ? parameters, TfArg<String, String> >bool> ? storedAsSubDirs, required List<BiglakeHiveTableColumns> columns, BiglakeHiveTableSerdeInfo? serdeInfo, BiglakeHiveTableSkewedInfo? skewedInfo, List<BiglakeHiveTableSortCols> ? sortCols}) -
const
Properties
-
bucketCols
→ TfArg<
List< ?String> > -
final
-
columns
→ List<
BiglakeHiveTableColumns> -
final
-
compressed
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFormat
→ TfArg<
String> ? -
final
-
locationUri
→ TfArg<
String> ? -
final
-
numBuckets
→ TfArg<
num> ? -
final
-
outputFormat
→ TfArg<
String> ? -
final
-
parameters
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serdeInfo → BiglakeHiveTableSerdeInfo?
-
final
- skewedInfo → BiglakeHiveTableSkewedInfo?
-
final
-
sortCols
→ List<
BiglakeHiveTableSortCols> ? -
final
-
storedAsSubDirs
→ TfArg<
bool> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited