BigqueryConnectionAwsAccessRole class
aws.access_role block — IAM role the Google-owned AWS identity
assumes when reading from S3 / Glue on behalf of BigQuery.
- Annotations
-
- @immutable
Constructors
-
BigqueryConnectionAwsAccessRole({required TfArg<
String> iamRoleId}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iamRoleId
→ TfArg<
String> -
Required. AWS IAM role ARN (e.g.
arn:aws:iam::111122223333:role/bq-omni). The role's trust policy must trust the connection's Google-owned identity (surfaced asaws.access_role.identityafter apply).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited