BigqueryConnectionAzure class final
azure block — BigQuery Omni federation into Azure Data Lake
Storage. The BigQuery location must be azure-eastus2. Most fields
are computed and consumed by the Azure side of the federation
bridge; only customerTenantId is required input.
- Inheritance
-
- Object
- BigqueryConnectionBackend
- BigqueryConnectionAzure
- Annotations
-
- @immutable
Constructors
-
BigqueryConnectionAzure({required TfArg<
String> customerTenantId, TfArg<String> ? federatedApplicationClientId}) -
const
Properties
- blockKey → String
-
no setteroverride
-
customerTenantId
→ TfArg<
String> -
Required. Tenant id of the Azure AD directory hosting the data.
final
-
federatedApplicationClientId
→ TfArg<
String> ? -
Optional. Azure Application (client) id where the federated
credentials are hosted.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited