BigqueryConnectionConfigurationAsset class
configuration.asset block — points the connector at a Google Cloud
resource (AlloyDB cluster / instance, etc.).
- Annotations
-
- @immutable
Constructors
-
BigqueryConnectionConfigurationAsset({TfArg<
String> ? database, TfArg<String> ? googleCloudResource}) -
const
Properties
-
database
→ TfArg<
String> ? -
Optional. Database name inside the asset.
final
-
googleCloudResource
→ TfArg<
String> ? -
Optional. Full Google Cloud resource self-link, e.g.
//alloydb.googleapis.com/projects/{project}/locations/{region}/clusters/{cluster}/instances/{instance}.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited