BigqueryConnectionConfigurationAuthentication class
configuration.authentication block — authentication configuration
for the connector. Output-only service_account is consumed via the
generated factory state, not a constructor input.
- Annotations
-
- @immutable
Constructors
- BigqueryConnectionConfigurationAuthentication({BigqueryConnectionConfigurationAuthenticationUsernamePassword? usernamePassword})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usernamePassword → BigqueryConnectionConfigurationAuthenticationUsernamePassword?
-
Optional. Username / password block. Only one authentication
mechanism is exposed by the schema today.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited