BigqueryConnectionConfigurationAuthenticationUsernamePassword class
configuration.authentication.username_password block — username /
password authentication for the connector framework.
- Annotations
-
- @immutable
Constructors
-
BigqueryConnectionConfigurationAuthenticationUsernamePassword({required TfArg<
String> username, required BigqueryConnectionConfigurationAuthenticationPassword password}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → BigqueryConnectionConfigurationAuthenticationPassword
-
Required. Password block — see
BigqueryConnectionConfigurationAuthenticationPassword.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
username
→ TfArg<
String> -
Required. Username forwarded to the connector.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited