BigqueryConnectionConfigurationNetwork class
configuration.network block — network configuration for the
connector. The schema only exposes private_service_connect today.
- Annotations
-
- @immutable
Constructors
- BigqueryConnectionConfigurationNetwork({BigqueryConnectionConfigurationNetworkPrivateServiceConnect? privateServiceConnect})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateServiceConnect → BigqueryConnectionConfigurationNetworkPrivateServiceConnect?
-
Optional. PSC network attachment.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited