BigqueryConnectionSparkSparkHistoryServerConfig class
spark.spark_history_server_config block — optional binding to a
Dataproc Cluster acting as Spark History Server for the connection.
- Annotations
-
- @immutable
Constructors
-
BigqueryConnectionSparkSparkHistoryServerConfig({TfArg<
String> ? dataprocCluster}) -
const
Properties
-
dataprocCluster
→ TfArg<
String> ? -
Resource name of an existing Dataproc Cluster in the form
projects/{projectId}/regions/{region}/clusters/{clusterName}.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited