BigqueryDataTransferConfigEncryptionConfiguration class
encryption_configuration block (max=1) — CMEK key used to encrypt
data written by this transfer config to the destination dataset.
When unset, the dataset's
default_encryption_configuration.kms_key_name (if any) applies; if
neither is set, Google-managed encryption is used.
The BigQuery DTS service identity
(service-{projectNumber}@gcp-sa-bigquerydatatransfer.iam.gserviceaccount.com)
must hold roles/cloudkms.cryptoKeyEncrypterDecrypter on the key
before the transfer config can use it.
- Annotations
-
- @immutable
Constructors
-
BigqueryDataTransferConfigEncryptionConfiguration({required TfArg<
String> kmsKeyName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyName
→ TfArg<
String> -
Fully-qualified KMS key resource name
(
projects/{p}/locations/{l}/keyRings/{r}/cryptoKeys/{k}).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited