BigqueryDatasetAccessCondition class
access.condition — CEL binding restricting when an access entry
applies. expression is the CEL source; the other three fields are
metadata for debugging / UI surfaces.
- Annotations
-
- @immutable
Constructors
-
BigqueryDatasetAccessCondition({required TfArg<
String> expression, TfArg<String> ? title, TfArg<String> ? description, TfArg<String> ? location}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
expression
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited