BigqueryJobEncryptionConfiguration class
query.destination_encryption_configuration /
load.destination_encryption_configuration /
copy.destination_encryption_configuration — CMEK key applied
to the destination table. kmsKeyVersion is computed (returned
by the API after the job runs); only kmsKeyName is settable
here.
- Annotations
-
- @immutable
Constructors
-
BigqueryJobEncryptionConfiguration({required TfArg<
String> kmsKeyName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyName
→ TfArg<
String> -
Self-link of the KMS crypto key, e.g.
projects/p/locations/us/keyRings/r/cryptoKeys/k.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited