BigqueryJobExtractDestinationFormat extension type
extract.destination_format. Schema description: "Possible
values include CSV, NEWLINE_DELIMITED_JSON and AVRO for tables
and SAVED_MODEL for models. The default value for tables is CSV.
Tables with nested or repeated fields cannot be exported as CSV.
The default value for models is SAVED_MODEL." Values transcribed
from the description prose (no formal enum_values array on
this attribute).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited