BigqueryJobLoadSourceFormat extension type
load.source_format. From the schema description: for CSV
specify CSV; for datastore backups DATASTORE_BACKUP; for
newline-delimited JSON NEWLINE_DELIMITED_JSON; for Avro AVRO;
for Parquet PARQUET; for ORC ORC; Beta for Bigtable
BIGTABLE. Default is CSV. The schema doesn't expose a
formal enum_values array, so this list is sourced from the
attribute's description prose.
Constructors
-
BigqueryJobLoadSourceFormat.arg(TfArg<
String> arg) -
const
- BigqueryJobLoadSourceFormat.expression(String template)
- BigqueryJobLoadSourceFormat.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- avro → const BigqueryJobLoadSourceFormat
- bigtable → const BigqueryJobLoadSourceFormat
- csv → const BigqueryJobLoadSourceFormat
- datastoreBackup → const BigqueryJobLoadSourceFormat
- newlineDelimitedJson → const BigqueryJobLoadSourceFormat
- orc → const BigqueryJobLoadSourceFormat
- parquet → const BigqueryJobLoadSourceFormat
-
values
→ const List<
BigqueryJobLoadSourceFormat>