BigqueryJobScriptOptions class
query.script_options (max_items=1) — multi-statement script
execution behavior.
- Annotations
-
- @immutable
Constructors
-
BigqueryJobScriptOptions({TfArg<
String> ? statementTimeoutMs, TfArg<String> ? statementByteBudget, BigqueryJobScriptKeyResultStatement? keyResultStatement}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyResultStatement → BigqueryJobScriptKeyResultStatement?
-
Which statement's result is the script's "key result".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statementByteBudget
→ TfArg<
String> ? -
Per-statement byte budget. Int64 as a String.
final
-
statementTimeoutMs
→ TfArg<
String> ? -
Per-statement timeout. Int64 as a String per BigQuery API
convention.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited