BigqueryRoutineRemoteFunctionOptions class
remote_function_options block (max=1). Required when
BigqueryRoutineType.scalarFunction is backed by a remote service
(Cloud Functions / Cloud Run). endpoint points at the HTTPS URL of
the function; connection is the fully-qualified BigQuery
connection (projects/{p}/locations/{l}/connections/{c}) holding
the credential.
- Annotations
-
- @immutable
Constructors
Properties
-
connection
→ TfArg<
String> ? -
final
-
endpoint
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxBatchingRows
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userDefinedContext
→ Map<
String, String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited