BigqueryRoutineSparkOptions class
spark_options block (max=1). Required when language is PYTHON,
JAVA, or SCALA. connection points at a BigQuery Spark
connection. The remaining fields configure the Spark application —
exactly one of mainClass / mainFileUri must be set for Java /
Scala; PySpark uses mainFileUri or definitionBody.
- Annotations
-
- @immutable
Constructors
-
BigqueryRoutineSparkOptions({TfArg<
String> ? connection, TfArg<String> ? runtimeVersion, TfArg<String> ? containerImage, Map<String, String> ? properties, TfArg<String> ? mainFileUri, List<String> ? pyFileUris, List<String> ? jarUris, List<String> ? fileUris, List<String> ? archiveUris, TfArg<String> ? mainClass}) -
const
Properties
-
archiveUris
→ List<
String> ? -
final
-
connection
→ TfArg<
String> ? -
final
-
containerImage
→ TfArg<
String> ? -
final
-
fileUris
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jarUris
→ List<
String> ? -
final
-
mainClass
→ TfArg<
String> ? -
final
-
mainFileUri
→ TfArg<
String> ? -
final
-
properties
→ Map<
String, String> ? -
final
-
pyFileUris
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
runtimeVersion
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited