BigqueryTableMaterializedView class
materialized_view block (max=1). query is required and frozen
at create time (changing it forces replacement). The other knobs
control refresh behaviour.
- Annotations
-
- @immutable
Constructors
-
BigqueryTableMaterializedView({required TfArg<
String> query, TfArg<bool> ? enableRefresh, TfArg<int> ? refreshIntervalMs, TfArg<bool> ? allowNonIncrementalDefinition}) -
const
Properties
-
allowNonIncrementalDefinition
→ TfArg<
bool> ? -
final
-
enableRefresh
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
query
→ TfArg<
String> -
final
-
refreshIntervalMs
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited