BigqueryTableParquetOptions class
external_data_configuration.parquet_options sub-block.
- Annotations
-
- @immutable
Constructors
-
BigqueryTableParquetOptions({TfArg<
bool> ? enableListInference, TfArg<bool> ? enumAsString}) -
const
Properties
-
enableListInference
→ TfArg<
bool> ? -
final
-
enumAsString
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited