BigqueryTableTableReplicationInfo class
table_replication_info block (max=1). Marks the table as a
replica of a source materialized view in another dataset
(CREATE MATERIALIZED VIEW ... AS REPLICA OF ...).
- Annotations
-
- @immutable
Constructors
-
BigqueryTableTableReplicationInfo({required TfArg<
String> sourceProjectId, required TfArg<String> sourceDatasetId, required TfArg<String> sourceTableId, TfArg<int> ? replicationIntervalMs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
replicationIntervalMs
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceDatasetId
→ TfArg<
String> -
final
-
sourceProjectId
→ TfArg<
String> -
final
-
sourceTableId
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited