CesAppWebWidgetConfig class final
Typed helper for the default_channel_profile.web_widget_config block of
google_ces_app (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CesAppWebWidgetConfig({TfArg<
String> ? modality, TfArg<String> ? theme, TfArg<String> ? webWidgetTitle, CesAppSecuritySettings? securitySettings}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modality
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securitySettings → CesAppSecuritySettings?
-
final
-
theme
→ TfArg<
String> ? -
final
-
webWidgetTitle
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited