CesToolsetTlsConfig class final
Typed helper for the mcp_toolset.tls_config block of
google_ces_toolset (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
CesToolsetTlsConfig({required List<
CesToolsetCaCerts> caCerts}) -
const
Properties
-
caCerts
→ List<
CesToolsetCaCerts> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited