ChronicleParserLowCodeFieldExtractors class final
Typed helper for the low_code.field_extractors block of
google_chronicle_parser (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ChronicleParserLowCodeFieldExtractors({TfArg<
bool> ? appendRepeatedFields, TfArg<String> ? logFormat, List<ChronicleParserLowCodeFieldExtractorsExtractors> ? extractors, ChronicleParserLowCodeFieldExtractorsPreprocessConfig? preprocessConfig}) -
const
Properties
-
appendRepeatedFields
→ TfArg<
bool> ? -
final
-
extractors
→ List<
ChronicleParserLowCodeFieldExtractorsExtractors> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logFormat
→ TfArg<
String> ? -
final
- preprocessConfig → ChronicleParserLowCodeFieldExtractorsPreprocessConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited