ChronicleParserLowCodeFieldExtractorsExtractors class final
Typed helper for the low_code.field_extractors.extractors block of
google_chronicle_parser (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
destinationPath
→ TfArg<
String> ? -
final
-
fieldPath
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
preconditionOp
→ TfArg<
String> ? -
final
-
preconditionPath
→ TfArg<
String> ? -
final
-
preconditionValue
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited