CloudBuildTriggerSourceToBuild class
source_to_build block. Declares the source the build operates on
— used by Pub/Sub, Webhook, and Manual triggers (i.e. triggers that
do not respond to SCM webhooks and therefore have no inherent ref).
- Annotations
-
- @immutable
Constructors
-
CloudBuildTriggerSourceToBuild({required TfArg<
String> ref, required TfArg<CloudBuildTriggerRepoType> repoType, TfArg<String> ? uri, TfArg<String> ? repository, TfArg<String> ? githubEnterpriseConfig, TfArg<String> ? bitbucketServerConfig}) -
const
Properties
-
bitbucketServerConfig
→ TfArg<
String> ? -
Bitbucket Server config resource name. Format:
'projects/{project}/locations/{location}/bitbucketServerConfigs/{id}'.final -
githubEnterpriseConfig
→ TfArg<
String> ? -
GitHub Enterprise config resource name. Format:
'projects/{project}/locations/{location}/githubEnterpriseConfigs/{id}'.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
ref
→ TfArg<
String> -
Branch / tag / SHA to build. Must start with
'refs/'.final -
repository
→ TfArg<
String> ? -
Repo API resource name (v2 form). Format:
'projects/{project}/locations/{location}/connections/{connection}/repositories/{repository}'.final -
repoType
→ TfArg<
CloudBuildTriggerRepoType> -
Repo type. Pick CloudBuildTriggerRepoType.unknown when the type
cannot be inferred from uri.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uri
→ TfArg<
String> ? -
Repo URI. Mutually exclusive with repository; supply at least
one.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited