CloudRunV2ServiceEnvVar class
One env var. Set source to inject a value (literal or secret-ref).
When source is null the variable is emitted with an empty literal
(the schema's documented default — provider suppresses the diff).
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceEnvVar({required TfArg<
String> name, CloudRunV2ServiceEnvVarSource? source}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> -
C_IDENTIFIER name. Required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → CloudRunV2ServiceEnvVarSource?
-
Value source. Pick exactly one of CloudRunV2ServiceEnvVarFromLiteral or
CloudRunV2ServiceEnvVarFromSecret.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited