CloudRunV2ServiceGcsVolume class final
GCSFuse-backed volume (gcs). Only supported in gen2 execution
environment.
- Inheritance
-
- Object
- CloudRunV2ServiceVolumeSource
- CloudRunV2ServiceGcsVolume
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceGcsVolume({required TfArg<
String> bucket, TfArg<bool> ? readOnly, TfArg<List< ? mountOptions})String> > -
const
Properties
-
bucket
→ TfArg<
String> -
GCS bucket name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mountOptions
→ TfArg<
List< ?String> > -
Flags passed to
gcsfuse(without leading dashes).final -
readOnly
→ TfArg<
bool> ? -
Mount as read-only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited