CloudRunV2ServiceLivenessProbeHttpGet class final
Typed helper for the template.containers.liveness_probe.http_get block of
google_cloud_run_v2_service (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceLivenessProbeHttpGet({TfArg<
String> ? path, TfArg<num> ? port, List<CloudRunV2ServiceHttpHeaders> ? httpHeaders}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
httpHeaders
→ List<
CloudRunV2ServiceHttpHeaders> ? -
final
-
path
→ TfArg<
String> ? -
final
-
port
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited