CloudRunV2ServiceServiceVolume class
One entry in template.volumes. The volume's name is referenced
from CloudRunV2ServiceVolumeMount.name inside any CloudRunV2ServiceServiceContainer.volumeMounts.
Pick exactly one source (sealed CloudRunV2ServiceVolumeSource).
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceServiceVolume({required TfArg<
String> name, required CloudRunV2ServiceVolumeSource source}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> -
Volume name. Must be unique within the revision and match
downstream CloudRunV2ServiceVolumeMount.name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → CloudRunV2ServiceVolumeSource
-
Backing storage. Pick exactly one of CloudRunV2ServiceVolumeSecret,
CloudRunV2ServiceCloudSqlVolume, CloudRunV2ServiceEmptyDirVolume, CloudRunV2ServiceGcsVolume, CloudRunV2ServiceNfsVolume.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited