CloudRunV2ServiceVolumeSecret class final
Secret Manager-backed volume. Files appear under
<mountPath>/<items[].path>, or under <mountPath>/<secretName>
when items is empty.
- Inheritance
-
- Object
- CloudRunV2ServiceVolumeSource
- CloudRunV2ServiceVolumeSecret
- Annotations
-
- @immutable
Constructors
-
CloudRunV2ServiceVolumeSecret({required TfArg<
String> secret, TfArg<int> ? defaultMode, List<CloudRunV2ServiceSecretVolumeItem> ? items}) -
const
Properties
-
defaultMode
→ TfArg<
int> ? -
Octal mode bits to apply to all keys by default. 0–0777. Default 0444.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
CloudRunV2ServiceSecretVolumeItem> ? -
Per-version file mappings. When set, the volume exposes ONLY these.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secret
→ TfArg<
String> -
Secret name. Short form when same-project, full
projects/{p}/secrets/{s}otherwise.final
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited