CloudRunV2WorkerPoolSecretKeyRef class final
Typed helper for the template.containers.env.value_source.secret_key_ref block of
google_cloud_run_v2_worker_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudRunV2WorkerPoolSecretKeyRef({required RefTo<
GoogleSecretManagerSecret> secret, TfArg<String> ? version}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secret
→ RefTo<
GoogleSecretManagerSecret> -
final
-
version
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited