CloudSecurityComplianceFrameworkDeploymentTargetResourceConfigTargetResourceCreationConfigProjectCreationConfig class final
Typed helper for the target_resource_config.target_resource_creation_config.project_creation_config block of
google_cloud_security_compliance_framework_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudSecurityComplianceFrameworkDeploymentTargetResourceConfigTargetResourceCreationConfigProjectCreationConfig({required TfArg<
String> billingAccountId, required TfArg<String> parent, required TfArg<String> projectDisplayName}) -
const
Properties
-
billingAccountId
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parent
→ TfArg<
String> -
final
-
projectDisplayName
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited