CloudTasksQueueQueueHttpTarget class
http_target block on the queue (NOT on the per-task HTTP request — this
is the queue-level URL override). Named CloudTasksQueueQueueHttpTarget to avoid
colliding with HttpTarget in cloud_scheduler/.
- Annotations
-
- @immutable
Constructors
-
CloudTasksQueueQueueHttpTarget({TfArg<
Map< ? uriOverride, TfArg<String, dynamic> >String> ? httpMethod, TfArg<List< ? headerOverrides, CloudTasksQueueQueueOauthToken? oauthToken, CloudTasksQueueQueueOidcToken? oidcToken})Map< >String, dynamic> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerOverrides
→ TfArg<
List< ?Map< >String, dynamic> > -
final
-
httpMethod
→ TfArg<
String> ? -
final
- oauthToken → CloudTasksQueueQueueOauthToken?
-
final
- oidcToken → CloudTasksQueueQueueOidcToken?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uriOverride
→ TfArg<
Map< ?String, dynamic> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited