Cloudfunctions2FunctionBuildConfig class final
Typed helper for the build_config block of
google_cloudfunctions2_function (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Cloudfunctions2FunctionBuildConfig({TfArg<
String> ? dockerRepository, TfArg<String> ? entryPoint, TfArg<Map< ? environmentVariables, TfArg<String, String> >String> ? runtime, RefTo<GoogleServiceAccount> ? serviceAccount, TfArg<String> ? workerPool, required Cloudfunctions2FunctionUpdatePolicy updatePolicy, Cloudfunctions2FunctionSource? source}) -
const
Properties
-
dockerRepository
→ TfArg<
String> ? -
final
-
entryPoint
→ TfArg<
String> ? -
final
-
environmentVariables
→ TfArg<
Map< ?String, String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
runtime
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccount
→ RefTo<
GoogleServiceAccount> ? -
final
- source → Cloudfunctions2FunctionSource?
-
final
- updatePolicy → Cloudfunctions2FunctionUpdatePolicy
-
final
-
workerPool
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited