Cloudfunctions2FunctionDirectVpcNetworkInterface class
One entry in service_config.direct_vpc_network_interface. Attaches
the function instance to a VPC network without going through a
Serverless VPC Access connector.
- Annotations
-
- @immutable
Constructors
-
Cloudfunctions2FunctionDirectVpcNetworkInterface({TfArg<
String> ? network, TfArg<String> ? subnetwork, TfArg<List< ? tags})String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
network
→ TfArg<
String> ? -
VPC network self-link or short name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetwork
→ TfArg<
String> ? -
VPC subnetwork self-link or short name.
final
-
Network tags applied to this Cloud Function.
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited