Cloudfunctions2FunctionEventFilter class
One entry in event_trigger.event_filters. Matches a CloudEvents
attribute against a literal value (or, when operator is
'match-path-pattern', a path pattern).
- Annotations
-
- @immutable
Constructors
-
Cloudfunctions2FunctionEventFilter({required TfArg<
String> attribute, required TfArg<String> value, TfArg<String> ? operator}) -
const
Properties
-
attribute
→ TfArg<
String> -
CloudEvents attribute name (e.g.
'bucket','document').final - hashCode → int
-
The hash code for this object.
no setterinherited
-
operator
→ TfArg<
String> ? -
Match operator. Omit for exact match; set to
'match-path-pattern'for wildcard matching.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ TfArg<
String> -
Literal value or path pattern.
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited