Cloudfunctions2FunctionSecretVolume class
One entry in service_config.secret_volumes. Mounts one or more
secret versions as files under mountPath.
- Annotations
-
- @immutable
Constructors
-
Cloudfunctions2FunctionSecretVolume({required TfArg<
String> mountPath, required TfArg<String> projectId, required TfArg<String> secret, List<Cloudfunctions2FunctionSecretVolumeVersion> ? versions}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mountPath
→ TfArg<
String> -
Mount path inside the container (e.g.
'/etc/secrets').final -
projectId
→ TfArg<
String> -
Project containing the secret.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secret
→ TfArg<
String> -
Secret name (short form).
final
-
versions
→ List<
Cloudfunctions2FunctionSecretVolumeVersion> ? -
Per-version file mappings. When null, the secret's
'latest'version is mounted at{mountPath}/{secret}.final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited