ColabNotebookExecutionVmImage class final
Typed helper for the workbench_runtime.vm_image block of
google_colab_notebook_execution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ColabNotebookExecutionVmImage({required ColabNotebookExecutionSelector selector, TfArg<
String> ? project}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
project
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → ColabNotebookExecutionSelector
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited