ColabScheduleCreatePipelineJobRequestPipelineJob class final
Typed helper for the create_pipeline_job_request.pipeline_job block of
google_colab_schedule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ColabScheduleCreatePipelineJobRequestPipelineJob({TfArg<
String> ? displayName, TfArg<Map< ? labels, TfArg<String, String> >String> ? network, TfArg<String> ? pipelineSpec, TfArg<bool> ? preflightValidations, TfArg<List< ? reservedIpRanges, TfArg<Object?> >String> ? serviceAccount, TfArg<String> ? templateUri, ColabScheduleCreatePipelineJobRequestPipelineJobEncryptionSpec? encryptionSpec, ColabScheduleCreatePipelineJobRequestPipelineJobPscInterfaceConfig? pscInterfaceConfig, ColabScheduleCreatePipelineJobRequestPipelineJobRuntimeConfig? runtimeConfig}) -
const
Properties
-
displayName
→ TfArg<
String> ? -
final
- encryptionSpec → ColabScheduleCreatePipelineJobRequestPipelineJobEncryptionSpec?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ TfArg<
Map< ?String, String> > -
final
-
network
→ TfArg<
String> ? -
final
-
pipelineSpec
→ TfArg<
String> ? -
final
-
preflightValidations
→ TfArg<
bool> ? -
final
- pscInterfaceConfig → ColabScheduleCreatePipelineJobRequestPipelineJobPscInterfaceConfig?
-
final
-
reservedIpRanges
→ TfArg<
List< ?Object?> > -
final
- runtimeConfig → ColabScheduleCreatePipelineJobRequestPipelineJobRuntimeConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccount
→ TfArg<
String> ? -
final
-
templateUri
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited