ColabScheduleRuntimeConfig class final
Typed helper for the create_pipeline_job_request.pipeline_job.runtime_config block of
google_colab_schedule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
failurePolicy
→ TfArg<
String> ? -
final
-
gcsOutputDirectory
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameterValues
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited