ComposerEnvironmentConfigNodeConfigIpAllocationPolicy class final
Typed helper for the config.node_config.ip_allocation_policy block of
google_composer_environment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
clusterIpv4CidrBlock
→ TfArg<
String> ? -
final
-
clusterSecondaryRangeName
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
servicesIpv4CidrBlock
→ TfArg<
String> ? -
final
-
servicesSecondaryRangeName
→ TfArg<
String> ? -
final
-
useIpAliases
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited