ComputeBackendServiceBackendServiceAwsV4Authentication class
security_settings.aws_v4_authentication (max_items=1).
accessKey is sensitive.
- Annotations
-
- @immutable
Constructors
-
ComputeBackendServiceBackendServiceAwsV4Authentication({TfArg<
String> ? accessKey, TfArg<String> ? accessKeyId, TfArg<String> ? accessKeyVersion, TfArg<String> ? originRegion}) -
const
Properties
-
accessKey
→ TfArg<
String> ? -
AWS secret access key. Sensitive — round-trips through
$sensitiveFields.final -
accessKeyId
→ TfArg<
String> ? -
AWS access key ID.
final
-
accessKeyVersion
→ TfArg<
String> ? -
Secret Manager version of the access key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
originRegion
→ TfArg<
String> ? -
AWS region the credentials are scoped to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited