ComputeBackendServiceBackendServiceCdnCacheKeyPolicy class
cdn_policy.cache_key_policy (max_items=1).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeHost
→ TfArg<
bool> ? -
final
-
includeHttpHeaders
→ List<
String> ? -
final
-
includeNamedCookies
→ List<
String> ? -
final
-
includeProtocol
→ TfArg<
bool> ? -
final
-
includeQueryString
→ TfArg<
bool> ? -
final
-
queryStringBlacklist
→ List<
String> ? -
final
-
queryStringWhitelist
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited