ComputeBackendServiceBackendServiceOutlierDetection class
outlier_detection block — passive health checking. Hosts that
exceed the configured failure thresholds are ejected from the load
balancing pool for base_ejection_time * consecutive-ejection-count.
- Annotations
-
- @immutable
Constructors
-
ComputeBackendServiceBackendServiceOutlierDetection({TfArg<
int> ? consecutiveErrors, TfArg<int> ? consecutiveGatewayFailure, TfArg<int> ? enforcingConsecutiveErrors, TfArg<int> ? enforcingConsecutiveGatewayFailure, TfArg<int> ? enforcingSuccessRate, TfArg<int> ? maxEjectionPercent, TfArg<int> ? successRateMinimumHosts, TfArg<int> ? successRateRequestVolume, TfArg<int> ? successRateStdevFactor, ComputeBackendServiceBackendServiceDuration? baseEjectionTime, ComputeBackendServiceBackendServiceDuration? interval}) -
const
Properties
- baseEjectionTime → ComputeBackendServiceBackendServiceDuration?
-
Base time a host stays ejected. Schema requires
seconds.final -
consecutiveErrors
→ TfArg<
int> ? -
final
-
consecutiveGatewayFailure
→ TfArg<
int> ? -
final
-
enforcingConsecutiveErrors
→ TfArg<
int> ? -
final
-
enforcingConsecutiveGatewayFailure
→ TfArg<
int> ? -
final
-
enforcingSuccessRate
→ TfArg<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → ComputeBackendServiceBackendServiceDuration?
-
How often outlier detection runs. Schema requires
seconds.final -
maxEjectionPercent
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
successRateMinimumHosts
→ TfArg<
int> ? -
final
-
successRateRequestVolume
→ TfArg<
int> ? -
final
-
successRateStdevFactor
→ TfArg<
int> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited