ComputeDiskGuestOsFeatureType enum
guest_os_features[].type for zonal persistent disks.
Values
- multiIpSubnet → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('MULTI_IP_SUBNET') - secureBoot → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SECURE_BOOT') - sevCapable → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SEV_CAPABLE') - uefiCompatible → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('UEFI_COMPATIBLE') - virtioScsiMultiqueue → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('VIRTIO_SCSI_MULTIQUEUE') - windows → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('WINDOWS') - gVnic → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('GVNIC') - sevLiveMigratable → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SEV_LIVE_MIGRATABLE') - sevSnpCapable → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SEV_SNP_CAPABLE') - suspendResumeCompatible → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SUSPEND_RESUME_COMPATIBLE') - tdxCapable → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('TDX_CAPABLE') - sevLiveMigratableV2 → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SEV_LIVE_MIGRATABLE_V2') - snpSvsmCapable → const ComputeDiskGuestOsFeatureType
-
const ComputeDiskGuestOsFeatureType('SNP_SVSM_CAPABLE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ComputeDiskGuestOsFeatureType> - A constant List of the values in this enum, in order of their declaration.