ComputeFirewallPolicyRuleMatch class final
Typed helper for the match block of
google_compute_firewall_policy_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeFirewallPolicyRuleMatch({TfArg<
List< ? destAddressGroups, TfArg<String> >List< ? destFqdns, TfArg<String> >List< ? destIpRanges, ComputeFirewallPolicyRuleDestNetworkContext? destNetworkContext, TfArg<String> >List< ? destRegionCodes, TfArg<String> >List< ? destThreatIntelligences, TfArg<String> >List< ? srcAddressGroups, TfArg<String> >List< ? srcFqdns, TfArg<String> >List< ? srcIpRanges, ComputeFirewallPolicyRuleSrcNetworkContext? srcNetworkContext, TfArg<String> >List< ? srcNetworks, TfArg<String> >List< ? srcRegionCodes, TfArg<String> >List< ? srcThreatIntelligences, required List<String> >ComputeFirewallPolicyRuleLayer4Configs> layer4Configs, List<ComputeFirewallPolicyRuleSrcSecureTags> ? srcSecureTags}) -
const
Properties
-
destAddressGroups
→ TfArg<
List< ?String> > -
final
-
destFqdns
→ TfArg<
List< ?String> > -
final
-
destIpRanges
→ TfArg<
List< ?String> > -
final
- destNetworkContext → ComputeFirewallPolicyRuleDestNetworkContext?
-
final
-
destRegionCodes
→ TfArg<
List< ?String> > -
final
-
destThreatIntelligences
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layer4Configs
→ List<
ComputeFirewallPolicyRuleLayer4Configs> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
srcAddressGroups
→ TfArg<
List< ?String> > -
final
-
srcFqdns
→ TfArg<
List< ?String> > -
final
-
srcIpRanges
→ TfArg<
List< ?String> > -
final
- srcNetworkContext → ComputeFirewallPolicyRuleSrcNetworkContext?
-
final
-
srcNetworks
→ TfArg<
List< ?String> > -
final
-
srcRegionCodes
→ TfArg<
List< ?String> > -
final
-
srcSecureTags
→ List<
ComputeFirewallPolicyRuleSrcSecureTags> ? -
final
-
srcThreatIntelligences
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited