ComputeGlobalForwardingRuleGlobalForwardingRuleServiceDirectoryRegistration class
One entry in service_directory_registrations. The schema caps the
list at one entry; populated only for Private Service Connect
forwarding rules that target Google APIs (so other consumers in the
same project can resolve the rule by Service Directory name).
- Annotations
-
- @immutable
Constructors
-
ComputeGlobalForwardingRuleGlobalForwardingRuleServiceDirectoryRegistration({TfArg<
String> ? namespace, TfArg<String> ? serviceDirectoryRegion}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
namespace
→ TfArg<
String> ? -
Service Directory namespace under which to register the rule.
Defaults from API when omitted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceDirectoryRegion
→ TfArg<
String> ? -
Service Directory region for the registration. Defaults to
'us-central1'on the API side. Only used for PSC-to-Google-APIs rules — all such rules on the same VPC should use the same region.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited