ComputeHealthCheckSslHealthCheckConfig class
ssl_health_check block. Pure SSL/TLS probe.
- Annotations
-
- @immutable
Constructors
-
ComputeHealthCheckSslHealthCheckConfig({TfArg<
String> ? request, TfArg<String> ? response, TfArg<int> ? port, TfArg<String> ? portName, HealthCheckProxyHeader? proxyHeader, HealthCheckPortSpecification? portSpecification}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
port
→ TfArg<
int> ? -
TCP port. Defaults to 443.
final
-
portName
→ TfArg<
String> ? -
final
- portSpecification → HealthCheckPortSpecification?
-
final
- proxyHeader → HealthCheckProxyHeader?
-
final
-
request
→ TfArg<
String> ? -
final
-
response
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited