ComputeInstanceGroupManagerInstanceGroupManagerAutoHealingPolicy class
auto_healing_policies block. When a VM fails its healthCheck
for longer than the initial-delay window, the MIG recreates it.
Schema marks both fields as required.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceGroupManagerInstanceGroupManagerAutoHealingPolicy({required TfArg<
String> healthCheck, required TfArg<int> initialDelaySec}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
healthCheck
→ TfArg<
String> -
Self-link of a
google_compute_health_check(or compatible regional health check). Typically wired asvar.health_check_id.final -
initialDelaySec
→ TfArg<
int> -
Seconds to wait after a VM is created before applying autohealing
to it. Schema range: 0-3600.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited