ComputeInstanceGroupManagerInstanceGroupManagerInstanceLifecyclePolicy class
instance_lifecycle_policy block — fine-grained behavior on
failures and template updates.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceGroupManagerInstanceGroupManagerInstanceLifecyclePolicy({TfArg<
String> ? defaultActionOnFailure, TfArg<String> ? forceUpdateOnRepair}) -
const
Properties
-
defaultActionOnFailure
→ TfArg<
String> ? -
Default behavior for instance or health check failures.
final
-
forceUpdateOnRepair
→ TfArg<
String> ? -
YESto apply the latest template when repairing a VM;NO(default) to honor the update policy.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited