ComputeInstanceGroupManagerInstanceGroupManagerStatefulDisk class
One entry in statefulDisks. Marks a disk attached at
deviceName as stateful — the MIG preserves the disk across
VM recreates per deleteRule.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceGroupManagerInstanceGroupManagerStatefulDisk({required TfArg<
String> deviceName, TfArg<String> ? deleteRule}) -
const
Properties
-
deleteRule
→ TfArg<
String> ? -
NEVER(default — detach but keep the disk) orON_PERMANENT_INSTANCE_DELETION(delete with the VM).final -
deviceName
→ TfArg<
String> -
Device name the disk is attached to on the VM (matches the
device_nameset on the instance template'sdiskblock).final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited