ComputeInstanceGroupManagerInstanceGroupManagerUpdatePolicy class
update_policy block. Drives how the MIG rolls a new
ComputeInstanceGroupManagerInstanceGroupManagerVersion across its members.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceGroupManagerInstanceGroupManagerUpdatePolicy({required InstanceGroupManagerUpdatePolicyAction minimalAction, required InstanceGroupManagerUpdatePolicyType type, InstanceGroupManagerUpdatePolicyAction? mostDisruptiveAllowedAction, TfArg<
int> ? maxSurgeFixed, TfArg<int> ? maxSurgePercent, InstanceGroupManagerUpdatePolicyReplacementMethod? replacementMethod}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxSurgeFixed
→ TfArg<
int> ? -
Extra VMs the MIG may add over
GoogleComputeInstanceGroupManager.targetSizeduring the rollout. Conflicts with maxSurgePercent.final -
maxSurgePercent
→ TfArg<
int> ? -
Percent equivalent of maxSurgeFixed.
final
-
VMs allowed to be unavailable simultaneously. Conflicts with
maxUnavailablePercent.
final
-
Percent equivalent of maxUnavailableFixed.
final
- minimalAction → InstanceGroupManagerUpdatePolicyAction
-
Required. Minimum action the MIG is allowed to apply to a VM.
final
- mostDisruptiveAllowedAction → InstanceGroupManagerUpdatePolicyAction?
-
Maximum action the MIG may escalate to.
final
- replacementMethod → InstanceGroupManagerUpdatePolicyReplacementMethod?
-
Whether to keep names (
RECREATE) or randomise them (SUBSTITUTE, default) when swapping VMs.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → InstanceGroupManagerUpdatePolicyType
-
Required.
OPPORTUNISTICwaits for resize/recreate-instances calls;PROACTIVEactively rolls.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited