ComputeInstanceIpv6AccessConfig class
One entry inside network_interface.ipv6_access_config. GCP currently
allows at most one IPv6 access config per interface.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceIpv6AccessConfig({required AccessConfigNetworkTier networkTier, TfArg<
String> ? publicPtrDomainName, TfArg<String> ? externalIpv6, TfArg<String> ? externalIpv6PrefixLength, TfArg<String> ? name}) -
const
Properties
-
externalIpv6
→ TfArg<
String> ? -
final
-
externalIpv6PrefixLength
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
- networkTier → AccessConfigNetworkTier
-
Service tier. Only
PREMIUMis valid for IPv6 today.final -
publicPtrDomainName
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited