ComputeInstanceIpv6AccessConfig class final

Typed helper for the network_interface.ipv6_access_config block of google_compute_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeInstanceIpv6AccessConfig({TfArg<String>? externalIpv6, TfArg<String>? externalIpv6PrefixLength, TfArg<String>? name, required AccessConfigNetworkTier networkTier, TfArg<String>? publicPtrDomainName})
const

Properties

externalIpv6 → TfArg<String>?
final
externalIpv6PrefixLength → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
networkTier → AccessConfigNetworkTier
final
publicPtrDomainName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited