ComputeInstanceServiceAccount class
service_account block (max_items=1). When set, the VM's metadata
exposes a Google service account credential to the guest.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceServiceAccount({TfArg<
String> ? email, required List<String> scopes}) -
const
Properties
-
email
→ TfArg<
String> ? -
Service account email. When null, GCP uses the project's default
Compute Engine service account.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
OAuth scopes granted (e.g.
'cloud-platform').final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited