ComputeInstanceTemplateInstanceTemplateDiskEncryptionKey class
disk.disk_encryption_key block (max_items=1). Customer-managed KMS
CryptoKey used to encrypt the disk at rest.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceTemplateInstanceTemplateDiskEncryptionKey({TfArg<
String> ? kmsKeySelfLink, TfArg<String> ? kmsKeyServiceAccount}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeySelfLink
→ TfArg<
String> ? -
Self-link of the KMS CryptoKey.
final
-
kmsKeyServiceAccount
→ TfArg<
String> ? -
Service account used for the KMS encryption request. If null, the
Compute Engine default service account is used.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited