ComputeInstanceTemplateInstanceTemplateNetworkInterface class
One entry inside network_interface. At least one is required by GCP.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceTemplateInstanceTemplateNetworkInterface({TfArg<
String> ? network, TfArg<String> ? subnetwork, TfArg<String> ? subnetworkProject, TfArg<String> ? networkIp, TfArg<String> ? networkAttachment, InstanceTemplateNicType? nicType, TfArg<num> ? queueCount, TfArg<String> ? stackType, TfArg<String> ? ipv6Address, TfArg<num> ? internalIpv6PrefixLength, TfArg<String> ? igmpQuery, TfArg<num> ? vlan, List<ComputeInstanceTemplateInstanceTemplateAccessConfig> ? accessConfig, List<ComputeInstanceTemplateInstanceTemplateIpv6AccessConfig> ? ipv6AccessConfig, List<ComputeInstanceTemplateInstanceTemplateAliasIpRange> ? aliasIpRange}) -
const
Properties
-
accessConfig
→ List<
ComputeInstanceTemplateInstanceTemplateAccessConfig> ? -
Up to one
access_configblock enables an external IPv4 address.final -
aliasIpRange
→ List<
ComputeInstanceTemplateInstanceTemplateAliasIpRange> ? -
Alias IP ranges (typically GKE pod / service ranges).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
igmpQuery
→ TfArg<
String> ? -
Whether IGMP query is enabled, plus the supported version.
final
-
internalIpv6PrefixLength
→ TfArg<
num> ? -
Prefix length of the primary internal IPv6 range.
final
-
ipv6AccessConfig
→ List<
ComputeInstanceTemplateInstanceTemplateIpv6AccessConfig> ? -
Up to one
ipv6_access_configblock enables an external IPv6 range.final -
ipv6Address
→ TfArg<
String> ? -
final
-
network
→ TfArg<
String> ? -
Network name or self-link. Mutually exclusive with subnetwork in
auto-mode networks.
final
-
networkAttachment
→ TfArg<
String> ? -
Network attachment URL
(
projects/{p}/regions/{r}/networkAttachments/{name}).final -
networkIp
→ TfArg<
String> ? -
Internal IP within the subnet. When null, GCP assigns one.
final
- nicType → InstanceTemplateNicType?
-
final
-
queueCount
→ TfArg<
num> ? -
vNIC queue count (Rx and Tx both use this value).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stackType
→ TfArg<
String> ? -
IP stack type (
'IPV4_ONLY','IPV4_IPV6','IPV6_ONLY').final -
subnetwork
→ TfArg<
String> ? -
Subnetwork name or self-link. Required for custom-mode networks.
final
-
subnetworkProject
→ TfArg<
String> ? -
Host project of the subnetwork (Shared VPC).
final
-
vlan
→ TfArg<
num> ? -
VLAN tag for a dynamic NIC (2-255).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited