ComputeInstanceTemplateInstanceTemplateNetworkPerformanceConfig class
network_performance_config block (max_items=1). Selects the Tier 1
network egress profile.
- Annotations
-
- @immutable
Constructors
- ComputeInstanceTemplateInstanceTemplateNetworkPerformanceConfig({required ComputeInstanceNetworkPerformanceConfigTotalEgressBandwidthTier totalEgressBandwidthTier})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalEgressBandwidthTier → ComputeInstanceNetworkPerformanceConfigTotalEgressBandwidthTier
-
Egress tier. ComputeInstanceNetworkPerformanceConfigTotalEgressBandwidthTier.tier1
enables higher per-VM egress bandwidth;
ComputeInstanceNetworkPerformanceConfigTotalEgressBandwidthTier.platformDefault
keeps the platform default.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited