ComputeInstanceTemplateInstanceTemplateNodeAffinity class
One entry inside scheduling.node_affinities. Sole-tenant placement
uses this to bind instances to a node group with matching labels.
- Annotations
-
- @immutable
Constructors
-
ComputeInstanceTemplateInstanceTemplateNodeAffinity({required TfArg<
String> key, required TfArg<String> operator, required List<String> values}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited