ComputeNetworkFirewallPolicyRuleMatch class final
Typed helper for the match block of
google_compute_network_firewall_policy_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeNetworkFirewallPolicyRuleMatch({TfArg<
List< ? destAddressGroups, TfArg<Object?> >List< ? destFqdns, TfArg<Object?> >List< ? destIpRanges, TfArg<Object?> >ComputeNetworkFirewallPolicyRuleMatchDestNetworkContext> ? destNetworkContext, TfArg<List< ? destRegionCodes, TfArg<Object?> >List< ? destThreatIntelligences, TfArg<Object?> >List< ? srcAddressGroups, TfArg<Object?> >List< ? srcFqdns, TfArg<Object?> >List< ? srcIpRanges, TfArg<Object?> >ComputeNetworkFirewallPolicyRuleMatchSrcNetworkContext> ? srcNetworkContext, TfArg<List< ? srcNetworks, TfArg<Object?> >List< ? srcRegionCodes, TfArg<Object?> >List< ? srcThreatIntelligences, required List<Object?> >ComputeNetworkFirewallPolicyRuleMatchLayer4Configs> layer4Configs, List<ComputeNetworkFirewallPolicyRuleMatchSrcSecureTags> ? srcSecureTags}) -
const
Properties
-
destAddressGroups
→ TfArg<
List< ?Object?> > -
final
-
destFqdns
→ TfArg<
List< ?Object?> > -
final
-
destIpRanges
→ TfArg<
List< ?Object?> > -
final
-
destNetworkContext
→ TfArg<
ComputeNetworkFirewallPolicyRuleMatchDestNetworkContext> ? -
final
-
destRegionCodes
→ TfArg<
List< ?Object?> > -
final
-
destThreatIntelligences
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layer4Configs
→ List<
ComputeNetworkFirewallPolicyRuleMatchLayer4Configs> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
srcAddressGroups
→ TfArg<
List< ?Object?> > -
final
-
srcFqdns
→ TfArg<
List< ?Object?> > -
final
-
srcIpRanges
→ TfArg<
List< ?Object?> > -
final
-
srcNetworkContext
→ TfArg<
ComputeNetworkFirewallPolicyRuleMatchSrcNetworkContext> ? -
final
-
srcNetworks
→ TfArg<
List< ?Object?> > -
final
-
srcRegionCodes
→ TfArg<
List< ?Object?> > -
final
-
srcSecureTags
→ List<
ComputeNetworkFirewallPolicyRuleMatchSrcSecureTags> ? -
final
-
srcThreatIntelligences
→ TfArg<
List< ?Object?> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited