ComputeRegionBackendServiceLeader class final
Typed helper for the ha_policy.leader block of
google_compute_region_backend_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceLeader({TfArg<
String> ? backendGroup, ComputeRegionBackendServiceNetworkEndpoint? networkEndpoint}) -
const
Properties
-
backendGroup
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkEndpoint → ComputeRegionBackendServiceNetworkEndpoint?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited