ComputeRegionBackendServiceLogConfig class final
Typed helper for the log_config block of
google_compute_region_backend_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceLogConfig({TfArg<
bool> ? enable, TfArg<List< ? optionalFields, RegionBackendServiceLogOptionalMode? optionalMode, TfArg<String> >num> ? sampleRate, List<ComputeRegionBackendServiceRequestHeaders> ? requestHeaders, List<ComputeRegionBackendServiceResponseHeaders> ? responseHeaders}) -
const
Properties
-
enable
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
optionalFields
→ TfArg<
List< ?String> > -
final
- optionalMode → RegionBackendServiceLogOptionalMode?
-
final
-
requestHeaders
→ List<
ComputeRegionBackendServiceRequestHeaders> ? -
final
-
responseHeaders
→ List<
ComputeRegionBackendServiceResponseHeaders> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampleRate
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited