ComputeRegionBackendServiceRegionBackendServiceCircuitBreakers class
circuit_breakers block — caps on simultaneous activity per backend
before the load balancer trips. Only honored for
INTERNAL_SELF_MANAGED / INTERNAL_MANAGED / EXTERNAL_MANAGED
schemes.
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxConnections
→ TfArg<
int> ? -
final
-
maxPendingRequests
→ TfArg<
int> ? -
final
-
maxRequests
→ TfArg<
int> ? -
final
-
maxRequestsPerConnection
→ TfArg<
int> ? -
final
-
maxRetries
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited