ComputeRegionBackendServiceRegionBackendServiceDuration class
google.protobuf.Duration-shaped value used by several sub-blocks
(consistent_hash.http_cookie.ttl,
strong_session_affinity_cookie.ttl,
outlier_detection.base_ejection_time,
outlier_detection.interval).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceRegionBackendServiceDuration({required TfArg<
int> seconds, TfArg<int> ? nanos}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nanos
→ TfArg<
int> ? -
Sub-second nanoseconds (
0-999_999_999).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seconds
→ TfArg<
int> -
Whole seconds. Required by the schema for every Duration block.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited