disableConnectionDrainOnFailover property
If true, connections to the old active pool are not drained on
failover. Can be set to true only when protocol is TCP.
Implementation
final TfArg<bool>? disableConnectionDrainOnFailover;
If true, connections to the old active pool are not drained on
failover. Can be set to true only when protocol is TCP.
final TfArg<bool>? disableConnectionDrainOnFailover;