ComputeRegionBackendServiceRegionBackendServiceHaPolicy class
ha_policy block — self-managed HA for External / Internal
Passthrough NLBs. Conflicts with sessionAffinity,
failoverPolicy, and healthChecks — when haPolicy is set, the
caller is responsible for tracking endpoint health and electing a
leader.
Backends under an HA policy must be zonal NEGs of type GCE_VM_IP.
- Annotations
-
- @immutable
Constructors
Properties
- fastIpMove → RegionBackendServiceFastIpMove?
-
Fast-IP-move mode. See RegionBackendServiceFastIpMove.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leader → ComputeRegionBackendServiceRegionBackendServiceHaPolicyLeader?
-
Selects the current leader endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited