ComputeRegionBackendServiceRegionBackendServiceHaPolicyLeader class
ha_policy.leader (max_items=1).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceRegionBackendServiceHaPolicyLeader({TfArg<
String> ? backendGroup, ComputeRegionBackendServiceRegionBackendServiceHaPolicyLeaderNetworkEndpoint? networkEndpoint}) -
const
Properties
-
backendGroup
→ TfArg<
String> ? -
Self-link of the zonal NEG that hosts the current leader endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkEndpoint → ComputeRegionBackendServiceRegionBackendServiceHaPolicyLeaderNetworkEndpoint?
-
Which endpoint inside backendGroup is the leader.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited