ComputeRegionBackendServiceRegionBackendServiceZonalAffinity class
network_pass_through_lb_traffic_policy.zonal_affinity
(max_items=1). New connections are load balanced across healthy
backend endpoints in the local zone first; behavior when the
in-zone healthy fraction drops below spilloverRatio is governed
by spillover.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionBackendServiceRegionBackendServiceZonalAffinity({RegionBackendServiceZonalAffinitySpillover? spillover, TfArg<
double> ? spilloverRatio}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spillover → RegionBackendServiceZonalAffinitySpillover?
-
Zonal-affinity mode.
final
-
spilloverRatio
→ TfArg<
double> ? -
Healthy-fraction threshold (
0.0-1.0) that triggers spillover.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited