ComputeRegionHealthCheckRegionHealthCheckHttpConfig class
http_health_check block. Set this (and only this) to make the
resource an HTTP health check.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionHealthCheckRegionHealthCheckHttpConfig({TfArg<
String> ? host, TfArg<String> ? requestPath, TfArg<String> ? response, TfArg<int> ? port, TfArg<String> ? portName, RegionHealthCheckProxyHeader? proxyHeader, RegionHealthCheckPortSpecification? portSpecification}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
host
→ TfArg<
String> ? -
Value of the
Hostheader on the probe request. Defaults to the public IP being probed when left empty.final -
port
→ TfArg<
int> ? -
TCP port. Defaults to 80.
final
-
portName
→ TfArg<
String> ? -
Named port (resolved via the InstanceGroup's named-port map).
final
- portSpecification → RegionHealthCheckPortSpecification?
-
How the probe port is resolved (
portvsportNamevs the serving port).final - proxyHeader → RegionHealthCheckProxyHeader?
-
Proxy header to prepend on the probe.
final
-
requestPath
→ TfArg<
String> ? -
Request path. Defaults to
/.final -
response
→ TfArg<
String> ? -
Bytes to match against the start of the response body. Empty
means "any response counts as healthy". ASCII only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited