ComputeRegionHealthCheckRegionHealthCheckTcpConfig class
tcp_health_check block. Pure TCP connect-or-payload probe.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionHealthCheckRegionHealthCheckTcpConfig({TfArg<
String> ? request, TfArg<String> ? response, TfArg<int> ? port, TfArg<String> ? portName, RegionHealthCheckProxyHeader? proxyHeader, RegionHealthCheckPortSpecification? portSpecification}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
port
→ TfArg<
int> ? -
TCP port. Defaults to 80 on the regional resource.
final
-
portName
→ TfArg<
String> ? -
final
- portSpecification → RegionHealthCheckPortSpecification?
-
final
- proxyHeader → RegionHealthCheckProxyHeader?
-
final
-
request
→ TfArg<
String> ? -
Bytes to send once the TCP connection is established. Empty means
"connect-only is enough to be healthy". ASCII only.
final
-
response
→ TfArg<
String> ? -
Bytes to match against the start of the response. Empty matches
any response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited