ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerUpdatePolicy class
update_policy block. Drives how the regional MIG rolls a new
ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerVersion across its members and how
aggressively it rebalances across distributionPolicyZones.
- Annotations
-
- @immutable
Constructors
-
ComputeRegionInstanceGroupManagerRegionInstanceGroupManagerUpdatePolicy({required RegionInstanceGroupManagerUpdatePolicyAction minimalAction, required RegionInstanceGroupManagerUpdatePolicyType type, RegionInstanceGroupManagerInstanceRedistributionType? instanceRedistributionType, RegionInstanceGroupManagerUpdatePolicyAction? mostDisruptiveAllowedAction, TfArg<
int> ? maxSurgeFixed, TfArg<int> ? maxSurgePercent, RegionInstanceGroupManagerUpdatePolicyReplacementMethod? replacementMethod}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceRedistributionType → RegionInstanceGroupManagerInstanceRedistributionType?
-
Regional-only. Whether the MIG proactively rebalances VMs
across
distributionPolicyZones. DefaultPROACTIVE.final -
maxSurgeFixed
→ TfArg<
int> ? -
Extra VMs the MIG may add over
GoogleComputeRegionInstanceGroupManager.targetSizeduring the rollout. Conflicts with maxSurgePercent.final -
maxSurgePercent
→ TfArg<
int> ? -
Percent equivalent of maxSurgeFixed.
final
-
VMs allowed to be unavailable simultaneously. Conflicts with
maxUnavailablePercent.
final
-
Percent equivalent of maxUnavailableFixed.
final
- minimalAction → RegionInstanceGroupManagerUpdatePolicyAction
-
Required. Minimum action the MIG is allowed to apply to a VM.
final
- mostDisruptiveAllowedAction → RegionInstanceGroupManagerUpdatePolicyAction?
-
Maximum action the MIG may escalate to.
final
- replacementMethod → RegionInstanceGroupManagerUpdatePolicyReplacementMethod?
-
Whether to keep names (
RECREATE) or randomise them (SUBSTITUTE, default) when swapping VMs.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → RegionInstanceGroupManagerUpdatePolicyType
-
Required.
OPPORTUNISTICwaits for resize/recreate-instances calls;PROACTIVEactively rolls.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited