ComputeRegionNetworkEndpointGroupCloudRun class
cloud_run slot of
google_compute_region_network_endpoint_group. Only valid when
networkEndpointType is RegionNetworkEndpointGroupType.serverless
and mutually exclusive with cloudFunction / appEngine.
Provide service to target a specific Cloud Run service by name, or
urlMask to route across multiple services via a URL template (the
schema's at_least_one_of rule requires at least one of the two). The
optional tag pins traffic to a named revision tag for fine-grained
canary routing.
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
service
→ TfArg<
String> ? -
Cloud Run service name (1-63 chars, RFC1035). Example:
'run-service'. At least one of service or urlMask must be set.final -
tag
→ TfArg<
String> ? -
Cloud Run revision tag for fine-grained traffic routing. 1-63 chars,
RFC1035. Example:
'revision-0010'.final -
urlMask
→ TfArg<
String> ? -
URL mask template for parsing
serviceandtagfrom the request URL. Allows one NEG + backend service to fan out to many Cloud Run services. At least one of service or urlMask must be set.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited