ComputeRegionNetworkEndpointGroupRegionNetworkEndpointGroupCloudFunction class
cloud_function slot of
google_compute_region_network_endpoint_group. Only valid when
networkEndpointType is RegionNetworkEndpointGroupType.serverless
and mutually exclusive with cloudRun / appEngine.
Provide function to target a specific Cloud Function by name, or
urlMask to route across multiple functions via a URL template (the
schema's at_least_one_of rule requires at least one of the two).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionNetworkEndpointGroupRegionNetworkEndpointGroupCloudFunction({TfArg<
String> ? function, TfArg<String> ? urlMask}) -
const
Properties
-
function
→ TfArg<
String> ? -
User-defined Cloud Function name. Case-sensitive, 1-63 chars.
Example:
'func1'. At least one of function or urlMask must be set.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
urlMask
→ TfArg<
String> ? -
URL mask template for parsing
functionfrom the request URL. Allows one NEG + backend service to fan out to many Cloud Functions. At least one of function or urlMask must be set.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited