ComputeRegionPerInstanceConfigDisk class final
Typed helper for the preserved_state.disk block of
google_compute_region_per_instance_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeRegionPerInstanceConfigDisk({ComputeRegionPerInstanceConfigDeleteRule? deleteRule, required TfArg<
String> deviceName, ComputeRegionPerInstanceConfigMode? mode, required TfArg<String> source}) -
const
Properties
- deleteRule → ComputeRegionPerInstanceConfigDeleteRule?
-
final
-
deviceName
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → ComputeRegionPerInstanceConfigMode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited