ComputeRegionSecurityPolicyUserDefinedField class
- Annotations
-
- @immutable
Constructors
-
ComputeRegionSecurityPolicyUserDefinedField({required RegionSecurityPolicyUserDefinedFieldBase base, TfArg<
String> ? mask, TfArg<String> ? name, TfArg<int> ? offset, TfArg<int> ? size}) -
const
Properties
- base → RegionSecurityPolicyUserDefinedFieldBase
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mask
→ TfArg<
String> ? -
final
-
name
→ TfArg<
String> ? -
final
-
offset
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ TfArg<
int> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited