ComputeReservationSpecificReservationInstanceProperties class final
Typed helper for the specific_reservation.instance_properties block of
google_compute_reservation (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeReservationSpecificReservationInstanceProperties({required TfArg<
String> machineType, TfArg<String> ? minCpuPlatform, List<ComputeReservationSpecificReservationInstancePropertiesGuestAccelerators> ? guestAccelerators, List<ComputeReservationSpecificReservationInstancePropertiesLocalSsds> ? localSsds}) -
const
Properties
-
guestAccelerators
→ List<
ComputeReservationSpecificReservationInstancePropertiesGuestAccelerators> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
localSsds
→ List<
ComputeReservationSpecificReservationInstancePropertiesLocalSsds> ? -
final
-
machineType
→ TfArg<
String> -
final
-
minCpuPlatform
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited