ComputeResourcePolicyOnSourceDiskDelete extension type
Behaviour when the source disk of a scheduled snapshot is deleted.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- applyRetentionPolicy → const ComputeResourcePolicyOnSourceDiskDelete
- Apply the retention policy to auto-created snapshots.
- keepAutoSnapshots → const ComputeResourcePolicyOnSourceDiskDelete
- Keep auto-created snapshots when the source disk is deleted.
-
values
→ const List<
ComputeResourcePolicyOnSourceDiskDelete>