ComputeResourcePolicyWeeklySchedule class final
Weekly snapshot schedule (one or more ComputeResourcePolicyDayOfWeek).
- Inheritance
-
- Object
- ComputeResourcePolicySnapshotSchedule
- ComputeResourcePolicyWeeklySchedule
- Annotations
-
- @immutable
Constructors
-
ComputeResourcePolicyWeeklySchedule(List<
ComputeResourcePolicyDayOfWeek> dayOfWeeks) -
const
Properties
-
dayOfWeeks
→ List<
ComputeResourcePolicyDayOfWeek> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited