ComputeRouteInstanceNextHop class final
Route via a Compute Engine VM instance (name or self-link).
- Inheritance
-
- Object
- ComputeRouteNextHop
- ComputeRouteInstanceNextHop
- Annotations
-
- @immutable
Constructors
-
ComputeRouteInstanceNextHop({required TfArg<
String> nextHopInstance}) -
const
Properties
- blockKey → String
-
Terraform attribute name (
next_hop_gateway,next_hop_ip, …).no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
-
nextHopInstance
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ TfArg<
String> -
Scalar value written under blockKey.
no setteroverride
Methods
-
encode(
) → Map< String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited