ComputeRouteNextHop class sealed
Next-hop target for GoogleComputeRoute. Sealed so the provider
exactly_one_of on the next_hop_* attributes is exhaustive at the
type level.
Properties
- blockKey → String
-
Terraform attribute name (
next_hop_gateway,next_hop_ip, …).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ TfArg<
String> -
Scalar value written under blockKey.
no setter
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited