ComputeRouterBgp class
bgp block — local BGP session parameters for a Cloud Router.
- Annotations
-
- @immutable
Constructors
-
ComputeRouterBgp({ComputeRouterBgpAdvertiseMode? advertiseMode, List<
String> ? advertisedGroups, TfArg<int> ? asn, TfArg<String> ? identifierRange, TfArg<int> ? keepaliveInterval}) -
const
Properties
-
advertisedGroups
→ List<
String> ? -
Prefix groups to advertise when advertiseMode is
ComputeRouterBgpAdvertiseMode.custom.
final
- advertiseMode → ComputeRouterBgpAdvertiseMode?
-
Advertisement mode. ComputeRouterBgpAdvertiseMode.custom requires
advertisedGroups.
final
-
asn
→ TfArg<
int> ? -
Local BGP ASN (RFC6996 private range).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifierRange
→ TfArg<
String> ? -
Link-local IPv4 range for valid BGP identifiers on this router.
final
-
keepaliveInterval
→ TfArg<
int> ? -
Seconds between BGP keepalive messages (hold time is 3× this value).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited