ComputeSecurityPolicySecurityPolicyRecaptchaOptionsConfig class
recaptcha_options_config -- policy-wide reCAPTCHA site key used
for redirect-to-reCAPTCHA actions. Only the redirect site key is
exposed by Terraform today; if unset, Cloud Armor uses a Google-
managed key.
- Annotations
-
- @immutable
Constructors
-
ComputeSecurityPolicySecurityPolicyRecaptchaOptionsConfig({required TfArg<
String> redirectSiteKey}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
redirectSiteKey
→ TfArg<
String> -
reCAPTCHA site key (callers are responsible for ensuring it is
valid and created from the reCAPTCHA API). Required by the schema.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited