ComputeSnapshotSource class sealed
Snapshot source for GoogleComputeSnapshot. Sealed so the provider
exactly_one_of on source_disk / source_instant_snapshot is
exhaustive at the type level.
- Implementers
Constructors
-
ComputeSnapshotSource.disk(TfArg<
String> sourceDisk) -
Create the snapshot from a Persistent Disk (name or self-link).
constfactory
-
ComputeSnapshotSource.instantSnapshot(TfArg<
String> sourceInstantSnapshot) -
Create the snapshot from a zonal Instant Snapshot (name or self-link).
constfactory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited