ComputeSubnetworkSubnetworkLogConfig class
log_config block. Enables VPC flow logs for the subnetwork. Flow
logging is not supported when the subnetwork purpose is
REGIONAL_MANAGED_PROXY or GLOBAL_MANAGED_PROXY.
- Annotations
-
- @immutable
Constructors
-
ComputeSubnetworkSubnetworkLogConfig({TfArg<
SubnetworkLogConfigAggregationInterval> ? aggregationInterval, TfArg<num> ? flowSampling, TfArg<SubnetworkLogConfigMetadata> ? metadata, TfArg<List< ? metadataFields, TfArg<String> >String> ? filterExpr}) -
const
Properties
-
aggregationInterval
→ TfArg<
SubnetworkLogConfigAggregationInterval> ? -
Toggles between dense and sparse aggregation. Defaults to
INTERVAL_5_SECon GCP.final -
filterExpr
→ TfArg<
String> ? -
CEL expression filtering which logs to export.
final
-
flowSampling
→ TfArg<
num> ? -
Fraction of packets to sample, between 0.0 and 1.0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ TfArg<
SubnetworkLogConfigMetadata> ? -
Metadata-inclusion mode. Use
customMetadatato scope via metadataFields.final -
metadataFields
→ TfArg<
List< ?String> > -
Metadata field names included when metadata is
customMetadata.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited