ComputeUrlMapCachePolicyCacheKeyPolicy class final
Typed helper for the path_matcher.default_route_action.cache_policy.cache_key_policy block of
google_compute_url_map (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapCachePolicyCacheKeyPolicy({TfArg<
List< ? excludedQueryParameters, TfArg<String> >bool> ? includeHost, TfArg<bool> ? includeProtocol, TfArg<bool> ? includeQueryString, TfArg<List< ? includedCookieNames, TfArg<String> >List< ? includedHeaderNames, TfArg<String> >List< ? includedQueryParameters})String> > -
const
Properties
-
excludedQueryParameters
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includedCookieNames
→ TfArg<
List< ?String> > -
final
-
includedHeaderNames
→ TfArg<
List< ?String> > -
final
-
includedQueryParameters
→ TfArg<
List< ?String> > -
final
-
includeHost
→ TfArg<
bool> ? -
final
-
includeProtocol
→ TfArg<
bool> ? -
final
-
includeQueryString
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited