ComputeUrlMapDefaultRouteActionCachePolicy class final
Typed helper for the path_matcher.default_route_action.cache_policy block of
google_compute_url_map (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapDefaultRouteActionCachePolicy({TfArg<
List< ? cacheBypassRequestHeaderNames, UrlMapCacheMode? cacheMode, TfArg<String> >bool> ? negativeCaching, TfArg<bool> ? requestCoalescing, ComputeUrlMapCachePolicyCacheKeyPolicy? cacheKeyPolicy, ComputeUrlMapClientTtl? clientTtl, ComputeUrlMapDefaultTtl? defaultTtl, ComputeUrlMapMaxTtl? maxTtl, List<ComputeUrlMapNegativeCachingPolicy> ? negativeCachingPolicy, ComputeUrlMapServeWhileStale? serveWhileStale}) -
const
Properties
-
cacheBypassRequestHeaderNames
→ TfArg<
List< ?String> > -
final
- cacheKeyPolicy → ComputeUrlMapCachePolicyCacheKeyPolicy?
-
final
- cacheMode → UrlMapCacheMode?
-
final
- clientTtl → ComputeUrlMapClientTtl?
-
final
- defaultTtl → ComputeUrlMapDefaultTtl?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTtl → ComputeUrlMapMaxTtl?
-
final
-
negativeCaching
→ TfArg<
bool> ? -
final
-
negativeCachingPolicy
→ List<
ComputeUrlMapNegativeCachingPolicy> ? -
final
-
requestCoalescing
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serveWhileStale → ComputeUrlMapServeWhileStale?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited