ComputeUrlMapDelay class final
Typed helper for the default_route_action.fault_injection_policy.delay block of
google_compute_url_map (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapDelay({TfArg<
num> ? percentage, ComputeUrlMapFixedDelay? fixedDelay}) -
const
Properties
- fixedDelay → ComputeUrlMapFixedDelay?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
percentage
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited