ComputeUrlMapPathMatcher class final
Typed helper for the path_matcher block of
google_compute_url_map (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapPathMatcher({RefTo<
GoogleComputeBackendService> ? defaultService, TfArg<String> ? description, required TfArg<String> name, ComputeUrlMapDefaultCustomErrorResponsePolicy? defaultCustomErrorResponsePolicy, ComputeUrlMapPathMatcherDefaultRouteAction? defaultRouteAction, ComputeUrlMapDefaultUrlRedirect? defaultUrlRedirect, ComputeUrlMapHeaderAction? headerAction, List<ComputeUrlMapPathRule> ? pathRule, List<ComputeUrlMapRouteRules> ? routeRules}) -
const
Properties
- defaultCustomErrorResponsePolicy → ComputeUrlMapDefaultCustomErrorResponsePolicy?
-
final
- defaultRouteAction → ComputeUrlMapPathMatcherDefaultRouteAction?
-
final
-
defaultService
→ RefTo<
GoogleComputeBackendService> ? -
final
- defaultUrlRedirect → ComputeUrlMapDefaultUrlRedirect?
-
final
-
description
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerAction → ComputeUrlMapHeaderAction?
-
final
-
name
→ TfArg<
String> -
final
-
pathRule
→ List<
ComputeUrlMapPathRule> ? -
final
-
routeRules
→ List<
ComputeUrlMapRouteRules> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited