ComputeUrlMapTest class final
Typed helper for the test block of
google_compute_url_map (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapTest({TfArg<
String> ? description, TfArg<String> ? expectedOutputUrl, TfArg<num> ? expectedRedirectResponseCode, required TfArg<String> host, required TfArg<String> path, RefTo<GoogleComputeBackendService> ? service, List<ComputeUrlMapHeaders> ? headers}) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
expectedOutputUrl
→ TfArg<
String> ? -
final
-
expectedRedirectResponseCode
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
ComputeUrlMapHeaders> ? -
final
-
host
→ TfArg<
String> -
final
-
path
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
service
→ RefTo<
GoogleComputeBackendService> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited