ComputeUrlMapUrlMapHeaderAction class
header_action block. Adds / removes headers on requests forwarded to
the backend and / or responses returned to the client. Used at the
top-level URL-map slot and inside ComputeUrlMapUrlMapRouteRule.headerAction.
Note: the nested requestHeadersToAdd / responseHeadersToAdd schema
requires every field (header_name, header_value, replace) at the
top-level header_action slot. The wrapper enforces that by making them
required on ComputeUrlMapUrlMapHeaderToAdd.
- Annotations
-
- @immutable
Constructors
-
ComputeUrlMapUrlMapHeaderAction({List<
ComputeUrlMapUrlMapHeaderToAdd> ? requestHeadersToAdd, TfArg<List< ? requestHeadersToRemove, List<String> >ComputeUrlMapUrlMapHeaderToAdd> ? responseHeadersToAdd, TfArg<List< ? responseHeadersToRemove})String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestHeadersToAdd
→ List<
ComputeUrlMapUrlMapHeaderToAdd> ? -
Headers to add to forwarded requests.
final
-
requestHeadersToRemove
→ TfArg<
List< ?String> > -
Header names (case-insensitive) to strip from forwarded requests.
final
-
responseHeadersToAdd
→ List<
ComputeUrlMapUrlMapHeaderToAdd> ? -
Headers to add to returned responses.
final
-
responseHeadersToRemove
→ TfArg<
List< ?String> > -
Header names (case-insensitive) to strip from returned responses.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited