ContainerAwsClusterControlPlane class final
Typed helper for the control_plane block of
google_container_aws_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerAwsClusterControlPlane({required TfArg<
String> iamInstanceProfile, TfArg<String> ? instanceType, TfArg<List< ? securityGroupIds, required TfArg<String> >List< subnetIds, TfArg<String> >Map< ? tags, required TfArg<String, String> >String> version, required ContainerAwsClusterAwsServicesAuthentication awsServicesAuthentication, required ContainerAwsClusterConfigEncryption configEncryption, required ContainerAwsClusterDatabaseEncryption databaseEncryption, ContainerAwsClusterMainVolume? mainVolume, ContainerAwsClusterProxyConfig? proxyConfig, ContainerAwsClusterRootVolume? rootVolume, ContainerAwsClusterSshConfig? sshConfig}) -
const
Properties
- awsServicesAuthentication → ContainerAwsClusterAwsServicesAuthentication
-
final
- configEncryption → ContainerAwsClusterConfigEncryption
-
final
- databaseEncryption → ContainerAwsClusterDatabaseEncryption
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
iamInstanceProfile
→ TfArg<
String> -
final
-
instanceType
→ TfArg<
String> ? -
final
- mainVolume → ContainerAwsClusterMainVolume?
-
final
- proxyConfig → ContainerAwsClusterProxyConfig?
-
final
- rootVolume → ContainerAwsClusterRootVolume?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
securityGroupIds
→ TfArg<
List< ?String> > -
final
- sshConfig → ContainerAwsClusterSshConfig?
-
final
-
subnetIds
→ TfArg<
List< String> > -
final
-
final
-
version
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited