ContainerAzureClusterControlPlaneReplicaPlacements class final
Typed helper for the control_plane.replica_placements block of
google_container_azure_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerAzureClusterControlPlaneReplicaPlacements({required TfArg<
String> azureAvailabilityZone, required TfArg<String> subnetId}) -
const
Properties
-
azureAvailabilityZone
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subnetId
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited