ContainerAzureNodePoolConfig class final
Typed helper for the config block of
google_container_azure_node_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerAzureNodePoolConfig({TfArg<
Map< ? labels, TfArg<String, String> >Map< ? tags, TfArg<String, String> >String> ? vmSize, ContainerAzureNodePoolProxyConfig? proxyConfig, ContainerAzureNodePoolRootVolume? rootVolume, required ContainerAzureNodePoolSshConfig sshConfig}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ TfArg<
Map< ?String, String> > -
final
- proxyConfig → ContainerAzureNodePoolProxyConfig?
-
final
- rootVolume → ContainerAzureNodePoolRootVolume?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sshConfig → ContainerAzureNodePoolSshConfig
-
final
-
final
-
vmSize
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited