ContainerAzureNodePoolProxyConfig class final
Typed helper for the config.proxy_config block of
google_container_azure_node_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerAzureNodePoolProxyConfig({required TfArg<
String> resourceGroupId, required TfArg<String> secretId}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceGroupId
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretId
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited