ContainerClusterAutoscaling class final
Typed helper for the cluster_autoscaling block of
google_container_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerClusterAutoscaling({TfArg<
List< ? autoProvisioningLocations, TfArg<String> >String> ? autoscalingProfile, TfArg<bool> ? defaultComputeClassEnabled, TfArg<bool> ? enabled, ContainerClusterAutoProvisioningDefaults? autoProvisioningDefaults, List<ContainerClusterResourceLimits> ? resourceLimits}) -
const
Properties
- autoProvisioningDefaults → ContainerClusterAutoProvisioningDefaults?
-
final
-
autoProvisioningLocations
→ TfArg<
List< ?String> > -
final
-
autoscalingProfile
→ TfArg<
String> ? -
final
-
defaultComputeClassEnabled
→ TfArg<
bool> ? -
final
-
enabled
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceLimits
→ List<
ContainerClusterResourceLimits> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited