ContainerClusterMonitoringConfig class final
Typed helper for the monitoring_config block of
google_container_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerClusterMonitoringConfig({TfArg<
List< ? enableComponents, ContainerClusterAdvancedDatapathObservabilityConfig? advancedDatapathObservabilityConfig, ContainerClusterManagedPrometheus? managedPrometheus})String> > -
const
Properties
- advancedDatapathObservabilityConfig → ContainerClusterAdvancedDatapathObservabilityConfig?
-
final
-
enableComponents
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedPrometheus → ContainerClusterManagedPrometheus?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited