ContainerClusterNodeConfigLinuxNodeConfig class final
Typed helper for the node_config.linux_node_config block of
google_container_cluster (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
ContainerClusterNodeConfigLinuxNodeConfig({TfArg<
String> ? cgroupMode, TfArg<Map< ? sysctls, TfArg<String, String> >String> ? transparentHugepageDefrag, TfArg<String> ? transparentHugepageEnabled, ContainerClusterAccurateTimeConfig? accurateTimeConfig, ContainerClusterCustomNodeInit? customNodeInit, ContainerClusterHugepagesConfig? hugepagesConfig, ContainerClusterNodeKernelModuleLoading? nodeKernelModuleLoading, ContainerClusterSwapConfig? swapConfig}) -
const
Properties
- accurateTimeConfig → ContainerClusterAccurateTimeConfig?
-
final
-
cgroupMode
→ TfArg<
String> ? -
final
- customNodeInit → ContainerClusterCustomNodeInit?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hugepagesConfig → ContainerClusterHugepagesConfig?
-
final
- nodeKernelModuleLoading → ContainerClusterNodeKernelModuleLoading?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swapConfig → ContainerClusterSwapConfig?
-
final
-
sysctls
→ TfArg<
Map< ?String, String> > -
final
-
transparentHugepageDefrag
→ TfArg<
String> ? -
final
-
transparentHugepageEnabled
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited