ContainerClusterRecurringMaintenanceWindow class final
Typed helper for the maintenance_policy.recurring_maintenance_window block of
google_container_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerClusterRecurringMaintenanceWindow({required TfArg<
String> recurrence, required TfArg<String> windowDuration, ContainerClusterDelayUntil? delayUntil, required ContainerClusterWindowStartTime windowStartTime}) -
const
Properties
- delayUntil → ContainerClusterDelayUntil?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
recurrence
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
windowDuration
→ TfArg<
String> -
final
- windowStartTime → ContainerClusterWindowStartTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited