ContainerNodePoolSwapConfig class final
Typed helper for the node_config.linux_node_config.swap_config block of
google_container_node_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ContainerNodePoolSwapConfig({TfArg<
bool> ? enabled, ContainerNodePoolBootDiskProfile? bootDiskProfile, ContainerNodePoolDedicatedLocalSsdProfile? dedicatedLocalSsdProfile, ContainerNodePoolEncryptionConfig? encryptionConfig, ContainerNodePoolEphemeralLocalSsdProfile? ephemeralLocalSsdProfile}) -
const
Properties
- bootDiskProfile → ContainerNodePoolBootDiskProfile?
-
final
- dedicatedLocalSsdProfile → ContainerNodePoolDedicatedLocalSsdProfile?
-
final
-
enabled
→ TfArg<
bool> ? -
final
- encryptionConfig → ContainerNodePoolEncryptionConfig?
-
final
- ephemeralLocalSsdProfile → ContainerNodePoolEphemeralLocalSsdProfile?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited