DataLossPreventionJobTriggerExclusionRule class final
Typed helper for the inspect_job.inspect_config.rule_set.rules.exclusion_rule block of
google_data_loss_prevention_job_trigger (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- DataLossPreventionJobTriggerExclusionRule({required DataLossPreventionJobTriggerMatchingType matchingType, DataLossPreventionJobTriggerDictionary? dictionary, DataLossPreventionJobTriggerExcludeByHotword? excludeByHotword, DataLossPreventionJobTriggerExcludeInfoTypes? excludeInfoTypes, DataLossPreventionJobTriggerRegex? regex})
-
const
Properties
- dictionary → DataLossPreventionJobTriggerDictionary?
-
final
- excludeByHotword → DataLossPreventionJobTriggerExcludeByHotword?
-
final
- excludeInfoTypes → DataLossPreventionJobTriggerExcludeInfoTypes?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchingType → DataLossPreventionJobTriggerMatchingType
-
final
- regex → DataLossPreventionJobTriggerRegex?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited