DatabaseMigrationServiceConnectionProfileAlloydbSettingsPrimaryInstanceSettings class final
Typed helper for the alloydb.settings.primary_instance_settings block of
google_database_migration_service_connection_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatabaseMigrationServiceConnectionProfileAlloydbSettingsPrimaryInstanceSettings({TfArg<
Map< ? databaseFlags, required TfArg<String, String> >String> id, TfArg<Map< ? labels, required DatabaseMigrationServiceConnectionProfileAlloydbSettingsPrimaryInstanceSettingsMachineConfig machineConfig})String, String> > -
const
Properties
-
databaseFlags
→ TfArg<
Map< ?String, String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> -
final
-
labels
→ TfArg<
Map< ?String, String> > -
final
- machineConfig → DatabaseMigrationServiceConnectionProfileAlloydbSettingsPrimaryInstanceSettingsMachineConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited