DatabaseMigrationServiceConnectionProfilePostgresql class final
Typed helper for the postgresql block of
google_database_migration_service_connection_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatabaseMigrationServiceConnectionProfilePostgresql({TfArg<
String> ? alloydbClusterId, TfArg<String> ? cloudSqlId, TfArg<String> ? database, TfArg<String> ? host, TfArg<String> ? password, TfArg<num> ? port, TfArg<String> ? username, DatabaseMigrationServiceConnectionProfilePostgresqlPrivateConnectivity? privateConnectivity, DatabaseMigrationServiceConnectionProfilePostgresqlSsl? ssl}) -
const
Properties
-
alloydbClusterId
→ TfArg<
String> ? -
final
-
cloudSqlId
→ TfArg<
String> ? -
final
-
database
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
host
→ TfArg<
String> ? -
final
-
password
→ TfArg<
String> ? -
final
-
port
→ TfArg<
num> ? -
final
- privateConnectivity → DatabaseMigrationServiceConnectionProfilePostgresqlPrivateConnectivity?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssl → DatabaseMigrationServiceConnectionProfilePostgresqlSsl?
-
final
-
username
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited