DataplexDatascanDataDiscoverySpec class final
data_discovery_spec — infer schema from Cloud Storage objects.
- Inheritance
-
- Object
- DataplexDatascanSpec
- DataplexDatascanDataDiscoverySpec
- Annotations
-
- @immutable
Constructors
Properties
-
bigqueryPublishingConfig
→ TfArg<
Map< ?String, Object?> > -
final
- blockKey → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storageConfig
→ TfArg<
Map< ?String, Object?> > -
final
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited