DataplexTaskContainerImage class final
Typed helper for the notebook.infrastructure_spec.container_image block of
google_dataplex_task (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
image
→ TfArg<
String> ? -
final
-
javaJars
→ TfArg<
List< ?String> > -
final
-
properties
→ TfArg<
Map< ?String, String> > -
final
-
pythonPackages
→ TfArg<
List< ?String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited