DataplexTaskNotebookWorkload class final
notebook — Vertex AI Workbench or Colab notebook execution.
- Inheritance
-
- Object
- DataplexTaskWorkload
- DataplexTaskNotebookWorkload
- Annotations
-
- @immutable
Constructors
Properties
-
archiveUris
→ TfArg<
List< ?String> > -
final
- blockKey → String
-
no setteroverride
-
fileUris
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
infrastructureSpec
→ TfArg<
Map< ?String, Object?> > -
final
-
notebook
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited