DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfig class final
Typed helper for the placement.managed_cluster.config.worker_config block of
google_dataproc_workflow_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfig({TfArg<
String> ? image, TfArg<String> ? machineType, TfArg<String> ? minCpuPlatform, TfArg<num> ? numInstances, TfArg<DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigPreemptibility> ? preemptibility, List<DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigAccelerators> ? accelerators, DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigDiskConfig? diskConfig}) -
const
Properties
-
accelerators
→ List<
DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigAccelerators> ? -
final
- diskConfig → DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigDiskConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
image
→ TfArg<
String> ? -
final
-
machineType
→ TfArg<
String> ? -
final
-
minCpuPlatform
→ TfArg<
String> ? -
final
-
numInstances
→ TfArg<
num> ? -
final
-
preemptibility
→ TfArg<
DataprocWorkflowTemplatePlacementManagedClusterConfigWorkerConfigPreemptibility> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited