DatastreamConnectionProfileMongodbProfile class final
Typed helper for the mongodb_profile block of
google_datastream_connection_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamConnectionProfileMongodbProfile({TfArg<
Map< ? additionalOptions, TfArg<String, String> >String> ? password, TfArg<String> ? replicaSet, TfArg<String> ? secretManagerStoredPassword, required TfArg<String> username, required List<DatastreamConnectionProfileMongodbProfileHostAddresses> hostAddresses, DatastreamConnectionProfileMongodbProfileSrvConnectionFormat? srvConnectionFormat, DatastreamConnectionProfileMongodbProfileSslConfig? sslConfig, DatastreamConnectionProfileMongodbProfileStandardConnectionFormat? standardConnectionFormat}) -
const
Properties
-
additionalOptions
→ TfArg<
Map< ?String, String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostAddresses
→ List<
DatastreamConnectionProfileMongodbProfileHostAddresses> -
final
-
password
→ TfArg<
String> ? -
final
-
replicaSet
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretManagerStoredPassword
→ TfArg<
String> ? -
final
- srvConnectionFormat → DatastreamConnectionProfileMongodbProfileSrvConnectionFormat?
-
final
- sslConfig → DatastreamConnectionProfileMongodbProfileSslConfig?
-
final
- standardConnectionFormat → DatastreamConnectionProfileMongodbProfileStandardConnectionFormat?
-
final
-
username
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited