DatastreamConnectionProfilePostgresqlProfile class final
Typed helper for the postgresql_profile block of
google_datastream_connection_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamConnectionProfilePostgresqlProfile({required TfArg<
String> database, required TfArg<String> hostname, Sensitive<String> ? password, TfArg<num> ? port, TfArg<String> ? secretManagerStoredPassword, required TfArg<String> username, DatastreamConnectionProfilePostgresqlProfileSslConfig? sslConfig}) -
const
Properties
-
database
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostname
→ TfArg<
String> -
final
-
password
→ Sensitive<
String> ? -
final
-
port
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretManagerStoredPassword
→ TfArg<
String> ? -
final
- sslConfig → DatastreamConnectionProfilePostgresqlProfileSslConfig?
-
final
-
username
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited