DatastreamStreamGcsDestinationConfig class final
Typed helper for the destination_config.gcs_destination_config block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamGcsDestinationConfig({TfArg<
String> ? fileRotationInterval, TfArg<num> ? fileRotationMb, TfArg<String> ? path, required DatastreamStreamFileFormat fileFormat}) -
const
Properties
- fileFormat → DatastreamStreamFileFormat
-
final
-
fileRotationInterval
→ TfArg<
String> ? -
final
-
fileRotationMb
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited