DatastreamStreamMysqlSourceConfig class final
Typed helper for the source_config.mysql_source_config block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamMysqlSourceConfig({TfArg<
num> ? maxConcurrentBackfillTasks, TfArg<num> ? maxConcurrentCdcTasks, DatastreamStreamCdcMethod? cdcMethod, DatastreamStreamMysqlSourceConfigExcludeObjects? excludeObjects, DatastreamStreamMysqlSourceConfigIncludeObjects? includeObjects}) -
const
Properties
- cdcMethod → DatastreamStreamCdcMethod?
-
final
- excludeObjects → DatastreamStreamMysqlSourceConfigExcludeObjects?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeObjects → DatastreamStreamMysqlSourceConfigIncludeObjects?
-
final
-
maxConcurrentBackfillTasks
→ TfArg<
num> ? -
final
-
maxConcurrentCdcTasks
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited