DatastreamStreamMysqlTables class final
Typed helper for the backfill_all.mysql_excluded_objects.mysql_databases.mysql_tables block of
google_datastream_stream (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamMysqlTables({required TfArg<
String> table, List<DatastreamStreamMysqlColumns> ? mysqlColumns}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mysqlColumns
→ List<
DatastreamStreamMysqlColumns> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited