DatastreamStreamRuleSets class final
Typed helper for the rule_sets block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamRuleSets({required List<
DatastreamStreamRuleSetsCustomizationRules> customizationRules, required DatastreamStreamRuleSetsObjectFilter objectFilter}) -
const
Properties
-
customizationRules
→ List<
DatastreamStreamRuleSetsCustomizationRules> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectFilter → DatastreamStreamRuleSetsObjectFilter
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited