DatastreamStreamRuleSetsObjectFilterSourceObjectIdentifierSalesforceIdentifier class final
Typed helper for the rule_sets.object_filter.source_object_identifier.salesforce_identifier block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamRuleSetsObjectFilterSourceObjectIdentifierSalesforceIdentifier({required TfArg<
String> objectName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
objectName
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited