DatastreamStreamSingleTargetDataset class final
Typed helper for the destination_config.bigquery_destination_config.single_target_dataset block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamSingleTargetDataset({required RefTo<
GoogleBigqueryDataset> datasetId}) -
const
Properties
-
datasetId
→ RefTo<
GoogleBigqueryDataset> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited