DatastreamStreamSourceConfigMysqlSourceConfigIncludeObjectsMysqlDatabasesMysqlTables class final
Typed helper for the source_config.mysql_source_config.include_objects.mysql_databases.mysql_tables block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamSourceConfigMysqlSourceConfigIncludeObjectsMysqlDatabasesMysqlTables({required TfArg<
String> table, List<DatastreamStreamSourceConfigMysqlSourceConfigIncludeObjectsMysqlDatabasesMysqlTablesMysqlColumns> ? mysqlColumns}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mysqlColumns
→ List<
DatastreamStreamSourceConfigMysqlSourceConfigIncludeObjectsMysqlDatabasesMysqlTablesMysqlColumns> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
table
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited