DatastreamStreamSourceConfigPostgresqlSourceConfig class final
Typed helper for the source_config.postgresql_source_config block of
google_datastream_stream (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DatastreamStreamSourceConfigPostgresqlSourceConfig({TfArg<
num> ? maxConcurrentBackfillTasks, required TfArg<String> publication, required TfArg<String> replicationSlot, DatastreamStreamSourceConfigPostgresqlSourceConfigExcludeObjects? excludeObjects, DatastreamStreamSourceConfigPostgresqlSourceConfigIncludeObjects? includeObjects}) -
const
Properties
- excludeObjects → DatastreamStreamSourceConfigPostgresqlSourceConfigExcludeObjects?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeObjects → DatastreamStreamSourceConfigPostgresqlSourceConfigIncludeObjects?
-
final
-
maxConcurrentBackfillTasks
→ TfArg<
num> ? -
final
-
publication
→ TfArg<
String> -
final
-
replicationSlot
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited