DatastreamStreamSqlServerExcludedObjectsTables class final

Typed helper for the backfill_all.sql_server_excluded_objects.schemas.tables block of google_datastream_stream (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

columns → List<DatastreamStreamSqlServerExcludedObjectsColumns>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited