DialogflowAgentApiVersion enum
Dialogflow API version surfaced for a GoogleDialogflowAgent.
Values
- v1 → const DialogflowAgentApiVersion
-
Legacy V1 API.
const DialogflowAgentApiVersion('API_VERSION_V1') - v2 → const DialogflowAgentApiVersion
-
V2 API (default).
const DialogflowAgentApiVersion('API_VERSION_V2') - v2Beta1 → const DialogflowAgentApiVersion
-
V2beta1 API.
const DialogflowAgentApiVersion('API_VERSION_V2_BETA_1')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DialogflowAgentApiVersion> - A constant List of the values in this enum, in order of their declaration.