DialogflowConversationProfileSttConfig class final
Typed helper for the stt_config block of
google_dialogflow_conversation_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowConversationProfileSttConfig({DialogflowConversationProfileAudioEncoding? audioEncoding, TfArg<
bool> ? enableWordInfo, TfArg<String> ? languageCode, TfArg<String> ? model, TfArg<num> ? sampleRateHertz, DialogflowConversationProfileSpeechModelVariant? speechModelVariant, TfArg<bool> ? useTimeoutBasedEndpointing}) -
const
Properties
- audioEncoding → DialogflowConversationProfileAudioEncoding?
-
final
-
enableWordInfo
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languageCode
→ TfArg<
String> ? -
final
-
model
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampleRateHertz
→ TfArg<
num> ? -
final
- speechModelVariant → DialogflowConversationProfileSpeechModelVariant?
-
final
-
useTimeoutBasedEndpointing
→ TfArg<
bool> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited