DialogflowCxTestCaseTestConfig class final

Typed helper for the test_config block of google_dialogflow_cx_test_case (derived from provider schema).

Annotations
  • @immutable

Constructors

DialogflowCxTestCaseTestConfig({TfArg<String>? flow, TfArg<String>? page, TfArg<List<Object?>>? trackingParameters})
const

Properties

flow → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
page → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingParameters → TfArg<List<Object?>>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited