DialogflowCxToolVersionToolDataStoreSpecDataStoreConnections class final
Typed helper for the tool.data_store_spec.data_store_connections block of
google_dialogflow_cx_tool_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DialogflowCxToolVersionToolDataStoreSpecDataStoreConnections({TfArg<
String> ? dataStore, TfArg<String> ? dataStoreType, TfArg<String> ? documentProcessingMode}) -
const
Properties
-
dataStore
→ TfArg<
String> ? -
final
-
dataStoreType
→ TfArg<
String> ? -
final
-
documentProcessingMode
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited