DialogflowCxWebhookGenericWebService class final
Typed helper for the generic_web_service block of
google_dialogflow_cx_webhook (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
DialogflowCxWebhookGenericWebService({TfArg<
List< ? allowedCaCerts, DialogflowCxWebhookHttpMethod? httpMethod, TfArg<String> >Map< ? parameterMapping, TfArg<String, String> >String> ? requestBody, TfArg<Map< ? requestHeaders, TfArg<String, String> >String> ? secretVersionForUsernamePassword, DialogflowCxWebhookServiceAgentAuth? serviceAgentAuth, required TfArg<String> uri, DialogflowCxWebhookType? webhookType, DialogflowCxWebhookOauthConfig? oauthConfig, List<DialogflowCxWebhookSecretVersionsForRequestHeaders> ? secretVersionsForRequestHeaders, DialogflowCxWebhookServiceAccountAuthConfig? serviceAccountAuthConfig}) -
const
Properties
-
allowedCaCerts
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → DialogflowCxWebhookHttpMethod?
-
final
- oauthConfig → DialogflowCxWebhookOauthConfig?
-
final
-
parameterMapping
→ TfArg<
Map< ?String, String> > -
final
-
requestBody
→ TfArg<
String> ? -
final
-
requestHeaders
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretVersionForUsernamePassword
→ TfArg<
String> ? -
final
-
secretVersionsForRequestHeaders
→ List<
DialogflowCxWebhookSecretVersionsForRequestHeaders> ? -
final
- serviceAccountAuthConfig → DialogflowCxWebhookServiceAccountAuthConfig?
-
final
- serviceAgentAuth → DialogflowCxWebhookServiceAgentAuth?
-
final
-
uri
→ TfArg<
String> -
final
- webhookType → DialogflowCxWebhookType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited