DiscoveryEngineSearchEngineKnowledgeGraphConfig class final
Typed helper for the knowledge_graph_config block of
google_discovery_engine_search_engine (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DiscoveryEngineSearchEngineKnowledgeGraphConfig({TfArg<
List< ? cloudKnowledgeGraphTypes, TfArg<String> >bool> ? enableCloudKnowledgeGraph, TfArg<bool> ? enablePrivateKnowledgeGraph, DiscoveryEngineSearchEngineFeatureConfig? featureConfig}) -
const
Properties
-
cloudKnowledgeGraphTypes
→ TfArg<
List< ?String> > -
final
-
enableCloudKnowledgeGraph
→ TfArg<
bool> ? -
final
-
enablePrivateKnowledgeGraph
→ TfArg<
bool> ? -
final
- featureConfig → DiscoveryEngineSearchEngineFeatureConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited