DnsRecordSetRoutingPolicyInternalLoadBalancer class
- Annotations
-
- @immutable
Constructors
-
DnsRecordSetRoutingPolicyInternalLoadBalancer({required TfArg<
String> ipAddress, DnsRecordSetRoutingPolicyIlbIpProtocol? ipProtocol, DnsRecordSetRoutingPolicyIlbType? loadBalancerType, TfArg<String> ? networkUrl, TfArg<String> ? port, TfArg<String> ? project, TfArg<String> ? region}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipAddress
→ TfArg<
String> -
final
- ipProtocol → DnsRecordSetRoutingPolicyIlbIpProtocol?
-
final
- loadBalancerType → DnsRecordSetRoutingPolicyIlbType?
-
final
-
networkUrl
→ TfArg<
String> ? -
final
-
port
→ TfArg<
String> ? -
final
-
project
→ TfArg<
String> ? -
final
-
region
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited