DnssecKeyAlgorithm enum
dnssec_config.default_key_specs.algorithm.
Values
- ecdsap256sha256 → const DnssecKeyAlgorithm
-
const DnssecKeyAlgorithm('ecdsap256sha256') - ecdsap384sha384 → const DnssecKeyAlgorithm
-
const DnssecKeyAlgorithm('ecdsap384sha384') - rsasha1 → const DnssecKeyAlgorithm
-
const DnssecKeyAlgorithm('rsasha1') - rsasha256 → const DnssecKeyAlgorithm
-
const DnssecKeyAlgorithm('rsasha256') - rsasha512 → const DnssecKeyAlgorithm
-
const DnssecKeyAlgorithm('rsasha512')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DnssecKeyAlgorithm> - A constant List of the values in this enum, in order of their declaration.