EventarcTriggerCloudRunService class
destination.cloud_run_service block.
- Annotations
-
- @immutable
Constructors
-
EventarcTriggerCloudRunService({required TfArg<
String> service, TfArg<String> ? region, TfArg<String> ? path}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ TfArg<
String> ? -
Optional URL path segment appended to the service URL when
dispatching events (e.g.
'/route','route/subroute'). Must conform to RFC2396 section 3.3.final -
region
→ TfArg<
String> ? -
Region the Cloud Run service is deployed in. Defaults to the
trigger's
locationwhen omitted.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
service
→ TfArg<
String> -
Cloud Run service name (NOT a self-link). Only services located in
the same project as the trigger can be addressed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited