EventarcTriggerNetworkConfig class
destination.network_config block. Configures how Eventarc resolves
and connects to the destination. ONLY valid when
EventarcTriggerDestination.httpEndpoint is set.
- Annotations
-
- @immutable
Constructors
-
EventarcTriggerNetworkConfig({required TfArg<
String> networkAttachment}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
networkAttachment
→ TfArg<
String> -
Name of the NetworkAttachment that allows access to the destination
VPC. Format:
projects/{PROJECT_ID}/regions/{REGION}/networkAttachments/{NAME}.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited