ExternalDataSourceFormat enum
Source format for external_data_configuration.source_format. The
googleSheets variant additionally requires
https://www.googleapis.com/auth/drive.readonly on the service
account performing the read.
Values
- csv → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('CSV') - newlineDelimitedJson → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('NEWLINE_DELIMITED_JSON') - avro → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('AVRO') - parquet → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('PARQUET') - orc → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('ORC') - datastoreBackup → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('DATASTORE_BACKUP') - bigtable → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('BIGTABLE') - googleSheets → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('GOOGLE_SHEETS') - iceberg → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('ICEBERG') - deltaLake → const ExternalDataSourceFormat
-
const ExternalDataSourceFormat('DELTA_LAKE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExternalDataSourceFormat> - A constant List of the values in this enum, in order of their declaration.