FirebaseAppHostingDomainRedirect class
serve.redirect sub-block. Returns an HTTP 3xx redirect for every
request hitting this domain.
- Annotations
-
- @immutable
Constructors
-
FirebaseAppHostingDomainRedirect({required TfArg<
String> uri, TfArg<String> ? status}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ TfArg<
String> ? -
HTTP 3xx status code (e.g.
'301','302','307'). Defaults to'302'server-side.final -
uri
→ TfArg<
String> -
Redirect target. URIs without a scheme are treated as HTTPS. The
original request path is appended to this prefix.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited