FirestoreIndexIndexFieldTextSpec class
search_config.text_spec block. Carries a list of
FirestoreIndexIndexFieldTextSpecEntry entries (one per index_spec the user wants
to configure -- e.g. one for substring matching, one for prefix
matching of the same field).
- Annotations
-
- @immutable
Constructors
-
FirestoreIndexIndexFieldTextSpec({required List<
FirestoreIndexIndexFieldTextSpecEntry> indexSpecs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indexSpecs
→ List<
FirestoreIndexIndexFieldTextSpecEntry> -
At least one per the schema's
min_items=1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited