GeminiCodeToolsSettingEnabledTool class final

Typed helper for the enabled_tool block of google_gemini_code_tools_setting (derived from provider schema).

Annotations
  • @immutable

Constructors

GeminiCodeToolsSettingEnabledTool({TfArg<String>? accountConnector, required TfArg<String> handle, required TfArg<String> tool, TfArg<String>? uriOverride, List<GeminiCodeToolsSettingConfig>? config})
const

Properties

accountConnector → TfArg<String>?
final
config → List<GeminiCodeToolsSettingConfig>?
final
handle → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tool → TfArg<String>
final
uriOverride → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited