GkeHubFeatureMembershipConfigmanagementConfigSyncDeploymentOverridesContainers class final
Typed helper for the configmanagement.config_sync.deployment_overrides.containers block of
google_gke_hub_feature_membership (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
containerName
→ TfArg<
String> ? -
final
-
cpuLimit
→ TfArg<
String> ? -
final
-
cpuRequest
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
memoryLimit
→ TfArg<
String> ? -
final
-
memoryRequest
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited