GkeHubFeaturePolicyControllerHubConfig class final
Typed helper for the fleet_default_member_config.policycontroller.policy_controller_hub_config block of
google_gke_hub_feature (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GkeHubFeaturePolicyControllerHubConfig({TfArg<
num> ? auditIntervalSeconds, TfArg<num> ? constraintViolationLimit, TfArg<List< ? exemptableNamespaces, required GkeHubFeatureInstallSpec installSpec, TfArg<String> >bool> ? logDeniesEnabled, TfArg<bool> ? mutationEnabled, TfArg<bool> ? referentialRulesEnabled, List<GkeHubFeatureDeploymentConfigs> ? deploymentConfigs, GkeHubFeatureMonitoring? monitoring, GkeHubFeaturePolicyContent? policyContent}) -
const
Properties
-
auditIntervalSeconds
→ TfArg<
num> ? -
final
-
constraintViolationLimit
→ TfArg<
num> ? -
final
-
deploymentConfigs
→ List<
GkeHubFeatureDeploymentConfigs> ? -
final
-
exemptableNamespaces
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installSpec → GkeHubFeatureInstallSpec
-
final
-
logDeniesEnabled
→ TfArg<
bool> ? -
final
- monitoring → GkeHubFeatureMonitoring?
-
final
-
mutationEnabled
→ TfArg<
bool> ? -
final
- policyContent → GkeHubFeaturePolicyContent?
-
final
-
referentialRulesEnabled
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited