GkeonpremBareMetalAdminClusterLoadBalancerBgpLbConfigLoadBalancerNodePoolConfigNodePoolConfigKubeletConfig class final
Typed helper for the load_balancer.bgp_lb_config.load_balancer_node_pool_config.node_pool_config.kubelet_config block of
google_gkeonprem_bare_metal_admin_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GkeonpremBareMetalAdminClusterLoadBalancerBgpLbConfigLoadBalancerNodePoolConfigNodePoolConfigKubeletConfig({TfArg<
num> ? registryBurst, TfArg<num> ? registryPullQps, TfArg<bool> ? serializeImagePullsDisabled}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
registryBurst
→ TfArg<
num> ? -
final
-
registryPullQps
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializeImagePullsDisabled
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited