GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigControlPlaneIpBlock class final
Typed helper for the network_config.control_plane_v2_config.control_plane_ip_block block of
google_gkeonprem_vmware_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigControlPlaneIpBlock({TfArg<
String> ? gateway, TfArg<String> ? netmask, List<GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigControlPlaneIpBlockIps> ? ips}) -
const
Properties
-
gateway
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ips
→ List<
GkeonpremVmwareClusterNetworkConfigControlPlaneV2ConfigControlPlaneIpBlockIps> ? -
final
-
netmask
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited