HypercomputeclusterClusterStorageResourcesConfigNewFilestore class final
Typed helper for the storage_resources.config.new_filestore block of
google_hypercomputecluster_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
HypercomputeclusterClusterStorageResourcesConfigNewFilestore({TfArg<
String> ? description, required TfArg<String> filestore, TfArg<HypercomputeclusterClusterStorageResourcesConfigNewFilestoreProtocol> ? protocol, required TfArg<HypercomputeclusterClusterStorageResourcesConfigNewFilestoreTier> tier, }) -
const
Properties
-
description
→ TfArg<
String> ? -
final
-
final
-
filestore
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
protocol
→ TfArg<
HypercomputeclusterClusterStorageResourcesConfigNewFilestoreProtocol> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tier
→ TfArg<
HypercomputeclusterClusterStorageResourcesConfigNewFilestoreTier> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited