IamProjectAccessPolicyRules class final
Typed helper for the details.rules block of
google_iam_project_access_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
IamProjectAccessPolicyRules({TfArg<
String> ? description, required IamProjectAccessPolicyEffect effect, TfArg<List< ? excludedPrincipals, required TfArg<String> >List< principals, List<String> >IamProjectAccessPolicyConditions> ? conditions, required IamProjectAccessPolicyOperation operation}) -
const
Properties
-
conditions
→ List<
IamProjectAccessPolicyConditions> ? -
final
-
description
→ TfArg<
String> ? -
final
- effect → IamProjectAccessPolicyEffect
-
final
-
excludedPrincipals
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → IamProjectAccessPolicyOperation
-
final
-
principals
→ TfArg<
List< String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited