IamWorkforcePoolProviderValue class final
Typed helper for the extended_attributes_oauth2_client.client_secret.value block of
google_iam_workforce_pool_provider (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
IamWorkforcePoolProviderValue({required IamWorkforcePoolProviderPlainText plainText, TfArg<
String> ? plainTextWoVersion}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- plainText → IamWorkforcePoolProviderPlainText
-
final
-
plainTextWoVersion
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited