IndexFieldArrayConfig class final
Array-contains dimension for a field. Firestore only supports
'CONTAINS' as the array config today, so no parameter is exposed.
- Inheritance
-
- Object
- IndexFieldSpec
- IndexFieldArrayConfig
- Annotations
-
- @immutable
Constructors
- IndexFieldArrayConfig()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
Returns the JSON fragment to merge into IndexField.encode.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited