InstanceGroupManagerStandbyPolicy class
standby_policy block — controls how the MIG resumes VMs from a
standby pool during scale-out.
- Annotations
-
- @immutable
Constructors
- InstanceGroupManagerStandbyPolicy({int? initialDelaySec, String? mode})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDelaySec → int?
-
Seconds to wait after creating a VM before allowing standby
transitions (0-3600, default 0).
final
- mode → String?
-
Standby mode. Defaults to
MANUAL.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited