InstanceParams class
params block (max_items=1). Carries request-side parameters that are
not persisted on the resource (currently only resource manager tags
applied at instance-create time).
- Annotations
-
- @immutable
Constructors
-
InstanceParams({Map<
String, String> ? resourceManagerTags}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceManagerTags
→ Map<
String, String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited