InstanceTemplateProvisioningModel enum
scheduling.provisioning_model -- VM provisioning model. STANDARD runs
at on-demand prices with no termination guarantees from GCP; SPOT runs
at preemptible prices and may be reclaimed at any time.
Values
- standard → const InstanceTemplateProvisioningModel
-
const InstanceTemplateProvisioningModel('STANDARD') - spot → const InstanceTemplateProvisioningModel
-
const InstanceTemplateProvisioningModel('SPOT')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InstanceTemplateProvisioningModel> - A constant List of the values in this enum, in order of their declaration.