InstanceTemplateShieldedInstanceConfig class
shielded_instance_config block (max_items=1). Enables Shielded VM
features (secure boot / vTPM / integrity monitoring).
- Annotations
-
- @immutable
Constructors
- InstanceTemplateShieldedInstanceConfig({bool? enableSecureBoot, bool? enableVtpm, bool? enableIntegrityMonitoring})
-
const
Properties
- enableIntegrityMonitoring → bool?
-
final
- enableSecureBoot → bool?
-
final
- enableVtpm → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited