InstanceTemplateSourceSnapshotEncryptionKey class
disk.source_snapshot_encryption_key block (max_items=1). Customer-
supplied key that decrypted the source snapshot.
- Annotations
-
- @immutable
Constructors
- InstanceTemplateSourceSnapshotEncryptionKey({String? kmsKeySelfLink, String? kmsKeyServiceAccount, String? rawKey, String? rsaEncryptedKey})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kmsKeySelfLink → String?
-
final
- kmsKeyServiceAccount → String?
-
final
- rawKey → String?
-
256-bit customer-supplied encryption key, encoded RFC 4648 base64.
Sensitive.
final
- rsaEncryptedKey → String?
-
RSA-wrapped 2048-bit customer-supplied encryption key, encoded RFC 4648
base64. Sensitive.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited