IntegrationsAuthConfigCredentialType enum
Integrations Auth Config Credential enum for credential_type.
Values
- usernameAndPassword → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('USERNAME_AND_PASSWORD') - oauth2AuthorizationCode → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('OAUTH2_AUTHORIZATION_CODE') - oauth2Implicit → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('OAUTH2_IMPLICIT') - oauth2ClientCredentials → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('OAUTH2_CLIENT_CREDENTIALS') - oauth2ResoruceOwnerCredentials → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('OAUTH2_RESORUCE_OWNER_CREDENTIALS') - jwt → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('JWT') - authToken → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('AUTH_TOKEN') - serviceAccount → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('SERVICE_ACCOUNT') - clientCertificateOnly → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('CLIENT_CERTIFICATE_ONLY') - oidcToken → const IntegrationsAuthConfigCredentialType
-
const IntegrationsAuthConfigCredentialType('OIDC_TOKEN')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IntegrationsAuthConfigCredentialType> - A constant List of the values in this enum, in order of their declaration.