IntegrationsAuthConfigOauth2AuthorizationCode class final
Typed helper for the decrypted_credential.oauth2_authorization_code block of
google_integrations_auth_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
authEndpoint
→ TfArg<
String> ? -
final
-
clientId
→ TfArg<
String> ? -
final
-
clientSecret
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scope
→ TfArg<
String> ? -
final
-
tokenEndpoint
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited