IntegrationsClientCloudKmsConfig class final
Typed helper for the cloud_kms_config block of
google_integrations_client (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> -
final
-
keyVersion
→ TfArg<
String> ? -
final
-
kmsLocation
→ TfArg<
String> -
final
-
kmsProjectId
→ TfArg<
String> ? -
final
-
kmsRing
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited