LookerInstancePeriodicExportConfig class final
Typed helper for the periodic_export_config block of
google_looker_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
LookerInstancePeriodicExportConfig({required TfArg<
String> gcsUri, required RefTo<GoogleKmsCryptoKey> kmsKey, required LookerInstanceStartTime startTime}) -
const
Properties
-
gcsUri
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKey
→ RefTo<
GoogleKmsCryptoKey> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → LookerInstanceStartTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited