MemorystoreInstancePersistenceConfigRdbConfig class final
Typed helper for the persistence_config.rdb_config block of
google_memorystore_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MemorystoreInstancePersistenceConfigRdbConfig({TfArg<
String> ? rdbSnapshotPeriod, TfArg<String> ? rdbSnapshotStartTime}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rdbSnapshotPeriod
→ TfArg<
String> ? -
final
-
rdbSnapshotStartTime
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited