MonitoringAlertPolicyConditionAbsent class
condition_absent block — fires when a time series stops receiving
data points for duration. Currently only multiples of a minute are
accepted by the API for duration.
Constructors
-
MonitoringAlertPolicyConditionAbsent({required TfArg<
String> duration, TfArg<String> ? filter, List<MonitoringAlertPolicyAggregation> ? aggregations, MonitoringAlertPolicyConditionTrigger? trigger}) -
const
Properties
-
aggregations
→ List<
MonitoringAlertPolicyAggregation> ? -
final
-
duration
→ TfArg<
String> -
final
-
filter
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trigger → MonitoringAlertPolicyConditionTrigger?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited