MonitoringAlertPolicyConditionPrometheusQueryLanguage class
condition_prometheus_query_language block — PromQL-driven condition.
duration is optional (default 0) but represents how long the PromQL
expression must evaluate to true before the alert fires.
Constructors
Properties
-
alertRule
→ TfArg<
String> ? -
final
-
disableMetricValidation
→ TfArg<
bool> ? -
final
-
duration
→ TfArg<
String> ? -
final
-
evaluationInterval
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ TfArg<
Map< ?String, String> > -
final
-
query
→ TfArg<
String> -
final
-
ruleGroup
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited