MonitoringAlertPolicySqlBooleanTest class
condition_sql.boolean_test — the SQL query returns a boolean column;
rows where column is true are treated as violations.
Constructors
-
MonitoringAlertPolicySqlBooleanTest({required TfArg<
String> column}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited