MonitoringServiceBasicService class
basic_service block (max=1) — a well-known service type defined by
its serviceType (e.g. 'APP_ENGINE', 'CLOUD_ENDPOINTS',
'CLUSTER_ISTIO', 'MESH_ISTIO') and a set of serviceLabels that
pin the variant to a specific service instance. See the
SLO monitoring docs
for the valid (serviceType, serviceLabels) combinations.
Constructors
-
MonitoringServiceBasicService({TfArg<
String> ? serviceType, TfArg<Map< ? serviceLabels})String, String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceLabels
→ TfArg<
Map< ?String, String> > -
Labels that pin the basic service to a specific monitored resource
(e.g.
{'module_id': 'default'}for App Engine).final -
serviceType
→ TfArg<
String> ? -
Well-known service type. Examples:
'APP_ENGINE','CLOUD_ENDPOINTS','CLUSTER_ISTIO','MESH_ISTIO'.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited