MonitoringUptimeCheckConfigServiceAgentAuthentication class
http_check.service_agent_authentication block (max=1) — emit an
OIDC token signed by the Monitoring service agent on the probe
request. Mutually exclusive with MonitoringUptimeCheckConfigHttpAuthInfo.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → MonitoringUptimeCheckServiceAgentAuthType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited