MonitoringUptimeCheckMatcher enum
Match mode for content_matchers[].matcher. Defaults to
containsString on the GCP API.
Schema enum_values: ["CONTAINS_STRING", "NOT_CONTAINS_STRING", "MATCHES_REGEX", "NOT_MATCHES_REGEX", "MATCHES_JSON_PATH", "NOT_MATCHES_JSON_PATH"].
Values
- containsString → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('CONTAINS_STRING') - notContainsString → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('NOT_CONTAINS_STRING') - matchesRegex → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('MATCHES_REGEX') - notMatchesRegex → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('NOT_MATCHES_REGEX') - matchesJsonPath → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('MATCHES_JSON_PATH') - notMatchesJsonPath → const MonitoringUptimeCheckMatcher
-
const MonitoringUptimeCheckMatcher('NOT_MATCHES_JSON_PATH')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MonitoringUptimeCheckMatcher> - A constant List of the values in this enum, in order of their declaration.