NetappVolumeCacheParameters class final

Typed helper for the cache_parameters block of google_netapp_volume (derived from provider schema).

Annotations
  • @immutable

Constructors

NetappVolumeCacheParameters({TfArg<bool>? enableGlobalFileLock, TfArg<String>? peerClusterName, TfArg<List<Object?>>? peerIpAddresses, TfArg<String>? peerSvmName, TfArg<String>? peerVolumeName, TfArg<String>? peeringCommandExpiryTime, NetappVolumeCacheParametersCacheConfig? cacheConfig})
const

Properties

cacheConfig NetappVolumeCacheParametersCacheConfig?
final
enableGlobalFileLock → TfArg<bool>?
final
hashCode int
The hash code for this object.
no setterinherited
peerClusterName → TfArg<String>?
final
peeringCommandExpiryTime → TfArg<String>?
final
peerIpAddresses → TfArg<List<Object?>>?
final
peerSvmName → TfArg<String>?
final
peerVolumeName → TfArg<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited