NetappVolumeExportPolicyRules class final
Typed helper for the export_policy.rules block of
google_netapp_volume (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetappVolumeExportPolicyRules({TfArg<
NetappVolumeExportPolicyRulesAccessType> ? accessType, TfArg<String> ? allowedClients, TfArg<num> ? anonUid, TfArg<String> ? hasRootAccess, TfArg<bool> ? kerberos5ReadOnly, TfArg<bool> ? kerberos5ReadWrite, TfArg<bool> ? kerberos5iReadOnly, TfArg<bool> ? kerberos5iReadWrite, TfArg<bool> ? kerberos5pReadOnly, TfArg<bool> ? kerberos5pReadWrite, TfArg<bool> ? nfsv3, TfArg<bool> ? nfsv4, TfArg<NetappVolumeExportPolicyRulesSquashMode> ? squashMode}) -
const
Properties
-
accessType
→ TfArg<
NetappVolumeExportPolicyRulesAccessType> ? -
final
-
allowedClients
→ TfArg<
String> ? -
final
-
anonUid
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hasRootAccess
→ TfArg<
String> ? -
final
-
kerberos5iReadOnly
→ TfArg<
bool> ? -
final
-
kerberos5iReadWrite
→ TfArg<
bool> ? -
final
-
kerberos5pReadOnly
→ TfArg<
bool> ? -
final
-
kerberos5pReadWrite
→ TfArg<
bool> ? -
final
-
kerberos5ReadOnly
→ TfArg<
bool> ? -
final
-
kerberos5ReadWrite
→ TfArg<
bool> ? -
final
-
nfsv3
→ TfArg<
bool> ? -
final
-
nfsv4
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
squashMode
→ TfArg<
NetappVolumeExportPolicyRulesSquashMode> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited