NetappVolumeReplicationDestinationVolumeParameters class final

Typed helper for the destination_volume_parameters block of google_netapp_volume_replication (derived from provider schema).

Annotations
  • @immutable

Constructors

NetappVolumeReplicationDestinationVolumeParameters({TfArg<String>? description, TfArg<String>? shareName, required TfArg<String> storagePool, TfArg<String>? volumeId, NetappVolumeReplicationDestinationVolumeParametersTieringPolicy? tieringPolicy})
const

Properties

description → TfArg<String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareName → TfArg<String>?
final
storagePool → TfArg<String>
final
tieringPolicy NetappVolumeReplicationDestinationVolumeParametersTieringPolicy?
final
volumeId → TfArg<String>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited