NetappVolumeSnapshotPolicy class final
Typed helper for the snapshot_policy block of
google_netapp_volume (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetappVolumeSnapshotPolicy({TfArg<
bool> ? enabled, NetappVolumeSnapshotPolicyDailySchedule? dailySchedule, NetappVolumeSnapshotPolicyHourlySchedule? hourlySchedule, NetappVolumeSnapshotPolicyMonthlySchedule? monthlySchedule, NetappVolumeSnapshotPolicyWeeklySchedule? weeklySchedule}) -
const
Properties
- dailySchedule → NetappVolumeSnapshotPolicyDailySchedule?
-
final
-
enabled
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hourlySchedule → NetappVolumeSnapshotPolicyHourlySchedule?
-
final
- monthlySchedule → NetappVolumeSnapshotPolicyMonthlySchedule?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weeklySchedule → NetappVolumeSnapshotPolicyWeeklySchedule?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited