NetworkInterface class
One entry inside network_interface. At least one is required by GCP.
- Annotations
-
- @immutable
Constructors
-
NetworkInterface({String? network, String? subnetwork, String? subnetworkProject, String? networkIp, String? name, NicType? nicType, List<
AccessConfig> ? accessConfig, List<Ipv6AccessConfig> ? ipv6AccessConfig, List<AliasIpRange> ? aliasIpRange}) -
const
Properties
-
accessConfig
→ List<
AccessConfig> ? -
Up to one
access_configblock enables an external IPv4 address.final -
aliasIpRange
→ List<
AliasIpRange> ? -
Alias IP ranges (typically GKE pod / service ranges).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipv6AccessConfig
→ List<
Ipv6AccessConfig> ? -
Up to one
ipv6_access_configblock enables an external IPv6 range.final - name → String?
-
Interface name as observed inside the guest (
nic0,nic1, ...).final - network → String?
-
Network name or self-link. Mutually exclusive with subnetwork in
auto-mode networks.
final
- networkIp → String?
-
Internal IP within the subnet. When null, GCP assigns one.
final
- nicType → NicType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subnetwork → String?
-
Subnetwork name or self-link. Required for custom-mode networks.
final
- subnetworkProject → String?
-
Host project of the subnetwork (Shared VPC).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited