NetworkServicesEdgeCacheOriginFlexShielding class final

Typed helper for the flex_shielding block of google_network_services_edge_cache_origin (derived from provider schema).

Annotations
  • @immutable

Properties

flexShieldingRegions → List<NetworkServicesEdgeCacheOriginFlexShieldingRegions>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited