NetworkServicesEdgeCacheServiceCorsPolicy class final
Typed helper for the routing.path_matcher.route_rule.route_action.cors_policy block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
allowCredentials
→ TfArg<
bool> ? -
final
-
allowHeaders
→ TfArg<
List< ?String> > -
final
-
allowMethods
→ TfArg<
List< ?String> > -
final
-
allowOrigins
→ TfArg<
List< ?String> > -
final
-
disabled
→ TfArg<
bool> ? -
final
-
exposeHeaders
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxAge
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited