NetworkServicesEdgeCacheServiceLogConfig class final
Typed helper for the log_config block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceLogConfig({TfArg<
bool> ? enable, TfArg<num> ? sampleRate}) -
const
Properties
-
enable
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampleRate
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited