NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures class final
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy.add_signatures block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignatures({required List<
TfArg< actions, TfArg<NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignaturesActions> >List< ? copiedParameters, TfArg<Object?> >String> ? keyset, TfArg<String> ? tokenQueryParameter, TfArg<String> ? tokenTtl}) -
const
Properties
-
actions
→ List<
TfArg< NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyAddSignaturesActions> > -
final
-
copiedParameters
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyset
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tokenQueryParameter
→ TfArg<
String> ? -
final
-
tokenTtl
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited