NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy class final
Typed helper for the routing.path_matcher.route_rule.route_action.cdn_policy.cache_key_policy block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCdnPolicyCacheKeyPolicy({TfArg<
bool> ? excludeHost, TfArg<bool> ? excludeQueryString, TfArg<List< ? excludedQueryParameters, TfArg<Object?> >bool> ? includeProtocol, TfArg<List< ? includedCookieNames, TfArg<Object?> >List< ? includedHeaderNames, TfArg<Object?> >List< ? includedQueryParameters})Object?> > -
const
Properties
-
excludedQueryParameters
→ TfArg<
List< ?Object?> > -
final
-
excludeHost
→ TfArg<
bool> ? -
final
-
excludeQueryString
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includedCookieNames
→ TfArg<
List< ?Object?> > -
final
-
includedHeaderNames
→ TfArg<
List< ?Object?> > -
final
-
includedQueryParameters
→ TfArg<
List< ?Object?> > -
final
-
includeProtocol
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited