NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCorsPolicy class final
Typed helper for the routing.path_matcher.route_rule.route_action.cors_policy block of
google_network_services_edge_cache_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesEdgeCacheServiceRoutingPathMatcherRouteRuleRouteActionCorsPolicy({TfArg<
bool> ? allowCredentials, TfArg<List< ? allowHeaders, TfArg<Object?> >List< ? allowMethods, TfArg<Object?> >List< ? allowOrigins, TfArg<Object?> >bool> ? disabled, TfArg<List< ? exposeHeaders, required TfArg<Object?> >String> maxAge}) -
const
Properties
-
allowCredentials
→ TfArg<
bool> ? -
final
-
allowHeaders
→ TfArg<
List< ?Object?> > -
final
-
allowMethods
→ TfArg<
List< ?Object?> > -
final
-
allowOrigins
→ TfArg<
List< ?Object?> > -
final
-
disabled
→ TfArg<
bool> ? -
final
-
exposeHeaders
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxAge
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited