NetworkServicesHttpRouteRedirect class final
Typed helper for the rules.action.redirect block of
google_network_services_http_route (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostRedirect
→ TfArg<
String> ? -
final
-
httpsRedirect
→ TfArg<
bool> ? -
final
-
pathRedirect
→ TfArg<
String> ? -
final
-
portRedirect
→ TfArg<
num> ? -
final
-
prefixRewrite
→ TfArg<
String> ? -
final
-
responseCode
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stripQuery
→ TfArg<
bool> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited