NetworkServicesTcpRouteRulesAction class final
Typed helper for the rules.action block of
google_network_services_tcp_route (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkServicesTcpRouteRulesAction({TfArg<
String> ? idleTimeout, TfArg<bool> ? originalDestination, List<NetworkServicesTcpRouteRulesActionDestinations> ? destinations}) -
const
Properties
-
destinations
→ List<
NetworkServicesTcpRouteRulesActionDestinations> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
idleTimeout
→ TfArg<
String> ? -
final
-
originalDestination
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited