NotebooksEnvironmentVmImage class final
vm_image — start notebooks from a Compute Engine image.
Provide imageName and/or imageFamily (newest in the family when only the family is set).
- Inheritance
-
- Object
- NotebooksEnvironmentImage
- NotebooksEnvironmentVmImage
- Annotations
-
- @immutable
Constructors
-
NotebooksEnvironmentVmImage({required TfArg<
String> project, TfArg<String> ? imageName, TfArg<String> ? imageFamily}) -
const
Properties
- blockKey → String
-
Terraform nested-block key (
container_imageorvm_image).no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
-
imageFamily
→ TfArg<
String> ? -
final
-
imageName
→ TfArg<
String> ? -
final
-
project
→ TfArg<
String> -
Image project, e.g.
deeplearning-platform-release.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → List< Map< String, Object?> > -
Single-element list matching
nesting_mode: list, max_items: 1.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited