OracleDatabaseGoldengateConnectionAssignmentProperties class final
Typed helper for the properties block of
google_oracle_database_goldengate_connection_assignment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OracleDatabaseGoldengateConnectionAssignmentProperties({required RefTo<
GoogleOracleDatabaseGoldengateConnection> goldengateConnection, required RefTo<GoogleOracleDatabaseGoldengateDeployment> goldengateDeployment}) -
const
Properties
-
goldengateConnection
→ RefTo<
GoogleOracleDatabaseGoldengateConnection> -
final
-
goldengateDeployment
→ RefTo<
GoogleOracleDatabaseGoldengateDeployment> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited