OracleDatabaseGoldengateConnectionOracleAiDataPlatformConnectionProperties class final
Typed helper for the properties.oracle_ai_data_platform_connection_properties block of
google_oracle_database_goldengate_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OracleDatabaseGoldengateConnectionOracleAiDataPlatformConnectionProperties({TfArg<
String> ? connectionUrl, TfArg<String> ? privateKeyFile, TfArg<String> ? privateKeyPassphraseSecret, TfArg<String> ? publicKeyFingerprint, TfArg<String> ? region, TfArg<String> ? technologyType, TfArg<String> ? tenancyId, TfArg<bool> ? useResourcePrincipal, TfArg<String> ? userId}) -
const
Properties
-
connectionUrl
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
privateKeyFile
→ TfArg<
String> ? -
final
-
privateKeyPassphraseSecret
→ TfArg<
String> ? -
final
-
publicKeyFingerprint
→ TfArg<
String> ? -
final
-
region
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
technologyType
→ TfArg<
String> ? -
final
-
tenancyId
→ TfArg<
String> ? -
final
-
useResourcePrincipal
→ TfArg<
bool> ? -
final
-
userId
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited