OrganizationPolicyListPolicy class final
Typed helper for the list_policy block of
google_organization_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OrganizationPolicyListPolicy({TfArg<
bool> ? inheritFromParent, TfArg<String> ? suggestedValue, OrganizationPolicyListPolicyAllow? allow, OrganizationPolicyListPolicyDeny? deny}) -
const
Properties
- allow → OrganizationPolicyListPolicyAllow?
-
final
- deny → OrganizationPolicyListPolicyDeny?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inheritFromParent
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
suggestedValue
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited