OsConfigOsPolicyAssignmentValidate class final
Typed helper for the os_policies.resource_groups.resources.exec.validate block of
google_os_config_os_policy_assignment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigOsPolicyAssignmentValidate({TfArg<
List< ? args, required OsConfigOsPolicyAssignmentInterpreter interpreter, TfArg<String> >String> ? outputFilePath, TfArg<String> ? script, OsConfigOsPolicyAssignmentFileFile? file}) -
const
Properties
-
args
→ TfArg<
List< ?String> > -
final
- file → OsConfigOsPolicyAssignmentFileFile?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpreter → OsConfigOsPolicyAssignmentInterpreter
-
final
-
outputFilePath
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
script
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited