OsConfigPatchDeploymentGcsObject class final
Typed helper for the patch_config.post_step.linux_exec_step_config.gcs_object block of
google_os_config_patch_deployment (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentGcsObject({required RefTo<
GoogleStorageBucket> bucket, required TfArg<String> generationNumber, required TfArg<String> object}) -
const
Properties
-
bucket
→ RefTo<
GoogleStorageBucket> -
final
-
generationNumber
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
object
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited