OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfig class final
Typed helper for the patch_config.pre_step.windows_exec_step_config block of
google_os_config_patch_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfig({TfArg<
List< ? allowedSuccessCodes, TfArg<Object?> >OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfigInterpreter> ? interpreter, TfArg<String> ? localPath, OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfigGcsObject? gcsObject}) -
const
Properties
-
allowedSuccessCodes
→ TfArg<
List< ?Object?> > -
final
- gcsObject → OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfigGcsObject?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interpreter
→ TfArg<
OsConfigPatchDeploymentPatchConfigPreStepWindowsExecStepConfigInterpreter> ? -
final
-
localPath
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited