OsConfigPatchDeploymentPatchConfigWindowsUpdate class final
Typed helper for the patch_config.windows_update block of
google_os_config_patch_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentPatchConfigWindowsUpdate({List<
TfArg< ? classifications, TfArg<OsConfigPatchDeploymentPatchConfigWindowsUpdateClassifications> >List< ? excludes, TfArg<Object?> >List< ? exclusivePatches})Object?> > -
const
Properties
-
classifications
→ List<
TfArg< ?OsConfigPatchDeploymentPatchConfigWindowsUpdateClassifications> > -
final
-
excludes
→ TfArg<
List< ?Object?> > -
final
-
exclusivePatches
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited