OsConfigPatchDeploymentWindowsExecStepConfig class final
Typed helper for the patch_config.post_step.windows_exec_step_config block of
google_os_config_patch_deployment (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
OsConfigPatchDeploymentWindowsExecStepConfig({TfArg<
List< ? allowedSuccessCodes, OsConfigPatchDeploymentInterpreter? interpreter, required OsConfigPatchDeploymentWindowsExecStepConfigScript script})num> > -
const
Properties
-
allowedSuccessCodes
→ TfArg<
List< ?num> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpreter → OsConfigPatchDeploymentInterpreter?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- script → OsConfigPatchDeploymentWindowsExecStepConfigScript
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited