OsConfigPatchDeploymentZypper class final
Typed helper for the patch_config.zypper block of
google_os_config_patch_deployment (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
categories
→ TfArg<
List< ?String> > -
final
-
excludes
→ TfArg<
List< ?String> > -
final
-
exclusivePatches
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
severities
→ TfArg<
List< ?String> > -
final
-
withOptional
→ TfArg<
bool> ? -
final
-
withUpdate
→ TfArg<
bool> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited