OsConfigV2PolicyOrchestratorForOrganizationFile class final
Typed helper for the orchestrated_resource.os_policy_assignment_v1_payload.os_policies.resource_groups.resources.file block of
google_os_config_v2_policy_orchestrator_for_organization (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigV2PolicyOrchestratorForOrganizationFile({TfArg<
String> ? content, required TfArg<String> path, TfArg<String> ? permissions, required TfArg<String> state, OsConfigV2PolicyOrchestratorForOrganizationFileFile? file}) -
const
Properties
-
content
→ TfArg<
String> ? -
final
- file → OsConfigV2PolicyOrchestratorForOrganizationFileFile?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ TfArg<
String> -
final
-
permissions
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited