OsConfigV2PolicyOrchestratorInstanceFilter class final
Typed helper for the orchestrated_resource.os_policy_assignment_v1_payload.instance_filter block of
google_os_config_v2_policy_orchestrator (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
OsConfigV2PolicyOrchestratorInstanceFilter({TfArg<
bool> ? all, List<OsConfigV2PolicyOrchestratorExclusionLabels> ? exclusionLabels, List<OsConfigV2PolicyOrchestratorInclusionLabels> ? inclusionLabels, List<OsConfigV2PolicyOrchestratorInventories> ? inventories}) -
const
Properties
-
all
→ TfArg<
bool> ? -
final
-
exclusionLabels
→ List<
OsConfigV2PolicyOrchestratorExclusionLabels> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inclusionLabels
→ List<
OsConfigV2PolicyOrchestratorInclusionLabels> ? -
final
-
inventories
→ List<
OsConfigV2PolicyOrchestratorInventories> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited