PointInTimeRecoveryEnablement enum
point_in_time_recovery_enablement -- when enabled, reads can
target timestamps within the past 7 days (1-minute granularity beyond
the most-recent hour). Default disabled.
Values
- enabled → const PointInTimeRecoveryEnablement
-
const PointInTimeRecoveryEnablement('POINT_IN_TIME_RECOVERY_ENABLED') - disabled → const PointInTimeRecoveryEnablement
-
const PointInTimeRecoveryEnablement('POINT_IN_TIME_RECOVERY_DISABLED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PointInTimeRecoveryEnablement> - A constant List of the values in this enum, in order of their declaration.