PrivatecaCaPoolRsa class final
Typed helper for the issuance_policy.allowed_key_types.rsa block of
google_privateca_ca_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
PrivatecaCaPoolRsa({TfArg<
String> ? maxModulusSize, TfArg<String> ? minModulusSize}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxModulusSize
→ TfArg<
String> ? -
final
-
minModulusSize
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited