ProjectIamAuditConfigAuditLogConfig class final
Typed helper for the audit_log_config block of
google_project_iam_audit_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ProjectIamAuditConfigAuditLogConfig({TfArg<
List< ? exemptedMembers, required TfArg<Object?> >String> logType}) -
const
Properties
-
exemptedMembers
→ TfArg<
List< ?Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logType
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited