PubsubSubscriptionCloudStorageConfig class
cloud_storage_config block.
- Annotations
-
- @immutable
Constructors
Properties
-
bucket
→ TfArg<
String> -
final
-
filenameDatetimeFormat
→ TfArg<
String> ? -
final
-
filenamePrefix
→ TfArg<
String> ? -
final
-
filenameSuffix
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxBytes
→ TfArg<
int> ? -
final
-
maxDuration
→ TfArg<
String> ? -
final
-
maxMessages
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccountEmail
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited