PubsubSubscriptionCloudStorageConfig class final
Typed helper for the cloud_storage_config block of
google_pubsub_subscription (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
PubsubSubscriptionCloudStorageConfig({required RefTo<
GoogleStorageBucket> bucket, TfArg<String> ? filenameDatetimeFormat, TfArg<String> ? filenamePrefix, TfArg<String> ? filenameSuffix, TfArg<num> ? maxBytes, TfArg<String> ? maxDuration, TfArg<num> ? maxMessages, RefTo<GoogleServiceAccount> ? serviceAccountEmail, PubsubSubscriptionAvroConfig? avroConfig, PubsubSubscriptionTextConfig? textConfig}) -
const
Properties
- avroConfig → PubsubSubscriptionAvroConfig?
-
final
-
bucket
→ RefTo<
GoogleStorageBucket> -
final
-
filenameDatetimeFormat
→ TfArg<
String> ? -
final
-
filenamePrefix
→ TfArg<
String> ? -
final
-
filenameSuffix
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxBytes
→ TfArg<
num> ? -
final
-
maxDuration
→ TfArg<
String> ? -
final
-
maxMessages
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccountEmail
→ RefTo<
GoogleServiceAccount> ? -
final
- textConfig → PubsubSubscriptionTextConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited