QueueOidcToken class
OIDC token for queue-level HTTP target.
- Annotations
-
- @immutable
Constructors
-
QueueOidcToken({required TfArg<
String> serviceAccountEmail, TfArg<String> ? audience}) -
const
Properties
-
audience
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceAccountEmail
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited