RangePartitioning class
range_partitioning block (max=1). field is the int64 column
being partitioned on; the inner RangePartitioningRange defines the
[start, end) window and bucket width.
- Annotations
-
- @immutable
Constructors
- RangePartitioning({required String field, required RangePartitioningRange range})
-
const
Properties
- field → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- range → RangePartitioningRange
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited