RealtimeUpdatesMode enum
realtime_updates_mode -- whether the WebSocket-based realtime
listener API is accessible. Only valid for enterprise edition.
Values
- enabled → const RealtimeUpdatesMode
-
const RealtimeUpdatesMode('REALTIME_UPDATES_MODE_ENABLED') - disabled → const RealtimeUpdatesMode
-
const RealtimeUpdatesMode('REALTIME_UPDATES_MODE_DISABLED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RealtimeUpdatesMode> - A constant List of the values in this enum, in order of their declaration.