RecaptchaEnterpriseKeyTestingOptions class final

Typed helper for the testing_options block of google_recaptcha_enterprise_key (derived from provider schema).

Annotations
  • @immutable

Constructors

RecaptchaEnterpriseKeyTestingOptions({TfArg<RecaptchaEnterpriseKeyTestingOptionsTestingChallenge>? testingChallenge, TfArg<num>? testingScore})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testingChallenge → TfArg<RecaptchaEnterpriseKeyTestingOptionsTestingChallenge>?
final
testingScore → TfArg<num>?
final

Methods

encode() Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited