RedisInstanceWeeklyMaintenanceWindow class
weekly_maintenance_window nested block — the weekly window
maintenance updates may start in. The provider requires startTime
(start_time carries min_items = 1).
Constructors
-
RedisInstanceWeeklyMaintenanceWindow({required TfArg<
RedisInstanceWeeklyMaintenanceDay> day, required RedisInstanceMaintenanceStartTime startTime}) -
const
Properties
-
day
→ TfArg<
RedisInstanceWeeklyMaintenanceDay> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → RedisInstanceMaintenanceStartTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited