RegionBackendServiceLoadBalancingScheme enum
load_balancing_scheme. A backend service of one scheme cannot be
repurposed for another — the value is effectively immutable.
Regional-vs-global: this wrapper is for the regional variant
(google_compute_region_backend_service). The full set of values
is accepted at apply time depending on the front-end load balancer
kind — most notably internal (Internal Passthrough NLB) and
internalManaged (Internal Application LB / Regional External
Application LB) are unique to the regional resource and will be
rejected by google_compute_backend_service.
Values
- external → const RegionBackendServiceLoadBalancingScheme
-
const RegionBackendServiceLoadBalancingScheme('EXTERNAL') - externalManaged → const RegionBackendServiceLoadBalancingScheme
-
const RegionBackendServiceLoadBalancingScheme('EXTERNAL_MANAGED') - internal → const RegionBackendServiceLoadBalancingScheme
-
const RegionBackendServiceLoadBalancingScheme('INTERNAL') - internalManaged → const RegionBackendServiceLoadBalancingScheme
-
const RegionBackendServiceLoadBalancingScheme('INTERNAL_MANAGED') - internalSelfManaged → const RegionBackendServiceLoadBalancingScheme
-
const RegionBackendServiceLoadBalancingScheme('INTERNAL_SELF_MANAGED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RegionBackendServiceLoadBalancingScheme> - A constant List of the values in this enum, in order of their declaration.