RegionBackendServiceProtocol enum
Wire protocol the regional backend service uses to talk to backends.
HTTP2 and H2C require an HTTP(S)-class load balancer; TCP,
SSL, and UDP are for Passthrough Network Load Balancing /
regional internal proxy routing. GRPC is required when the URL
map is bound to a regional target gRPC proxy.
Values
- http → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('HTTP') - https → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('HTTPS') - http2 → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('HTTP2') - tcp → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('TCP') - ssl → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('SSL') - udp → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('UDP') - grpc → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('GRPC') - unspecified → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('UNSPECIFIED') - h2c → const RegionBackendServiceProtocol
-
const RegionBackendServiceProtocol('H2C')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RegionBackendServiceProtocol> - A constant List of the values in this enum, in order of their declaration.