SchedulerRetryConfig class
retry_config block on a Scheduler job (distinct from Cloud Tasks).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxBackoffDuration
→ TfArg<
String> ? -
final
-
maxDoublings
→ TfArg<
int> ? -
final
-
maxRetryDuration
→ TfArg<
String> ? -
final
-
minBackoffDuration
→ TfArg<
String> ? -
final
-
retryCount
→ TfArg<
int> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited