Scheduling class
scheduling block (max_items=1). Controls preemptibility, host
maintenance, max run duration, and sole-tenant affinities.
- Annotations
-
- @immutable
Constructors
-
Scheduling({bool? preemptible, OnHostMaintenance? onHostMaintenance, bool? automaticRestart, ProvisioningModel? provisioningModel, InstanceTerminationAction? instanceTerminationAction, int? minNodeCpus, List<
NodeAffinity> ? nodeAffinities, SchedulingDuration? maxRunDuration, SchedulingDuration? localSsdRecoveryTimeout}) -
const
Properties
- automaticRestart → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceTerminationAction → InstanceTerminationAction?
-
final
- localSsdRecoveryTimeout → SchedulingDuration?
-
Local SSD data-recovery grace period for VMs with
--local-ssd.final - maxRunDuration → SchedulingDuration?
-
Hard cap on instance run time. After this elapses GCP applies the
instanceTerminationAction (stop or delete).
final
- minNodeCpus → int?
-
final
-
nodeAffinities
→ List<
NodeAffinity> ? -
final
- onHostMaintenance → OnHostMaintenance?
-
final
- preemptible → bool?
-
final
- provisioningModel → ProvisioningModel?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited