SecurityPolicyLogLevel enum
advanced_options_config.log_level -- verbosity of Cloud Armor's
Cloud Logging output. verbose includes preconfigured-WAF rule
match details and is the recommended setting during policy tuning;
switch back to normal for steady-state to control log volume.
Values
- normal → const SecurityPolicyLogLevel
-
const SecurityPolicyLogLevel('NORMAL') - verbose → const SecurityPolicyLogLevel
-
const SecurityPolicyLogLevel('VERBOSE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecurityPolicyLogLevel> - A constant List of the values in this enum, in order of their declaration.