SecurityPolicyType enum
type -- intended use of the security policy. Forces replacement
when changed. The default (when unset on create) is
SecurityPolicyType.cloudArmor.
Values
- cloudArmor → const SecurityPolicyType
-
Backend-service policies. Filter incoming HTTP requests targeting backend services BEFORE they hit the origin servers. The default.
const SecurityPolicyType('CLOUD_ARMOR') - cloudArmorEdge → const SecurityPolicyType
-
Edge policies. Filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) and backend buckets (Cloud Storage) at Google's cache layer, BEFORE the request is served from cache. Use for cache-poisoning / cache-bypass protection.
const SecurityPolicyType('CLOUD_ARMOR_EDGE') - cloudArmorNetwork → const SecurityPolicyType
-
Network Load Balancing policies. Filter L3/L4 packets at the network edge for external Network Load Balancers.
const SecurityPolicyType('CLOUD_ARMOR_NETWORK')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecurityPolicyType> - A constant List of the values in this enum, in order of their declaration.