SecurityposturePostureOrgPolicyConstraintCustom class final
Typed helper for the policy_sets.policies.constraint.org_policy_constraint_custom block of
google_securityposture_posture (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SecurityposturePostureOrgPolicyConstraintCustom({SecurityposturePostureCustomConstraint? customConstraint, required List<
SecurityposturePosturePolicyRules> policyRules}) -
const
Properties
- customConstraint → SecurityposturePostureCustomConstraint?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
policyRules
→ List<
SecurityposturePosturePolicyRules> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited