SiteVerificationWebResourceSite class final
Typed helper for the site block of
google_site_verification_web_resource (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SiteVerificationWebResourceSite({required TfArg<
String> identifier, required TfArg<SiteVerificationWebResourceSiteType> type}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifier
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ TfArg<
SiteVerificationWebResourceSiteType> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited