SqlDatabaseInstanceBackupRetentionSettings class

backup_configuration.backup_retention_settings.

Annotations
  • @immutable

Constructors

SqlDatabaseInstanceBackupRetentionSettings({required TfArg<int> retainedBackups, TfArg<String>? retentionUnit})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
retainedBackups → TfArg<int>
How many backups to keep.
final
retentionUnit → TfArg<String>?
Currently 'COUNT' is the only value the API accepts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArgMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited