StorageBatchOperationsJobPutMetadata class final
Typed helper for the put_metadata block of
google_storage_batch_operations_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
cacheControl
→ TfArg<
String> ? -
final
-
contentDisposition
→ TfArg<
String> ? -
final
-
contentEncoding
→ TfArg<
String> ? -
final
-
contentLanguage
→ TfArg<
String> ? -
final
-
contentType
→ TfArg<
String> ? -
final
-
customMetadata
→ TfArg<
Map< ?String, String> > -
final
-
customTime
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited