StorageBucketObjectBucketObjectRetention class
Object-level retention policy (retention block).
Conflicts with eventBasedHold at the provider level — the schema
rejects both being set.
- Annotations
-
- @immutable
Constructors
-
StorageBucketObjectBucketObjectRetention({required TfArg<
String> mode, required TfArg<String> retainUntilTime}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mode
→ TfArg<
String> -
Retention mode. Supported values:
'Unlocked','Locked'.final -
retainUntilTime
→ TfArg<
String> -
RFC 3339 timestamp until which the object is retained.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited