StorageBucketObjectCustomerEncryption class
Customer-supplied encryption (CSEK) for customer_encryption.
encryptionKey must be a base64-encoded 32-byte AES-256 key. The
provider's ValidateFunc rejects non-base64 input.
- Annotations
-
- @immutable
Constructors
-
StorageBucketObjectCustomerEncryption({required TfArg<
String> encryptionKey, TfArg<String> ? encryptionAlgorithm}) -
const
Properties
-
encryptionAlgorithm
→ TfArg<
String> ? -
Encryption algorithm. Defaults to
AES256server-side; usually omitted.final -
encryptionKey
→ TfArg<
String> -
Base64-encoded customer-supplied AES-256 key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited