StorageInsightsReportConfigCsvFormat class final
csv_options — CSV inventory reports.
- Inheritance
-
- Object
- StorageInsightsReportConfigFormat
- StorageInsightsReportConfigCsvFormat
- Annotations
-
- @immutable
Constructors
-
StorageInsightsReportConfigCsvFormat({TfArg<
String> ? delimiter, TfArg<bool> ? headerRequired, TfArg<String> ? recordSeparator}) -
const
Properties
- blockKey → String
-
no setteroverride
-
delimiter
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerRequired
→ TfArg<
bool> ? -
final
-
recordSeparator
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → List< Map< String, Object?> > -
Single-element list (
nesting_mode: list, max_items: 1). Parquet is an empty object (allow_empty_object).override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited