StorageTransferJobObjectConditions class final
Typed helper for the replication_spec.object_conditions block of
google_storage_transfer_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
Properties
-
excludePrefixes
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includePrefixes
→ TfArg<
List< ?String> > -
final
-
lastModifiedBefore
→ TfArg<
String> ? -
final
-
lastModifiedSince
→ TfArg<
String> ? -
final
-
maxTimeElapsedSinceLastModification
→ TfArg<
String> ? -
final
-
minTimeElapsedSinceLastModification
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited