StorageTransferJobReplicationSpec class final
Typed helper for the replication_spec block of
google_storage_transfer_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- StorageTransferJobReplicationSpec({StorageTransferJobGcsDataSink? gcsDataSink, StorageTransferJobGcsDataSource? gcsDataSource, StorageTransferJobObjectConditions? objectConditions, StorageTransferJobTransferOptions? transferOptions})
-
const
Properties
- gcsDataSink → StorageTransferJobGcsDataSink?
-
final
- gcsDataSource → StorageTransferJobGcsDataSource?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectConditions → StorageTransferJobObjectConditions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transferOptions → StorageTransferJobTransferOptions?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited