StorageTransferJobTransferOptions class final
Typed helper for the replication_spec.transfer_options block of
google_storage_transfer_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
StorageTransferJobTransferOptions({TfArg<
bool> ? deleteObjectsFromSourceAfterTransfer, TfArg<bool> ? deleteObjectsUniqueInSink, TfArg<bool> ? overwriteObjectsAlreadyExistingInSink, TfArg<String> ? overwriteWhen, StorageTransferJobMetadataOptions? metadataOptions}) -
const
Properties
-
deleteObjectsFromSourceAfterTransfer
→ TfArg<
bool> ? -
final
-
deleteObjectsUniqueInSink
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadataOptions → StorageTransferJobMetadataOptions?
-
final
-
overwriteObjectsAlreadyExistingInSink
→ TfArg<
bool> ? -
final
-
overwriteWhen
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited