Traffic class
One traffic entry. Splits traffic across revisions. Default (when
the list is omitted) is 100% to the latest Ready revision.
- Annotations
-
- @immutable
Constructors
-
Traffic({TfArg<
TrafficTargetAllocationType> ? type, TfArg<String> ? revision, TfArg<int> ? percent, TfArg<String> ? tag}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
percent
→ TfArg<
int> ? -
Percent of traffic (0–100). Sum across the list should be 100.
final
-
revision
→ TfArg<
String> ? -
Target revision name. Required when type is
revision.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tag
→ TfArg<
String> ? -
Optional tag — exposes the revision under
https://<tag>---<service>-<hash>.<region>.run.app.final -
type
→ TfArg<
TrafficTargetAllocationType> ? -
latestorrevision. Whenrevision, revision is required.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toArgMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited