VectorSearchDataObjectVectors class final
Typed helper for the vectors block of
google_vector_search_data_object (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VectorSearchDataObjectVectors({required TfArg<
String> fieldName, VectorSearchDataObjectDense? dense, VectorSearchDataObjectSparse? sparse}) -
const
Properties
- dense → VectorSearchDataObjectDense?
-
final
-
fieldName
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sparse → VectorSearchDataObjectSparse?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited