VertexAiReasoningEngineDeveloperConnectSource class final
Typed helper for the spec.source_code_spec.developer_connect_source block of
google_vertex_ai_reasoning_engine (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- VertexAiReasoningEngineDeveloperConnectSource({required VertexAiReasoningEngineConfig config})
-
const
Properties
- config → VertexAiReasoningEngineConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited